//
// TextMMSClient.java,v 1.10 2003/04/05 01:40:02 dsg Exp
//
// Copyright 2001 The Regents of the University of California
// All Rights Reserved
//
// OpenMMS was developed by Dr. Douglas S. Greer at the San Diego
// Supercomputer Center, a research unit of the University of California,
// San Diego.  Support for this effort was provided by NSF through the
// Protein Data Bank (Grant DBI-9814284) and the National Partnership for
// Advanced Computational Infrastructure (Grant ACI-9619020)
//
// Permission to use, copy, modify and distribute any part of OpenMMS for
// educational, research and non-profit purposes, without fee, and
// without a written agreement is hereby granted, provided that the above
// copyright notice, this paragraph and the following paragraphs appear
// in all copies.
//
// Those desiring to incorporate this OpenMMS into commercial products or
// use for commercial purposes should contact the Technology Transfer
// Office, University of California, San Diego, 9500 Gilman Drive, La
// Jolla, CA 92093-0910, Ph: (619) 534-5815, FAX: (619) 534-7345.
//
// In no event shall the University of California be liable to any party
// for direct, indirect, special, incidental, or consequential damages,
// including lost profits, arising out of the use of this OpenMMS, even
// if the University of California has been advised of the possibility of
// such damage.
//
// The OpenMMS provided herein is on an "as is" basis, and the
// University of California has no obligation to provide maintenance,
// support, updates, enhancements, or modifications.  The University of
// California makes no representations and extends no warranties of any
// kind, either implied or express, including, but not limited to, the
// implied warranties of merchantability or fitness for a particular
// purpose, or that the use of the OpenMMS will not infringe any patent,
// trademark or other rights.

package org.rcsb.openmms.apps.text;

import java.io.*;
import java.awt.*;
import java.util.Date;
import javax.swing.*;

import org.omg.CORBA.*;
import org.omg.CosPropertyService.*;

import org.omg.DsLSRMacromolecularStructure.*;
import org.omg.DsLSRXRayCrystallography.*;
import org.omg.DsLSRMmsReference.*;
import org.omg.DsLSRMmsDeposition.*;

/**
 * Top-level main program that prints the text representations of values
 *  obtained from an MMS Corba server
 *
 * @author Douglas S. Greer
 * @version 1.10
 */
public class TextMMSClient
{
  // basic status messages
  public static int debug = 3;
  protected boolean printTimes = false;

  String frameName;
  MMSConnection msc;
  String nameServURL;
  String serviceName;
  TxFrame txf;

  String testEntry;
  MmsReferenceEntry refE;
  XRayCrystallographyEntry xrayE;

  Date stime, etime;

  public static void main(String args[])
    {
      TextMMSClient tc = new TextMMSClient("Text MMS Client");
      tc.init(args);
      tc.execute(args);
    }

  public TextMMSClient(String name)
    {
      frameName = name;
    }

  public void init(String[] args)
    {
      String debugStr = parseArguments("debug", args);
      if(debugStr != null)
	{
	  // debug <= 0 only fatal errors
	  // debug >= 1 recoverable error messages
	  // debug >= 3 basic status messages
	  // debug >= 5 trace
	  // debug >= 7 dump various data structures
	  debug = Integer.parseInt(debugStr);
	}
      printTimes = parseArgumentsBool("time", args);
      nameServURL = parseArguments("nameserv", args);
      if (nameServURL == null)
	{
	  nameServURL = "iiopname://corba.sdsc.edu:5001";
	}
      serviceName = parseArguments("servicename", args);
      if (serviceName == null)
	{
	  serviceName = "OpenMMS_Server";
	}
    }

  public void execute(String[] args)
    {
      String ior;

      txf = new TxFrame(frameName);
      txf.setDebug(debug);
      txf.pack();
      txf.show();

      try
	{
	  msc = new MMSConnection();
	  // ior = getIOR(args);
	  txf.logMessage("Attempting to reach a server named: "
			 + serviceName);
	  txf.logMessage("    using name server located at: " + nameServURL);
	  msc.connect(nameServURL, serviceName);
	  String vers = msc.getEntryFactory().get_version();
	  txf.logMessage("Successfully Connected to MMS Server Version: "
			 + vers);
	  startTime("get_entry_id_list()");
	  String entryIds[] = msc.getEntryFactory().get_entry_id_list();
	  endTime("get_entry_id_list()");
	  if (debug > 0)
	    {
	      txf.logMessage("First 3 of " + entryIds.length + " EntryIds:");
	      int len = Math.min(entryIds.length, 3);
	      for (int i = 0; i < len; i++)
		{
		  txf.logMessage("  Entry " + i + " = " + entryIds[i]);
		}
	    }

	  startTime("get_entry_group_list()");
	  String groupIds[] = msc.getEntryFactory().get_entry_group_list();
	  endTime("get_entry_group_list()");
	  if (debug > 0)
	    {
	      txf.logMessage("First 3 of " + groupIds.length
			     + " Entry Groups:");
	      int len = Math.min(groupIds.length, 3);
	      for (int i = 0; i < len; i++)
		{
		  txf.logMessage("  Group " + i + " = " + groupIds[i]);
		}
	    }

	  if (groupIds.length < 3)
	    {
	      txf.logMessage("Number of Entry Groups = " +  groupIds.length);
	    }
	  else
	    {
	      startTime("get_entries_in_group()");
	      String geIds[] = msc.getEntryFactory()
		.get_entries_in_group(groupIds[1]);
	      endTime("get_entries_in_group()");
	      if (debug > 0)
		{
		  txf.logMessage("First 3 of " + geIds.length
				 + " entries in group " + groupIds[1] + ":");
		  int len = Math.min(geIds.length, 3);
		  for (int i = 0; i < len; i++)
		    {
		      txf.logMessage("  Group " + groupIds[1] 
				     + " Entry " + i + " = " + geIds[i]);
		    }
		}
	    }

	  startTime("get_entry_modification_dates()");
	  ModificationDate[] md = msc.getEntryFactory()
	    .get_entry_modification_dates();
	  endTime("get_entry_modification_dates()");
	  if (debug > 0)
	    {
	      Date date = new Date();
	      txf.logMessage("First 3 of " + md.length
			     + " modification dates:");
	      int len = Math.min(md.length, 3);
	      for (int i = 0; i < len; i++)
		{
		  date.setTime(md[i].date);
		  txf.logMessage("  Modification Date on Entry " 
				 + md[i].entry_id + " = "
				 + date.toString());
		}
	    }
	  Entry etry;

	  // small test file
	  testEntry = "3ebx";
	  etry = fetchEntry(testEntry);

	  // small test file
	  testEntry = "1xy2";
	  etry = fetchEntry(testEntry);

	  // medium size test file
	  testEntry = "4hhb";
	  etry = fetchEntry(testEntry);

	  // Test to make sure exception are thrown for invalid
	  // Entry names
	  try
	    {
	      // BAD Entry name "xyzw"
	      Entry badEntry = fetchEntry("xyzw");
	      Entity[] badEnti = badEntry.get_entity_list();
	    }
	  catch (DataAccessException e)
	    {
	      // should end up here
	      String er = "Passed Corba exception test: " + e.description;
	      txf.logMessage(er);
	    }

	  txf.logMessage("\nFollowing data received from server for entry: "
			 + testEntry);
	  try
	    {
	      Any a;
	      Property[] eExt = etry.get_subentry_list();

	      a = fetchExt("MmsReferenceEntry", eExt);
	      refE =  MmsReferenceEntryHelper.extract(a);
	      a = fetchExt("XRayCrystallographyEntry", eExt);
	      xrayE =  XRayCrystallographyEntryHelper.extract(a);
	    }
	  catch (Exception e)
	    {
	      String er = "Fetch subentry ERROR:\n" + e;
	      txf.logMessage(er);
	    }
	  byte[] mFlags;
	  byte[] xFlags;
	  byte[] rFlags;

	  startTime("get_presence_flags()");
	  mFlags = etry.get_presence_flags();
	  rFlags = refE.get_presence_flags();
	  xFlags = xrayE.get_presence_flags();
	  endTime("get_presence_flags()");
	  if (debug > 0)
	    {
	      txf.logMessage("Core presence Flags:");
	      for (int i = 0; i < mFlags.length; i++)
		{
		  txf.logMessage("  Flag[" + i + "]=0x" 
			 + Integer.toString(0xFF & (int)mFlags[i], 16));
		}
	      txf.logMessage("    Atom Site flag="
			     + isFlagSet(mFlags, Entry.S_ATOM_SITE));
	      txf.logMessage("    Software flag="
			     + isFlagSet(rFlags,
				       MmsReferenceEntry.S_SOFTWARE));
	    }

	  String[] formats = msc.getEntryFactory().native_formats_supported();
	  if (debug > 0)
	    {
	      txf.logMessage("\nNative formats supported:");
	      for (int i = 0; i < formats.length; i++)
		{
		  txf.logMessage("  Format " + i + "=" + formats[i]);
		}
	    }
	  for (int i = 0; i < formats.length; i++)
	    {
	      if ("mmCIF".equalsIgnoreCase(formats[i]))
		  {
		    startTime("get_native_entry_representation()");
		    byte[] cifBytes = msc.getEntryFactory()
		      .get_native_entry_representation("mMcIf", testEntry);
		    endTime("get_native_entry_representation()");
		    if (debug > 0)
		      {
			txf.logMessage("First 1000 bytes of entry "
				       + testEntry + " in native format");
			int len = Math.min(1000, cifBytes.length);
			txf.logMessage(new String(cifBytes, 0, len) +"\n\n");
		      }
		    if (debug > 6)
		      {
			String oFilename = testEntry + ".cif";
			txf.logMessage("WRITING NATIVE FORMAT FILE "
				       + oFilename 
				       + " IN CURRENT WORKING DIRECTORY\n\n");
			FileWriter of = new FileWriter(oFilename);
			of.write(new String(cifBytes));
			of.close();
		      }
		  }
	    }

	  if (isFlagSet(xFlags, XRayCrystallographyEntry.S_CELL))
	    {
	      startTime("get_cell_list()");
	      Cell[] cel = xrayE.get_cell_list();
	      endTime("get_cell_list()");
	      if (debug > 0)
		{
		  txf.logMessage("Cells:");
		  if (cel.length < 1)
		    {
		      txf.logMessage("NO CELL INFORMATION RETURNED");
		    }
		  else
		    {
		      for (int i = 0; i < cel.length; i++)
			{
			  txf.logMessage("  Cell.lenght_a ="
					 + cel[0].cell.length_a);
			  txf.logMessage("  Cell.lenght_b =" 
					 + cel[0].cell.length_b);
			  txf.logMessage("  Cell.lenght_c ="
					 + cel[0].cell.length_c);
			  txf.logMessage("  Cell.volume ="
					 + cel[0].volume);
			}
		    }
		}
	    }

	  if (isFlagSet(rFlags, MmsReferenceEntry.S_SOFTWARE))
	    {
	      startTime("get_software_list() test");
	      Software[] sw = refE.get_software_list();
	      if (isFlagSet(rFlags, MmsReferenceEntry.F_SOFTWARE_LOCATION))
		  {
		    txf.logMessage("  Software.location=" + sw[0].location);
		  }
	      txf.logMessage("  Software.version=" + sw[0].version);

	      endTime("get_software_list() test");
	    }

	  AtomSites[] as = null;
	  if (isFlagSet(xFlags, XRayCrystallographyEntry.S_ATOM_SITES))
	    {
	      startTime("get_atom_sites_list()");
	      as = xrayE.get_atom_sites_list();
	      endTime("get_atom_sites_list()");
	    }
	  if (isFlagSet(xFlags, XRayCrystallographyEntry
		      .F_ATOM_SITES_FRACT_TRANSF_VECTOR))
	    {
	      txf.logMessage("\nFract_Transf_Vector:");
	      for (int i = 0; i < 3; i++)
		{
		  txf.logMessage("    Fract_Transf[" + i + "]=" +
				 as[0].fract_transf_vector[i]);
		}
	    }
	  if (isFlagSet(xFlags, XRayCrystallographyEntry
		      .F_ATOM_SITES_FRACT_TRANSF_MATRIX))
	    {
	      txf.logMessage("Fract_Transf_Matrix:");
	      for (int j = 0; j < 3; j++)
		{
		  for (int i = 0; i < 3; i++)
		    {
		      txf.logMessage("    Fract_Transf["+j+"]["+i+"]=" +
				     as[0].fract_transf_matrix[j][i]);
		    }
		}
	    }

	  if (isFlagSet(mFlags, Entry.S_ATOM_SITE))
	    {
	      int astSz = etry.atom_site_list_size();
	      startTime("get_atom_site_list()");
	      AtomSite[] ast = etry.get_atom_site_list();
	      endTime("get_atom_site_list()");
	      if (debug > 0)
		{
		  txf.logMessage("Atoms (Total=" + astSz + "):");
		  // list first 20 and last 5 atoms
		  for (int i = 0; i < ast.length; i++)
		    {
		      if (i == 20)
			{
			  i = Math.max(10, ast.length) - 5;
			}
		      txf.logMessage
			("  Atom[" + i + "] id=" + ast[i].id
			 + ", type_symbol.id=" + ast[i].type_symbol.id);
		      txf.logMessage
			("    label.atom.id=" + ast[i].label.atom.id
			 + ", label.asym.id=" + ast[i].label.asym.id
			 + ", label.asym.index=" + ast[i].label.asym.index);
		      txf.logMessage
			("    label_entity.id=" + ast[i].label_entity.id
			 + ", label_entity.index="
			 + ast[i].label_entity.index);
		      txf.logMessage
			("    label.seq.id=" + ast[i].label.seq.id
			 + ", label.seq.index="
			 + ast[i].label.seq.index);
		      txf.logMessage
			("    Position=("
			 + ast[i].cartn.x + ", "
			 + ast[i].cartn.y + ", "
			 + ast[i].cartn.z + ")");
		    }
		}
	      
	      startTime("get_atom_site_block_n()");
	      AtomSite[] abst = etry.get_atom_site_block_n(1065, 1075);
	      endTime("get_atom_site_block_n()");
	      if (debug > 0)
		{
		  txf.logMessage("Atoms Block (1065-1075):");
		  for (int i = 0; i < 10; i++)
		    {
		      txf.logMessage
			("  Atom(block_n)[" + i + "] id=" + abst[i].id
			 + ", type_symbol.id=" + abst[i].type_symbol.id);
		      txf.logMessage
			("    label.atom.id=" + abst[i].label.atom.id
			 + ", label.asym.id=" + abst[i].label.asym.id
			 + ", label.asym.index=" + abst[i].label.asym.index);
		      txf.logMessage
			("    label_entity.id=" + abst[i].label_entity.id
			+ ", label_entity.index="
			+ abst[i].label_entity.index);
		      txf.logMessage
			("    label.seq.id=" + abst[i].label.seq.id
			 + ", label.seq.index="
			 + abst[i].label.seq.index);
		  txf.logMessage
		    ("    Position=("
		     + abst[i].cartn.x + ", "
		     + abst[i].cartn.y + ", "
		     + abst[i].cartn.z + ")");
		    }
		}
	    }

	  if (isFlagSet(mFlags, Entry.S_ENTITY_POLY_SEQ))
	    {
	      startTime("get_entity_poly_seq_list()");
	      EntityPolySeq[] eps = etry.get_entity_poly_seq_list();
	      endTime("get_entity_poly_seq_list()");
	      if (debug > 0)
		{
		  txf.logMessage("Polymer Sequence:");
		  for (int i = 0; i < eps.length; i++)
		    {
		      txf.logMessage("  EntityPolySeq[" + i + "] mon.id="
				     + eps[i].mon.id 
				     + ", entity.id=" + eps[i].entity.id
				     + ", num=" + eps[i].num);
		    }
		}
	    }
	  if (isFlagSet(mFlags, Entry.S_CHEM_COMP))
	    {
	      startTime("get_chem_comp_list()");
	      ChemComp[] ccs = etry.get_chem_comp_list();
	      endTime("get_chem_comp_list()");
	      if (debug > 0)
		{
		  txf.logMessage("ChemComp:");
		  for (int i = 0; i < ccs.length; i++)
		    {
		      txf.logMessage("  ChemComp[" + i + "] id="
				     + ccs[i].id 
				     + ", name=" + ccs[i].name
				     + ", formula=" + ccs[i].formula);
		    }
		}
	    }
	  if (isFlagSet(rFlags, MmsReferenceEntry.S_CITATION_AUTHOR))
	    {
	      startTime("get_citation_author_list()");
	      CitationAuthor[] cal = refE.get_citation_author_list();
	      endTime("get_citation_author_list()");
	      if (debug > 0)
		{
		  txf.logMessage("Citations Authors:");
		  for (int i = 0; i < cal.length; i++)
		    {
		      txf.logMessage("  CitiationAuthor[" + i 
				     + "] id=" + cal[i].citation.id 
				     + ", index=" + cal[i].citation.index 
				     + ", name=" + cal[i].name );
		    }
		}
	    }
	  if (isFlagSet(rFlags, MmsReferenceEntry.S_CITATION))
	    {
	      startTime("get_citation_list()");
	      Citation[] cl = refE.get_citation_list();
	      endTime("get_citation_list()");
	      if (debug > 0)
		{
		  txf.logMessage("Citations:");
		  for (int i = 0; i < cl.length; i++)
		    {
		      txf.logMessage("  Citiation[" + i + "] <"
				     + cl[i].id + "> =\n\t"
				     + cl[i].title );
		    }
		}
	    }
	  txf.logMessage("\n\nDONE\n");
	}
      catch (DataAccessException e)
	{
	  String er = "Data Access Error: " + e.description;
	  if (e.method_name != null)
	    {
	      er += ", in method: " + e.method_name;
	    }
	  txf.logMessage(er);
	  System.out.println(er);
	  e.printStackTrace();
	}
      catch(Exception e)
	{
	  String er = "MMS Connection Error: ";
	  txf.logMessage(er + e.toString());
	  System.out.println(er);
	  e.printStackTrace();
	}
    }

  public Entry fetchEntry(String id)
    throws DataAccessException
    {
      startTime("get_entry_from_id(" + id + ")");
      Entry etry= msc.getEntryFactory().get_entry_from_id(id);
      endTime("get_entry_from_id(" + id + ")");
      if (debug > 0)
	{
	  txf.logMessage("ENTRY " + id + " Received");
	}
      byte[] flags = etry.get_presence_flags();
      if (isFlagSet(flags, Entry.S_ENTITY))
	{
	  startTime("get_entity_list()");
	  Entity[] enti = etry.get_entity_list();
	  endTime("get_entity_list()");
	  if (debug > 0)
	    {
	      txf.logMessage("Entities:");
	      for (int i = 0; i < enti.length; i++)
		{
		  String em = "  Entity[" + i + "].id=" + enti[i].id;
		    if (isFlagSet(flags, Entry.F_ENTITY_TYPE))
		      {
			em += ", type=" + enti[i].type;
		      }
		    if (isFlagSet(flags, Entry.F_ENTITY_DETAILS))
		      {
			em += ", details=" + enti[i].details;
		      }
		  txf.logMessage(em);
		}
	    }
	}
      return etry;
    }

  public Any fetchExt(String ename, Property[] pl)
    throws Exception
    {
      for (int i = 0; i < pl.length; i++)
	{
	  if (ename.equals(pl[i].property_name))
	    {
	      return pl[i].property_value;
	    }
	}
      throw new Exception("TextMMSClient.fetchExt: Property "
			  + ename + " not found");
    }

  void startTime(String m)
    {
      txf.logMessage("");
      if (printTimes)
	{
	  stime = new Date();
	  txf.logMessage("Start " + m + ":" + stime.toString());
	}
      else
	{
	  txf.logMessage("Start " + m + ":");
	}
    }

  void endTime(String m)
    {
      if (printTimes)
	{
	  etime = new Date();
	  txf.logMessage("End " + m + " ELAPSED: "
	      + ((float) (etime.getTime() - stime.getTime())) / 1000);
	}
    }

  public boolean isFlagSet(byte[] bits, int flag)
    {
      if ((bits[flag/8] & (1 << (flag%8))) != 0)
	return true;
      else
	return false;
    }

  public String parseArguments(String param, String[] argv)
    {
      for(int i=0; i<argv.length; i++)
	{
	  if(argv[i].startsWith(param))
	    {
	      int index=argv[i].indexOf('=');
	      if(index!=-1) return (argv[i].substring(index+1));
	    }
	}
      return null;
    }

  public boolean parseArgumentsBool(String param, String[] argv)
    {
      for(int i=0; i<argv.length; i++)
	if(argv[i].equalsIgnoreCase(param)) return true;

      return false;
    }
}
