//
// TxPanel.java,v 1.5 2001/10/27 02:02:48 dsg Exp
//
// Copyright 2001 The Regents of the University of California
// All Rights Reserved
//
// OpenMMS was developed by Dr. Douglas S. Greer at the San Diego
// Supercomputer Center, a research unit of the University of California,
// San Diego.  Support for this effort was provided by NSF through the
// Protein Data Bank (Grant DBI-9814284) and the National Partnership for
// Advanced Computational Infrastructure (Grant ACI-9619020)
//
// Permission to use, copy, modify and distribute any part of OpenMMS for
// educational, research and non-profit purposes, without fee, and
// without a written agreement is hereby granted, provided that the above
// copyright notice, this paragraph and the following paragraphs appear
// in all copies.
//
// Those desiring to incorporate this OpenMMS into commercial products or
// use for commercial purposes should contact the Technology Transfer
// Office, University of California, San Diego, 9500 Gilman Drive, La
// Jolla, CA 92093-0910, Ph: (619) 534-5815, FAX: (619) 534-7345.
//
// In no event shall the University of California be liable to any party
// for direct, indirect, special, incidental, or consequential damages,
// including lost profits, arising out of the use of this OpenMMS, even
// if the University of California has been advised of the possibility of
// such damage.
//
// The OpenMMS provided herein is on an "as is" basis, and the
// University of California has no obligation to provide maintenance,
// support, updates, enhancements, or modifications.  The University of
// California makes no representations and extends no warranties of any
// kind, either implied or express, including, but not limited to, the
// implied warranties of merchantability or fitness for a particular
// purpose, or that the use of the OpenMMS will not infringe any patent,
// trademark or other rights.

package org.rcsb.openmms.apps.text;

import java.io.*;
import java.awt.*;
import java.awt.event.*;

import javax.swing.*;
import javax.swing.text.*;
import javax.swing.border.*;

/**
 * Java Swing JPanel for an MMS Corba test client.  Contains a
 * constructor which generates all GUI objects for this application.
 *
 * @author Douglas S. Greer
 * @version 1.5
 */
public class TxPanel extends JPanel
{
  private static int debug = 0;
  BufferedWriter debugFileWriter;

  JTextArea msgs;

  public TxPanel()
    {
      createPanel();
      try
	{
	  debugFileWriter = new BufferedWriter(new FileWriter
					       ("TXCLIENT.LOG"));
	}
      catch(IOException e)
	{
	  System.out.println("Cannot open debug log file: " + e);
	}
    }

  public void setDebug(int d)
    {
      debug = d;
    }

  public void createPanel()
    {
      setLayout(new BorderLayout());

      setBorder( new EmptyBorder(20, 50, 20 ,50));
      Box bigb = Box.createVerticalBox();
      add(bigb);

      JLabel jl = new JLabel("MMS Client Log Messages");
      jl.setFont(new Font("Dialog", Font.BOLD, 20));
      jl.setForeground(Color.black);
      bigb.add(jl);

      bigb.add(Box.createVerticalStrut(5));

      msgs = new JTextArea(20, 70);
      // msgs.setFont(new Font("Serif", Font.PLAIN, 16));
      msgs.setFont(new Font("Monospaced", Font.PLAIN, 16));
      bigb.add(new JScrollPane(msgs));
      
      bigb.add(Box.createVerticalStrut(20));

      JButton exit_button = new JButton("  Exit  ");
      exit_button.setBackground(TxFrame.backgroundColor);
      exit_button.setBorder( new BevelBorder(BevelBorder.RAISED));
      exit_button.setFont(new Font("Dialog", Font.PLAIN, 20));
      exit_button.addActionListener(new ExitButtonObserver());
      bigb.add(exit_button);}

  public void logMessage(String s)
    {
      msgs.append(s + "\n");
      if (debug > 0)
	{
	  try
	    {
	      debugFileWriter.write(s + "\n");
	      debugFileWriter.flush();
	    }
	  catch(IOException e)
	    {
	      System.out.println("Error writing to debug log file: " + e);
	    }
	}
    }

  class ExitButtonObserver implements ActionListener, Serializable
  {
    public void actionPerformed(ActionEvent e)
      {
	System.exit(0);
      }
  }
}


