//
// **** DERIVED FILE - DO NOT EDIT ****
//
// Copyright 2003 The Regents of the University of California
// All Rights Reserved
//
// OpenMMS was developed by Dr. Douglas S. Greer at the San Diego
// Supercomputer Center, a research unit of the University of California,
// San Diego.  Support for this effort was provided by NSF through the
// Protein Data Bank (Grant DBI-9814284) and the National Partnership for
// Advanced Computational Infrastructure (Grant ACI-9619020)
//
// Permission to use, copy, modify and distribute any part of OpenMMS for
// educational, research and non-profit purposes, without fee, and
// without a written agreement is hereby granted, provided that the above
// copyright notice, this paragraph and the following paragraphs appear
// in all copies.
//
// Those desiring to incorporate this OpenMMS into commercial products or
// use for commercial purposes should contact the Technology Transfer
// Office, University of California, San Diego, 9500 Gilman Drive, La
// Jolla, CA 92093-0910, Ph: (619) 534-5815, FAX: (619) 534-7345.
//
// In no event shall the University of California be liable to any party
// for direct, indirect, special, incidental, or consequential damages,
// including lost profits, arising out of the use of this OpenMMS, even
// if the University of California has been advised of the possibility of
// such damage.
//
// The OpenMMS provided herein is on an "as is" basis, and the
// University of California has no obligation to provide maintenance,
// support, updates, enhancements, or modifications.  The University of
// California makes no representations and extends no warranties of any
// kind, either implied or express, including, but not limited to, the
// implied warranties of merchantability or fitness for a particular
// purpose, or that the use of the OpenMMS will not infringe any patent,
// trademark or other rights.

package org.rcsb.openmms.loader;

import java.util.*;
import org.rcsb.openmms.cifparse.*;
import org.rcsb.openmms.util.*;
import org.omg.DsLSRMacromolecularStructure.*;
import org.omg.DsLSRXRayCrystallography.*;

/**
 * Category Loader to load data into the XRayCrystallographyEntryMethodImpl.Cell
 * structure.
 * <p>
 * Generated by the program MMSExpr. Model: Std, Revision: 3.0
 * <p>
 * Date: Tue Jul 29 17:48:45 PDT 2003
 *
 * @author Douglas S. Greer
 * @version OpenMMS Release V_1_5_1
 */
public class CellCatLoader
   extends CatUtil implements CatLoader
{
   public CellCatLoader()
      {
      }

   CellImpl varCell;
   ArrayList arrayCell = new ArrayList();

   static final int CELL_LENGTH_A = 983;
   static final int CELL_LENGTH_B = 984;
   static final int CELL_LENGTH_C = 985;
   static final int CELL_ANGLE_ALPHA = 986;
   static final int CELL_ANGLE_BETA = 987;
   static final int CELL_ANGLE_GAMMA = 988;
   static final int CELL_ESD_LENGTH_A = 989;
   static final int CELL_ESD_LENGTH_B = 990;
   static final int CELL_ESD_LENGTH_C = 991;
   static final int CELL_ESD_ANGLE_ALPHA = 992;
   static final int CELL_ESD_ANGLE_BETA = 993;
   static final int CELL_ESD_ANGLE_GAMMA = 994;
   static final int ENTRY_ID = 995;
   static final int DETAILS = 996;
   static final int VOLUME = 997;
   static final int VOLUME_ESD = 998;
   static final int Z_PDB = 999;
   static final int PDBX_UNIQUE_AXIS = 1000;

   public void beginCategory()
      {
         varCell = null;
      }

   public void endCompound(Object e)
      throws CifParseException
      {
      }

   public void beginRow()
      {
         varCell = new CellImpl();
         varCell.cell = new UnitCell();
         varCell.cell_esd = new UnitCell();
         varCell.entry_id = "";
         varCell.details = "";
         varCell.pdbx_unique_axis = "";
      }

   public void endRow()
      {
         arrayCell.add(varCell);
      }

   public void endLoop(Object e)
      {
         int i;
         EntryMethodImpl xe = (EntryMethodImpl) e;
         xe.xray._cell_list = new CellImpl[arrayCell.size()];
         for (i = 0; i < arrayCell.size(); i++)
            {
               xe.xray._cell_list[i]
                  = (CellImpl) arrayCell.get(i);
            }
         arrayCell.clear();
      }

   public void defineSingleItem(Object e, int fieldCode)
      {
         EntryMethodImpl xe = (EntryMethodImpl) e;
         defineItem(xe, fieldCode);
      }

   public void defineLoopItem(Object e, int fieldCode)
      {
         EntryMethodImpl xe = (EntryMethodImpl) e;
         defineItem(xe, fieldCode);
      }

   public void defineItem(EntryMethodImpl xe, int fieldCode)
      {
      switch (fieldCode)
         {
         case CELL_LENGTH_A:
            xe.xray._presence_flags[XRayCrystallographyEntry.S_CELL/8] |=
               1 << (XRayCrystallographyEntry.S_CELL%8);
            xe.xray._presence_flags[XRayCrystallographyEntry.F_CELL_CELL_LENGTH_A/8] |=
               1 << (XRayCrystallographyEntry.F_CELL_CELL_LENGTH_A%8);
            break;

         case CELL_LENGTH_B:
            xe.xray._presence_flags[XRayCrystallographyEntry.S_CELL/8] |=
               1 << (XRayCrystallographyEntry.S_CELL%8);
            xe.xray._presence_flags[XRayCrystallographyEntry.F_CELL_CELL_LENGTH_B/8] |=
               1 << (XRayCrystallographyEntry.F_CELL_CELL_LENGTH_B%8);
            break;

         case CELL_LENGTH_C:
            xe.xray._presence_flags[XRayCrystallographyEntry.S_CELL/8] |=
               1 << (XRayCrystallographyEntry.S_CELL%8);
            xe.xray._presence_flags[XRayCrystallographyEntry.F_CELL_CELL_LENGTH_C/8] |=
               1 << (XRayCrystallographyEntry.F_CELL_CELL_LENGTH_C%8);
            break;

         case CELL_ANGLE_ALPHA:
            xe.xray._presence_flags[XRayCrystallographyEntry.S_CELL/8] |=
               1 << (XRayCrystallographyEntry.S_CELL%8);
            xe.xray._presence_flags[XRayCrystallographyEntry.F_CELL_CELL_ANGLE_ALPHA/8] |=
               1 << (XRayCrystallographyEntry.F_CELL_CELL_ANGLE_ALPHA%8);
            break;

         case CELL_ANGLE_BETA:
            xe.xray._presence_flags[XRayCrystallographyEntry.S_CELL/8] |=
               1 << (XRayCrystallographyEntry.S_CELL%8);
            xe.xray._presence_flags[XRayCrystallographyEntry.F_CELL_CELL_ANGLE_BETA/8] |=
               1 << (XRayCrystallographyEntry.F_CELL_CELL_ANGLE_BETA%8);
            break;

         case CELL_ANGLE_GAMMA:
            xe.xray._presence_flags[XRayCrystallographyEntry.S_CELL/8] |=
               1 << (XRayCrystallographyEntry.S_CELL%8);
            xe.xray._presence_flags[XRayCrystallographyEntry.F_CELL_CELL_ANGLE_GAMMA/8] |=
               1 << (XRayCrystallographyEntry.F_CELL_CELL_ANGLE_GAMMA%8);
            break;

         case CELL_ESD_LENGTH_A:
            xe.xray._presence_flags[XRayCrystallographyEntry.S_CELL/8] |=
               1 << (XRayCrystallographyEntry.S_CELL%8);
            xe.xray._presence_flags[XRayCrystallographyEntry.F_CELL_CELL_ESD_LENGTH_A/8] |=
               1 << (XRayCrystallographyEntry.F_CELL_CELL_ESD_LENGTH_A%8);
            break;

         case CELL_ESD_LENGTH_B:
            xe.xray._presence_flags[XRayCrystallographyEntry.S_CELL/8] |=
               1 << (XRayCrystallographyEntry.S_CELL%8);
            xe.xray._presence_flags[XRayCrystallographyEntry.F_CELL_CELL_ESD_LENGTH_B/8] |=
               1 << (XRayCrystallographyEntry.F_CELL_CELL_ESD_LENGTH_B%8);
            break;

         case CELL_ESD_LENGTH_C:
            xe.xray._presence_flags[XRayCrystallographyEntry.S_CELL/8] |=
               1 << (XRayCrystallographyEntry.S_CELL%8);
            xe.xray._presence_flags[XRayCrystallographyEntry.F_CELL_CELL_ESD_LENGTH_C/8] |=
               1 << (XRayCrystallographyEntry.F_CELL_CELL_ESD_LENGTH_C%8);
            break;

         case CELL_ESD_ANGLE_ALPHA:
            xe.xray._presence_flags[XRayCrystallographyEntry.S_CELL/8] |=
               1 << (XRayCrystallographyEntry.S_CELL%8);
            xe.xray._presence_flags[XRayCrystallographyEntry.F_CELL_CELL_ESD_ANGLE_ALPHA/8] |=
               1 << (XRayCrystallographyEntry.F_CELL_CELL_ESD_ANGLE_ALPHA%8);
            break;

         case CELL_ESD_ANGLE_BETA:
            xe.xray._presence_flags[XRayCrystallographyEntry.S_CELL/8] |=
               1 << (XRayCrystallographyEntry.S_CELL%8);
            xe.xray._presence_flags[XRayCrystallographyEntry.F_CELL_CELL_ESD_ANGLE_BETA/8] |=
               1 << (XRayCrystallographyEntry.F_CELL_CELL_ESD_ANGLE_BETA%8);
            break;

         case CELL_ESD_ANGLE_GAMMA:
            xe.xray._presence_flags[XRayCrystallographyEntry.S_CELL/8] |=
               1 << (XRayCrystallographyEntry.S_CELL%8);
            xe.xray._presence_flags[XRayCrystallographyEntry.F_CELL_CELL_ESD_ANGLE_GAMMA/8] |=
               1 << (XRayCrystallographyEntry.F_CELL_CELL_ESD_ANGLE_GAMMA%8);
            break;

         case ENTRY_ID:
            xe.xray._presence_flags[XRayCrystallographyEntry.S_CELL/8] |=
               1 << (XRayCrystallographyEntry.S_CELL%8);
            break;

         case DETAILS:
            xe.xray._presence_flags[XRayCrystallographyEntry.S_CELL/8] |=
               1 << (XRayCrystallographyEntry.S_CELL%8);
            xe.xray._presence_flags[XRayCrystallographyEntry.F_CELL_DETAILS/8] |=
               1 << (XRayCrystallographyEntry.F_CELL_DETAILS%8);
            break;

         case VOLUME:
            xe.xray._presence_flags[XRayCrystallographyEntry.S_CELL/8] |=
               1 << (XRayCrystallographyEntry.S_CELL%8);
            xe.xray._presence_flags[XRayCrystallographyEntry.F_CELL_VOLUME/8] |=
               1 << (XRayCrystallographyEntry.F_CELL_VOLUME%8);
            break;

         case VOLUME_ESD:
            xe.xray._presence_flags[XRayCrystallographyEntry.S_CELL/8] |=
               1 << (XRayCrystallographyEntry.S_CELL%8);
            xe.xray._presence_flags[XRayCrystallographyEntry.F_CELL_VOLUME_ESD/8] |=
               1 << (XRayCrystallographyEntry.F_CELL_VOLUME_ESD%8);
            break;

         case Z_PDB:
            xe.xray._presence_flags[XRayCrystallographyEntry.S_CELL/8] |=
               1 << (XRayCrystallographyEntry.S_CELL%8);
            xe.xray._presence_flags[XRayCrystallographyEntry.F_CELL_Z_PDB/8] |=
               1 << (XRayCrystallographyEntry.F_CELL_Z_PDB%8);
            break;

         case PDBX_UNIQUE_AXIS:
            xe.xray._presence_flags[XRayCrystallographyEntry.S_CELL/8] |=
               1 << (XRayCrystallographyEntry.S_CELL%8);
            xe.xray._presence_flags[XRayCrystallographyEntry.F_CELL_PDBX_UNIQUE_AXIS/8] |=
               1 << (XRayCrystallographyEntry.F_CELL_PDBX_UNIQUE_AXIS%8);
            break;

         }
      }

   public void insertSingleValue(Object e, int fieldCode, String value)
      {
      switch (fieldCode)
         {
         case CELL_LENGTH_A:
         case CELL_LENGTH_B:
         case CELL_LENGTH_C:
         case CELL_ANGLE_ALPHA:
         case CELL_ANGLE_BETA:
         case CELL_ANGLE_GAMMA:
         case CELL_ESD_LENGTH_A:
         case CELL_ESD_LENGTH_B:
         case CELL_ESD_LENGTH_C:
         case CELL_ESD_ANGLE_ALPHA:
         case CELL_ESD_ANGLE_BETA:
         case CELL_ESD_ANGLE_GAMMA:
         case ENTRY_ID:
         case DETAILS:
         case VOLUME:
         case VOLUME_ESD:
         case Z_PDB:
         case PDBX_UNIQUE_AXIS:
            if(varCell == null)
               {
                  beginRow();
                  EntryMethodImpl xe = (EntryMethodImpl) e;
                  xe.xray._cell_list = new CellImpl[1];
                  xe.xray._cell_list[0] = varCell;
               }
            break;
         }
      insertValue(fieldCode, value);
      }

   public void insertLoopValue(int fieldCode, String value)
      {
         insertValue(fieldCode, value);
      }

   public void insertValue(int fieldCode, String value)
      {
      switch (fieldCode)
         {
         case CELL_LENGTH_A:
            varCell.cell.length_a = cifFloat(value);
            break;
         case CELL_LENGTH_B:
            varCell.cell.length_b = cifFloat(value);
            break;
         case CELL_LENGTH_C:
            varCell.cell.length_c = cifFloat(value);
            break;
         case CELL_ANGLE_ALPHA:
            varCell.cell.angle_alpha = cifFloat(value);
            break;
         case CELL_ANGLE_BETA:
            varCell.cell.angle_beta = cifFloat(value);
            break;
         case CELL_ANGLE_GAMMA:
            varCell.cell.angle_gamma = cifFloat(value);
            break;
         case CELL_ESD_LENGTH_A:
            varCell.cell_esd.length_a = cifFloat(value);
            break;
         case CELL_ESD_LENGTH_B:
            varCell.cell_esd.length_b = cifFloat(value);
            break;
         case CELL_ESD_LENGTH_C:
            varCell.cell_esd.length_c = cifFloat(value);
            break;
         case CELL_ESD_ANGLE_ALPHA:
            varCell.cell_esd.angle_alpha = cifFloat(value);
            break;
         case CELL_ESD_ANGLE_BETA:
            varCell.cell_esd.angle_beta = cifFloat(value);
            break;
         case CELL_ESD_ANGLE_GAMMA:
            varCell.cell_esd.angle_gamma = cifFloat(value);
            break;
         case ENTRY_ID:
            varCell.entry_id = cifString(value);
            break;
         case DETAILS:
            varCell.details = cifString(value);
            break;
         case VOLUME:
            varCell.volume = cifFloat(value);
            break;
         case VOLUME_ESD:
            varCell.volume_esd = cifFloat(value);
            break;
         case Z_PDB:
            varCell.z_pdb = cifInt(value);
            break;
         case PDBX_UNIQUE_AXIS:
            varCell.pdbx_unique_axis = cifString(value);
            break;
         }
      }
}

