//
// **** DERIVED FILE - DO NOT EDIT ****
//
// Copyright 2003 The Regents of the University of California
// All Rights Reserved
//
// OpenMMS was developed by Dr. Douglas S. Greer at the San Diego
// Supercomputer Center, a research unit of the University of California,
// San Diego.  Support for this effort was provided by NSF through the
// Protein Data Bank (Grant DBI-9814284) and the National Partnership for
// Advanced Computational Infrastructure (Grant ACI-9619020)
//
// Permission to use, copy, modify and distribute any part of OpenMMS for
// educational, research and non-profit purposes, without fee, and
// without a written agreement is hereby granted, provided that the above
// copyright notice, this paragraph and the following paragraphs appear
// in all copies.
//
// Those desiring to incorporate this OpenMMS into commercial products or
// use for commercial purposes should contact the Technology Transfer
// Office, University of California, San Diego, 9500 Gilman Drive, La
// Jolla, CA 92093-0910, Ph: (619) 534-5815, FAX: (619) 534-7345.
//
// In no event shall the University of California be liable to any party
// for direct, indirect, special, incidental, or consequential damages,
// including lost profits, arising out of the use of this OpenMMS, even
// if the University of California has been advised of the possibility of
// such damage.
//
// The OpenMMS provided herein is on an "as is" basis, and the
// University of California has no obligation to provide maintenance,
// support, updates, enhancements, or modifications.  The University of
// California makes no representations and extends no warranties of any
// kind, either implied or express, including, but not limited to, the
// implied warranties of merchantability or fitness for a particular
// purpose, or that the use of the OpenMMS will not infringe any patent,
// trademark or other rights.

package org.rcsb.openmms.loader;

import java.util.*;
import org.omg.DsLSRMacromolecularStructure.*;
import org.omg.DsLSRMmsReference.*;
import org.omg.DsLSRXRayCrystallography.*;
import org.omg.DsLSRNmr.*;

/**
 * The Entry/Subentry classes contain the arrays of data structures
 * that store all of the information known about a particular entry
 * (i.e. an MMS structure) as well as the methods for accessing
 * those data structures.
 * <p>
 * Generated by the program MMSExpr. Model: Std, Revision: 3.0
 * <p>
 * Date: Tue Jul 29 17:48:42 PDT 2003
 *
 * @author Douglas S. Greer
 * @version OpenMMS Release V_1_5_1
 */
public abstract class EntryMethodImpl
     extends EntryPOA
    {
    public EntryMethodImpl()
        {
        }

    abstract public boolean initEntry()
            throws DataAccessException;
    abstract public Object[] getList(int sFlag)
            throws DataAccessException;
    abstract public int getListSize(int sFlag)
            throws DataAccessException;
    abstract public Object[] getListBlock(int sFlag, int from, int to)
            throws DataAccessException;
    abstract public boolean cacheValue(Object[] var, int sFlag)
            throws DataAccessException;

    public byte[] _presence_flags
            = new byte[(Entry.MAX_FLAG/8)+1];

    abstract public int getKey();
    abstract public void setCompositeSeqIndexList(ArrayList sia);
    abstract public void setCompositeAtomIndexList(ArrayList aia);

    public XRayCrystallographyEntryMethodImpl xray;
    public NmrEntryMethodImpl nmr;
    public MmsReferenceEntryMethodImpl ref;

    // ______ ATOM_SITE ______ //
    public AtomSite[] _atom_site_list;
    public int atom_site_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_atom_site_list != null)
            {
                return _atom_site_list.length;
            }
            else
            {
                return getListSize(Entry.S_ATOM_SITE);
            }
        }

    public AtomSite[] get_atom_site_list()
        throws DataAccessException
        {
            AtomSite[] var = null;
            boolean allVarsRead = initEntry();
            if (_atom_site_list != null)
            {
                var = _atom_site_list;
            }
            else if ( ! allVarsRead)
            {
                var = (AtomSite[]) getList(Entry.S_ATOM_SITE);
                if (cacheValue(var, Entry.S_ATOM_SITE))
                {
                    _atom_site_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_atom_site_list",
                    "Requested data not present");
            }
            return var;
        }

    public AtomSite[] get_atom_site_block_n(int from, int to)
        throws DataAccessException
        {
            AtomSite[] var = null;
            boolean allVarsRead = initEntry();
            if (_atom_site_list != null)
            {
                try
                {
                    var = new AtomSite[to-from+1];
                    System.arraycopy(_atom_site_list, from,
                            var, 0, to-from+1);
                }
                catch (Exception e)
                {
                    throw new DataAccessException("get_atom_site_block_n",
                    "Requested block out of range");
                }
            }
            else if ( ! allVarsRead)
            {
                var = (AtomSite[]) getListBlock(Entry.S_ATOM_SITE,
                    from, to);
            }
            if (var == null)
                {
                throw new DataAccessException("get_atom_site_block_n",
                    "Requested data not present");
                }
            return var;
        }

    // ______ ATOM_SITE ______ //
    public AtomSiteExt[] _atom_site_ext_list;
    public int atom_site_ext_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_atom_site_ext_list != null)
            {
                return _atom_site_ext_list.length;
            }
            else
            {
                return getListSize(Entry.S_ATOM_SITE_EXT);
            }
        }

    public AtomSiteExt[] get_atom_site_ext_list()
        throws DataAccessException
        {
            AtomSiteExt[] var = null;
            boolean allVarsRead = initEntry();
            if (_atom_site_ext_list != null)
            {
                var = _atom_site_ext_list;
            }
            else if ( ! allVarsRead)
            {
                var = (AtomSiteExt[]) getList(Entry.S_ATOM_SITE_EXT);
                if (cacheValue(var, Entry.S_ATOM_SITE_EXT))
                {
                    _atom_site_ext_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_atom_site_ext_list",
                    "Requested data not present");
            }
            return var;
        }

    public AtomSiteExt[] get_atom_site_ext_block_n(int from, int to)
        throws DataAccessException
        {
            AtomSiteExt[] var = null;
            boolean allVarsRead = initEntry();
            if (_atom_site_ext_list != null)
            {
                try
                {
                    var = new AtomSiteExt[to-from+1];
                    System.arraycopy(_atom_site_ext_list, from,
                            var, 0, to-from+1);
                }
                catch (Exception e)
                {
                    throw new DataAccessException("get_atom_site_ext_block_n",
                    "Requested block out of range");
                }
            }
            else if ( ! allVarsRead)
            {
                var = (AtomSiteExt[]) getListBlock(Entry.S_ATOM_SITE_EXT,
                    from, to);
            }
            if (var == null)
                {
                throw new DataAccessException("get_atom_site_ext_block_n",
                    "Requested data not present");
                }
            return var;
        }

    // ______ ATOM_SITE_ANISOTROP ______ //
    public AtomSiteAnisotrop[] _atom_site_anisotrop_list;
    public int atom_site_anisotrop_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_atom_site_anisotrop_list != null)
            {
                return _atom_site_anisotrop_list.length;
            }
            else
            {
                return getListSize(Entry.S_ATOM_SITE_ANISOTROP);
            }
        }

    public AtomSiteAnisotrop[] get_atom_site_anisotrop_list()
        throws DataAccessException
        {
            AtomSiteAnisotrop[] var = null;
            boolean allVarsRead = initEntry();
            if (_atom_site_anisotrop_list != null)
            {
                var = _atom_site_anisotrop_list;
            }
            else if ( ! allVarsRead)
            {
                var = (AtomSiteAnisotrop[]) getList(Entry.S_ATOM_SITE_ANISOTROP);
                if (cacheValue(var, Entry.S_ATOM_SITE_ANISOTROP))
                {
                    _atom_site_anisotrop_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_atom_site_anisotrop_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ ATOM_TYPE ______ //
    public AtomType[] _atom_type_list;
    public int atom_type_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_atom_type_list != null)
            {
                return _atom_type_list.length;
            }
            else
            {
                return getListSize(Entry.S_ATOM_TYPE);
            }
        }

    public AtomType[] get_atom_type_list()
        throws DataAccessException
        {
            AtomType[] var = null;
            boolean allVarsRead = initEntry();
            if (_atom_type_list != null)
            {
                var = _atom_type_list;
            }
            else if ( ! allVarsRead)
            {
                var = (AtomType[]) getList(Entry.S_ATOM_TYPE);
                if (cacheValue(var, Entry.S_ATOM_TYPE))
                {
                    _atom_type_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_atom_type_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ CHEM_COMP ______ //
    public ChemComp[] _chem_comp_list;
    public int chem_comp_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_chem_comp_list != null)
            {
                return _chem_comp_list.length;
            }
            else
            {
                return getListSize(Entry.S_CHEM_COMP);
            }
        }

    public ChemComp[] get_chem_comp_list()
        throws DataAccessException
        {
            ChemComp[] var = null;
            boolean allVarsRead = initEntry();
            if (_chem_comp_list != null)
            {
                var = _chem_comp_list;
            }
            else if ( ! allVarsRead)
            {
                var = (ChemComp[]) getList(Entry.S_CHEM_COMP);
                if (cacheValue(var, Entry.S_CHEM_COMP))
                {
                    _chem_comp_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_chem_comp_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ CHEM_COMP_ANGLE ______ //
    public ChemCompAngle[] _chem_comp_angle_list;
    public int chem_comp_angle_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_chem_comp_angle_list != null)
            {
                return _chem_comp_angle_list.length;
            }
            else
            {
                return getListSize(Entry.S_CHEM_COMP_ANGLE);
            }
        }

    public ChemCompAngle[] get_chem_comp_angle_list()
        throws DataAccessException
        {
            ChemCompAngle[] var = null;
            boolean allVarsRead = initEntry();
            if (_chem_comp_angle_list != null)
            {
                var = _chem_comp_angle_list;
            }
            else if ( ! allVarsRead)
            {
                var = (ChemCompAngle[]) getList(Entry.S_CHEM_COMP_ANGLE);
                if (cacheValue(var, Entry.S_CHEM_COMP_ANGLE))
                {
                    _chem_comp_angle_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_chem_comp_angle_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ CHEM_COMP_ATOM ______ //
    public ChemCompAtom[] _chem_comp_atom_list;
    public int chem_comp_atom_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_chem_comp_atom_list != null)
            {
                return _chem_comp_atom_list.length;
            }
            else
            {
                return getListSize(Entry.S_CHEM_COMP_ATOM);
            }
        }

    public ChemCompAtom[] get_chem_comp_atom_list()
        throws DataAccessException
        {
            ChemCompAtom[] var = null;
            boolean allVarsRead = initEntry();
            if (_chem_comp_atom_list != null)
            {
                var = _chem_comp_atom_list;
            }
            else if ( ! allVarsRead)
            {
                var = (ChemCompAtom[]) getList(Entry.S_CHEM_COMP_ATOM);
                if (cacheValue(var, Entry.S_CHEM_COMP_ATOM))
                {
                    _chem_comp_atom_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_chem_comp_atom_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ CHEM_COMP_BOND ______ //
    public ChemCompBond[] _chem_comp_bond_list;
    public int chem_comp_bond_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_chem_comp_bond_list != null)
            {
                return _chem_comp_bond_list.length;
            }
            else
            {
                return getListSize(Entry.S_CHEM_COMP_BOND);
            }
        }

    public ChemCompBond[] get_chem_comp_bond_list()
        throws DataAccessException
        {
            ChemCompBond[] var = null;
            boolean allVarsRead = initEntry();
            if (_chem_comp_bond_list != null)
            {
                var = _chem_comp_bond_list;
            }
            else if ( ! allVarsRead)
            {
                var = (ChemCompBond[]) getList(Entry.S_CHEM_COMP_BOND);
                if (cacheValue(var, Entry.S_CHEM_COMP_BOND))
                {
                    _chem_comp_bond_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_chem_comp_bond_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ CHEM_COMP_CHIR ______ //
    public ChemCompChir[] _chem_comp_chir_list;
    public int chem_comp_chir_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_chem_comp_chir_list != null)
            {
                return _chem_comp_chir_list.length;
            }
            else
            {
                return getListSize(Entry.S_CHEM_COMP_CHIR);
            }
        }

    public ChemCompChir[] get_chem_comp_chir_list()
        throws DataAccessException
        {
            ChemCompChir[] var = null;
            boolean allVarsRead = initEntry();
            if (_chem_comp_chir_list != null)
            {
                var = _chem_comp_chir_list;
            }
            else if ( ! allVarsRead)
            {
                var = (ChemCompChir[]) getList(Entry.S_CHEM_COMP_CHIR);
                if (cacheValue(var, Entry.S_CHEM_COMP_CHIR))
                {
                    _chem_comp_chir_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_chem_comp_chir_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ CHEM_COMP_CHIR_ATOM ______ //
    public ChemCompChirAtom[] _chem_comp_chir_atom_list;
    public int chem_comp_chir_atom_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_chem_comp_chir_atom_list != null)
            {
                return _chem_comp_chir_atom_list.length;
            }
            else
            {
                return getListSize(Entry.S_CHEM_COMP_CHIR_ATOM);
            }
        }

    public ChemCompChirAtom[] get_chem_comp_chir_atom_list()
        throws DataAccessException
        {
            ChemCompChirAtom[] var = null;
            boolean allVarsRead = initEntry();
            if (_chem_comp_chir_atom_list != null)
            {
                var = _chem_comp_chir_atom_list;
            }
            else if ( ! allVarsRead)
            {
                var = (ChemCompChirAtom[]) getList(Entry.S_CHEM_COMP_CHIR_ATOM);
                if (cacheValue(var, Entry.S_CHEM_COMP_CHIR_ATOM))
                {
                    _chem_comp_chir_atom_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_chem_comp_chir_atom_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ CHEM_COMP_LINK ______ //
    public ChemCompLink[] _chem_comp_link_list;
    public int chem_comp_link_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_chem_comp_link_list != null)
            {
                return _chem_comp_link_list.length;
            }
            else
            {
                return getListSize(Entry.S_CHEM_COMP_LINK);
            }
        }

    public ChemCompLink[] get_chem_comp_link_list()
        throws DataAccessException
        {
            ChemCompLink[] var = null;
            boolean allVarsRead = initEntry();
            if (_chem_comp_link_list != null)
            {
                var = _chem_comp_link_list;
            }
            else if ( ! allVarsRead)
            {
                var = (ChemCompLink[]) getList(Entry.S_CHEM_COMP_LINK);
                if (cacheValue(var, Entry.S_CHEM_COMP_LINK))
                {
                    _chem_comp_link_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_chem_comp_link_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ CHEM_COMP_PLANE ______ //
    public ChemCompPlane[] _chem_comp_plane_list;
    public int chem_comp_plane_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_chem_comp_plane_list != null)
            {
                return _chem_comp_plane_list.length;
            }
            else
            {
                return getListSize(Entry.S_CHEM_COMP_PLANE);
            }
        }

    public ChemCompPlane[] get_chem_comp_plane_list()
        throws DataAccessException
        {
            ChemCompPlane[] var = null;
            boolean allVarsRead = initEntry();
            if (_chem_comp_plane_list != null)
            {
                var = _chem_comp_plane_list;
            }
            else if ( ! allVarsRead)
            {
                var = (ChemCompPlane[]) getList(Entry.S_CHEM_COMP_PLANE);
                if (cacheValue(var, Entry.S_CHEM_COMP_PLANE))
                {
                    _chem_comp_plane_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_chem_comp_plane_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ CHEM_COMP_PLANE_ATOM ______ //
    public ChemCompPlaneAtom[] _chem_comp_plane_atom_list;
    public int chem_comp_plane_atom_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_chem_comp_plane_atom_list != null)
            {
                return _chem_comp_plane_atom_list.length;
            }
            else
            {
                return getListSize(Entry.S_CHEM_COMP_PLANE_ATOM);
            }
        }

    public ChemCompPlaneAtom[] get_chem_comp_plane_atom_list()
        throws DataAccessException
        {
            ChemCompPlaneAtom[] var = null;
            boolean allVarsRead = initEntry();
            if (_chem_comp_plane_atom_list != null)
            {
                var = _chem_comp_plane_atom_list;
            }
            else if ( ! allVarsRead)
            {
                var = (ChemCompPlaneAtom[]) getList(Entry.S_CHEM_COMP_PLANE_ATOM);
                if (cacheValue(var, Entry.S_CHEM_COMP_PLANE_ATOM))
                {
                    _chem_comp_plane_atom_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_chem_comp_plane_atom_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ CHEM_COMP_TOR ______ //
    public ChemCompTor[] _chem_comp_tor_list;
    public int chem_comp_tor_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_chem_comp_tor_list != null)
            {
                return _chem_comp_tor_list.length;
            }
            else
            {
                return getListSize(Entry.S_CHEM_COMP_TOR);
            }
        }

    public ChemCompTor[] get_chem_comp_tor_list()
        throws DataAccessException
        {
            ChemCompTor[] var = null;
            boolean allVarsRead = initEntry();
            if (_chem_comp_tor_list != null)
            {
                var = _chem_comp_tor_list;
            }
            else if ( ! allVarsRead)
            {
                var = (ChemCompTor[]) getList(Entry.S_CHEM_COMP_TOR);
                if (cacheValue(var, Entry.S_CHEM_COMP_TOR))
                {
                    _chem_comp_tor_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_chem_comp_tor_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ CHEM_COMP_TOR_VALUE ______ //
    public ChemCompTorValue[] _chem_comp_tor_value_list;
    public int chem_comp_tor_value_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_chem_comp_tor_value_list != null)
            {
                return _chem_comp_tor_value_list.length;
            }
            else
            {
                return getListSize(Entry.S_CHEM_COMP_TOR_VALUE);
            }
        }

    public ChemCompTorValue[] get_chem_comp_tor_value_list()
        throws DataAccessException
        {
            ChemCompTorValue[] var = null;
            boolean allVarsRead = initEntry();
            if (_chem_comp_tor_value_list != null)
            {
                var = _chem_comp_tor_value_list;
            }
            else if ( ! allVarsRead)
            {
                var = (ChemCompTorValue[]) getList(Entry.S_CHEM_COMP_TOR_VALUE);
                if (cacheValue(var, Entry.S_CHEM_COMP_TOR_VALUE))
                {
                    _chem_comp_tor_value_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_chem_comp_tor_value_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ CHEM_LINK ______ //
    public ChemLink[] _chem_link_list;
    public int chem_link_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_chem_link_list != null)
            {
                return _chem_link_list.length;
            }
            else
            {
                return getListSize(Entry.S_CHEM_LINK);
            }
        }

    public ChemLink[] get_chem_link_list()
        throws DataAccessException
        {
            ChemLink[] var = null;
            boolean allVarsRead = initEntry();
            if (_chem_link_list != null)
            {
                var = _chem_link_list;
            }
            else if ( ! allVarsRead)
            {
                var = (ChemLink[]) getList(Entry.S_CHEM_LINK);
                if (cacheValue(var, Entry.S_CHEM_LINK))
                {
                    _chem_link_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_chem_link_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ CHEM_LINK_ANGLE ______ //
    public ChemLinkAngle[] _chem_link_angle_list;
    public int chem_link_angle_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_chem_link_angle_list != null)
            {
                return _chem_link_angle_list.length;
            }
            else
            {
                return getListSize(Entry.S_CHEM_LINK_ANGLE);
            }
        }

    public ChemLinkAngle[] get_chem_link_angle_list()
        throws DataAccessException
        {
            ChemLinkAngle[] var = null;
            boolean allVarsRead = initEntry();
            if (_chem_link_angle_list != null)
            {
                var = _chem_link_angle_list;
            }
            else if ( ! allVarsRead)
            {
                var = (ChemLinkAngle[]) getList(Entry.S_CHEM_LINK_ANGLE);
                if (cacheValue(var, Entry.S_CHEM_LINK_ANGLE))
                {
                    _chem_link_angle_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_chem_link_angle_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ CHEM_LINK_BOND ______ //
    public ChemLinkBond[] _chem_link_bond_list;
    public int chem_link_bond_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_chem_link_bond_list != null)
            {
                return _chem_link_bond_list.length;
            }
            else
            {
                return getListSize(Entry.S_CHEM_LINK_BOND);
            }
        }

    public ChemLinkBond[] get_chem_link_bond_list()
        throws DataAccessException
        {
            ChemLinkBond[] var = null;
            boolean allVarsRead = initEntry();
            if (_chem_link_bond_list != null)
            {
                var = _chem_link_bond_list;
            }
            else if ( ! allVarsRead)
            {
                var = (ChemLinkBond[]) getList(Entry.S_CHEM_LINK_BOND);
                if (cacheValue(var, Entry.S_CHEM_LINK_BOND))
                {
                    _chem_link_bond_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_chem_link_bond_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ CHEM_LINK_CHIR ______ //
    public ChemLinkChir[] _chem_link_chir_list;
    public int chem_link_chir_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_chem_link_chir_list != null)
            {
                return _chem_link_chir_list.length;
            }
            else
            {
                return getListSize(Entry.S_CHEM_LINK_CHIR);
            }
        }

    public ChemLinkChir[] get_chem_link_chir_list()
        throws DataAccessException
        {
            ChemLinkChir[] var = null;
            boolean allVarsRead = initEntry();
            if (_chem_link_chir_list != null)
            {
                var = _chem_link_chir_list;
            }
            else if ( ! allVarsRead)
            {
                var = (ChemLinkChir[]) getList(Entry.S_CHEM_LINK_CHIR);
                if (cacheValue(var, Entry.S_CHEM_LINK_CHIR))
                {
                    _chem_link_chir_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_chem_link_chir_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ CHEM_LINK_CHIR_ATOM ______ //
    public ChemLinkChirAtom[] _chem_link_chir_atom_list;
    public int chem_link_chir_atom_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_chem_link_chir_atom_list != null)
            {
                return _chem_link_chir_atom_list.length;
            }
            else
            {
                return getListSize(Entry.S_CHEM_LINK_CHIR_ATOM);
            }
        }

    public ChemLinkChirAtom[] get_chem_link_chir_atom_list()
        throws DataAccessException
        {
            ChemLinkChirAtom[] var = null;
            boolean allVarsRead = initEntry();
            if (_chem_link_chir_atom_list != null)
            {
                var = _chem_link_chir_atom_list;
            }
            else if ( ! allVarsRead)
            {
                var = (ChemLinkChirAtom[]) getList(Entry.S_CHEM_LINK_CHIR_ATOM);
                if (cacheValue(var, Entry.S_CHEM_LINK_CHIR_ATOM))
                {
                    _chem_link_chir_atom_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_chem_link_chir_atom_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ CHEM_LINK_PLANE ______ //
    public ChemLinkPlane[] _chem_link_plane_list;
    public int chem_link_plane_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_chem_link_plane_list != null)
            {
                return _chem_link_plane_list.length;
            }
            else
            {
                return getListSize(Entry.S_CHEM_LINK_PLANE);
            }
        }

    public ChemLinkPlane[] get_chem_link_plane_list()
        throws DataAccessException
        {
            ChemLinkPlane[] var = null;
            boolean allVarsRead = initEntry();
            if (_chem_link_plane_list != null)
            {
                var = _chem_link_plane_list;
            }
            else if ( ! allVarsRead)
            {
                var = (ChemLinkPlane[]) getList(Entry.S_CHEM_LINK_PLANE);
                if (cacheValue(var, Entry.S_CHEM_LINK_PLANE))
                {
                    _chem_link_plane_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_chem_link_plane_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ CHEM_LINK_PLANE_ATOM ______ //
    public ChemLinkPlaneAtom[] _chem_link_plane_atom_list;
    public int chem_link_plane_atom_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_chem_link_plane_atom_list != null)
            {
                return _chem_link_plane_atom_list.length;
            }
            else
            {
                return getListSize(Entry.S_CHEM_LINK_PLANE_ATOM);
            }
        }

    public ChemLinkPlaneAtom[] get_chem_link_plane_atom_list()
        throws DataAccessException
        {
            ChemLinkPlaneAtom[] var = null;
            boolean allVarsRead = initEntry();
            if (_chem_link_plane_atom_list != null)
            {
                var = _chem_link_plane_atom_list;
            }
            else if ( ! allVarsRead)
            {
                var = (ChemLinkPlaneAtom[]) getList(Entry.S_CHEM_LINK_PLANE_ATOM);
                if (cacheValue(var, Entry.S_CHEM_LINK_PLANE_ATOM))
                {
                    _chem_link_plane_atom_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_chem_link_plane_atom_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ CHEM_LINK_TOR ______ //
    public ChemLinkTor[] _chem_link_tor_list;
    public int chem_link_tor_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_chem_link_tor_list != null)
            {
                return _chem_link_tor_list.length;
            }
            else
            {
                return getListSize(Entry.S_CHEM_LINK_TOR);
            }
        }

    public ChemLinkTor[] get_chem_link_tor_list()
        throws DataAccessException
        {
            ChemLinkTor[] var = null;
            boolean allVarsRead = initEntry();
            if (_chem_link_tor_list != null)
            {
                var = _chem_link_tor_list;
            }
            else if ( ! allVarsRead)
            {
                var = (ChemLinkTor[]) getList(Entry.S_CHEM_LINK_TOR);
                if (cacheValue(var, Entry.S_CHEM_LINK_TOR))
                {
                    _chem_link_tor_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_chem_link_tor_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ CHEM_LINK_TOR_VALUE ______ //
    public ChemLinkTorValue[] _chem_link_tor_value_list;
    public int chem_link_tor_value_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_chem_link_tor_value_list != null)
            {
                return _chem_link_tor_value_list.length;
            }
            else
            {
                return getListSize(Entry.S_CHEM_LINK_TOR_VALUE);
            }
        }

    public ChemLinkTorValue[] get_chem_link_tor_value_list()
        throws DataAccessException
        {
            ChemLinkTorValue[] var = null;
            boolean allVarsRead = initEntry();
            if (_chem_link_tor_value_list != null)
            {
                var = _chem_link_tor_value_list;
            }
            else if ( ! allVarsRead)
            {
                var = (ChemLinkTorValue[]) getList(Entry.S_CHEM_LINK_TOR_VALUE);
                if (cacheValue(var, Entry.S_CHEM_LINK_TOR_VALUE))
                {
                    _chem_link_tor_value_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_chem_link_tor_value_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ ENTITY ______ //
    public Entity[] _entity_list;
    public int entity_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_entity_list != null)
            {
                return _entity_list.length;
            }
            else
            {
                return getListSize(Entry.S_ENTITY);
            }
        }

    public Entity[] get_entity_list()
        throws DataAccessException
        {
            Entity[] var = null;
            boolean allVarsRead = initEntry();
            if (_entity_list != null)
            {
                var = _entity_list;
            }
            else if ( ! allVarsRead)
            {
                var = (Entity[]) getList(Entry.S_ENTITY);
                if (cacheValue(var, Entry.S_ENTITY))
                {
                    _entity_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_entity_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ ENTITY_KEYWORDS ______ //
    public EntityKeywords[] _entity_keywords_list;
    public int entity_keywords_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_entity_keywords_list != null)
            {
                return _entity_keywords_list.length;
            }
            else
            {
                return getListSize(Entry.S_ENTITY_KEYWORDS);
            }
        }

    public EntityKeywords[] get_entity_keywords_list()
        throws DataAccessException
        {
            EntityKeywords[] var = null;
            boolean allVarsRead = initEntry();
            if (_entity_keywords_list != null)
            {
                var = _entity_keywords_list;
            }
            else if ( ! allVarsRead)
            {
                var = (EntityKeywords[]) getList(Entry.S_ENTITY_KEYWORDS);
                if (cacheValue(var, Entry.S_ENTITY_KEYWORDS))
                {
                    _entity_keywords_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_entity_keywords_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ ENTITY_LINK ______ //
    public EntityLink[] _entity_link_list;
    public int entity_link_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_entity_link_list != null)
            {
                return _entity_link_list.length;
            }
            else
            {
                return getListSize(Entry.S_ENTITY_LINK);
            }
        }

    public EntityLink[] get_entity_link_list()
        throws DataAccessException
        {
            EntityLink[] var = null;
            boolean allVarsRead = initEntry();
            if (_entity_link_list != null)
            {
                var = _entity_link_list;
            }
            else if ( ! allVarsRead)
            {
                var = (EntityLink[]) getList(Entry.S_ENTITY_LINK);
                if (cacheValue(var, Entry.S_ENTITY_LINK))
                {
                    _entity_link_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_entity_link_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ ENTITY_NAME_COM ______ //
    public EntityNameCom[] _entity_name_com_list;
    public int entity_name_com_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_entity_name_com_list != null)
            {
                return _entity_name_com_list.length;
            }
            else
            {
                return getListSize(Entry.S_ENTITY_NAME_COM);
            }
        }

    public EntityNameCom[] get_entity_name_com_list()
        throws DataAccessException
        {
            EntityNameCom[] var = null;
            boolean allVarsRead = initEntry();
            if (_entity_name_com_list != null)
            {
                var = _entity_name_com_list;
            }
            else if ( ! allVarsRead)
            {
                var = (EntityNameCom[]) getList(Entry.S_ENTITY_NAME_COM);
                if (cacheValue(var, Entry.S_ENTITY_NAME_COM))
                {
                    _entity_name_com_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_entity_name_com_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ ENTITY_NAME_SYS ______ //
    public EntityNameSys[] _entity_name_sys_list;
    public int entity_name_sys_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_entity_name_sys_list != null)
            {
                return _entity_name_sys_list.length;
            }
            else
            {
                return getListSize(Entry.S_ENTITY_NAME_SYS);
            }
        }

    public EntityNameSys[] get_entity_name_sys_list()
        throws DataAccessException
        {
            EntityNameSys[] var = null;
            boolean allVarsRead = initEntry();
            if (_entity_name_sys_list != null)
            {
                var = _entity_name_sys_list;
            }
            else if ( ! allVarsRead)
            {
                var = (EntityNameSys[]) getList(Entry.S_ENTITY_NAME_SYS);
                if (cacheValue(var, Entry.S_ENTITY_NAME_SYS))
                {
                    _entity_name_sys_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_entity_name_sys_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ ENTITY_POLY ______ //
    public EntityPoly[] _entity_poly_list;
    public int entity_poly_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_entity_poly_list != null)
            {
                return _entity_poly_list.length;
            }
            else
            {
                return getListSize(Entry.S_ENTITY_POLY);
            }
        }

    public EntityPoly[] get_entity_poly_list()
        throws DataAccessException
        {
            EntityPoly[] var = null;
            boolean allVarsRead = initEntry();
            if (_entity_poly_list != null)
            {
                var = _entity_poly_list;
            }
            else if ( ! allVarsRead)
            {
                var = (EntityPoly[]) getList(Entry.S_ENTITY_POLY);
                if (cacheValue(var, Entry.S_ENTITY_POLY))
                {
                    _entity_poly_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_entity_poly_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ ENTITY_POLY_SEQ ______ //
    public EntityPolySeq[] _entity_poly_seq_list;
    public int entity_poly_seq_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_entity_poly_seq_list != null)
            {
                return _entity_poly_seq_list.length;
            }
            else
            {
                return getListSize(Entry.S_ENTITY_POLY_SEQ);
            }
        }

    public EntityPolySeq[] get_entity_poly_seq_list()
        throws DataAccessException
        {
            EntityPolySeq[] var = null;
            boolean allVarsRead = initEntry();
            if (_entity_poly_seq_list != null)
            {
                var = _entity_poly_seq_list;
            }
            else if ( ! allVarsRead)
            {
                var = (EntityPolySeq[]) getList(Entry.S_ENTITY_POLY_SEQ);
                if (cacheValue(var, Entry.S_ENTITY_POLY_SEQ))
                {
                    _entity_poly_seq_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_entity_poly_seq_list",
                    "Requested data not present");
            }
            return var;
        }

    public EntityPolySeq[] get_entity_poly_seq_block_n(int from, int to)
        throws DataAccessException
        {
            EntityPolySeq[] var = null;
            boolean allVarsRead = initEntry();
            if (_entity_poly_seq_list != null)
            {
                try
                {
                    var = new EntityPolySeq[to-from+1];
                    System.arraycopy(_entity_poly_seq_list, from,
                            var, 0, to-from+1);
                }
                catch (Exception e)
                {
                    throw new DataAccessException("get_entity_poly_seq_block_n",
                    "Requested block out of range");
                }
            }
            else if ( ! allVarsRead)
            {
                var = (EntityPolySeq[]) getListBlock(Entry.S_ENTITY_POLY_SEQ,
                    from, to);
            }
            if (var == null)
                {
                throw new DataAccessException("get_entity_poly_seq_block_n",
                    "Requested data not present");
                }
            return var;
        }

    // ______ ENTITY_SRC_GEN ______ //
    public EntitySrcGen[] _entity_src_gen_list;
    public int entity_src_gen_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_entity_src_gen_list != null)
            {
                return _entity_src_gen_list.length;
            }
            else
            {
                return getListSize(Entry.S_ENTITY_SRC_GEN);
            }
        }

    public EntitySrcGen[] get_entity_src_gen_list()
        throws DataAccessException
        {
            EntitySrcGen[] var = null;
            boolean allVarsRead = initEntry();
            if (_entity_src_gen_list != null)
            {
                var = _entity_src_gen_list;
            }
            else if ( ! allVarsRead)
            {
                var = (EntitySrcGen[]) getList(Entry.S_ENTITY_SRC_GEN);
                if (cacheValue(var, Entry.S_ENTITY_SRC_GEN))
                {
                    _entity_src_gen_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_entity_src_gen_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ ENTITY_SRC_NAT ______ //
    public EntitySrcNat[] _entity_src_nat_list;
    public int entity_src_nat_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_entity_src_nat_list != null)
            {
                return _entity_src_nat_list.length;
            }
            else
            {
                return getListSize(Entry.S_ENTITY_SRC_NAT);
            }
        }

    public EntitySrcNat[] get_entity_src_nat_list()
        throws DataAccessException
        {
            EntitySrcNat[] var = null;
            boolean allVarsRead = initEntry();
            if (_entity_src_nat_list != null)
            {
                var = _entity_src_nat_list;
            }
            else if ( ! allVarsRead)
            {
                var = (EntitySrcNat[]) getList(Entry.S_ENTITY_SRC_NAT);
                if (cacheValue(var, Entry.S_ENTITY_SRC_NAT))
                {
                    _entity_src_nat_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_entity_src_nat_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ PDBX_ENTITY_NAME ______ //
    public PdbxEntityName[] _pdbx_entity_name_list;
    public int pdbx_entity_name_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_pdbx_entity_name_list != null)
            {
                return _pdbx_entity_name_list.length;
            }
            else
            {
                return getListSize(Entry.S_PDBX_ENTITY_NAME);
            }
        }

    public PdbxEntityName[] get_pdbx_entity_name_list()
        throws DataAccessException
        {
            PdbxEntityName[] var = null;
            boolean allVarsRead = initEntry();
            if (_pdbx_entity_name_list != null)
            {
                var = _pdbx_entity_name_list;
            }
            else if ( ! allVarsRead)
            {
                var = (PdbxEntityName[]) getList(Entry.S_PDBX_ENTITY_NAME);
                if (cacheValue(var, Entry.S_PDBX_ENTITY_NAME))
                {
                    _pdbx_entity_name_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_pdbx_entity_name_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ PDBX_PRERELEASE_SEQ ______ //
    public PdbxPrereleaseSeq[] _pdbx_prerelease_seq_list;
    public int pdbx_prerelease_seq_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_pdbx_prerelease_seq_list != null)
            {
                return _pdbx_prerelease_seq_list.length;
            }
            else
            {
                return getListSize(Entry.S_PDBX_PRERELEASE_SEQ);
            }
        }

    public PdbxPrereleaseSeq[] get_pdbx_prerelease_seq_list()
        throws DataAccessException
        {
            PdbxPrereleaseSeq[] var = null;
            boolean allVarsRead = initEntry();
            if (_pdbx_prerelease_seq_list != null)
            {
                var = _pdbx_prerelease_seq_list;
            }
            else if ( ! allVarsRead)
            {
                var = (PdbxPrereleaseSeq[]) getList(Entry.S_PDBX_PRERELEASE_SEQ);
                if (cacheValue(var, Entry.S_PDBX_PRERELEASE_SEQ))
                {
                    _pdbx_prerelease_seq_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_pdbx_prerelease_seq_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ PDBX_POLY_SEQ_SCHEME ______ //
    public PdbxPolySeqScheme[] _pdbx_poly_seq_scheme_list;
    public int pdbx_poly_seq_scheme_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_pdbx_poly_seq_scheme_list != null)
            {
                return _pdbx_poly_seq_scheme_list.length;
            }
            else
            {
                return getListSize(Entry.S_PDBX_POLY_SEQ_SCHEME);
            }
        }

    public PdbxPolySeqScheme[] get_pdbx_poly_seq_scheme_list()
        throws DataAccessException
        {
            PdbxPolySeqScheme[] var = null;
            boolean allVarsRead = initEntry();
            if (_pdbx_poly_seq_scheme_list != null)
            {
                var = _pdbx_poly_seq_scheme_list;
            }
            else if ( ! allVarsRead)
            {
                var = (PdbxPolySeqScheme[]) getList(Entry.S_PDBX_POLY_SEQ_SCHEME);
                if (cacheValue(var, Entry.S_PDBX_POLY_SEQ_SCHEME))
                {
                    _pdbx_poly_seq_scheme_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_pdbx_poly_seq_scheme_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ PDBX_NONPOLY_SCHEME ______ //
    public PdbxNonpolyScheme[] _pdbx_nonpoly_scheme_list;
    public int pdbx_nonpoly_scheme_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_pdbx_nonpoly_scheme_list != null)
            {
                return _pdbx_nonpoly_scheme_list.length;
            }
            else
            {
                return getListSize(Entry.S_PDBX_NONPOLY_SCHEME);
            }
        }

    public PdbxNonpolyScheme[] get_pdbx_nonpoly_scheme_list()
        throws DataAccessException
        {
            PdbxNonpolyScheme[] var = null;
            boolean allVarsRead = initEntry();
            if (_pdbx_nonpoly_scheme_list != null)
            {
                var = _pdbx_nonpoly_scheme_list;
            }
            else if ( ! allVarsRead)
            {
                var = (PdbxNonpolyScheme[]) getList(Entry.S_PDBX_NONPOLY_SCHEME);
                if (cacheValue(var, Entry.S_PDBX_NONPOLY_SCHEME))
                {
                    _pdbx_nonpoly_scheme_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_pdbx_nonpoly_scheme_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ PDBX_ENTITY_ASSEMBLY ______ //
    public PdbxEntityAssembly[] _pdbx_entity_assembly_list;
    public int pdbx_entity_assembly_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_pdbx_entity_assembly_list != null)
            {
                return _pdbx_entity_assembly_list.length;
            }
            else
            {
                return getListSize(Entry.S_PDBX_ENTITY_ASSEMBLY);
            }
        }

    public PdbxEntityAssembly[] get_pdbx_entity_assembly_list()
        throws DataAccessException
        {
            PdbxEntityAssembly[] var = null;
            boolean allVarsRead = initEntry();
            if (_pdbx_entity_assembly_list != null)
            {
                var = _pdbx_entity_assembly_list;
            }
            else if ( ! allVarsRead)
            {
                var = (PdbxEntityAssembly[]) getList(Entry.S_PDBX_ENTITY_ASSEMBLY);
                if (cacheValue(var, Entry.S_PDBX_ENTITY_ASSEMBLY))
                {
                    _pdbx_entity_assembly_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_pdbx_entity_assembly_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ PDBX_ENTITY_SRC_SYN ______ //
    public PdbxEntitySrcSyn[] _pdbx_entity_src_syn_list;
    public int pdbx_entity_src_syn_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_pdbx_entity_src_syn_list != null)
            {
                return _pdbx_entity_src_syn_list.length;
            }
            else
            {
                return getListSize(Entry.S_PDBX_ENTITY_SRC_SYN);
            }
        }

    public PdbxEntitySrcSyn[] get_pdbx_entity_src_syn_list()
        throws DataAccessException
        {
            PdbxEntitySrcSyn[] var = null;
            boolean allVarsRead = initEntry();
            if (_pdbx_entity_src_syn_list != null)
            {
                var = _pdbx_entity_src_syn_list;
            }
            else if ( ! allVarsRead)
            {
                var = (PdbxEntitySrcSyn[]) getList(Entry.S_PDBX_ENTITY_SRC_SYN);
                if (cacheValue(var, Entry.S_PDBX_ENTITY_SRC_SYN))
                {
                    _pdbx_entity_src_syn_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_pdbx_entity_src_syn_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ ENTRY_LINK ______ //
    public EntryLink[] _entry_link_list;
    public int entry_link_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_entry_link_list != null)
            {
                return _entry_link_list.length;
            }
            else
            {
                return getListSize(Entry.S_ENTRY_LINK);
            }
        }

    public EntryLink[] get_entry_link_list()
        throws DataAccessException
        {
            EntryLink[] var = null;
            boolean allVarsRead = initEntry();
            if (_entry_link_list != null)
            {
                var = _entry_link_list;
            }
            else if ( ! allVarsRead)
            {
                var = (EntryLink[]) getList(Entry.S_ENTRY_LINK);
                if (cacheValue(var, Entry.S_ENTRY_LINK))
                {
                    _entry_link_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_entry_link_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ GEOM ______ //
    public Geom[] _geom_list;
    public int geom_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_geom_list != null)
            {
                return _geom_list.length;
            }
            else
            {
                return getListSize(Entry.S_GEOM);
            }
        }

    public Geom[] get_geom_list()
        throws DataAccessException
        {
            Geom[] var = null;
            boolean allVarsRead = initEntry();
            if (_geom_list != null)
            {
                var = _geom_list;
            }
            else if ( ! allVarsRead)
            {
                var = (Geom[]) getList(Entry.S_GEOM);
                if (cacheValue(var, Entry.S_GEOM))
                {
                    _geom_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_geom_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ GEOM_ANGLE ______ //
    public GeomAngle[] _geom_angle_list;
    public int geom_angle_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_geom_angle_list != null)
            {
                return _geom_angle_list.length;
            }
            else
            {
                return getListSize(Entry.S_GEOM_ANGLE);
            }
        }

    public GeomAngle[] get_geom_angle_list()
        throws DataAccessException
        {
            GeomAngle[] var = null;
            boolean allVarsRead = initEntry();
            if (_geom_angle_list != null)
            {
                var = _geom_angle_list;
            }
            else if ( ! allVarsRead)
            {
                var = (GeomAngle[]) getList(Entry.S_GEOM_ANGLE);
                if (cacheValue(var, Entry.S_GEOM_ANGLE))
                {
                    _geom_angle_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_geom_angle_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ GEOM_BOND ______ //
    public GeomBond[] _geom_bond_list;
    public int geom_bond_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_geom_bond_list != null)
            {
                return _geom_bond_list.length;
            }
            else
            {
                return getListSize(Entry.S_GEOM_BOND);
            }
        }

    public GeomBond[] get_geom_bond_list()
        throws DataAccessException
        {
            GeomBond[] var = null;
            boolean allVarsRead = initEntry();
            if (_geom_bond_list != null)
            {
                var = _geom_bond_list;
            }
            else if ( ! allVarsRead)
            {
                var = (GeomBond[]) getList(Entry.S_GEOM_BOND);
                if (cacheValue(var, Entry.S_GEOM_BOND))
                {
                    _geom_bond_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_geom_bond_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ GEOM_CONTACT ______ //
    public GeomContact[] _geom_contact_list;
    public int geom_contact_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_geom_contact_list != null)
            {
                return _geom_contact_list.length;
            }
            else
            {
                return getListSize(Entry.S_GEOM_CONTACT);
            }
        }

    public GeomContact[] get_geom_contact_list()
        throws DataAccessException
        {
            GeomContact[] var = null;
            boolean allVarsRead = initEntry();
            if (_geom_contact_list != null)
            {
                var = _geom_contact_list;
            }
            else if ( ! allVarsRead)
            {
                var = (GeomContact[]) getList(Entry.S_GEOM_CONTACT);
                if (cacheValue(var, Entry.S_GEOM_CONTACT))
                {
                    _geom_contact_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_geom_contact_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ GEOM_HBOND ______ //
    public GeomHbond[] _geom_hbond_list;
    public int geom_hbond_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_geom_hbond_list != null)
            {
                return _geom_hbond_list.length;
            }
            else
            {
                return getListSize(Entry.S_GEOM_HBOND);
            }
        }

    public GeomHbond[] get_geom_hbond_list()
        throws DataAccessException
        {
            GeomHbond[] var = null;
            boolean allVarsRead = initEntry();
            if (_geom_hbond_list != null)
            {
                var = _geom_hbond_list;
            }
            else if ( ! allVarsRead)
            {
                var = (GeomHbond[]) getList(Entry.S_GEOM_HBOND);
                if (cacheValue(var, Entry.S_GEOM_HBOND))
                {
                    _geom_hbond_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_geom_hbond_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ GEOM_TORSION ______ //
    public GeomTorsion[] _geom_torsion_list;
    public int geom_torsion_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_geom_torsion_list != null)
            {
                return _geom_torsion_list.length;
            }
            else
            {
                return getListSize(Entry.S_GEOM_TORSION);
            }
        }

    public GeomTorsion[] get_geom_torsion_list()
        throws DataAccessException
        {
            GeomTorsion[] var = null;
            boolean allVarsRead = initEntry();
            if (_geom_torsion_list != null)
            {
                var = _geom_torsion_list;
            }
            else if ( ! allVarsRead)
            {
                var = (GeomTorsion[]) getList(Entry.S_GEOM_TORSION);
                if (cacheValue(var, Entry.S_GEOM_TORSION))
                {
                    _geom_torsion_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_geom_torsion_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ STRUCT ______ //
    public Structure[] _structure_list;
    public int structure_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_structure_list != null)
            {
                return _structure_list.length;
            }
            else
            {
                return getListSize(Entry.S_STRUCTURE);
            }
        }

    public Structure[] get_structure_list()
        throws DataAccessException
        {
            Structure[] var = null;
            boolean allVarsRead = initEntry();
            if (_structure_list != null)
            {
                var = _structure_list;
            }
            else if ( ! allVarsRead)
            {
                var = (Structure[]) getList(Entry.S_STRUCTURE);
                if (cacheValue(var, Entry.S_STRUCTURE))
                {
                    _structure_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_structure_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ STRUCT_ASYM ______ //
    public StructAsym[] _struct_asym_list;
    public int struct_asym_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_struct_asym_list != null)
            {
                return _struct_asym_list.length;
            }
            else
            {
                return getListSize(Entry.S_STRUCT_ASYM);
            }
        }

    public StructAsym[] get_struct_asym_list()
        throws DataAccessException
        {
            StructAsym[] var = null;
            boolean allVarsRead = initEntry();
            if (_struct_asym_list != null)
            {
                var = _struct_asym_list;
            }
            else if ( ! allVarsRead)
            {
                var = (StructAsym[]) getList(Entry.S_STRUCT_ASYM);
                if (cacheValue(var, Entry.S_STRUCT_ASYM))
                {
                    _struct_asym_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_struct_asym_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ STRUCT_BIOL ______ //
    public StructBiol[] _struct_biol_list;
    public int struct_biol_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_struct_biol_list != null)
            {
                return _struct_biol_list.length;
            }
            else
            {
                return getListSize(Entry.S_STRUCT_BIOL);
            }
        }

    public StructBiol[] get_struct_biol_list()
        throws DataAccessException
        {
            StructBiol[] var = null;
            boolean allVarsRead = initEntry();
            if (_struct_biol_list != null)
            {
                var = _struct_biol_list;
            }
            else if ( ! allVarsRead)
            {
                var = (StructBiol[]) getList(Entry.S_STRUCT_BIOL);
                if (cacheValue(var, Entry.S_STRUCT_BIOL))
                {
                    _struct_biol_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_struct_biol_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ STRUCT_BIOL_GEN ______ //
    public StructBiolGen[] _struct_biol_gen_list;
    public int struct_biol_gen_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_struct_biol_gen_list != null)
            {
                return _struct_biol_gen_list.length;
            }
            else
            {
                return getListSize(Entry.S_STRUCT_BIOL_GEN);
            }
        }

    public StructBiolGen[] get_struct_biol_gen_list()
        throws DataAccessException
        {
            StructBiolGen[] var = null;
            boolean allVarsRead = initEntry();
            if (_struct_biol_gen_list != null)
            {
                var = _struct_biol_gen_list;
            }
            else if ( ! allVarsRead)
            {
                var = (StructBiolGen[]) getList(Entry.S_STRUCT_BIOL_GEN);
                if (cacheValue(var, Entry.S_STRUCT_BIOL_GEN))
                {
                    _struct_biol_gen_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_struct_biol_gen_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ STRUCT_BIOL_KEYWORDS ______ //
    public StructBiolKeywords[] _struct_biol_keywords_list;
    public int struct_biol_keywords_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_struct_biol_keywords_list != null)
            {
                return _struct_biol_keywords_list.length;
            }
            else
            {
                return getListSize(Entry.S_STRUCT_BIOL_KEYWORDS);
            }
        }

    public StructBiolKeywords[] get_struct_biol_keywords_list()
        throws DataAccessException
        {
            StructBiolKeywords[] var = null;
            boolean allVarsRead = initEntry();
            if (_struct_biol_keywords_list != null)
            {
                var = _struct_biol_keywords_list;
            }
            else if ( ! allVarsRead)
            {
                var = (StructBiolKeywords[]) getList(Entry.S_STRUCT_BIOL_KEYWORDS);
                if (cacheValue(var, Entry.S_STRUCT_BIOL_KEYWORDS))
                {
                    _struct_biol_keywords_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_struct_biol_keywords_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ STRUCT_BIOL_VIEW ______ //
    public StructBiolView[] _struct_biol_view_list;
    public int struct_biol_view_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_struct_biol_view_list != null)
            {
                return _struct_biol_view_list.length;
            }
            else
            {
                return getListSize(Entry.S_STRUCT_BIOL_VIEW);
            }
        }

    public StructBiolView[] get_struct_biol_view_list()
        throws DataAccessException
        {
            StructBiolView[] var = null;
            boolean allVarsRead = initEntry();
            if (_struct_biol_view_list != null)
            {
                var = _struct_biol_view_list;
            }
            else if ( ! allVarsRead)
            {
                var = (StructBiolView[]) getList(Entry.S_STRUCT_BIOL_VIEW);
                if (cacheValue(var, Entry.S_STRUCT_BIOL_VIEW))
                {
                    _struct_biol_view_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_struct_biol_view_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ STRUCT_CONF ______ //
    public StructConf[] _struct_conf_list;
    public int struct_conf_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_struct_conf_list != null)
            {
                return _struct_conf_list.length;
            }
            else
            {
                return getListSize(Entry.S_STRUCT_CONF);
            }
        }

    public StructConf[] get_struct_conf_list()
        throws DataAccessException
        {
            StructConf[] var = null;
            boolean allVarsRead = initEntry();
            if (_struct_conf_list != null)
            {
                var = _struct_conf_list;
            }
            else if ( ! allVarsRead)
            {
                var = (StructConf[]) getList(Entry.S_STRUCT_CONF);
                if (cacheValue(var, Entry.S_STRUCT_CONF))
                {
                    _struct_conf_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_struct_conf_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ STRUCT_CONF_TYPE ______ //
    public StructConfType[] _struct_conf_type_list;
    public int struct_conf_type_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_struct_conf_type_list != null)
            {
                return _struct_conf_type_list.length;
            }
            else
            {
                return getListSize(Entry.S_STRUCT_CONF_TYPE);
            }
        }

    public StructConfType[] get_struct_conf_type_list()
        throws DataAccessException
        {
            StructConfType[] var = null;
            boolean allVarsRead = initEntry();
            if (_struct_conf_type_list != null)
            {
                var = _struct_conf_type_list;
            }
            else if ( ! allVarsRead)
            {
                var = (StructConfType[]) getList(Entry.S_STRUCT_CONF_TYPE);
                if (cacheValue(var, Entry.S_STRUCT_CONF_TYPE))
                {
                    _struct_conf_type_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_struct_conf_type_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ STRUCT_CONN ______ //
    public StructConn[] _struct_conn_list;
    public int struct_conn_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_struct_conn_list != null)
            {
                return _struct_conn_list.length;
            }
            else
            {
                return getListSize(Entry.S_STRUCT_CONN);
            }
        }

    public StructConn[] get_struct_conn_list()
        throws DataAccessException
        {
            StructConn[] var = null;
            boolean allVarsRead = initEntry();
            if (_struct_conn_list != null)
            {
                var = _struct_conn_list;
            }
            else if ( ! allVarsRead)
            {
                var = (StructConn[]) getList(Entry.S_STRUCT_CONN);
                if (cacheValue(var, Entry.S_STRUCT_CONN))
                {
                    _struct_conn_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_struct_conn_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ STRUCT_CONN_TYPE ______ //
    public StructConnType[] _struct_conn_type_list;
    public int struct_conn_type_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_struct_conn_type_list != null)
            {
                return _struct_conn_type_list.length;
            }
            else
            {
                return getListSize(Entry.S_STRUCT_CONN_TYPE);
            }
        }

    public StructConnType[] get_struct_conn_type_list()
        throws DataAccessException
        {
            StructConnType[] var = null;
            boolean allVarsRead = initEntry();
            if (_struct_conn_type_list != null)
            {
                var = _struct_conn_type_list;
            }
            else if ( ! allVarsRead)
            {
                var = (StructConnType[]) getList(Entry.S_STRUCT_CONN_TYPE);
                if (cacheValue(var, Entry.S_STRUCT_CONN_TYPE))
                {
                    _struct_conn_type_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_struct_conn_type_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ STRUCT_KEYWORDS ______ //
    public StructKeywords[] _struct_keywords_list;
    public int struct_keywords_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_struct_keywords_list != null)
            {
                return _struct_keywords_list.length;
            }
            else
            {
                return getListSize(Entry.S_STRUCT_KEYWORDS);
            }
        }

    public StructKeywords[] get_struct_keywords_list()
        throws DataAccessException
        {
            StructKeywords[] var = null;
            boolean allVarsRead = initEntry();
            if (_struct_keywords_list != null)
            {
                var = _struct_keywords_list;
            }
            else if ( ! allVarsRead)
            {
                var = (StructKeywords[]) getList(Entry.S_STRUCT_KEYWORDS);
                if (cacheValue(var, Entry.S_STRUCT_KEYWORDS))
                {
                    _struct_keywords_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_struct_keywords_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ STRUCT_MON_DETAILS ______ //
    public StructMonDetails[] _struct_mon_details_list;
    public int struct_mon_details_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_struct_mon_details_list != null)
            {
                return _struct_mon_details_list.length;
            }
            else
            {
                return getListSize(Entry.S_STRUCT_MON_DETAILS);
            }
        }

    public StructMonDetails[] get_struct_mon_details_list()
        throws DataAccessException
        {
            StructMonDetails[] var = null;
            boolean allVarsRead = initEntry();
            if (_struct_mon_details_list != null)
            {
                var = _struct_mon_details_list;
            }
            else if ( ! allVarsRead)
            {
                var = (StructMonDetails[]) getList(Entry.S_STRUCT_MON_DETAILS);
                if (cacheValue(var, Entry.S_STRUCT_MON_DETAILS))
                {
                    _struct_mon_details_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_struct_mon_details_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ STRUCT_MON_NUCL ______ //
    public StructMonNucl[] _struct_mon_nucl_list;
    public int struct_mon_nucl_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_struct_mon_nucl_list != null)
            {
                return _struct_mon_nucl_list.length;
            }
            else
            {
                return getListSize(Entry.S_STRUCT_MON_NUCL);
            }
        }

    public StructMonNucl[] get_struct_mon_nucl_list()
        throws DataAccessException
        {
            StructMonNucl[] var = null;
            boolean allVarsRead = initEntry();
            if (_struct_mon_nucl_list != null)
            {
                var = _struct_mon_nucl_list;
            }
            else if ( ! allVarsRead)
            {
                var = (StructMonNucl[]) getList(Entry.S_STRUCT_MON_NUCL);
                if (cacheValue(var, Entry.S_STRUCT_MON_NUCL))
                {
                    _struct_mon_nucl_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_struct_mon_nucl_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ STRUCT_MON_PROT ______ //
    public StructMonProt[] _struct_mon_prot_list;
    public int struct_mon_prot_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_struct_mon_prot_list != null)
            {
                return _struct_mon_prot_list.length;
            }
            else
            {
                return getListSize(Entry.S_STRUCT_MON_PROT);
            }
        }

    public StructMonProt[] get_struct_mon_prot_list()
        throws DataAccessException
        {
            StructMonProt[] var = null;
            boolean allVarsRead = initEntry();
            if (_struct_mon_prot_list != null)
            {
                var = _struct_mon_prot_list;
            }
            else if ( ! allVarsRead)
            {
                var = (StructMonProt[]) getList(Entry.S_STRUCT_MON_PROT);
                if (cacheValue(var, Entry.S_STRUCT_MON_PROT))
                {
                    _struct_mon_prot_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_struct_mon_prot_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ STRUCT_MON_PROT_CIS ______ //
    public StructMonProtCis[] _struct_mon_prot_cis_list;
    public int struct_mon_prot_cis_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_struct_mon_prot_cis_list != null)
            {
                return _struct_mon_prot_cis_list.length;
            }
            else
            {
                return getListSize(Entry.S_STRUCT_MON_PROT_CIS);
            }
        }

    public StructMonProtCis[] get_struct_mon_prot_cis_list()
        throws DataAccessException
        {
            StructMonProtCis[] var = null;
            boolean allVarsRead = initEntry();
            if (_struct_mon_prot_cis_list != null)
            {
                var = _struct_mon_prot_cis_list;
            }
            else if ( ! allVarsRead)
            {
                var = (StructMonProtCis[]) getList(Entry.S_STRUCT_MON_PROT_CIS);
                if (cacheValue(var, Entry.S_STRUCT_MON_PROT_CIS))
                {
                    _struct_mon_prot_cis_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_struct_mon_prot_cis_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ STRUCT_NCS_DOM ______ //
    public StructNcsDom[] _struct_ncs_dom_list;
    public int struct_ncs_dom_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_struct_ncs_dom_list != null)
            {
                return _struct_ncs_dom_list.length;
            }
            else
            {
                return getListSize(Entry.S_STRUCT_NCS_DOM);
            }
        }

    public StructNcsDom[] get_struct_ncs_dom_list()
        throws DataAccessException
        {
            StructNcsDom[] var = null;
            boolean allVarsRead = initEntry();
            if (_struct_ncs_dom_list != null)
            {
                var = _struct_ncs_dom_list;
            }
            else if ( ! allVarsRead)
            {
                var = (StructNcsDom[]) getList(Entry.S_STRUCT_NCS_DOM);
                if (cacheValue(var, Entry.S_STRUCT_NCS_DOM))
                {
                    _struct_ncs_dom_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_struct_ncs_dom_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ STRUCT_NCS_DOM_LIM ______ //
    public StructNcsDomLim[] _struct_ncs_dom_lim_list;
    public int struct_ncs_dom_lim_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_struct_ncs_dom_lim_list != null)
            {
                return _struct_ncs_dom_lim_list.length;
            }
            else
            {
                return getListSize(Entry.S_STRUCT_NCS_DOM_LIM);
            }
        }

    public StructNcsDomLim[] get_struct_ncs_dom_lim_list()
        throws DataAccessException
        {
            StructNcsDomLim[] var = null;
            boolean allVarsRead = initEntry();
            if (_struct_ncs_dom_lim_list != null)
            {
                var = _struct_ncs_dom_lim_list;
            }
            else if ( ! allVarsRead)
            {
                var = (StructNcsDomLim[]) getList(Entry.S_STRUCT_NCS_DOM_LIM);
                if (cacheValue(var, Entry.S_STRUCT_NCS_DOM_LIM))
                {
                    _struct_ncs_dom_lim_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_struct_ncs_dom_lim_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ STRUCT_NCS_ENS ______ //
    public StructNcsEns[] _struct_ncs_ens_list;
    public int struct_ncs_ens_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_struct_ncs_ens_list != null)
            {
                return _struct_ncs_ens_list.length;
            }
            else
            {
                return getListSize(Entry.S_STRUCT_NCS_ENS);
            }
        }

    public StructNcsEns[] get_struct_ncs_ens_list()
        throws DataAccessException
        {
            StructNcsEns[] var = null;
            boolean allVarsRead = initEntry();
            if (_struct_ncs_ens_list != null)
            {
                var = _struct_ncs_ens_list;
            }
            else if ( ! allVarsRead)
            {
                var = (StructNcsEns[]) getList(Entry.S_STRUCT_NCS_ENS);
                if (cacheValue(var, Entry.S_STRUCT_NCS_ENS))
                {
                    _struct_ncs_ens_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_struct_ncs_ens_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ STRUCT_NCS_ENS_GEN ______ //
    public StructNcsEnsGen[] _struct_ncs_ens_gen_list;
    public int struct_ncs_ens_gen_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_struct_ncs_ens_gen_list != null)
            {
                return _struct_ncs_ens_gen_list.length;
            }
            else
            {
                return getListSize(Entry.S_STRUCT_NCS_ENS_GEN);
            }
        }

    public StructNcsEnsGen[] get_struct_ncs_ens_gen_list()
        throws DataAccessException
        {
            StructNcsEnsGen[] var = null;
            boolean allVarsRead = initEntry();
            if (_struct_ncs_ens_gen_list != null)
            {
                var = _struct_ncs_ens_gen_list;
            }
            else if ( ! allVarsRead)
            {
                var = (StructNcsEnsGen[]) getList(Entry.S_STRUCT_NCS_ENS_GEN);
                if (cacheValue(var, Entry.S_STRUCT_NCS_ENS_GEN))
                {
                    _struct_ncs_ens_gen_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_struct_ncs_ens_gen_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ STRUCT_NCS_OPER ______ //
    public StructNcsOper[] _struct_ncs_oper_list;
    public int struct_ncs_oper_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_struct_ncs_oper_list != null)
            {
                return _struct_ncs_oper_list.length;
            }
            else
            {
                return getListSize(Entry.S_STRUCT_NCS_OPER);
            }
        }

    public StructNcsOper[] get_struct_ncs_oper_list()
        throws DataAccessException
        {
            StructNcsOper[] var = null;
            boolean allVarsRead = initEntry();
            if (_struct_ncs_oper_list != null)
            {
                var = _struct_ncs_oper_list;
            }
            else if ( ! allVarsRead)
            {
                var = (StructNcsOper[]) getList(Entry.S_STRUCT_NCS_OPER);
                if (cacheValue(var, Entry.S_STRUCT_NCS_OPER))
                {
                    _struct_ncs_oper_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_struct_ncs_oper_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ STRUCT_REF ______ //
    public StructRef[] _struct_ref_list;
    public int struct_ref_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_struct_ref_list != null)
            {
                return _struct_ref_list.length;
            }
            else
            {
                return getListSize(Entry.S_STRUCT_REF);
            }
        }

    public StructRef[] get_struct_ref_list()
        throws DataAccessException
        {
            StructRef[] var = null;
            boolean allVarsRead = initEntry();
            if (_struct_ref_list != null)
            {
                var = _struct_ref_list;
            }
            else if ( ! allVarsRead)
            {
                var = (StructRef[]) getList(Entry.S_STRUCT_REF);
                if (cacheValue(var, Entry.S_STRUCT_REF))
                {
                    _struct_ref_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_struct_ref_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ STRUCT_REF_SEQ ______ //
    public StructRefSeq[] _struct_ref_seq_list;
    public int struct_ref_seq_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_struct_ref_seq_list != null)
            {
                return _struct_ref_seq_list.length;
            }
            else
            {
                return getListSize(Entry.S_STRUCT_REF_SEQ);
            }
        }

    public StructRefSeq[] get_struct_ref_seq_list()
        throws DataAccessException
        {
            StructRefSeq[] var = null;
            boolean allVarsRead = initEntry();
            if (_struct_ref_seq_list != null)
            {
                var = _struct_ref_seq_list;
            }
            else if ( ! allVarsRead)
            {
                var = (StructRefSeq[]) getList(Entry.S_STRUCT_REF_SEQ);
                if (cacheValue(var, Entry.S_STRUCT_REF_SEQ))
                {
                    _struct_ref_seq_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_struct_ref_seq_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ STRUCT_REF_SEQ_DIF ______ //
    public StructRefSeqDif[] _struct_ref_seq_dif_list;
    public int struct_ref_seq_dif_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_struct_ref_seq_dif_list != null)
            {
                return _struct_ref_seq_dif_list.length;
            }
            else
            {
                return getListSize(Entry.S_STRUCT_REF_SEQ_DIF);
            }
        }

    public StructRefSeqDif[] get_struct_ref_seq_dif_list()
        throws DataAccessException
        {
            StructRefSeqDif[] var = null;
            boolean allVarsRead = initEntry();
            if (_struct_ref_seq_dif_list != null)
            {
                var = _struct_ref_seq_dif_list;
            }
            else if ( ! allVarsRead)
            {
                var = (StructRefSeqDif[]) getList(Entry.S_STRUCT_REF_SEQ_DIF);
                if (cacheValue(var, Entry.S_STRUCT_REF_SEQ_DIF))
                {
                    _struct_ref_seq_dif_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_struct_ref_seq_dif_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ STRUCT_SHEET ______ //
    public StructSheet[] _struct_sheet_list;
    public int struct_sheet_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_struct_sheet_list != null)
            {
                return _struct_sheet_list.length;
            }
            else
            {
                return getListSize(Entry.S_STRUCT_SHEET);
            }
        }

    public StructSheet[] get_struct_sheet_list()
        throws DataAccessException
        {
            StructSheet[] var = null;
            boolean allVarsRead = initEntry();
            if (_struct_sheet_list != null)
            {
                var = _struct_sheet_list;
            }
            else if ( ! allVarsRead)
            {
                var = (StructSheet[]) getList(Entry.S_STRUCT_SHEET);
                if (cacheValue(var, Entry.S_STRUCT_SHEET))
                {
                    _struct_sheet_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_struct_sheet_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ STRUCT_SHEET_HBOND ______ //
    public StructSheetHbond[] _struct_sheet_hbond_list;
    public int struct_sheet_hbond_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_struct_sheet_hbond_list != null)
            {
                return _struct_sheet_hbond_list.length;
            }
            else
            {
                return getListSize(Entry.S_STRUCT_SHEET_HBOND);
            }
        }

    public StructSheetHbond[] get_struct_sheet_hbond_list()
        throws DataAccessException
        {
            StructSheetHbond[] var = null;
            boolean allVarsRead = initEntry();
            if (_struct_sheet_hbond_list != null)
            {
                var = _struct_sheet_hbond_list;
            }
            else if ( ! allVarsRead)
            {
                var = (StructSheetHbond[]) getList(Entry.S_STRUCT_SHEET_HBOND);
                if (cacheValue(var, Entry.S_STRUCT_SHEET_HBOND))
                {
                    _struct_sheet_hbond_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_struct_sheet_hbond_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ PDBX_STRUCT_SHEET_HBOND ______ //
    public PdbxStructSheetHbond[] _pdbx_struct_sheet_hbond_list;
    public int pdbx_struct_sheet_hbond_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_pdbx_struct_sheet_hbond_list != null)
            {
                return _pdbx_struct_sheet_hbond_list.length;
            }
            else
            {
                return getListSize(Entry.S_PDBX_STRUCT_SHEET_HBOND);
            }
        }

    public PdbxStructSheetHbond[] get_pdbx_struct_sheet_hbond_list()
        throws DataAccessException
        {
            PdbxStructSheetHbond[] var = null;
            boolean allVarsRead = initEntry();
            if (_pdbx_struct_sheet_hbond_list != null)
            {
                var = _pdbx_struct_sheet_hbond_list;
            }
            else if ( ! allVarsRead)
            {
                var = (PdbxStructSheetHbond[]) getList(Entry.S_PDBX_STRUCT_SHEET_HBOND);
                if (cacheValue(var, Entry.S_PDBX_STRUCT_SHEET_HBOND))
                {
                    _pdbx_struct_sheet_hbond_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_pdbx_struct_sheet_hbond_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ STRUCT_SHEET_ORDER ______ //
    public StructSheetOrder[] _struct_sheet_order_list;
    public int struct_sheet_order_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_struct_sheet_order_list != null)
            {
                return _struct_sheet_order_list.length;
            }
            else
            {
                return getListSize(Entry.S_STRUCT_SHEET_ORDER);
            }
        }

    public StructSheetOrder[] get_struct_sheet_order_list()
        throws DataAccessException
        {
            StructSheetOrder[] var = null;
            boolean allVarsRead = initEntry();
            if (_struct_sheet_order_list != null)
            {
                var = _struct_sheet_order_list;
            }
            else if ( ! allVarsRead)
            {
                var = (StructSheetOrder[]) getList(Entry.S_STRUCT_SHEET_ORDER);
                if (cacheValue(var, Entry.S_STRUCT_SHEET_ORDER))
                {
                    _struct_sheet_order_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_struct_sheet_order_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ STRUCT_SHEET_RANGE ______ //
    public StructSheetRange[] _struct_sheet_range_list;
    public int struct_sheet_range_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_struct_sheet_range_list != null)
            {
                return _struct_sheet_range_list.length;
            }
            else
            {
                return getListSize(Entry.S_STRUCT_SHEET_RANGE);
            }
        }

    public StructSheetRange[] get_struct_sheet_range_list()
        throws DataAccessException
        {
            StructSheetRange[] var = null;
            boolean allVarsRead = initEntry();
            if (_struct_sheet_range_list != null)
            {
                var = _struct_sheet_range_list;
            }
            else if ( ! allVarsRead)
            {
                var = (StructSheetRange[]) getList(Entry.S_STRUCT_SHEET_RANGE);
                if (cacheValue(var, Entry.S_STRUCT_SHEET_RANGE))
                {
                    _struct_sheet_range_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_struct_sheet_range_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ STRUCT_SHEET_TOPOLOGY ______ //
    public StructSheetTopology[] _struct_sheet_topology_list;
    public int struct_sheet_topology_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_struct_sheet_topology_list != null)
            {
                return _struct_sheet_topology_list.length;
            }
            else
            {
                return getListSize(Entry.S_STRUCT_SHEET_TOPOLOGY);
            }
        }

    public StructSheetTopology[] get_struct_sheet_topology_list()
        throws DataAccessException
        {
            StructSheetTopology[] var = null;
            boolean allVarsRead = initEntry();
            if (_struct_sheet_topology_list != null)
            {
                var = _struct_sheet_topology_list;
            }
            else if ( ! allVarsRead)
            {
                var = (StructSheetTopology[]) getList(Entry.S_STRUCT_SHEET_TOPOLOGY);
                if (cacheValue(var, Entry.S_STRUCT_SHEET_TOPOLOGY))
                {
                    _struct_sheet_topology_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_struct_sheet_topology_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ STRUCT_SITE ______ //
    public StructSite[] _struct_site_list;
    public int struct_site_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_struct_site_list != null)
            {
                return _struct_site_list.length;
            }
            else
            {
                return getListSize(Entry.S_STRUCT_SITE);
            }
        }

    public StructSite[] get_struct_site_list()
        throws DataAccessException
        {
            StructSite[] var = null;
            boolean allVarsRead = initEntry();
            if (_struct_site_list != null)
            {
                var = _struct_site_list;
            }
            else if ( ! allVarsRead)
            {
                var = (StructSite[]) getList(Entry.S_STRUCT_SITE);
                if (cacheValue(var, Entry.S_STRUCT_SITE))
                {
                    _struct_site_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_struct_site_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ STRUCT_SITE_GEN ______ //
    public StructSiteGen[] _struct_site_gen_list;
    public int struct_site_gen_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_struct_site_gen_list != null)
            {
                return _struct_site_gen_list.length;
            }
            else
            {
                return getListSize(Entry.S_STRUCT_SITE_GEN);
            }
        }

    public StructSiteGen[] get_struct_site_gen_list()
        throws DataAccessException
        {
            StructSiteGen[] var = null;
            boolean allVarsRead = initEntry();
            if (_struct_site_gen_list != null)
            {
                var = _struct_site_gen_list;
            }
            else if ( ! allVarsRead)
            {
                var = (StructSiteGen[]) getList(Entry.S_STRUCT_SITE_GEN);
                if (cacheValue(var, Entry.S_STRUCT_SITE_GEN))
                {
                    _struct_site_gen_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_struct_site_gen_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ STRUCT_SITE_KEYWORDS ______ //
    public StructSiteKeywords[] _struct_site_keywords_list;
    public int struct_site_keywords_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_struct_site_keywords_list != null)
            {
                return _struct_site_keywords_list.length;
            }
            else
            {
                return getListSize(Entry.S_STRUCT_SITE_KEYWORDS);
            }
        }

    public StructSiteKeywords[] get_struct_site_keywords_list()
        throws DataAccessException
        {
            StructSiteKeywords[] var = null;
            boolean allVarsRead = initEntry();
            if (_struct_site_keywords_list != null)
            {
                var = _struct_site_keywords_list;
            }
            else if ( ! allVarsRead)
            {
                var = (StructSiteKeywords[]) getList(Entry.S_STRUCT_SITE_KEYWORDS);
                if (cacheValue(var, Entry.S_STRUCT_SITE_KEYWORDS))
                {
                    _struct_site_keywords_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_struct_site_keywords_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ STRUCT_SITE_VIEW ______ //
    public StructSiteView[] _struct_site_view_list;
    public int struct_site_view_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_struct_site_view_list != null)
            {
                return _struct_site_view_list.length;
            }
            else
            {
                return getListSize(Entry.S_STRUCT_SITE_VIEW);
            }
        }

    public StructSiteView[] get_struct_site_view_list()
        throws DataAccessException
        {
            StructSiteView[] var = null;
            boolean allVarsRead = initEntry();
            if (_struct_site_view_list != null)
            {
                var = _struct_site_view_list;
            }
            else if ( ! allVarsRead)
            {
                var = (StructSiteView[]) getList(Entry.S_STRUCT_SITE_VIEW);
                if (cacheValue(var, Entry.S_STRUCT_SITE_VIEW))
                {
                    _struct_site_view_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_struct_site_view_list",
                    "Requested data not present");
            }
            return var;
        }

    }
