//
// **** DERIVED FILE - DO NOT EDIT ****
//
// Copyright 2003 The Regents of the University of California
// All Rights Reserved
//
// OpenMMS was developed by Dr. Douglas S. Greer at the San Diego
// Supercomputer Center, a research unit of the University of California,
// San Diego.  Support for this effort was provided by NSF through the
// Protein Data Bank (Grant DBI-9814284) and the National Partnership for
// Advanced Computational Infrastructure (Grant ACI-9619020)
//
// Permission to use, copy, modify and distribute any part of OpenMMS for
// educational, research and non-profit purposes, without fee, and
// without a written agreement is hereby granted, provided that the above
// copyright notice, this paragraph and the following paragraphs appear
// in all copies.
//
// Those desiring to incorporate this OpenMMS into commercial products or
// use for commercial purposes should contact the Technology Transfer
// Office, University of California, San Diego, 9500 Gilman Drive, La
// Jolla, CA 92093-0910, Ph: (619) 534-5815, FAX: (619) 534-7345.
//
// In no event shall the University of California be liable to any party
// for direct, indirect, special, incidental, or consequential damages,
// including lost profits, arising out of the use of this OpenMMS, even
// if the University of California has been advised of the possibility of
// such damage.
//
// The OpenMMS provided herein is on an "as is" basis, and the
// University of California has no obligation to provide maintenance,
// support, updates, enhancements, or modifications.  The University of
// California makes no representations and extends no warranties of any
// kind, either implied or express, including, but not limited to, the
// implied warranties of merchantability or fitness for a particular
// purpose, or that the use of the OpenMMS will not infringe any patent,
// trademark or other rights.

package org.rcsb.openmms.loader;

import java.util.*;
import org.omg.DsLSRMacromolecularStructure.*;
import org.omg.DsLSRMmsReference.*;
import org.omg.DsLSRXRayCrystallography.*;
import org.omg.DsLSRNmr.*;

/**
 * The Entry/Subentry classes contain the arrays of data structures
 * that store all of the information known about a particular entry
 * (i.e. an MMS structure) as well as the methods for accessing
 * those data structures.
 * <p>
 * Generated by the program MMSExpr. Model: Std, Revision: 3.0
 * <p>
 * Date: Tue Jul 29 17:48:42 PDT 2003
 *
 * @author Douglas S. Greer
 * @version OpenMMS Release V_1_5_1
 */
public abstract class MmsReferenceEntryMethodImpl
     extends MmsReferenceEntryPOA
    {
    public MmsReferenceEntryMethodImpl()
        {
        }

    abstract public boolean initEntry()
            throws DataAccessException;
    abstract public Object[] getList(int sFlag)
            throws DataAccessException;
    abstract public int getListSize(int sFlag)
            throws DataAccessException;
    abstract public Object[] getListBlock(int sFlag, int from, int to)
            throws DataAccessException;
    abstract public boolean cacheValue(Object[] var, int sFlag)
            throws DataAccessException;

    public byte[] _presence_flags
            = new byte[(MmsReferenceEntry.MAX_FLAG/8)+1];

    // ______ CITATION ______ //
    public Citation[] _citation_list;
    public int citation_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_citation_list != null)
            {
                return _citation_list.length;
            }
            else
            {
                return getListSize(MmsReferenceEntry.S_CITATION);
            }
        }

    public Citation[] get_citation_list()
        throws DataAccessException
        {
            Citation[] var = null;
            boolean allVarsRead = initEntry();
            if (_citation_list != null)
            {
                var = _citation_list;
            }
            else if ( ! allVarsRead)
            {
                var = (Citation[]) getList(MmsReferenceEntry.S_CITATION);
                if (cacheValue(var, MmsReferenceEntry.S_CITATION))
                {
                    _citation_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_citation_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ CITATION_AUTHOR ______ //
    public CitationAuthor[] _citation_author_list;
    public int citation_author_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_citation_author_list != null)
            {
                return _citation_author_list.length;
            }
            else
            {
                return getListSize(MmsReferenceEntry.S_CITATION_AUTHOR);
            }
        }

    public CitationAuthor[] get_citation_author_list()
        throws DataAccessException
        {
            CitationAuthor[] var = null;
            boolean allVarsRead = initEntry();
            if (_citation_author_list != null)
            {
                var = _citation_author_list;
            }
            else if ( ! allVarsRead)
            {
                var = (CitationAuthor[]) getList(MmsReferenceEntry.S_CITATION_AUTHOR);
                if (cacheValue(var, MmsReferenceEntry.S_CITATION_AUTHOR))
                {
                    _citation_author_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_citation_author_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ CITATION_EDITOR ______ //
    public CitationEditor[] _citation_editor_list;
    public int citation_editor_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_citation_editor_list != null)
            {
                return _citation_editor_list.length;
            }
            else
            {
                return getListSize(MmsReferenceEntry.S_CITATION_EDITOR);
            }
        }

    public CitationEditor[] get_citation_editor_list()
        throws DataAccessException
        {
            CitationEditor[] var = null;
            boolean allVarsRead = initEntry();
            if (_citation_editor_list != null)
            {
                var = _citation_editor_list;
            }
            else if ( ! allVarsRead)
            {
                var = (CitationEditor[]) getList(MmsReferenceEntry.S_CITATION_EDITOR);
                if (cacheValue(var, MmsReferenceEntry.S_CITATION_EDITOR))
                {
                    _citation_editor_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_citation_editor_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ DATABASE_2 ______ //
    public Database[] _database_list;
    public int database_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_database_list != null)
            {
                return _database_list.length;
            }
            else
            {
                return getListSize(MmsReferenceEntry.S_DATABASE);
            }
        }

    public Database[] get_database_list()
        throws DataAccessException
        {
            Database[] var = null;
            boolean allVarsRead = initEntry();
            if (_database_list != null)
            {
                var = _database_list;
            }
            else if ( ! allVarsRead)
            {
                var = (Database[]) getList(MmsReferenceEntry.S_DATABASE);
                if (cacheValue(var, MmsReferenceEntry.S_DATABASE))
                {
                    _database_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_database_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ DATABASE_PDB_CAVEAT ______ //
    public DatabasePdbCaveat[] _database_pdb_caveat_list;
    public int database_pdb_caveat_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_database_pdb_caveat_list != null)
            {
                return _database_pdb_caveat_list.length;
            }
            else
            {
                return getListSize(MmsReferenceEntry.S_DATABASE_PDB_CAVEAT);
            }
        }

    public DatabasePdbCaveat[] get_database_pdb_caveat_list()
        throws DataAccessException
        {
            DatabasePdbCaveat[] var = null;
            boolean allVarsRead = initEntry();
            if (_database_pdb_caveat_list != null)
            {
                var = _database_pdb_caveat_list;
            }
            else if ( ! allVarsRead)
            {
                var = (DatabasePdbCaveat[]) getList(MmsReferenceEntry.S_DATABASE_PDB_CAVEAT);
                if (cacheValue(var, MmsReferenceEntry.S_DATABASE_PDB_CAVEAT))
                {
                    _database_pdb_caveat_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_database_pdb_caveat_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ DATABASE_PDB_MATRIX ______ //
    public DatabasePdbMatrix[] _database_pdb_matrix_list;
    public int database_pdb_matrix_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_database_pdb_matrix_list != null)
            {
                return _database_pdb_matrix_list.length;
            }
            else
            {
                return getListSize(MmsReferenceEntry.S_DATABASE_PDB_MATRIX);
            }
        }

    public DatabasePdbMatrix[] get_database_pdb_matrix_list()
        throws DataAccessException
        {
            DatabasePdbMatrix[] var = null;
            boolean allVarsRead = initEntry();
            if (_database_pdb_matrix_list != null)
            {
                var = _database_pdb_matrix_list;
            }
            else if ( ! allVarsRead)
            {
                var = (DatabasePdbMatrix[]) getList(MmsReferenceEntry.S_DATABASE_PDB_MATRIX);
                if (cacheValue(var, MmsReferenceEntry.S_DATABASE_PDB_MATRIX))
                {
                    _database_pdb_matrix_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_database_pdb_matrix_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ DATABASE_PDB_REMARK ______ //
    public DatabasePdbRemark[] _database_pdb_remark_list;
    public int database_pdb_remark_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_database_pdb_remark_list != null)
            {
                return _database_pdb_remark_list.length;
            }
            else
            {
                return getListSize(MmsReferenceEntry.S_DATABASE_PDB_REMARK);
            }
        }

    public DatabasePdbRemark[] get_database_pdb_remark_list()
        throws DataAccessException
        {
            DatabasePdbRemark[] var = null;
            boolean allVarsRead = initEntry();
            if (_database_pdb_remark_list != null)
            {
                var = _database_pdb_remark_list;
            }
            else if ( ! allVarsRead)
            {
                var = (DatabasePdbRemark[]) getList(MmsReferenceEntry.S_DATABASE_PDB_REMARK);
                if (cacheValue(var, MmsReferenceEntry.S_DATABASE_PDB_REMARK))
                {
                    _database_pdb_remark_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_database_pdb_remark_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ DATABASE_PDB_REV ______ //
    public DatabasePdbRev[] _database_pdb_rev_list;
    public int database_pdb_rev_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_database_pdb_rev_list != null)
            {
                return _database_pdb_rev_list.length;
            }
            else
            {
                return getListSize(MmsReferenceEntry.S_DATABASE_PDB_REV);
            }
        }

    public DatabasePdbRev[] get_database_pdb_rev_list()
        throws DataAccessException
        {
            DatabasePdbRev[] var = null;
            boolean allVarsRead = initEntry();
            if (_database_pdb_rev_list != null)
            {
                var = _database_pdb_rev_list;
            }
            else if ( ! allVarsRead)
            {
                var = (DatabasePdbRev[]) getList(MmsReferenceEntry.S_DATABASE_PDB_REV);
                if (cacheValue(var, MmsReferenceEntry.S_DATABASE_PDB_REV))
                {
                    _database_pdb_rev_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_database_pdb_rev_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ DATABASE_PDB_REV_RECORD ______ //
    public DatabasePdbRevRecord[] _database_pdb_rev_record_list;
    public int database_pdb_rev_record_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_database_pdb_rev_record_list != null)
            {
                return _database_pdb_rev_record_list.length;
            }
            else
            {
                return getListSize(MmsReferenceEntry.S_DATABASE_PDB_REV_RECORD);
            }
        }

    public DatabasePdbRevRecord[] get_database_pdb_rev_record_list()
        throws DataAccessException
        {
            DatabasePdbRevRecord[] var = null;
            boolean allVarsRead = initEntry();
            if (_database_pdb_rev_record_list != null)
            {
                var = _database_pdb_rev_record_list;
            }
            else if ( ! allVarsRead)
            {
                var = (DatabasePdbRevRecord[]) getList(MmsReferenceEntry.S_DATABASE_PDB_REV_RECORD);
                if (cacheValue(var, MmsReferenceEntry.S_DATABASE_PDB_REV_RECORD))
                {
                    _database_pdb_rev_record_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_database_pdb_rev_record_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ DATABASE_PDB_TVECT ______ //
    public DatabasePdbTvect[] _database_pdb_tvect_list;
    public int database_pdb_tvect_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_database_pdb_tvect_list != null)
            {
                return _database_pdb_tvect_list.length;
            }
            else
            {
                return getListSize(MmsReferenceEntry.S_DATABASE_PDB_TVECT);
            }
        }

    public DatabasePdbTvect[] get_database_pdb_tvect_list()
        throws DataAccessException
        {
            DatabasePdbTvect[] var = null;
            boolean allVarsRead = initEntry();
            if (_database_pdb_tvect_list != null)
            {
                var = _database_pdb_tvect_list;
            }
            else if ( ! allVarsRead)
            {
                var = (DatabasePdbTvect[]) getList(MmsReferenceEntry.S_DATABASE_PDB_TVECT);
                if (cacheValue(var, MmsReferenceEntry.S_DATABASE_PDB_TVECT))
                {
                    _database_pdb_tvect_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_database_pdb_tvect_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ PDBX_DATABASE_MESSAGE ______ //
    public PdbxDatabaseMessage[] _pdbx_database_message_list;
    public int pdbx_database_message_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_pdbx_database_message_list != null)
            {
                return _pdbx_database_message_list.length;
            }
            else
            {
                return getListSize(MmsReferenceEntry.S_PDBX_DATABASE_MESSAGE);
            }
        }

    public PdbxDatabaseMessage[] get_pdbx_database_message_list()
        throws DataAccessException
        {
            PdbxDatabaseMessage[] var = null;
            boolean allVarsRead = initEntry();
            if (_pdbx_database_message_list != null)
            {
                var = _pdbx_database_message_list;
            }
            else if ( ! allVarsRead)
            {
                var = (PdbxDatabaseMessage[]) getList(MmsReferenceEntry.S_PDBX_DATABASE_MESSAGE);
                if (cacheValue(var, MmsReferenceEntry.S_PDBX_DATABASE_MESSAGE))
                {
                    _pdbx_database_message_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_pdbx_database_message_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ PDBX_DATABASE_PDB_OBS_SPR ______ //
    public PdbxDatabasePdbObsSpr[] _pdbx_database_pdb_obs_spr_list;
    public int pdbx_database_pdb_obs_spr_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_pdbx_database_pdb_obs_spr_list != null)
            {
                return _pdbx_database_pdb_obs_spr_list.length;
            }
            else
            {
                return getListSize(MmsReferenceEntry.S_PDBX_DATABASE_PDB_OBS_SPR);
            }
        }

    public PdbxDatabasePdbObsSpr[] get_pdbx_database_pdb_obs_spr_list()
        throws DataAccessException
        {
            PdbxDatabasePdbObsSpr[] var = null;
            boolean allVarsRead = initEntry();
            if (_pdbx_database_pdb_obs_spr_list != null)
            {
                var = _pdbx_database_pdb_obs_spr_list;
            }
            else if ( ! allVarsRead)
            {
                var = (PdbxDatabasePdbObsSpr[]) getList(MmsReferenceEntry.S_PDBX_DATABASE_PDB_OBS_SPR);
                if (cacheValue(var, MmsReferenceEntry.S_PDBX_DATABASE_PDB_OBS_SPR))
                {
                    _pdbx_database_pdb_obs_spr_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_pdbx_database_pdb_obs_spr_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ PDBX_DATABASE_PROC ______ //
    public PdbxDatabaseProc[] _pdbx_database_proc_list;
    public int pdbx_database_proc_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_pdbx_database_proc_list != null)
            {
                return _pdbx_database_proc_list.length;
            }
            else
            {
                return getListSize(MmsReferenceEntry.S_PDBX_DATABASE_PROC);
            }
        }

    public PdbxDatabaseProc[] get_pdbx_database_proc_list()
        throws DataAccessException
        {
            PdbxDatabaseProc[] var = null;
            boolean allVarsRead = initEntry();
            if (_pdbx_database_proc_list != null)
            {
                var = _pdbx_database_proc_list;
            }
            else if ( ! allVarsRead)
            {
                var = (PdbxDatabaseProc[]) getList(MmsReferenceEntry.S_PDBX_DATABASE_PROC);
                if (cacheValue(var, MmsReferenceEntry.S_PDBX_DATABASE_PROC))
                {
                    _pdbx_database_proc_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_pdbx_database_proc_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ PDBX_DATABASE_REMARK ______ //
    public PdbxDatabaseRemark[] _pdbx_database_remark_list;
    public int pdbx_database_remark_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_pdbx_database_remark_list != null)
            {
                return _pdbx_database_remark_list.length;
            }
            else
            {
                return getListSize(MmsReferenceEntry.S_PDBX_DATABASE_REMARK);
            }
        }

    public PdbxDatabaseRemark[] get_pdbx_database_remark_list()
        throws DataAccessException
        {
            PdbxDatabaseRemark[] var = null;
            boolean allVarsRead = initEntry();
            if (_pdbx_database_remark_list != null)
            {
                var = _pdbx_database_remark_list;
            }
            else if ( ! allVarsRead)
            {
                var = (PdbxDatabaseRemark[]) getList(MmsReferenceEntry.S_PDBX_DATABASE_REMARK);
                if (cacheValue(var, MmsReferenceEntry.S_PDBX_DATABASE_REMARK))
                {
                    _pdbx_database_remark_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_pdbx_database_remark_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ PDBX_DATABASE_STATUS ______ //
    public PdbxDatabaseStatus[] _pdbx_database_status_list;
    public int pdbx_database_status_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_pdbx_database_status_list != null)
            {
                return _pdbx_database_status_list.length;
            }
            else
            {
                return getListSize(MmsReferenceEntry.S_PDBX_DATABASE_STATUS);
            }
        }

    public PdbxDatabaseStatus[] get_pdbx_database_status_list()
        throws DataAccessException
        {
            PdbxDatabaseStatus[] var = null;
            boolean allVarsRead = initEntry();
            if (_pdbx_database_status_list != null)
            {
                var = _pdbx_database_status_list;
            }
            else if ( ! allVarsRead)
            {
                var = (PdbxDatabaseStatus[]) getList(MmsReferenceEntry.S_PDBX_DATABASE_STATUS);
                if (cacheValue(var, MmsReferenceEntry.S_PDBX_DATABASE_STATUS))
                {
                    _pdbx_database_status_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_pdbx_database_status_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ PDBX_DATABASE_RELATED ______ //
    public PdbxDatabaseRelated[] _pdbx_database_related_list;
    public int pdbx_database_related_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_pdbx_database_related_list != null)
            {
                return _pdbx_database_related_list.length;
            }
            else
            {
                return getListSize(MmsReferenceEntry.S_PDBX_DATABASE_RELATED);
            }
        }

    public PdbxDatabaseRelated[] get_pdbx_database_related_list()
        throws DataAccessException
        {
            PdbxDatabaseRelated[] var = null;
            boolean allVarsRead = initEntry();
            if (_pdbx_database_related_list != null)
            {
                var = _pdbx_database_related_list;
            }
            else if ( ! allVarsRead)
            {
                var = (PdbxDatabaseRelated[]) getList(MmsReferenceEntry.S_PDBX_DATABASE_RELATED);
                if (cacheValue(var, MmsReferenceEntry.S_PDBX_DATABASE_RELATED))
                {
                    _pdbx_database_related_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_pdbx_database_related_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ COMPUTING ______ //
    public Computing[] _computing_list;
    public int computing_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_computing_list != null)
            {
                return _computing_list.length;
            }
            else
            {
                return getListSize(MmsReferenceEntry.S_COMPUTING);
            }
        }

    public Computing[] get_computing_list()
        throws DataAccessException
        {
            Computing[] var = null;
            boolean allVarsRead = initEntry();
            if (_computing_list != null)
            {
                var = _computing_list;
            }
            else if ( ! allVarsRead)
            {
                var = (Computing[]) getList(MmsReferenceEntry.S_COMPUTING);
                if (cacheValue(var, MmsReferenceEntry.S_COMPUTING))
                {
                    _computing_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_computing_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ SOFTWARE ______ //
    public Software[] _software_list;
    public int software_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_software_list != null)
            {
                return _software_list.length;
            }
            else
            {
                return getListSize(MmsReferenceEntry.S_SOFTWARE);
            }
        }

    public Software[] get_software_list()
        throws DataAccessException
        {
            Software[] var = null;
            boolean allVarsRead = initEntry();
            if (_software_list != null)
            {
                var = _software_list;
            }
            else if ( ! allVarsRead)
            {
                var = (Software[]) getList(MmsReferenceEntry.S_SOFTWARE);
                if (cacheValue(var, MmsReferenceEntry.S_SOFTWARE))
                {
                    _software_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_software_list",
                    "Requested data not present");
            }
            return var;
        }

    }
