//
// **** DERIVED FILE - DO NOT EDIT ****
//
// Copyright 2003 The Regents of the University of California
// All Rights Reserved
//
// OpenMMS was developed by Dr. Douglas S. Greer at the San Diego
// Supercomputer Center, a research unit of the University of California,
// San Diego.  Support for this effort was provided by NSF through the
// Protein Data Bank (Grant DBI-9814284) and the National Partnership for
// Advanced Computational Infrastructure (Grant ACI-9619020)
//
// Permission to use, copy, modify and distribute any part of OpenMMS for
// educational, research and non-profit purposes, without fee, and
// without a written agreement is hereby granted, provided that the above
// copyright notice, this paragraph and the following paragraphs appear
// in all copies.
//
// Those desiring to incorporate this OpenMMS into commercial products or
// use for commercial purposes should contact the Technology Transfer
// Office, University of California, San Diego, 9500 Gilman Drive, La
// Jolla, CA 92093-0910, Ph: (619) 534-5815, FAX: (619) 534-7345.
//
// In no event shall the University of California be liable to any party
// for direct, indirect, special, incidental, or consequential damages,
// including lost profits, arising out of the use of this OpenMMS, even
// if the University of California has been advised of the possibility of
// such damage.
//
// The OpenMMS provided herein is on an "as is" basis, and the
// University of California has no obligation to provide maintenance,
// support, updates, enhancements, or modifications.  The University of
// California makes no representations and extends no warranties of any
// kind, either implied or express, including, but not limited to, the
// implied warranties of merchantability or fitness for a particular
// purpose, or that the use of the OpenMMS will not infringe any patent,
// trademark or other rights.

package org.rcsb.openmms.loader;

import java.util.*;
import org.omg.DsLSRMacromolecularStructure.*;
import org.omg.DsLSRMmsReference.*;
import org.omg.DsLSRXRayCrystallography.*;
import org.omg.DsLSRNmr.*;

/**
 * The Entry/Subentry classes contain the arrays of data structures
 * that store all of the information known about a particular entry
 * (i.e. an MMS structure) as well as the methods for accessing
 * those data structures.
 * <p>
 * Generated by the program MMSExpr. Model: Std, Revision: 3.0
 * <p>
 * Date: Tue Jul 29 17:48:42 PDT 2003
 *
 * @author Douglas S. Greer
 * @version OpenMMS Release V_1_5_1
 */
public abstract class NmrEntryMethodImpl
     extends NmrEntryPOA
    {
    public NmrEntryMethodImpl()
        {
        }

    abstract public boolean initEntry()
            throws DataAccessException;
    abstract public Object[] getList(int sFlag)
            throws DataAccessException;
    abstract public int getListSize(int sFlag)
            throws DataAccessException;
    abstract public Object[] getListBlock(int sFlag, int from, int to)
            throws DataAccessException;
    abstract public boolean cacheValue(Object[] var, int sFlag)
            throws DataAccessException;

    public byte[] _presence_flags
            = new byte[(NmrEntry.MAX_FLAG/8)+1];

    // ______ PDBX_NMR_DETAILS ______ //
    public PdbxNmrDetails[] _pdbx_nmr_details_list;
    public int pdbx_nmr_details_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_pdbx_nmr_details_list != null)
            {
                return _pdbx_nmr_details_list.length;
            }
            else
            {
                return getListSize(NmrEntry.S_PDBX_NMR_DETAILS);
            }
        }

    public PdbxNmrDetails[] get_pdbx_nmr_details_list()
        throws DataAccessException
        {
            PdbxNmrDetails[] var = null;
            boolean allVarsRead = initEntry();
            if (_pdbx_nmr_details_list != null)
            {
                var = _pdbx_nmr_details_list;
            }
            else if ( ! allVarsRead)
            {
                var = (PdbxNmrDetails[]) getList(NmrEntry.S_PDBX_NMR_DETAILS);
                if (cacheValue(var, NmrEntry.S_PDBX_NMR_DETAILS))
                {
                    _pdbx_nmr_details_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_pdbx_nmr_details_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ PDBX_NMR_SAMPLE_DETAILS ______ //
    public PdbxNmrSampleDetails[] _pdbx_nmr_sample_details_list;
    public int pdbx_nmr_sample_details_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_pdbx_nmr_sample_details_list != null)
            {
                return _pdbx_nmr_sample_details_list.length;
            }
            else
            {
                return getListSize(NmrEntry.S_PDBX_NMR_SAMPLE_DETAILS);
            }
        }

    public PdbxNmrSampleDetails[] get_pdbx_nmr_sample_details_list()
        throws DataAccessException
        {
            PdbxNmrSampleDetails[] var = null;
            boolean allVarsRead = initEntry();
            if (_pdbx_nmr_sample_details_list != null)
            {
                var = _pdbx_nmr_sample_details_list;
            }
            else if ( ! allVarsRead)
            {
                var = (PdbxNmrSampleDetails[]) getList(NmrEntry.S_PDBX_NMR_SAMPLE_DETAILS);
                if (cacheValue(var, NmrEntry.S_PDBX_NMR_SAMPLE_DETAILS))
                {
                    _pdbx_nmr_sample_details_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_pdbx_nmr_sample_details_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ PDBX_NMR_EXPTL_SAMPLE ______ //
    public PdbxNmrExptlSample[] _pdbx_nmr_exptl_sample_list;
    public int pdbx_nmr_exptl_sample_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_pdbx_nmr_exptl_sample_list != null)
            {
                return _pdbx_nmr_exptl_sample_list.length;
            }
            else
            {
                return getListSize(NmrEntry.S_PDBX_NMR_EXPTL_SAMPLE);
            }
        }

    public PdbxNmrExptlSample[] get_pdbx_nmr_exptl_sample_list()
        throws DataAccessException
        {
            PdbxNmrExptlSample[] var = null;
            boolean allVarsRead = initEntry();
            if (_pdbx_nmr_exptl_sample_list != null)
            {
                var = _pdbx_nmr_exptl_sample_list;
            }
            else if ( ! allVarsRead)
            {
                var = (PdbxNmrExptlSample[]) getList(NmrEntry.S_PDBX_NMR_EXPTL_SAMPLE);
                if (cacheValue(var, NmrEntry.S_PDBX_NMR_EXPTL_SAMPLE))
                {
                    _pdbx_nmr_exptl_sample_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_pdbx_nmr_exptl_sample_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ PDBX_NMR_EXPTL_SAMPLE_CONDITIONS ______ //
    public PdbxNmrExptlSampleConditions[] _pdbx_nmr_exptl_sample_conditions_list;
    public int pdbx_nmr_exptl_sample_conditions_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_pdbx_nmr_exptl_sample_conditions_list != null)
            {
                return _pdbx_nmr_exptl_sample_conditions_list.length;
            }
            else
            {
                return getListSize(NmrEntry.S_PDBX_NMR_EXPTL_SAMPLE_CONDITIONS);
            }
        }

    public PdbxNmrExptlSampleConditions[] get_pdbx_nmr_exptl_sample_conditions_list()
        throws DataAccessException
        {
            PdbxNmrExptlSampleConditions[] var = null;
            boolean allVarsRead = initEntry();
            if (_pdbx_nmr_exptl_sample_conditions_list != null)
            {
                var = _pdbx_nmr_exptl_sample_conditions_list;
            }
            else if ( ! allVarsRead)
            {
                var = (PdbxNmrExptlSampleConditions[]) getList(NmrEntry.S_PDBX_NMR_EXPTL_SAMPLE_CONDITIONS);
                if (cacheValue(var, NmrEntry.S_PDBX_NMR_EXPTL_SAMPLE_CONDITIONS))
                {
                    _pdbx_nmr_exptl_sample_conditions_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_pdbx_nmr_exptl_sample_conditions_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ PDBX_NMR_SPECTROMETER ______ //
    public PdbxNmrSpectrometer[] _pdbx_nmr_spectrometer_list;
    public int pdbx_nmr_spectrometer_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_pdbx_nmr_spectrometer_list != null)
            {
                return _pdbx_nmr_spectrometer_list.length;
            }
            else
            {
                return getListSize(NmrEntry.S_PDBX_NMR_SPECTROMETER);
            }
        }

    public PdbxNmrSpectrometer[] get_pdbx_nmr_spectrometer_list()
        throws DataAccessException
        {
            PdbxNmrSpectrometer[] var = null;
            boolean allVarsRead = initEntry();
            if (_pdbx_nmr_spectrometer_list != null)
            {
                var = _pdbx_nmr_spectrometer_list;
            }
            else if ( ! allVarsRead)
            {
                var = (PdbxNmrSpectrometer[]) getList(NmrEntry.S_PDBX_NMR_SPECTROMETER);
                if (cacheValue(var, NmrEntry.S_PDBX_NMR_SPECTROMETER))
                {
                    _pdbx_nmr_spectrometer_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_pdbx_nmr_spectrometer_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ PDBX_NMR_EXPTL ______ //
    public PdbxNmrExptl[] _pdbx_nmr_exptl_list;
    public int pdbx_nmr_exptl_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_pdbx_nmr_exptl_list != null)
            {
                return _pdbx_nmr_exptl_list.length;
            }
            else
            {
                return getListSize(NmrEntry.S_PDBX_NMR_EXPTL);
            }
        }

    public PdbxNmrExptl[] get_pdbx_nmr_exptl_list()
        throws DataAccessException
        {
            PdbxNmrExptl[] var = null;
            boolean allVarsRead = initEntry();
            if (_pdbx_nmr_exptl_list != null)
            {
                var = _pdbx_nmr_exptl_list;
            }
            else if ( ! allVarsRead)
            {
                var = (PdbxNmrExptl[]) getList(NmrEntry.S_PDBX_NMR_EXPTL);
                if (cacheValue(var, NmrEntry.S_PDBX_NMR_EXPTL))
                {
                    _pdbx_nmr_exptl_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_pdbx_nmr_exptl_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ PDBX_NMR_SOFTWARE ______ //
    public PdbxNmrSoftware[] _pdbx_nmr_software_list;
    public int pdbx_nmr_software_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_pdbx_nmr_software_list != null)
            {
                return _pdbx_nmr_software_list.length;
            }
            else
            {
                return getListSize(NmrEntry.S_PDBX_NMR_SOFTWARE);
            }
        }

    public PdbxNmrSoftware[] get_pdbx_nmr_software_list()
        throws DataAccessException
        {
            PdbxNmrSoftware[] var = null;
            boolean allVarsRead = initEntry();
            if (_pdbx_nmr_software_list != null)
            {
                var = _pdbx_nmr_software_list;
            }
            else if ( ! allVarsRead)
            {
                var = (PdbxNmrSoftware[]) getList(NmrEntry.S_PDBX_NMR_SOFTWARE);
                if (cacheValue(var, NmrEntry.S_PDBX_NMR_SOFTWARE))
                {
                    _pdbx_nmr_software_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_pdbx_nmr_software_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ PDBX_NMR_CONSTRAINTS ______ //
    public PdbxNmrConstraints[] _pdbx_nmr_constraints_list;
    public int pdbx_nmr_constraints_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_pdbx_nmr_constraints_list != null)
            {
                return _pdbx_nmr_constraints_list.length;
            }
            else
            {
                return getListSize(NmrEntry.S_PDBX_NMR_CONSTRAINTS);
            }
        }

    public PdbxNmrConstraints[] get_pdbx_nmr_constraints_list()
        throws DataAccessException
        {
            PdbxNmrConstraints[] var = null;
            boolean allVarsRead = initEntry();
            if (_pdbx_nmr_constraints_list != null)
            {
                var = _pdbx_nmr_constraints_list;
            }
            else if ( ! allVarsRead)
            {
                var = (PdbxNmrConstraints[]) getList(NmrEntry.S_PDBX_NMR_CONSTRAINTS);
                if (cacheValue(var, NmrEntry.S_PDBX_NMR_CONSTRAINTS))
                {
                    _pdbx_nmr_constraints_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_pdbx_nmr_constraints_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ PDBX_NMR_ENSEMBLE ______ //
    public PdbxNmrEnsemble[] _pdbx_nmr_ensemble_list;
    public int pdbx_nmr_ensemble_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_pdbx_nmr_ensemble_list != null)
            {
                return _pdbx_nmr_ensemble_list.length;
            }
            else
            {
                return getListSize(NmrEntry.S_PDBX_NMR_ENSEMBLE);
            }
        }

    public PdbxNmrEnsemble[] get_pdbx_nmr_ensemble_list()
        throws DataAccessException
        {
            PdbxNmrEnsemble[] var = null;
            boolean allVarsRead = initEntry();
            if (_pdbx_nmr_ensemble_list != null)
            {
                var = _pdbx_nmr_ensemble_list;
            }
            else if ( ! allVarsRead)
            {
                var = (PdbxNmrEnsemble[]) getList(NmrEntry.S_PDBX_NMR_ENSEMBLE);
                if (cacheValue(var, NmrEntry.S_PDBX_NMR_ENSEMBLE))
                {
                    _pdbx_nmr_ensemble_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_pdbx_nmr_ensemble_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ PDBX_NMR_ENSEMBLE_RMS ______ //
    public PdbxNmrEnsembleRms[] _pdbx_nmr_ensemble_rms_list;
    public int pdbx_nmr_ensemble_rms_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_pdbx_nmr_ensemble_rms_list != null)
            {
                return _pdbx_nmr_ensemble_rms_list.length;
            }
            else
            {
                return getListSize(NmrEntry.S_PDBX_NMR_ENSEMBLE_RMS);
            }
        }

    public PdbxNmrEnsembleRms[] get_pdbx_nmr_ensemble_rms_list()
        throws DataAccessException
        {
            PdbxNmrEnsembleRms[] var = null;
            boolean allVarsRead = initEntry();
            if (_pdbx_nmr_ensemble_rms_list != null)
            {
                var = _pdbx_nmr_ensemble_rms_list;
            }
            else if ( ! allVarsRead)
            {
                var = (PdbxNmrEnsembleRms[]) getList(NmrEntry.S_PDBX_NMR_ENSEMBLE_RMS);
                if (cacheValue(var, NmrEntry.S_PDBX_NMR_ENSEMBLE_RMS))
                {
                    _pdbx_nmr_ensemble_rms_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_pdbx_nmr_ensemble_rms_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ PDBX_NMR_REPRESENTATIVE ______ //
    public PdbxNmrRepresentative[] _pdbx_nmr_representative_list;
    public int pdbx_nmr_representative_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_pdbx_nmr_representative_list != null)
            {
                return _pdbx_nmr_representative_list.length;
            }
            else
            {
                return getListSize(NmrEntry.S_PDBX_NMR_REPRESENTATIVE);
            }
        }

    public PdbxNmrRepresentative[] get_pdbx_nmr_representative_list()
        throws DataAccessException
        {
            PdbxNmrRepresentative[] var = null;
            boolean allVarsRead = initEntry();
            if (_pdbx_nmr_representative_list != null)
            {
                var = _pdbx_nmr_representative_list;
            }
            else if ( ! allVarsRead)
            {
                var = (PdbxNmrRepresentative[]) getList(NmrEntry.S_PDBX_NMR_REPRESENTATIVE);
                if (cacheValue(var, NmrEntry.S_PDBX_NMR_REPRESENTATIVE))
                {
                    _pdbx_nmr_representative_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_pdbx_nmr_representative_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ PDBX_NMR_REFINE ______ //
    public PdbxNmrRefine[] _pdbx_nmr_refine_list;
    public int pdbx_nmr_refine_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_pdbx_nmr_refine_list != null)
            {
                return _pdbx_nmr_refine_list.length;
            }
            else
            {
                return getListSize(NmrEntry.S_PDBX_NMR_REFINE);
            }
        }

    public PdbxNmrRefine[] get_pdbx_nmr_refine_list()
        throws DataAccessException
        {
            PdbxNmrRefine[] var = null;
            boolean allVarsRead = initEntry();
            if (_pdbx_nmr_refine_list != null)
            {
                var = _pdbx_nmr_refine_list;
            }
            else if ( ! allVarsRead)
            {
                var = (PdbxNmrRefine[]) getList(NmrEntry.S_PDBX_NMR_REFINE);
                if (cacheValue(var, NmrEntry.S_PDBX_NMR_REFINE))
                {
                    _pdbx_nmr_refine_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_pdbx_nmr_refine_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ PDBX_NMR_FORCE_CONSTANTS ______ //
    public PdbxNmrForceConstants[] _pdbx_nmr_force_constants_list;
    public int pdbx_nmr_force_constants_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_pdbx_nmr_force_constants_list != null)
            {
                return _pdbx_nmr_force_constants_list.length;
            }
            else
            {
                return getListSize(NmrEntry.S_PDBX_NMR_FORCE_CONSTANTS);
            }
        }

    public PdbxNmrForceConstants[] get_pdbx_nmr_force_constants_list()
        throws DataAccessException
        {
            PdbxNmrForceConstants[] var = null;
            boolean allVarsRead = initEntry();
            if (_pdbx_nmr_force_constants_list != null)
            {
                var = _pdbx_nmr_force_constants_list;
            }
            else if ( ! allVarsRead)
            {
                var = (PdbxNmrForceConstants[]) getList(NmrEntry.S_PDBX_NMR_FORCE_CONSTANTS);
                if (cacheValue(var, NmrEntry.S_PDBX_NMR_FORCE_CONSTANTS))
                {
                    _pdbx_nmr_force_constants_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_pdbx_nmr_force_constants_list",
                    "Requested data not present");
            }
            return var;
        }

    }
