//
// **** DERIVED FILE - DO NOT EDIT ****
//
// Copyright 2003 The Regents of the University of California
// All Rights Reserved
//
// OpenMMS was developed by Dr. Douglas S. Greer at the San Diego
// Supercomputer Center, a research unit of the University of California,
// San Diego.  Support for this effort was provided by NSF through the
// Protein Data Bank (Grant DBI-9814284) and the National Partnership for
// Advanced Computational Infrastructure (Grant ACI-9619020)
//
// Permission to use, copy, modify and distribute any part of OpenMMS for
// educational, research and non-profit purposes, without fee, and
// without a written agreement is hereby granted, provided that the above
// copyright notice, this paragraph and the following paragraphs appear
// in all copies.
//
// Those desiring to incorporate this OpenMMS into commercial products or
// use for commercial purposes should contact the Technology Transfer
// Office, University of California, San Diego, 9500 Gilman Drive, La
// Jolla, CA 92093-0910, Ph: (619) 534-5815, FAX: (619) 534-7345.
//
// In no event shall the University of California be liable to any party
// for direct, indirect, special, incidental, or consequential damages,
// including lost profits, arising out of the use of this OpenMMS, even
// if the University of California has been advised of the possibility of
// such damage.
//
// The OpenMMS provided herein is on an "as is" basis, and the
// University of California has no obligation to provide maintenance,
// support, updates, enhancements, or modifications.  The University of
// California makes no representations and extends no warranties of any
// kind, either implied or express, including, but not limited to, the
// implied warranties of merchantability or fitness for a particular
// purpose, or that the use of the OpenMMS will not infringe any patent,
// trademark or other rights.

package org.rcsb.openmms.loader;

import java.util.*;
import org.rcsb.openmms.cifparse.*;
import org.rcsb.openmms.util.*;
import org.omg.DsLSRMacromolecularStructure.*;
import org.omg.DsLSRXRayCrystallography.*;

/**
 * Category Loader to load data into the XRayCrystallographyEntryMethodImpl.PhasingSet
 * structure.
 * <p>
 * Generated by the program MMSExpr. Model: Std, Revision: 3.0
 * <p>
 * Date: Tue Jul 29 17:48:46 PDT 2003
 *
 * @author Douglas S. Greer
 * @version OpenMMS Release V_1_5_1
 */
public class PhasingSetCatLoader
   extends CatUtil implements CatLoader
{
   public PhasingSetCatLoader()
      {
      }

   PhasingSetImpl varPhasingSet;
   ArrayList arrayPhasingSet = new ArrayList();

   static final int CELL_LENGTH_A = 1324;
   static final int CELL_LENGTH_B = 1325;
   static final int CELL_LENGTH_C = 1326;
   static final int CELL_ANGLE_ALPHA = 1327;
   static final int CELL_ANGLE_BETA = 1328;
   static final int CELL_ANGLE_GAMMA = 1329;
   static final int DETECTOR_SPECIFIC = 1330;
   static final int DETECTOR_TYPE = 1331;
   static final int ID = 1332;
   static final int RADIATION_SOURCE_SPECIFIC = 1333;
   static final int RADIATION_WAVELENGTH = 1334;
   static final int TEMP = 1335;

   public void beginCategory()
      {
         varPhasingSet = null;
      }

   public void endCompound(Object e)
      throws CifParseException
      {
      }

   public void beginRow()
      {
         varPhasingSet = new PhasingSetImpl();
         varPhasingSet.cell = new UnitCell();
         varPhasingSet.detector_specific = "";
         varPhasingSet.detector_type = "";
         varPhasingSet.id = "";
         varPhasingSet.radiation_source_specific = "";
      }

   public void endRow()
      {
         arrayPhasingSet.add(varPhasingSet);
      }

   public void endLoop(Object e)
      {
         int i;
         EntryMethodImpl xe = (EntryMethodImpl) e;
         xe.xray._phasing_set_list = new PhasingSetImpl[arrayPhasingSet.size()];
         for (i = 0; i < arrayPhasingSet.size(); i++)
            {
               xe.xray._phasing_set_list[i]
                  = (PhasingSetImpl) arrayPhasingSet.get(i);
            }
         arrayPhasingSet.clear();
      }

   public void defineSingleItem(Object e, int fieldCode)
      {
         EntryMethodImpl xe = (EntryMethodImpl) e;
         defineItem(xe, fieldCode);
      }

   public void defineLoopItem(Object e, int fieldCode)
      {
         EntryMethodImpl xe = (EntryMethodImpl) e;
         defineItem(xe, fieldCode);
      }

   public void defineItem(EntryMethodImpl xe, int fieldCode)
      {
      switch (fieldCode)
         {
         case CELL_LENGTH_A:
            xe.xray._presence_flags[XRayCrystallographyEntry.S_PHASING_SET/8] |=
               1 << (XRayCrystallographyEntry.S_PHASING_SET%8);
            xe.xray._presence_flags[XRayCrystallographyEntry.F_PHASING_SET_CELL_LENGTH_A/8] |=
               1 << (XRayCrystallographyEntry.F_PHASING_SET_CELL_LENGTH_A%8);
            break;

         case CELL_LENGTH_B:
            xe.xray._presence_flags[XRayCrystallographyEntry.S_PHASING_SET/8] |=
               1 << (XRayCrystallographyEntry.S_PHASING_SET%8);
            xe.xray._presence_flags[XRayCrystallographyEntry.F_PHASING_SET_CELL_LENGTH_B/8] |=
               1 << (XRayCrystallographyEntry.F_PHASING_SET_CELL_LENGTH_B%8);
            break;

         case CELL_LENGTH_C:
            xe.xray._presence_flags[XRayCrystallographyEntry.S_PHASING_SET/8] |=
               1 << (XRayCrystallographyEntry.S_PHASING_SET%8);
            xe.xray._presence_flags[XRayCrystallographyEntry.F_PHASING_SET_CELL_LENGTH_C/8] |=
               1 << (XRayCrystallographyEntry.F_PHASING_SET_CELL_LENGTH_C%8);
            break;

         case CELL_ANGLE_ALPHA:
            xe.xray._presence_flags[XRayCrystallographyEntry.S_PHASING_SET/8] |=
               1 << (XRayCrystallographyEntry.S_PHASING_SET%8);
            xe.xray._presence_flags[XRayCrystallographyEntry.F_PHASING_SET_CELL_ANGLE_ALPHA/8] |=
               1 << (XRayCrystallographyEntry.F_PHASING_SET_CELL_ANGLE_ALPHA%8);
            break;

         case CELL_ANGLE_BETA:
            xe.xray._presence_flags[XRayCrystallographyEntry.S_PHASING_SET/8] |=
               1 << (XRayCrystallographyEntry.S_PHASING_SET%8);
            xe.xray._presence_flags[XRayCrystallographyEntry.F_PHASING_SET_CELL_ANGLE_BETA/8] |=
               1 << (XRayCrystallographyEntry.F_PHASING_SET_CELL_ANGLE_BETA%8);
            break;

         case CELL_ANGLE_GAMMA:
            xe.xray._presence_flags[XRayCrystallographyEntry.S_PHASING_SET/8] |=
               1 << (XRayCrystallographyEntry.S_PHASING_SET%8);
            xe.xray._presence_flags[XRayCrystallographyEntry.F_PHASING_SET_CELL_ANGLE_GAMMA/8] |=
               1 << (XRayCrystallographyEntry.F_PHASING_SET_CELL_ANGLE_GAMMA%8);
            break;

         case DETECTOR_SPECIFIC:
            xe.xray._presence_flags[XRayCrystallographyEntry.S_PHASING_SET/8] |=
               1 << (XRayCrystallographyEntry.S_PHASING_SET%8);
            xe.xray._presence_flags[XRayCrystallographyEntry.F_PHASING_SET_DETECTOR_SPECIFIC/8] |=
               1 << (XRayCrystallographyEntry.F_PHASING_SET_DETECTOR_SPECIFIC%8);
            break;

         case DETECTOR_TYPE:
            xe.xray._presence_flags[XRayCrystallographyEntry.S_PHASING_SET/8] |=
               1 << (XRayCrystallographyEntry.S_PHASING_SET%8);
            xe.xray._presence_flags[XRayCrystallographyEntry.F_PHASING_SET_DETECTOR_TYPE/8] |=
               1 << (XRayCrystallographyEntry.F_PHASING_SET_DETECTOR_TYPE%8);
            break;

         case ID:
            xe.xray._presence_flags[XRayCrystallographyEntry.S_PHASING_SET/8] |=
               1 << (XRayCrystallographyEntry.S_PHASING_SET%8);
            break;

         case RADIATION_SOURCE_SPECIFIC:
            xe.xray._presence_flags[XRayCrystallographyEntry.S_PHASING_SET/8] |=
               1 << (XRayCrystallographyEntry.S_PHASING_SET%8);
            xe.xray._presence_flags[XRayCrystallographyEntry.F_PHASING_SET_RADIATION_SOURCE_SPECIFIC/8] |=
               1 << (XRayCrystallographyEntry.F_PHASING_SET_RADIATION_SOURCE_SPECIFIC%8);
            break;

         case RADIATION_WAVELENGTH:
            xe.xray._presence_flags[XRayCrystallographyEntry.S_PHASING_SET/8] |=
               1 << (XRayCrystallographyEntry.S_PHASING_SET%8);
            xe.xray._presence_flags[XRayCrystallographyEntry.F_PHASING_SET_RADIATION_WAVELENGTH/8] |=
               1 << (XRayCrystallographyEntry.F_PHASING_SET_RADIATION_WAVELENGTH%8);
            break;

         case TEMP:
            xe.xray._presence_flags[XRayCrystallographyEntry.S_PHASING_SET/8] |=
               1 << (XRayCrystallographyEntry.S_PHASING_SET%8);
            xe.xray._presence_flags[XRayCrystallographyEntry.F_PHASING_SET_TEMP/8] |=
               1 << (XRayCrystallographyEntry.F_PHASING_SET_TEMP%8);
            break;

         }
      }

   public void insertSingleValue(Object e, int fieldCode, String value)
      {
      switch (fieldCode)
         {
         case CELL_LENGTH_A:
         case CELL_LENGTH_B:
         case CELL_LENGTH_C:
         case CELL_ANGLE_ALPHA:
         case CELL_ANGLE_BETA:
         case CELL_ANGLE_GAMMA:
         case DETECTOR_SPECIFIC:
         case DETECTOR_TYPE:
         case ID:
         case RADIATION_SOURCE_SPECIFIC:
         case RADIATION_WAVELENGTH:
         case TEMP:
            if(varPhasingSet == null)
               {
                  beginRow();
                  EntryMethodImpl xe = (EntryMethodImpl) e;
                  xe.xray._phasing_set_list = new PhasingSetImpl[1];
                  xe.xray._phasing_set_list[0] = varPhasingSet;
               }
            break;
         }
      insertValue(fieldCode, value);
      }

   public void insertLoopValue(int fieldCode, String value)
      {
         insertValue(fieldCode, value);
      }

   public void insertValue(int fieldCode, String value)
      {
      switch (fieldCode)
         {
         case CELL_LENGTH_A:
            varPhasingSet.cell.length_a = cifFloat(value);
            break;
         case CELL_LENGTH_B:
            varPhasingSet.cell.length_b = cifFloat(value);
            break;
         case CELL_LENGTH_C:
            varPhasingSet.cell.length_c = cifFloat(value);
            break;
         case CELL_ANGLE_ALPHA:
            varPhasingSet.cell.angle_alpha = cifFloat(value);
            break;
         case CELL_ANGLE_BETA:
            varPhasingSet.cell.angle_beta = cifFloat(value);
            break;
         case CELL_ANGLE_GAMMA:
            varPhasingSet.cell.angle_gamma = cifFloat(value);
            break;
         case DETECTOR_SPECIFIC:
            varPhasingSet.detector_specific = cifString(value);
            break;
         case DETECTOR_TYPE:
            varPhasingSet.detector_type = cifString(value);
            break;
         case ID:
            varPhasingSet.id = cifString(value);
            break;
         case RADIATION_SOURCE_SPECIFIC:
            varPhasingSet.radiation_source_specific = cifString(value);
            break;
         case RADIATION_WAVELENGTH:
            varPhasingSet.radiation_wavelength = cifFloat(value);
            break;
         case TEMP:
            varPhasingSet.temp = cifFloat(value);
            break;
         }
      }
}

