//
// **** DERIVED FILE - DO NOT EDIT ****
//
// Copyright 2003 The Regents of the University of California
// All Rights Reserved
//
// OpenMMS was developed by Dr. Douglas S. Greer at the San Diego
// Supercomputer Center, a research unit of the University of California,
// San Diego.  Support for this effort was provided by NSF through the
// Protein Data Bank (Grant DBI-9814284) and the National Partnership for
// Advanced Computational Infrastructure (Grant ACI-9619020)
//
// Permission to use, copy, modify and distribute any part of OpenMMS for
// educational, research and non-profit purposes, without fee, and
// without a written agreement is hereby granted, provided that the above
// copyright notice, this paragraph and the following paragraphs appear
// in all copies.
//
// Those desiring to incorporate this OpenMMS into commercial products or
// use for commercial purposes should contact the Technology Transfer
// Office, University of California, San Diego, 9500 Gilman Drive, La
// Jolla, CA 92093-0910, Ph: (619) 534-5815, FAX: (619) 534-7345.
//
// In no event shall the University of California be liable to any party
// for direct, indirect, special, incidental, or consequential damages,
// including lost profits, arising out of the use of this OpenMMS, even
// if the University of California has been advised of the possibility of
// such damage.
//
// The OpenMMS provided herein is on an "as is" basis, and the
// University of California has no obligation to provide maintenance,
// support, updates, enhancements, or modifications.  The University of
// California makes no representations and extends no warranties of any
// kind, either implied or express, including, but not limited to, the
// implied warranties of merchantability or fitness for a particular
// purpose, or that the use of the OpenMMS will not infringe any patent,
// trademark or other rights.

package org.rcsb.openmms.loader;

import java.util.*;
import org.rcsb.openmms.cifparse.*;
import org.rcsb.openmms.util.*;
import org.omg.DsLSRMacromolecularStructure.*;
import org.omg.DsLSRXRayCrystallography.*;

/**
 * Category Loader to load data into the XRayCrystallographyEntryMethodImpl.Symmetry
 * structure.
 * <p>
 * Generated by the program MMSExpr. Model: Std, Revision: 3.0
 * <p>
 * Date: Tue Jul 29 17:48:47 PDT 2003
 *
 * @author Douglas S. Greer
 * @version OpenMMS Release V_1_5_1
 */
public class SymmetryCatLoader
   extends CatUtil implements CatLoader
{
   public SymmetryCatLoader()
      {
      }

   SymmetryImpl varSymmetry;
   ArrayList arraySymmetry = new ArrayList();

   static final int ENTRY_ID = 1665;
   static final int CELL_SETTING = 1666;
   static final int INT_TABLES_NUMBER = 1667;
   static final int SPACE_GROUP_NAME_HALL = 1668;
   static final int SPACE_GROUP_NAME_H_M = 1669;
   static final int PDBX_FULL_SPACE_GROUP_NAME_H_M = 1670;

   public void beginCategory()
      {
         varSymmetry = null;
      }

   public void endCompound(Object e)
      throws CifParseException
      {
      }

   public void beginRow()
      {
         varSymmetry = new SymmetryImpl();
         varSymmetry.entry_id = "";
         varSymmetry.cell_setting = "";
         varSymmetry.space_group_name_hall = "";
         varSymmetry.space_group_name_h_m = "";
         varSymmetry.pdbx_full_space_group_name_h_m = "";
      }

   public void endRow()
      {
         arraySymmetry.add(varSymmetry);
      }

   public void endLoop(Object e)
      {
         int i;
         EntryMethodImpl xe = (EntryMethodImpl) e;
         xe.xray._symmetry_list = new SymmetryImpl[arraySymmetry.size()];
         for (i = 0; i < arraySymmetry.size(); i++)
            {
               xe.xray._symmetry_list[i]
                  = (SymmetryImpl) arraySymmetry.get(i);
            }
         arraySymmetry.clear();
      }

   public void defineSingleItem(Object e, int fieldCode)
      {
         EntryMethodImpl xe = (EntryMethodImpl) e;
         defineItem(xe, fieldCode);
      }

   public void defineLoopItem(Object e, int fieldCode)
      {
         EntryMethodImpl xe = (EntryMethodImpl) e;
         defineItem(xe, fieldCode);
      }

   public void defineItem(EntryMethodImpl xe, int fieldCode)
      {
      switch (fieldCode)
         {
         case ENTRY_ID:
            xe.xray._presence_flags[XRayCrystallographyEntry.S_SYMMETRY/8] |=
               1 << (XRayCrystallographyEntry.S_SYMMETRY%8);
            break;

         case CELL_SETTING:
            xe.xray._presence_flags[XRayCrystallographyEntry.S_SYMMETRY/8] |=
               1 << (XRayCrystallographyEntry.S_SYMMETRY%8);
            xe.xray._presence_flags[XRayCrystallographyEntry.F_SYMMETRY_CELL_SETTING/8] |=
               1 << (XRayCrystallographyEntry.F_SYMMETRY_CELL_SETTING%8);
            break;

         case INT_TABLES_NUMBER:
            xe.xray._presence_flags[XRayCrystallographyEntry.S_SYMMETRY/8] |=
               1 << (XRayCrystallographyEntry.S_SYMMETRY%8);
            xe.xray._presence_flags[XRayCrystallographyEntry.F_SYMMETRY_INT_TABLES_NUMBER/8] |=
               1 << (XRayCrystallographyEntry.F_SYMMETRY_INT_TABLES_NUMBER%8);
            break;

         case SPACE_GROUP_NAME_HALL:
            xe.xray._presence_flags[XRayCrystallographyEntry.S_SYMMETRY/8] |=
               1 << (XRayCrystallographyEntry.S_SYMMETRY%8);
            xe.xray._presence_flags[XRayCrystallographyEntry.F_SYMMETRY_SPACE_GROUP_NAME_HALL/8] |=
               1 << (XRayCrystallographyEntry.F_SYMMETRY_SPACE_GROUP_NAME_HALL%8);
            break;

         case SPACE_GROUP_NAME_H_M:
            xe.xray._presence_flags[XRayCrystallographyEntry.S_SYMMETRY/8] |=
               1 << (XRayCrystallographyEntry.S_SYMMETRY%8);
            xe.xray._presence_flags[XRayCrystallographyEntry.F_SYMMETRY_SPACE_GROUP_NAME_H_M/8] |=
               1 << (XRayCrystallographyEntry.F_SYMMETRY_SPACE_GROUP_NAME_H_M%8);
            break;

         case PDBX_FULL_SPACE_GROUP_NAME_H_M:
            xe.xray._presence_flags[XRayCrystallographyEntry.S_SYMMETRY/8] |=
               1 << (XRayCrystallographyEntry.S_SYMMETRY%8);
            xe.xray._presence_flags[XRayCrystallographyEntry.F_SYMMETRY_PDBX_FULL_SPACE_GROUP_NAME_H_M/8] |=
               1 << (XRayCrystallographyEntry.F_SYMMETRY_PDBX_FULL_SPACE_GROUP_NAME_H_M%8);
            break;

         }
      }

   public void insertSingleValue(Object e, int fieldCode, String value)
      {
      switch (fieldCode)
         {
         case ENTRY_ID:
         case CELL_SETTING:
         case INT_TABLES_NUMBER:
         case SPACE_GROUP_NAME_HALL:
         case SPACE_GROUP_NAME_H_M:
         case PDBX_FULL_SPACE_GROUP_NAME_H_M:
            if(varSymmetry == null)
               {
                  beginRow();
                  EntryMethodImpl xe = (EntryMethodImpl) e;
                  xe.xray._symmetry_list = new SymmetryImpl[1];
                  xe.xray._symmetry_list[0] = varSymmetry;
               }
            break;
         }
      insertValue(fieldCode, value);
      }

   public void insertLoopValue(int fieldCode, String value)
      {
         insertValue(fieldCode, value);
      }

   public void insertValue(int fieldCode, String value)
      {
      switch (fieldCode)
         {
         case ENTRY_ID:
            varSymmetry.entry_id = cifString(value);
            break;
         case CELL_SETTING:
            varSymmetry.cell_setting = cifString(value);
            break;
         case INT_TABLES_NUMBER:
            varSymmetry.int_tables_number = cifInt(value);
            break;
         case SPACE_GROUP_NAME_HALL:
            varSymmetry.space_group_name_hall = cifString(value);
            break;
         case SPACE_GROUP_NAME_H_M:
            varSymmetry.space_group_name_h_m = cifString(value);
            break;
         case PDBX_FULL_SPACE_GROUP_NAME_H_M:
            varSymmetry.pdbx_full_space_group_name_h_m = cifString(value);
            break;
         }
      }
}

