//
// **** DERIVED FILE - DO NOT EDIT ****
//
// Copyright 2003 The Regents of the University of California
// All Rights Reserved
//
// OpenMMS was developed by Dr. Douglas S. Greer at the San Diego
// Supercomputer Center, a research unit of the University of California,
// San Diego.  Support for this effort was provided by NSF through the
// Protein Data Bank (Grant DBI-9814284) and the National Partnership for
// Advanced Computational Infrastructure (Grant ACI-9619020)
//
// Permission to use, copy, modify and distribute any part of OpenMMS for
// educational, research and non-profit purposes, without fee, and
// without a written agreement is hereby granted, provided that the above
// copyright notice, this paragraph and the following paragraphs appear
// in all copies.
//
// Those desiring to incorporate this OpenMMS into commercial products or
// use for commercial purposes should contact the Technology Transfer
// Office, University of California, San Diego, 9500 Gilman Drive, La
// Jolla, CA 92093-0910, Ph: (619) 534-5815, FAX: (619) 534-7345.
//
// In no event shall the University of California be liable to any party
// for direct, indirect, special, incidental, or consequential damages,
// including lost profits, arising out of the use of this OpenMMS, even
// if the University of California has been advised of the possibility of
// such damage.
//
// The OpenMMS provided herein is on an "as is" basis, and the
// University of California has no obligation to provide maintenance,
// support, updates, enhancements, or modifications.  The University of
// California makes no representations and extends no warranties of any
// kind, either implied or express, including, but not limited to, the
// implied warranties of merchantability or fitness for a particular
// purpose, or that the use of the OpenMMS will not infringe any patent,
// trademark or other rights.

package org.rcsb.openmms.loader;

import java.util.*;
import org.omg.DsLSRMacromolecularStructure.*;
import org.omg.DsLSRMmsReference.*;
import org.omg.DsLSRXRayCrystallography.*;
import org.omg.DsLSRNmr.*;

/**
 * The Entry/Subentry classes contain the arrays of data structures
 * that store all of the information known about a particular entry
 * (i.e. an MMS structure) as well as the methods for accessing
 * those data structures.
 * <p>
 * Generated by the program MMSExpr. Model: Std, Revision: 3.0
 * <p>
 * Date: Tue Jul 29 17:48:42 PDT 2003
 *
 * @author Douglas S. Greer
 * @version OpenMMS Release V_1_5_1
 */
public abstract class XRayCrystallographyEntryMethodImpl
     extends XRayCrystallographyEntryPOA
    {
    public XRayCrystallographyEntryMethodImpl()
        {
        }

    abstract public boolean initEntry()
            throws DataAccessException;
    abstract public Object[] getList(int sFlag)
            throws DataAccessException;
    abstract public int getListSize(int sFlag)
            throws DataAccessException;
    abstract public Object[] getListBlock(int sFlag, int from, int to)
            throws DataAccessException;
    abstract public boolean cacheValue(Object[] var, int sFlag)
            throws DataAccessException;

    public byte[] _presence_flags
            = new byte[(XRayCrystallographyEntry.MAX_FLAG/8)+1];

    // ______ ATOM_SITES ______ //
    public AtomSites[] _atom_sites_list;
    public int atom_sites_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_atom_sites_list != null)
            {
                return _atom_sites_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_ATOM_SITES);
            }
        }

    public AtomSites[] get_atom_sites_list()
        throws DataAccessException
        {
            AtomSites[] var = null;
            boolean allVarsRead = initEntry();
            if (_atom_sites_list != null)
            {
                var = _atom_sites_list;
            }
            else if ( ! allVarsRead)
            {
                var = (AtomSites[]) getList(XRayCrystallographyEntry.S_ATOM_SITES);
                if (cacheValue(var, XRayCrystallographyEntry.S_ATOM_SITES))
                {
                    _atom_sites_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_atom_sites_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ ATOM_SITES_ALT ______ //
    public AtomSitesAlt[] _atom_sites_alt_list;
    public int atom_sites_alt_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_atom_sites_alt_list != null)
            {
                return _atom_sites_alt_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_ATOM_SITES_ALT);
            }
        }

    public AtomSitesAlt[] get_atom_sites_alt_list()
        throws DataAccessException
        {
            AtomSitesAlt[] var = null;
            boolean allVarsRead = initEntry();
            if (_atom_sites_alt_list != null)
            {
                var = _atom_sites_alt_list;
            }
            else if ( ! allVarsRead)
            {
                var = (AtomSitesAlt[]) getList(XRayCrystallographyEntry.S_ATOM_SITES_ALT);
                if (cacheValue(var, XRayCrystallographyEntry.S_ATOM_SITES_ALT))
                {
                    _atom_sites_alt_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_atom_sites_alt_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ ATOM_SITES_ALT_ENS ______ //
    public AtomSitesAltEns[] _atom_sites_alt_ens_list;
    public int atom_sites_alt_ens_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_atom_sites_alt_ens_list != null)
            {
                return _atom_sites_alt_ens_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_ATOM_SITES_ALT_ENS);
            }
        }

    public AtomSitesAltEns[] get_atom_sites_alt_ens_list()
        throws DataAccessException
        {
            AtomSitesAltEns[] var = null;
            boolean allVarsRead = initEntry();
            if (_atom_sites_alt_ens_list != null)
            {
                var = _atom_sites_alt_ens_list;
            }
            else if ( ! allVarsRead)
            {
                var = (AtomSitesAltEns[]) getList(XRayCrystallographyEntry.S_ATOM_SITES_ALT_ENS);
                if (cacheValue(var, XRayCrystallographyEntry.S_ATOM_SITES_ALT_ENS))
                {
                    _atom_sites_alt_ens_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_atom_sites_alt_ens_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ ATOM_SITES_ALT_GEN ______ //
    public AtomSitesAltGen[] _atom_sites_alt_gen_list;
    public int atom_sites_alt_gen_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_atom_sites_alt_gen_list != null)
            {
                return _atom_sites_alt_gen_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_ATOM_SITES_ALT_GEN);
            }
        }

    public AtomSitesAltGen[] get_atom_sites_alt_gen_list()
        throws DataAccessException
        {
            AtomSitesAltGen[] var = null;
            boolean allVarsRead = initEntry();
            if (_atom_sites_alt_gen_list != null)
            {
                var = _atom_sites_alt_gen_list;
            }
            else if ( ! allVarsRead)
            {
                var = (AtomSitesAltGen[]) getList(XRayCrystallographyEntry.S_ATOM_SITES_ALT_GEN);
                if (cacheValue(var, XRayCrystallographyEntry.S_ATOM_SITES_ALT_GEN))
                {
                    _atom_sites_alt_gen_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_atom_sites_alt_gen_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ ATOM_SITES_FOOTNOTE ______ //
    public AtomSitesFootnote[] _atom_sites_footnote_list;
    public int atom_sites_footnote_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_atom_sites_footnote_list != null)
            {
                return _atom_sites_footnote_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_ATOM_SITES_FOOTNOTE);
            }
        }

    public AtomSitesFootnote[] get_atom_sites_footnote_list()
        throws DataAccessException
        {
            AtomSitesFootnote[] var = null;
            boolean allVarsRead = initEntry();
            if (_atom_sites_footnote_list != null)
            {
                var = _atom_sites_footnote_list;
            }
            else if ( ! allVarsRead)
            {
                var = (AtomSitesFootnote[]) getList(XRayCrystallographyEntry.S_ATOM_SITES_FOOTNOTE);
                if (cacheValue(var, XRayCrystallographyEntry.S_ATOM_SITES_FOOTNOTE))
                {
                    _atom_sites_footnote_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_atom_sites_footnote_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ CELL ______ //
    public Cell[] _cell_list;
    public int cell_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_cell_list != null)
            {
                return _cell_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_CELL);
            }
        }

    public Cell[] get_cell_list()
        throws DataAccessException
        {
            Cell[] var = null;
            boolean allVarsRead = initEntry();
            if (_cell_list != null)
            {
                var = _cell_list;
            }
            else if ( ! allVarsRead)
            {
                var = (Cell[]) getList(XRayCrystallographyEntry.S_CELL);
                if (cacheValue(var, XRayCrystallographyEntry.S_CELL))
                {
                    _cell_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_cell_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ CELL_MEASUREMENT ______ //
    public CellMeasurement[] _cell_measurement_list;
    public int cell_measurement_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_cell_measurement_list != null)
            {
                return _cell_measurement_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_CELL_MEASUREMENT);
            }
        }

    public CellMeasurement[] get_cell_measurement_list()
        throws DataAccessException
        {
            CellMeasurement[] var = null;
            boolean allVarsRead = initEntry();
            if (_cell_measurement_list != null)
            {
                var = _cell_measurement_list;
            }
            else if ( ! allVarsRead)
            {
                var = (CellMeasurement[]) getList(XRayCrystallographyEntry.S_CELL_MEASUREMENT);
                if (cacheValue(var, XRayCrystallographyEntry.S_CELL_MEASUREMENT))
                {
                    _cell_measurement_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_cell_measurement_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ CELL_MEASUREMENT_REFLN ______ //
    public CellMeasurementRefln[] _cell_measurement_refln_list;
    public int cell_measurement_refln_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_cell_measurement_refln_list != null)
            {
                return _cell_measurement_refln_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_CELL_MEASUREMENT_REFLN);
            }
        }

    public CellMeasurementRefln[] get_cell_measurement_refln_list()
        throws DataAccessException
        {
            CellMeasurementRefln[] var = null;
            boolean allVarsRead = initEntry();
            if (_cell_measurement_refln_list != null)
            {
                var = _cell_measurement_refln_list;
            }
            else if ( ! allVarsRead)
            {
                var = (CellMeasurementRefln[]) getList(XRayCrystallographyEntry.S_CELL_MEASUREMENT_REFLN);
                if (cacheValue(var, XRayCrystallographyEntry.S_CELL_MEASUREMENT_REFLN))
                {
                    _cell_measurement_refln_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_cell_measurement_refln_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ DIFFRN ______ //
    public Diffrn[] _diffrn_list;
    public int diffrn_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_diffrn_list != null)
            {
                return _diffrn_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_DIFFRN);
            }
        }

    public Diffrn[] get_diffrn_list()
        throws DataAccessException
        {
            Diffrn[] var = null;
            boolean allVarsRead = initEntry();
            if (_diffrn_list != null)
            {
                var = _diffrn_list;
            }
            else if ( ! allVarsRead)
            {
                var = (Diffrn[]) getList(XRayCrystallographyEntry.S_DIFFRN);
                if (cacheValue(var, XRayCrystallographyEntry.S_DIFFRN))
                {
                    _diffrn_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_diffrn_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ DIFFRN_ATTENUATOR ______ //
    public DiffrnAttenuator[] _diffrn_attenuator_list;
    public int diffrn_attenuator_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_diffrn_attenuator_list != null)
            {
                return _diffrn_attenuator_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_DIFFRN_ATTENUATOR);
            }
        }

    public DiffrnAttenuator[] get_diffrn_attenuator_list()
        throws DataAccessException
        {
            DiffrnAttenuator[] var = null;
            boolean allVarsRead = initEntry();
            if (_diffrn_attenuator_list != null)
            {
                var = _diffrn_attenuator_list;
            }
            else if ( ! allVarsRead)
            {
                var = (DiffrnAttenuator[]) getList(XRayCrystallographyEntry.S_DIFFRN_ATTENUATOR);
                if (cacheValue(var, XRayCrystallographyEntry.S_DIFFRN_ATTENUATOR))
                {
                    _diffrn_attenuator_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_diffrn_attenuator_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ DIFFRN_DETECTOR ______ //
    public DiffrnDetector[] _diffrn_detector_list;
    public int diffrn_detector_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_diffrn_detector_list != null)
            {
                return _diffrn_detector_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_DIFFRN_DETECTOR);
            }
        }

    public DiffrnDetector[] get_diffrn_detector_list()
        throws DataAccessException
        {
            DiffrnDetector[] var = null;
            boolean allVarsRead = initEntry();
            if (_diffrn_detector_list != null)
            {
                var = _diffrn_detector_list;
            }
            else if ( ! allVarsRead)
            {
                var = (DiffrnDetector[]) getList(XRayCrystallographyEntry.S_DIFFRN_DETECTOR);
                if (cacheValue(var, XRayCrystallographyEntry.S_DIFFRN_DETECTOR))
                {
                    _diffrn_detector_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_diffrn_detector_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ DIFFRN_MEASUREMENT ______ //
    public DiffrnMeasurement[] _diffrn_measurement_list;
    public int diffrn_measurement_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_diffrn_measurement_list != null)
            {
                return _diffrn_measurement_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_DIFFRN_MEASUREMENT);
            }
        }

    public DiffrnMeasurement[] get_diffrn_measurement_list()
        throws DataAccessException
        {
            DiffrnMeasurement[] var = null;
            boolean allVarsRead = initEntry();
            if (_diffrn_measurement_list != null)
            {
                var = _diffrn_measurement_list;
            }
            else if ( ! allVarsRead)
            {
                var = (DiffrnMeasurement[]) getList(XRayCrystallographyEntry.S_DIFFRN_MEASUREMENT);
                if (cacheValue(var, XRayCrystallographyEntry.S_DIFFRN_MEASUREMENT))
                {
                    _diffrn_measurement_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_diffrn_measurement_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ DIFFRN_ORIENT_MATRIX ______ //
    public DiffrnOrientMatrix[] _diffrn_orient_matrix_list;
    public int diffrn_orient_matrix_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_diffrn_orient_matrix_list != null)
            {
                return _diffrn_orient_matrix_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_DIFFRN_ORIENT_MATRIX);
            }
        }

    public DiffrnOrientMatrix[] get_diffrn_orient_matrix_list()
        throws DataAccessException
        {
            DiffrnOrientMatrix[] var = null;
            boolean allVarsRead = initEntry();
            if (_diffrn_orient_matrix_list != null)
            {
                var = _diffrn_orient_matrix_list;
            }
            else if ( ! allVarsRead)
            {
                var = (DiffrnOrientMatrix[]) getList(XRayCrystallographyEntry.S_DIFFRN_ORIENT_MATRIX);
                if (cacheValue(var, XRayCrystallographyEntry.S_DIFFRN_ORIENT_MATRIX))
                {
                    _diffrn_orient_matrix_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_diffrn_orient_matrix_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ DIFFRN_ORIENT_REFLN ______ //
    public DiffrnOrientRefln[] _diffrn_orient_refln_list;
    public int diffrn_orient_refln_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_diffrn_orient_refln_list != null)
            {
                return _diffrn_orient_refln_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_DIFFRN_ORIENT_REFLN);
            }
        }

    public DiffrnOrientRefln[] get_diffrn_orient_refln_list()
        throws DataAccessException
        {
            DiffrnOrientRefln[] var = null;
            boolean allVarsRead = initEntry();
            if (_diffrn_orient_refln_list != null)
            {
                var = _diffrn_orient_refln_list;
            }
            else if ( ! allVarsRead)
            {
                var = (DiffrnOrientRefln[]) getList(XRayCrystallographyEntry.S_DIFFRN_ORIENT_REFLN);
                if (cacheValue(var, XRayCrystallographyEntry.S_DIFFRN_ORIENT_REFLN))
                {
                    _diffrn_orient_refln_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_diffrn_orient_refln_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ DIFFRN_RADIATION ______ //
    public DiffrnRadiation[] _diffrn_radiation_list;
    public int diffrn_radiation_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_diffrn_radiation_list != null)
            {
                return _diffrn_radiation_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_DIFFRN_RADIATION);
            }
        }

    public DiffrnRadiation[] get_diffrn_radiation_list()
        throws DataAccessException
        {
            DiffrnRadiation[] var = null;
            boolean allVarsRead = initEntry();
            if (_diffrn_radiation_list != null)
            {
                var = _diffrn_radiation_list;
            }
            else if ( ! allVarsRead)
            {
                var = (DiffrnRadiation[]) getList(XRayCrystallographyEntry.S_DIFFRN_RADIATION);
                if (cacheValue(var, XRayCrystallographyEntry.S_DIFFRN_RADIATION))
                {
                    _diffrn_radiation_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_diffrn_radiation_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ DIFFRN_RADIATION_WAVELENGTH ______ //
    public DiffrnRadiationWavelength[] _diffrn_radiation_wavelength_list;
    public int diffrn_radiation_wavelength_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_diffrn_radiation_wavelength_list != null)
            {
                return _diffrn_radiation_wavelength_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_DIFFRN_RADIATION_WAVELENGTH);
            }
        }

    public DiffrnRadiationWavelength[] get_diffrn_radiation_wavelength_list()
        throws DataAccessException
        {
            DiffrnRadiationWavelength[] var = null;
            boolean allVarsRead = initEntry();
            if (_diffrn_radiation_wavelength_list != null)
            {
                var = _diffrn_radiation_wavelength_list;
            }
            else if ( ! allVarsRead)
            {
                var = (DiffrnRadiationWavelength[]) getList(XRayCrystallographyEntry.S_DIFFRN_RADIATION_WAVELENGTH);
                if (cacheValue(var, XRayCrystallographyEntry.S_DIFFRN_RADIATION_WAVELENGTH))
                {
                    _diffrn_radiation_wavelength_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_diffrn_radiation_wavelength_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ DIFFRN_REFLN ______ //
    public DiffrnRefln[] _diffrn_refln_list;
    public int diffrn_refln_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_diffrn_refln_list != null)
            {
                return _diffrn_refln_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_DIFFRN_REFLN);
            }
        }

    public DiffrnRefln[] get_diffrn_refln_list()
        throws DataAccessException
        {
            DiffrnRefln[] var = null;
            boolean allVarsRead = initEntry();
            if (_diffrn_refln_list != null)
            {
                var = _diffrn_refln_list;
            }
            else if ( ! allVarsRead)
            {
                var = (DiffrnRefln[]) getList(XRayCrystallographyEntry.S_DIFFRN_REFLN);
                if (cacheValue(var, XRayCrystallographyEntry.S_DIFFRN_REFLN))
                {
                    _diffrn_refln_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_diffrn_refln_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ DIFFRN_REFLNS ______ //
    public DiffrnReflns[] _diffrn_reflns_list;
    public int diffrn_reflns_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_diffrn_reflns_list != null)
            {
                return _diffrn_reflns_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_DIFFRN_REFLNS);
            }
        }

    public DiffrnReflns[] get_diffrn_reflns_list()
        throws DataAccessException
        {
            DiffrnReflns[] var = null;
            boolean allVarsRead = initEntry();
            if (_diffrn_reflns_list != null)
            {
                var = _diffrn_reflns_list;
            }
            else if ( ! allVarsRead)
            {
                var = (DiffrnReflns[]) getList(XRayCrystallographyEntry.S_DIFFRN_REFLNS);
                if (cacheValue(var, XRayCrystallographyEntry.S_DIFFRN_REFLNS))
                {
                    _diffrn_reflns_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_diffrn_reflns_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ DIFFRN_SCALE_GROUP ______ //
    public DiffrnScaleGroup[] _diffrn_scale_group_list;
    public int diffrn_scale_group_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_diffrn_scale_group_list != null)
            {
                return _diffrn_scale_group_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_DIFFRN_SCALE_GROUP);
            }
        }

    public DiffrnScaleGroup[] get_diffrn_scale_group_list()
        throws DataAccessException
        {
            DiffrnScaleGroup[] var = null;
            boolean allVarsRead = initEntry();
            if (_diffrn_scale_group_list != null)
            {
                var = _diffrn_scale_group_list;
            }
            else if ( ! allVarsRead)
            {
                var = (DiffrnScaleGroup[]) getList(XRayCrystallographyEntry.S_DIFFRN_SCALE_GROUP);
                if (cacheValue(var, XRayCrystallographyEntry.S_DIFFRN_SCALE_GROUP))
                {
                    _diffrn_scale_group_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_diffrn_scale_group_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ DIFFRN_SOURCE ______ //
    public DiffrnSource[] _diffrn_source_list;
    public int diffrn_source_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_diffrn_source_list != null)
            {
                return _diffrn_source_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_DIFFRN_SOURCE);
            }
        }

    public DiffrnSource[] get_diffrn_source_list()
        throws DataAccessException
        {
            DiffrnSource[] var = null;
            boolean allVarsRead = initEntry();
            if (_diffrn_source_list != null)
            {
                var = _diffrn_source_list;
            }
            else if ( ! allVarsRead)
            {
                var = (DiffrnSource[]) getList(XRayCrystallographyEntry.S_DIFFRN_SOURCE);
                if (cacheValue(var, XRayCrystallographyEntry.S_DIFFRN_SOURCE))
                {
                    _diffrn_source_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_diffrn_source_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ DIFFRN_STANDARD_REFLN ______ //
    public DiffrnStandardRefln[] _diffrn_standard_refln_list;
    public int diffrn_standard_refln_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_diffrn_standard_refln_list != null)
            {
                return _diffrn_standard_refln_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_DIFFRN_STANDARD_REFLN);
            }
        }

    public DiffrnStandardRefln[] get_diffrn_standard_refln_list()
        throws DataAccessException
        {
            DiffrnStandardRefln[] var = null;
            boolean allVarsRead = initEntry();
            if (_diffrn_standard_refln_list != null)
            {
                var = _diffrn_standard_refln_list;
            }
            else if ( ! allVarsRead)
            {
                var = (DiffrnStandardRefln[]) getList(XRayCrystallographyEntry.S_DIFFRN_STANDARD_REFLN);
                if (cacheValue(var, XRayCrystallographyEntry.S_DIFFRN_STANDARD_REFLN))
                {
                    _diffrn_standard_refln_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_diffrn_standard_refln_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ DIFFRN_STANDARDS ______ //
    public DiffrnStandards[] _diffrn_standards_list;
    public int diffrn_standards_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_diffrn_standards_list != null)
            {
                return _diffrn_standards_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_DIFFRN_STANDARDS);
            }
        }

    public DiffrnStandards[] get_diffrn_standards_list()
        throws DataAccessException
        {
            DiffrnStandards[] var = null;
            boolean allVarsRead = initEntry();
            if (_diffrn_standards_list != null)
            {
                var = _diffrn_standards_list;
            }
            else if ( ! allVarsRead)
            {
                var = (DiffrnStandards[]) getList(XRayCrystallographyEntry.S_DIFFRN_STANDARDS);
                if (cacheValue(var, XRayCrystallographyEntry.S_DIFFRN_STANDARDS))
                {
                    _diffrn_standards_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_diffrn_standards_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ EXPTL ______ //
    public Exptl[] _exptl_list;
    public int exptl_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_exptl_list != null)
            {
                return _exptl_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_EXPTL);
            }
        }

    public Exptl[] get_exptl_list()
        throws DataAccessException
        {
            Exptl[] var = null;
            boolean allVarsRead = initEntry();
            if (_exptl_list != null)
            {
                var = _exptl_list;
            }
            else if ( ! allVarsRead)
            {
                var = (Exptl[]) getList(XRayCrystallographyEntry.S_EXPTL);
                if (cacheValue(var, XRayCrystallographyEntry.S_EXPTL))
                {
                    _exptl_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_exptl_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ EXPTL_CRYSTAL ______ //
    public ExptlCrystal[] _exptl_crystal_list;
    public int exptl_crystal_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_exptl_crystal_list != null)
            {
                return _exptl_crystal_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_EXPTL_CRYSTAL);
            }
        }

    public ExptlCrystal[] get_exptl_crystal_list()
        throws DataAccessException
        {
            ExptlCrystal[] var = null;
            boolean allVarsRead = initEntry();
            if (_exptl_crystal_list != null)
            {
                var = _exptl_crystal_list;
            }
            else if ( ! allVarsRead)
            {
                var = (ExptlCrystal[]) getList(XRayCrystallographyEntry.S_EXPTL_CRYSTAL);
                if (cacheValue(var, XRayCrystallographyEntry.S_EXPTL_CRYSTAL))
                {
                    _exptl_crystal_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_exptl_crystal_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ EXPTL_CRYSTAL_FACE ______ //
    public ExptlCrystalFace[] _exptl_crystal_face_list;
    public int exptl_crystal_face_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_exptl_crystal_face_list != null)
            {
                return _exptl_crystal_face_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_EXPTL_CRYSTAL_FACE);
            }
        }

    public ExptlCrystalFace[] get_exptl_crystal_face_list()
        throws DataAccessException
        {
            ExptlCrystalFace[] var = null;
            boolean allVarsRead = initEntry();
            if (_exptl_crystal_face_list != null)
            {
                var = _exptl_crystal_face_list;
            }
            else if ( ! allVarsRead)
            {
                var = (ExptlCrystalFace[]) getList(XRayCrystallographyEntry.S_EXPTL_CRYSTAL_FACE);
                if (cacheValue(var, XRayCrystallographyEntry.S_EXPTL_CRYSTAL_FACE))
                {
                    _exptl_crystal_face_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_exptl_crystal_face_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ EXPTL_CRYSTAL_GROW ______ //
    public ExptlCrystalGrow[] _exptl_crystal_grow_list;
    public int exptl_crystal_grow_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_exptl_crystal_grow_list != null)
            {
                return _exptl_crystal_grow_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_EXPTL_CRYSTAL_GROW);
            }
        }

    public ExptlCrystalGrow[] get_exptl_crystal_grow_list()
        throws DataAccessException
        {
            ExptlCrystalGrow[] var = null;
            boolean allVarsRead = initEntry();
            if (_exptl_crystal_grow_list != null)
            {
                var = _exptl_crystal_grow_list;
            }
            else if ( ! allVarsRead)
            {
                var = (ExptlCrystalGrow[]) getList(XRayCrystallographyEntry.S_EXPTL_CRYSTAL_GROW);
                if (cacheValue(var, XRayCrystallographyEntry.S_EXPTL_CRYSTAL_GROW))
                {
                    _exptl_crystal_grow_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_exptl_crystal_grow_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ EXPTL_CRYSTAL_GROW_COMP ______ //
    public ExptlCrystalGrowComp[] _exptl_crystal_grow_comp_list;
    public int exptl_crystal_grow_comp_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_exptl_crystal_grow_comp_list != null)
            {
                return _exptl_crystal_grow_comp_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_EXPTL_CRYSTAL_GROW_COMP);
            }
        }

    public ExptlCrystalGrowComp[] get_exptl_crystal_grow_comp_list()
        throws DataAccessException
        {
            ExptlCrystalGrowComp[] var = null;
            boolean allVarsRead = initEntry();
            if (_exptl_crystal_grow_comp_list != null)
            {
                var = _exptl_crystal_grow_comp_list;
            }
            else if ( ! allVarsRead)
            {
                var = (ExptlCrystalGrowComp[]) getList(XRayCrystallographyEntry.S_EXPTL_CRYSTAL_GROW_COMP);
                if (cacheValue(var, XRayCrystallographyEntry.S_EXPTL_CRYSTAL_GROW_COMP))
                {
                    _exptl_crystal_grow_comp_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_exptl_crystal_grow_comp_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ PHASING ______ //
    public Phasing[] _phasing_list;
    public int phasing_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_phasing_list != null)
            {
                return _phasing_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_PHASING);
            }
        }

    public Phasing[] get_phasing_list()
        throws DataAccessException
        {
            Phasing[] var = null;
            boolean allVarsRead = initEntry();
            if (_phasing_list != null)
            {
                var = _phasing_list;
            }
            else if ( ! allVarsRead)
            {
                var = (Phasing[]) getList(XRayCrystallographyEntry.S_PHASING);
                if (cacheValue(var, XRayCrystallographyEntry.S_PHASING))
                {
                    _phasing_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_phasing_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ PHASING_AVERAGING ______ //
    public PhasingAveraging[] _phasing_averaging_list;
    public int phasing_averaging_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_phasing_averaging_list != null)
            {
                return _phasing_averaging_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_PHASING_AVERAGING);
            }
        }

    public PhasingAveraging[] get_phasing_averaging_list()
        throws DataAccessException
        {
            PhasingAveraging[] var = null;
            boolean allVarsRead = initEntry();
            if (_phasing_averaging_list != null)
            {
                var = _phasing_averaging_list;
            }
            else if ( ! allVarsRead)
            {
                var = (PhasingAveraging[]) getList(XRayCrystallographyEntry.S_PHASING_AVERAGING);
                if (cacheValue(var, XRayCrystallographyEntry.S_PHASING_AVERAGING))
                {
                    _phasing_averaging_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_phasing_averaging_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ PHASING_ISOMORPHOUS ______ //
    public PhasingIsomorphous[] _phasing_isomorphous_list;
    public int phasing_isomorphous_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_phasing_isomorphous_list != null)
            {
                return _phasing_isomorphous_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_PHASING_ISOMORPHOUS);
            }
        }

    public PhasingIsomorphous[] get_phasing_isomorphous_list()
        throws DataAccessException
        {
            PhasingIsomorphous[] var = null;
            boolean allVarsRead = initEntry();
            if (_phasing_isomorphous_list != null)
            {
                var = _phasing_isomorphous_list;
            }
            else if ( ! allVarsRead)
            {
                var = (PhasingIsomorphous[]) getList(XRayCrystallographyEntry.S_PHASING_ISOMORPHOUS);
                if (cacheValue(var, XRayCrystallographyEntry.S_PHASING_ISOMORPHOUS))
                {
                    _phasing_isomorphous_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_phasing_isomorphous_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ PHASING_MAD ______ //
    public PhasingMad[] _phasing_mad_list;
    public int phasing_mad_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_phasing_mad_list != null)
            {
                return _phasing_mad_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_PHASING_MAD);
            }
        }

    public PhasingMad[] get_phasing_mad_list()
        throws DataAccessException
        {
            PhasingMad[] var = null;
            boolean allVarsRead = initEntry();
            if (_phasing_mad_list != null)
            {
                var = _phasing_mad_list;
            }
            else if ( ! allVarsRead)
            {
                var = (PhasingMad[]) getList(XRayCrystallographyEntry.S_PHASING_MAD);
                if (cacheValue(var, XRayCrystallographyEntry.S_PHASING_MAD))
                {
                    _phasing_mad_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_phasing_mad_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ PHASING_MAD_CLUST ______ //
    public PhasingMadClust[] _phasing_mad_clust_list;
    public int phasing_mad_clust_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_phasing_mad_clust_list != null)
            {
                return _phasing_mad_clust_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_PHASING_MAD_CLUST);
            }
        }

    public PhasingMadClust[] get_phasing_mad_clust_list()
        throws DataAccessException
        {
            PhasingMadClust[] var = null;
            boolean allVarsRead = initEntry();
            if (_phasing_mad_clust_list != null)
            {
                var = _phasing_mad_clust_list;
            }
            else if ( ! allVarsRead)
            {
                var = (PhasingMadClust[]) getList(XRayCrystallographyEntry.S_PHASING_MAD_CLUST);
                if (cacheValue(var, XRayCrystallographyEntry.S_PHASING_MAD_CLUST))
                {
                    _phasing_mad_clust_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_phasing_mad_clust_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ PHASING_MAD_EXPT ______ //
    public PhasingMadExpt[] _phasing_mad_expt_list;
    public int phasing_mad_expt_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_phasing_mad_expt_list != null)
            {
                return _phasing_mad_expt_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_PHASING_MAD_EXPT);
            }
        }

    public PhasingMadExpt[] get_phasing_mad_expt_list()
        throws DataAccessException
        {
            PhasingMadExpt[] var = null;
            boolean allVarsRead = initEntry();
            if (_phasing_mad_expt_list != null)
            {
                var = _phasing_mad_expt_list;
            }
            else if ( ! allVarsRead)
            {
                var = (PhasingMadExpt[]) getList(XRayCrystallographyEntry.S_PHASING_MAD_EXPT);
                if (cacheValue(var, XRayCrystallographyEntry.S_PHASING_MAD_EXPT))
                {
                    _phasing_mad_expt_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_phasing_mad_expt_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ PHASING_MAD_RATIO ______ //
    public PhasingMadRatio[] _phasing_mad_ratio_list;
    public int phasing_mad_ratio_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_phasing_mad_ratio_list != null)
            {
                return _phasing_mad_ratio_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_PHASING_MAD_RATIO);
            }
        }

    public PhasingMadRatio[] get_phasing_mad_ratio_list()
        throws DataAccessException
        {
            PhasingMadRatio[] var = null;
            boolean allVarsRead = initEntry();
            if (_phasing_mad_ratio_list != null)
            {
                var = _phasing_mad_ratio_list;
            }
            else if ( ! allVarsRead)
            {
                var = (PhasingMadRatio[]) getList(XRayCrystallographyEntry.S_PHASING_MAD_RATIO);
                if (cacheValue(var, XRayCrystallographyEntry.S_PHASING_MAD_RATIO))
                {
                    _phasing_mad_ratio_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_phasing_mad_ratio_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ PHASING_MAD_SET ______ //
    public PhasingMadSet[] _phasing_mad_set_list;
    public int phasing_mad_set_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_phasing_mad_set_list != null)
            {
                return _phasing_mad_set_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_PHASING_MAD_SET);
            }
        }

    public PhasingMadSet[] get_phasing_mad_set_list()
        throws DataAccessException
        {
            PhasingMadSet[] var = null;
            boolean allVarsRead = initEntry();
            if (_phasing_mad_set_list != null)
            {
                var = _phasing_mad_set_list;
            }
            else if ( ! allVarsRead)
            {
                var = (PhasingMadSet[]) getList(XRayCrystallographyEntry.S_PHASING_MAD_SET);
                if (cacheValue(var, XRayCrystallographyEntry.S_PHASING_MAD_SET))
                {
                    _phasing_mad_set_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_phasing_mad_set_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ PHASING_MIR ______ //
    public PhasingMir[] _phasing_mir_list;
    public int phasing_mir_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_phasing_mir_list != null)
            {
                return _phasing_mir_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_PHASING_MIR);
            }
        }

    public PhasingMir[] get_phasing_mir_list()
        throws DataAccessException
        {
            PhasingMir[] var = null;
            boolean allVarsRead = initEntry();
            if (_phasing_mir_list != null)
            {
                var = _phasing_mir_list;
            }
            else if ( ! allVarsRead)
            {
                var = (PhasingMir[]) getList(XRayCrystallographyEntry.S_PHASING_MIR);
                if (cacheValue(var, XRayCrystallographyEntry.S_PHASING_MIR))
                {
                    _phasing_mir_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_phasing_mir_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ PHASING_MIR_DER ______ //
    public PhasingMirDer[] _phasing_mir_der_list;
    public int phasing_mir_der_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_phasing_mir_der_list != null)
            {
                return _phasing_mir_der_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_PHASING_MIR_DER);
            }
        }

    public PhasingMirDer[] get_phasing_mir_der_list()
        throws DataAccessException
        {
            PhasingMirDer[] var = null;
            boolean allVarsRead = initEntry();
            if (_phasing_mir_der_list != null)
            {
                var = _phasing_mir_der_list;
            }
            else if ( ! allVarsRead)
            {
                var = (PhasingMirDer[]) getList(XRayCrystallographyEntry.S_PHASING_MIR_DER);
                if (cacheValue(var, XRayCrystallographyEntry.S_PHASING_MIR_DER))
                {
                    _phasing_mir_der_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_phasing_mir_der_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ PHASING_MIR_DER_REFLN ______ //
    public PhasingMirDerRefln[] _phasing_mir_der_refln_list;
    public int phasing_mir_der_refln_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_phasing_mir_der_refln_list != null)
            {
                return _phasing_mir_der_refln_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_PHASING_MIR_DER_REFLN);
            }
        }

    public PhasingMirDerRefln[] get_phasing_mir_der_refln_list()
        throws DataAccessException
        {
            PhasingMirDerRefln[] var = null;
            boolean allVarsRead = initEntry();
            if (_phasing_mir_der_refln_list != null)
            {
                var = _phasing_mir_der_refln_list;
            }
            else if ( ! allVarsRead)
            {
                var = (PhasingMirDerRefln[]) getList(XRayCrystallographyEntry.S_PHASING_MIR_DER_REFLN);
                if (cacheValue(var, XRayCrystallographyEntry.S_PHASING_MIR_DER_REFLN))
                {
                    _phasing_mir_der_refln_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_phasing_mir_der_refln_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ PHASING_MIR_DER_SHELL ______ //
    public PhasingMirDerShell[] _phasing_mir_der_shell_list;
    public int phasing_mir_der_shell_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_phasing_mir_der_shell_list != null)
            {
                return _phasing_mir_der_shell_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_PHASING_MIR_DER_SHELL);
            }
        }

    public PhasingMirDerShell[] get_phasing_mir_der_shell_list()
        throws DataAccessException
        {
            PhasingMirDerShell[] var = null;
            boolean allVarsRead = initEntry();
            if (_phasing_mir_der_shell_list != null)
            {
                var = _phasing_mir_der_shell_list;
            }
            else if ( ! allVarsRead)
            {
                var = (PhasingMirDerShell[]) getList(XRayCrystallographyEntry.S_PHASING_MIR_DER_SHELL);
                if (cacheValue(var, XRayCrystallographyEntry.S_PHASING_MIR_DER_SHELL))
                {
                    _phasing_mir_der_shell_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_phasing_mir_der_shell_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ PHASING_MIR_DER_SITE ______ //
    public PhasingMirDerSite[] _phasing_mir_der_site_list;
    public int phasing_mir_der_site_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_phasing_mir_der_site_list != null)
            {
                return _phasing_mir_der_site_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_PHASING_MIR_DER_SITE);
            }
        }

    public PhasingMirDerSite[] get_phasing_mir_der_site_list()
        throws DataAccessException
        {
            PhasingMirDerSite[] var = null;
            boolean allVarsRead = initEntry();
            if (_phasing_mir_der_site_list != null)
            {
                var = _phasing_mir_der_site_list;
            }
            else if ( ! allVarsRead)
            {
                var = (PhasingMirDerSite[]) getList(XRayCrystallographyEntry.S_PHASING_MIR_DER_SITE);
                if (cacheValue(var, XRayCrystallographyEntry.S_PHASING_MIR_DER_SITE))
                {
                    _phasing_mir_der_site_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_phasing_mir_der_site_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ PHASING_MIR_SHELL ______ //
    public PhasingMirShell[] _phasing_mir_shell_list;
    public int phasing_mir_shell_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_phasing_mir_shell_list != null)
            {
                return _phasing_mir_shell_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_PHASING_MIR_SHELL);
            }
        }

    public PhasingMirShell[] get_phasing_mir_shell_list()
        throws DataAccessException
        {
            PhasingMirShell[] var = null;
            boolean allVarsRead = initEntry();
            if (_phasing_mir_shell_list != null)
            {
                var = _phasing_mir_shell_list;
            }
            else if ( ! allVarsRead)
            {
                var = (PhasingMirShell[]) getList(XRayCrystallographyEntry.S_PHASING_MIR_SHELL);
                if (cacheValue(var, XRayCrystallographyEntry.S_PHASING_MIR_SHELL))
                {
                    _phasing_mir_shell_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_phasing_mir_shell_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ PHASING_SET ______ //
    public PhasingSet[] _phasing_set_list;
    public int phasing_set_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_phasing_set_list != null)
            {
                return _phasing_set_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_PHASING_SET);
            }
        }

    public PhasingSet[] get_phasing_set_list()
        throws DataAccessException
        {
            PhasingSet[] var = null;
            boolean allVarsRead = initEntry();
            if (_phasing_set_list != null)
            {
                var = _phasing_set_list;
            }
            else if ( ! allVarsRead)
            {
                var = (PhasingSet[]) getList(XRayCrystallographyEntry.S_PHASING_SET);
                if (cacheValue(var, XRayCrystallographyEntry.S_PHASING_SET))
                {
                    _phasing_set_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_phasing_set_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ PHASING_SET_REFLN ______ //
    public PhasingSetRefln[] _phasing_set_refln_list;
    public int phasing_set_refln_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_phasing_set_refln_list != null)
            {
                return _phasing_set_refln_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_PHASING_SET_REFLN);
            }
        }

    public PhasingSetRefln[] get_phasing_set_refln_list()
        throws DataAccessException
        {
            PhasingSetRefln[] var = null;
            boolean allVarsRead = initEntry();
            if (_phasing_set_refln_list != null)
            {
                var = _phasing_set_refln_list;
            }
            else if ( ! allVarsRead)
            {
                var = (PhasingSetRefln[]) getList(XRayCrystallographyEntry.S_PHASING_SET_REFLN);
                if (cacheValue(var, XRayCrystallographyEntry.S_PHASING_SET_REFLN))
                {
                    _phasing_set_refln_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_phasing_set_refln_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ REFINE ______ //
    public Refine[] _refine_list;
    public int refine_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_refine_list != null)
            {
                return _refine_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_REFINE);
            }
        }

    public Refine[] get_refine_list()
        throws DataAccessException
        {
            Refine[] var = null;
            boolean allVarsRead = initEntry();
            if (_refine_list != null)
            {
                var = _refine_list;
            }
            else if ( ! allVarsRead)
            {
                var = (Refine[]) getList(XRayCrystallographyEntry.S_REFINE);
                if (cacheValue(var, XRayCrystallographyEntry.S_REFINE))
                {
                    _refine_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_refine_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ REFINE_ANALYZE ______ //
    public RefineAnalyze[] _refine_analyze_list;
    public int refine_analyze_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_refine_analyze_list != null)
            {
                return _refine_analyze_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_REFINE_ANALYZE);
            }
        }

    public RefineAnalyze[] get_refine_analyze_list()
        throws DataAccessException
        {
            RefineAnalyze[] var = null;
            boolean allVarsRead = initEntry();
            if (_refine_analyze_list != null)
            {
                var = _refine_analyze_list;
            }
            else if ( ! allVarsRead)
            {
                var = (RefineAnalyze[]) getList(XRayCrystallographyEntry.S_REFINE_ANALYZE);
                if (cacheValue(var, XRayCrystallographyEntry.S_REFINE_ANALYZE))
                {
                    _refine_analyze_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_refine_analyze_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ REFINE_B_ISO ______ //
    public RefineBIso[] _refine_b_iso_list;
    public int refine_b_iso_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_refine_b_iso_list != null)
            {
                return _refine_b_iso_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_REFINE_B_ISO);
            }
        }

    public RefineBIso[] get_refine_b_iso_list()
        throws DataAccessException
        {
            RefineBIso[] var = null;
            boolean allVarsRead = initEntry();
            if (_refine_b_iso_list != null)
            {
                var = _refine_b_iso_list;
            }
            else if ( ! allVarsRead)
            {
                var = (RefineBIso[]) getList(XRayCrystallographyEntry.S_REFINE_B_ISO);
                if (cacheValue(var, XRayCrystallographyEntry.S_REFINE_B_ISO))
                {
                    _refine_b_iso_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_refine_b_iso_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ REFINE_HIST ______ //
    public RefineHist[] _refine_hist_list;
    public int refine_hist_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_refine_hist_list != null)
            {
                return _refine_hist_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_REFINE_HIST);
            }
        }

    public RefineHist[] get_refine_hist_list()
        throws DataAccessException
        {
            RefineHist[] var = null;
            boolean allVarsRead = initEntry();
            if (_refine_hist_list != null)
            {
                var = _refine_hist_list;
            }
            else if ( ! allVarsRead)
            {
                var = (RefineHist[]) getList(XRayCrystallographyEntry.S_REFINE_HIST);
                if (cacheValue(var, XRayCrystallographyEntry.S_REFINE_HIST))
                {
                    _refine_hist_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_refine_hist_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ REFINE_LS_RESTR ______ //
    public RefineLsRestr[] _refine_ls_restr_list;
    public int refine_ls_restr_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_refine_ls_restr_list != null)
            {
                return _refine_ls_restr_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_REFINE_LS_RESTR);
            }
        }

    public RefineLsRestr[] get_refine_ls_restr_list()
        throws DataAccessException
        {
            RefineLsRestr[] var = null;
            boolean allVarsRead = initEntry();
            if (_refine_ls_restr_list != null)
            {
                var = _refine_ls_restr_list;
            }
            else if ( ! allVarsRead)
            {
                var = (RefineLsRestr[]) getList(XRayCrystallographyEntry.S_REFINE_LS_RESTR);
                if (cacheValue(var, XRayCrystallographyEntry.S_REFINE_LS_RESTR))
                {
                    _refine_ls_restr_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_refine_ls_restr_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ REFINE_LS_RESTR_NCS ______ //
    public RefineLsRestrNcs[] _refine_ls_restr_ncs_list;
    public int refine_ls_restr_ncs_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_refine_ls_restr_ncs_list != null)
            {
                return _refine_ls_restr_ncs_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_REFINE_LS_RESTR_NCS);
            }
        }

    public RefineLsRestrNcs[] get_refine_ls_restr_ncs_list()
        throws DataAccessException
        {
            RefineLsRestrNcs[] var = null;
            boolean allVarsRead = initEntry();
            if (_refine_ls_restr_ncs_list != null)
            {
                var = _refine_ls_restr_ncs_list;
            }
            else if ( ! allVarsRead)
            {
                var = (RefineLsRestrNcs[]) getList(XRayCrystallographyEntry.S_REFINE_LS_RESTR_NCS);
                if (cacheValue(var, XRayCrystallographyEntry.S_REFINE_LS_RESTR_NCS))
                {
                    _refine_ls_restr_ncs_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_refine_ls_restr_ncs_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ REFINE_LS_SHELL ______ //
    public RefineLsShell[] _refine_ls_shell_list;
    public int refine_ls_shell_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_refine_ls_shell_list != null)
            {
                return _refine_ls_shell_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_REFINE_LS_SHELL);
            }
        }

    public RefineLsShell[] get_refine_ls_shell_list()
        throws DataAccessException
        {
            RefineLsShell[] var = null;
            boolean allVarsRead = initEntry();
            if (_refine_ls_shell_list != null)
            {
                var = _refine_ls_shell_list;
            }
            else if ( ! allVarsRead)
            {
                var = (RefineLsShell[]) getList(XRayCrystallographyEntry.S_REFINE_LS_SHELL);
                if (cacheValue(var, XRayCrystallographyEntry.S_REFINE_LS_SHELL))
                {
                    _refine_ls_shell_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_refine_ls_shell_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ REFINE_OCCUPANCY ______ //
    public RefineOccupancy[] _refine_occupancy_list;
    public int refine_occupancy_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_refine_occupancy_list != null)
            {
                return _refine_occupancy_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_REFINE_OCCUPANCY);
            }
        }

    public RefineOccupancy[] get_refine_occupancy_list()
        throws DataAccessException
        {
            RefineOccupancy[] var = null;
            boolean allVarsRead = initEntry();
            if (_refine_occupancy_list != null)
            {
                var = _refine_occupancy_list;
            }
            else if ( ! allVarsRead)
            {
                var = (RefineOccupancy[]) getList(XRayCrystallographyEntry.S_REFINE_OCCUPANCY);
                if (cacheValue(var, XRayCrystallographyEntry.S_REFINE_OCCUPANCY))
                {
                    _refine_occupancy_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_refine_occupancy_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ PDBX_REFINE ______ //
    public PdbxRefine[] _pdbx_refine_list;
    public int pdbx_refine_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_pdbx_refine_list != null)
            {
                return _pdbx_refine_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_PDBX_REFINE);
            }
        }

    public PdbxRefine[] get_pdbx_refine_list()
        throws DataAccessException
        {
            PdbxRefine[] var = null;
            boolean allVarsRead = initEntry();
            if (_pdbx_refine_list != null)
            {
                var = _pdbx_refine_list;
            }
            else if ( ! allVarsRead)
            {
                var = (PdbxRefine[]) getList(XRayCrystallographyEntry.S_PDBX_REFINE);
                if (cacheValue(var, XRayCrystallographyEntry.S_PDBX_REFINE))
                {
                    _pdbx_refine_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_pdbx_refine_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ PDBX_XPLOR_FILE ______ //
    public PdbxXplorFile[] _pdbx_xplor_file_list;
    public int pdbx_xplor_file_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_pdbx_xplor_file_list != null)
            {
                return _pdbx_xplor_file_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_PDBX_XPLOR_FILE);
            }
        }

    public PdbxXplorFile[] get_pdbx_xplor_file_list()
        throws DataAccessException
        {
            PdbxXplorFile[] var = null;
            boolean allVarsRead = initEntry();
            if (_pdbx_xplor_file_list != null)
            {
                var = _pdbx_xplor_file_list;
            }
            else if ( ! allVarsRead)
            {
                var = (PdbxXplorFile[]) getList(XRayCrystallographyEntry.S_PDBX_XPLOR_FILE);
                if (cacheValue(var, XRayCrystallographyEntry.S_PDBX_XPLOR_FILE))
                {
                    _pdbx_xplor_file_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_pdbx_xplor_file_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ PDBX_REFINE_AUX_FILE ______ //
    public PdbxRefineAuxFile[] _pdbx_refine_aux_file_list;
    public int pdbx_refine_aux_file_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_pdbx_refine_aux_file_list != null)
            {
                return _pdbx_refine_aux_file_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_PDBX_REFINE_AUX_FILE);
            }
        }

    public PdbxRefineAuxFile[] get_pdbx_refine_aux_file_list()
        throws DataAccessException
        {
            PdbxRefineAuxFile[] var = null;
            boolean allVarsRead = initEntry();
            if (_pdbx_refine_aux_file_list != null)
            {
                var = _pdbx_refine_aux_file_list;
            }
            else if ( ! allVarsRead)
            {
                var = (PdbxRefineAuxFile[]) getList(XRayCrystallographyEntry.S_PDBX_REFINE_AUX_FILE);
                if (cacheValue(var, XRayCrystallographyEntry.S_PDBX_REFINE_AUX_FILE))
                {
                    _pdbx_refine_aux_file_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_pdbx_refine_aux_file_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ PDBX_REFINE_TLS ______ //
    public PdbxRefineTls[] _pdbx_refine_tls_list;
    public int pdbx_refine_tls_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_pdbx_refine_tls_list != null)
            {
                return _pdbx_refine_tls_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_PDBX_REFINE_TLS);
            }
        }

    public PdbxRefineTls[] get_pdbx_refine_tls_list()
        throws DataAccessException
        {
            PdbxRefineTls[] var = null;
            boolean allVarsRead = initEntry();
            if (_pdbx_refine_tls_list != null)
            {
                var = _pdbx_refine_tls_list;
            }
            else if ( ! allVarsRead)
            {
                var = (PdbxRefineTls[]) getList(XRayCrystallographyEntry.S_PDBX_REFINE_TLS);
                if (cacheValue(var, XRayCrystallographyEntry.S_PDBX_REFINE_TLS))
                {
                    _pdbx_refine_tls_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_pdbx_refine_tls_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ PDBX_REFINE_TLS_GROUP ______ //
    public PdbxRefineTlsGroup[] _pdbx_refine_tls_group_list;
    public int pdbx_refine_tls_group_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_pdbx_refine_tls_group_list != null)
            {
                return _pdbx_refine_tls_group_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_PDBX_REFINE_TLS_GROUP);
            }
        }

    public PdbxRefineTlsGroup[] get_pdbx_refine_tls_group_list()
        throws DataAccessException
        {
            PdbxRefineTlsGroup[] var = null;
            boolean allVarsRead = initEntry();
            if (_pdbx_refine_tls_group_list != null)
            {
                var = _pdbx_refine_tls_group_list;
            }
            else if ( ! allVarsRead)
            {
                var = (PdbxRefineTlsGroup[]) getList(XRayCrystallographyEntry.S_PDBX_REFINE_TLS_GROUP);
                if (cacheValue(var, XRayCrystallographyEntry.S_PDBX_REFINE_TLS_GROUP))
                {
                    _pdbx_refine_tls_group_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_pdbx_refine_tls_group_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ REFLN ______ //
    public Refln[] _refln_list;
    public int refln_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_refln_list != null)
            {
                return _refln_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_REFLN);
            }
        }

    public Refln[] get_refln_list()
        throws DataAccessException
        {
            Refln[] var = null;
            boolean allVarsRead = initEntry();
            if (_refln_list != null)
            {
                var = _refln_list;
            }
            else if ( ! allVarsRead)
            {
                var = (Refln[]) getList(XRayCrystallographyEntry.S_REFLN);
                if (cacheValue(var, XRayCrystallographyEntry.S_REFLN))
                {
                    _refln_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_refln_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ REFLNS ______ //
    public Reflns[] _reflns_list;
    public int reflns_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_reflns_list != null)
            {
                return _reflns_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_REFLNS);
            }
        }

    public Reflns[] get_reflns_list()
        throws DataAccessException
        {
            Reflns[] var = null;
            boolean allVarsRead = initEntry();
            if (_reflns_list != null)
            {
                var = _reflns_list;
            }
            else if ( ! allVarsRead)
            {
                var = (Reflns[]) getList(XRayCrystallographyEntry.S_REFLNS);
                if (cacheValue(var, XRayCrystallographyEntry.S_REFLNS))
                {
                    _reflns_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_reflns_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ REFLNS_SCALE ______ //
    public ReflnsScale[] _reflns_scale_list;
    public int reflns_scale_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_reflns_scale_list != null)
            {
                return _reflns_scale_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_REFLNS_SCALE);
            }
        }

    public ReflnsScale[] get_reflns_scale_list()
        throws DataAccessException
        {
            ReflnsScale[] var = null;
            boolean allVarsRead = initEntry();
            if (_reflns_scale_list != null)
            {
                var = _reflns_scale_list;
            }
            else if ( ! allVarsRead)
            {
                var = (ReflnsScale[]) getList(XRayCrystallographyEntry.S_REFLNS_SCALE);
                if (cacheValue(var, XRayCrystallographyEntry.S_REFLNS_SCALE))
                {
                    _reflns_scale_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_reflns_scale_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ REFLNS_SHELL ______ //
    public ReflnsShell[] _reflns_shell_list;
    public int reflns_shell_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_reflns_shell_list != null)
            {
                return _reflns_shell_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_REFLNS_SHELL);
            }
        }

    public ReflnsShell[] get_reflns_shell_list()
        throws DataAccessException
        {
            ReflnsShell[] var = null;
            boolean allVarsRead = initEntry();
            if (_reflns_shell_list != null)
            {
                var = _reflns_shell_list;
            }
            else if ( ! allVarsRead)
            {
                var = (ReflnsShell[]) getList(XRayCrystallographyEntry.S_REFLNS_SHELL);
                if (cacheValue(var, XRayCrystallographyEntry.S_REFLNS_SHELL))
                {
                    _reflns_shell_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_reflns_shell_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ SYMMETRY ______ //
    public Symmetry[] _symmetry_list;
    public int symmetry_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_symmetry_list != null)
            {
                return _symmetry_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_SYMMETRY);
            }
        }

    public Symmetry[] get_symmetry_list()
        throws DataAccessException
        {
            Symmetry[] var = null;
            boolean allVarsRead = initEntry();
            if (_symmetry_list != null)
            {
                var = _symmetry_list;
            }
            else if ( ! allVarsRead)
            {
                var = (Symmetry[]) getList(XRayCrystallographyEntry.S_SYMMETRY);
                if (cacheValue(var, XRayCrystallographyEntry.S_SYMMETRY))
                {
                    _symmetry_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_symmetry_list",
                    "Requested data not present");
            }
            return var;
        }

    // ______ SYMMETRY_EQUIV ______ //
    public SymmetryEquiv[] _symmetry_equiv_list;
    public int symmetry_equiv_list_size()
        throws DataAccessException
        {
            boolean allVarsRead = initEntry();
            if (_symmetry_equiv_list != null)
            {
                return _symmetry_equiv_list.length;
            }
            else
            {
                return getListSize(XRayCrystallographyEntry.S_SYMMETRY_EQUIV);
            }
        }

    public SymmetryEquiv[] get_symmetry_equiv_list()
        throws DataAccessException
        {
            SymmetryEquiv[] var = null;
            boolean allVarsRead = initEntry();
            if (_symmetry_equiv_list != null)
            {
                var = _symmetry_equiv_list;
            }
            else if ( ! allVarsRead)
            {
                var = (SymmetryEquiv[]) getList(XRayCrystallographyEntry.S_SYMMETRY_EQUIV);
                if (cacheValue(var, XRayCrystallographyEntry.S_SYMMETRY_EQUIV))
                {
                    _symmetry_equiv_list = var;
                }
            }
            if (var == null)
            {
                throw new DataAccessException("get_symmetry_equiv_list",
                    "Requested data not present");
            }
            return var;
        }

    }
