//
// EntryFoundry.java,v 1.3 2002/06/19 01:55:07 dsg Exp
//
// Copyright 2001 The Regents of the University of California
// All Rights Reserved
//
// OpenMMS was developed by Dr. Douglas S. Greer at the San Diego
// Supercomputer Center, a research unit of the University of California,
// San Diego.  Support for this effort was provided by NSF through the
// Protein Data Bank (Grant DBI-9814284) and the National Partnership for
// Advanced Computational Infrastructure (Grant ACI-9619020)
//
// Permission to use, copy, modify and distribute any part of OpenMMS for
// educational, research and non-profit purposes, without fee, and
// without a written agreement is hereby granted, provided that the above
// copyright notice, this paragraph and the following paragraphs appear
// in all copies.
//
// Those desiring to incorporate this OpenMMS into commercial products or
// use for commercial purposes should contact the Technology Transfer
// Office, University of California, San Diego, 9500 Gilman Drive, La
// Jolla, CA 92093-0910, Ph: (619) 534-5815, FAX: (619) 534-7345.
//
// In no event shall the University of California be liable to any party
// for direct, indirect, special, incidental, or consequential damages,
// including lost profits, arising out of the use of this OpenMMS, even
// if the University of California has been advised of the possibility of
// such damage.
//
// The OpenMMS provided herein is on an "as is" basis, and the
// University of California has no obligation to provide maintenance,
// support, updates, enhancements, or modifications.  The University of
// California makes no representations and extends no warranties of any
// kind, either implied or express, including, but not limited to, the
// implied warranties of merchantability or fitness for a particular
// purpose, or that the use of the OpenMMS will not infringe any patent,
// trademark or other rights.

package org.rcsb.openmms.entry;

import java.io.*;
import java.util.*;

import org.omg.CORBA.ORB;
import org.omg.PortableServer.*;
import org.omg.DsLSRMacromolecularStructure.*;

import org.rcsb.openmms.util.*;

/**
 * Base class for Entry Foundaries (Factories) that create
 * Entry Objects
 *
 * @author Douglas S. Greer
 * @version 1.3
 */
abstract public class EntryFoundry
{
  int debug;
  EntryFoundry next;
  ServerHandler servh;

  public EntryFoundry(ServerHandler a)
    {
      servh = a;
    }

  abstract public boolean allVariablesRead();
  abstract public boolean cacheValue(EntryImpl ei, int modType, int sFlag,
				     Object[] var);
  abstract public EntryImpl createEntryImpl(String id)
    throws DataAccessException;
  abstract public void readEntryData(EntryImpl ei)
    throws DataAccessException;
  abstract public Object[] getList(EntryImpl ei, int modType, int sFlag)
    throws DataAccessException;
  abstract public Object[] getListBlock
    (EntryImpl ei, int modType, int sFlag, int from, int to)
    throws DataAccessException;
  abstract public int getListSize(EntryImpl ei, int modType, int sFlag)
    throws DataAccessException;

  public void setDebug(int d)
    {
      debug = d;
    }

  public void setNext(EntryFoundry ef)
    {
      next = ef;
    }

  public EntryFoundry getNext()
    {
      return next;
    }
  
  public ORB getOrb()
    {
      return servh.getOrb();
    }

  public POA getRootPoa()
    {
      return servh.getRootPoa();
    }
  
  public MessageHandler getMessageHandler()
    {
      return servh;
    }

  public String idToGroup(String id)
    {
      if (id == null)
	{
	  return null;
	}
      return id.substring(1,3);
    }
}
