//
// EntryImpl.java,v 1.10 2003/05/28 01:09:03 dsg Exp
//
// Copyright 2001 The Regents of the University of California
// All Rights Reserved
//
// OpenMMS was developed by Dr. Douglas S. Greer at the San Diego
// Supercomputer Center, a research unit of the University of California,
// San Diego.  Support for this effort was provided by NSF through the
// Protein Data Bank (Grant DBI-9814284) and the National Partnership for
// Advanced Computational Infrastructure (Grant ACI-9619020)
//
// Permission to use, copy, modify and distribute any part of OpenMMS for
// educational, research and non-profit purposes, without fee, and
// without a written agreement is hereby granted, provided that the above
// copyright notice, this paragraph and the following paragraphs appear
// in all copies.
//
// Those desiring to incorporate this OpenMMS into commercial products or
// use for commercial purposes should contact the Technology Transfer
// Office, University of California, San Diego, 9500 Gilman Drive, La
// Jolla, CA 92093-0910, Ph: (619) 534-5815, FAX: (619) 534-7345.
//
// In no event shall the University of California be liable to any party
// for direct, indirect, special, incidental, or consequential damages,
// including lost profits, arising out of the use of this OpenMMS, even
// if the University of California has been advised of the possibility of
// such damage.
//
// The OpenMMS provided herein is on an "as is" basis, and the
// University of California has no obligation to provide maintenance,
// support, updates, enhancements, or modifications.  The University of
// California makes no representations and extends no warranties of any
// kind, either implied or express, including, but not limited to, the
// implied warranties of merchantability or fitness for a particular
// purpose, or that the use of the OpenMMS will not infringe any patent,
// trademark or other rights.

package org.rcsb.openmms.entry;

import java.io.*;
import java.util.*;

import org.omg.CORBA.Any;
import org.omg.PortableServer.*;
import org.omg.CosPropertyService.*;

import org.omg.DsLSRMacromolecularStructure.*;
import org.omg.DsLSRXRayCrystallography.*;
import org.omg.DsLSRMmsReference.*;

import org.rcsb.openmms.util.*;
import org.rcsb.openmms.cifparse.*;
import org.rcsb.openmms.meta.*;
import org.rcsb.openmms.loader.*;

/**
 * This Class, EntryImpl extends EntryMethodImpl
 * which extends _EntryImplBase 
 *
 * EntryMethodImpl is generated by MMSExpr and defines
 * all of the "getList" methods for the Core module.
 *
 * _EntryImplBase is generated by the IDL to Java compiler for
 * the "Entry" Corba interface.
 *
 * @author Douglas S. Greer
 * @version 1.10
 */
public class EntryImpl extends EntryMethodImpl
{
  int debug = 5;
  boolean CifFileRead = false;

  EntryFoundry foundry;
  String entryId;
  String entryPath;
  int key;

  Date depositionDate = new Date();

  public EntryImpl(String id, EntryFoundry e)
    {
      entryId = id;
      foundry = e;

      // %% Sub-Modules names are hard coded here. This should
      // %%  probably be in the EntryMethodImpl.java generated code.
      xray = new XRayCrystallographyEntryImpl(this);
      nmr = new NmrEntryImpl(this);
      ref = new MmsReferenceEntryImpl(this);
    }

  public EntryImpl(String id, EntryFoundry e,  String path)
    {
      // mmCIF file constructor
      this(id, e);
      entryPath = path;
      key = -1;
    }

  public EntryImpl(String id, EntryFoundry e,  int k)
    {
      // Database constructor
      this(id, e);
      entryPath = "NO_PATH";
      key = k;
    }

  public void setDebug(int d)
    {
      debug = d;
    }

  public String getEntryId()
    {
      return entryId;
    }

  public EntryFoundry getFoundry()
    {
      return foundry;
    }

  /**
   * The existing presence flags are set to the OR of the specified flags
   * and the old value.
   */
  public void setPresenceFlags(int mod, byte[] also)
    {
      byte[] vs = null;
      switch (mod)
	{
	case ModuleTypes.MMS_CORE:
	  vs = _presence_flags;
	  break;
	case ModuleTypes.MMS_XRAY_CRYSTALLOGRAPHY:
	  vs = xray._presence_flags;
	  break;
	case ModuleTypes.MMS_NUCLEAR_MAGNETIC_RESONANCE:
	  vs = nmr._presence_flags;
	  break;
	case ModuleTypes.MMS_REFERENCE:
	  vs = ref._presence_flags;
	  break;
	}
      if (vs != null)
	{
	  for (int i = 0; i < vs.length; i++)
	    {
	      vs[i] |= also[i];
	    }
	}
    }

  public byte[] getPresenceFlags(int mod)
    {
      byte[] vs = null;
      switch (mod)
	{
	case ModuleTypes.MMS_CORE:
	  vs = _presence_flags;
	  break;
	case ModuleTypes.MMS_XRAY_CRYSTALLOGRAPHY:
	  vs = xray._presence_flags;
	  break;
	case ModuleTypes.MMS_NUCLEAR_MAGNETIC_RESONANCE:
	  vs = nmr._presence_flags;
	  break;
	case ModuleTypes.MMS_REFERENCE:
	  vs = ref._presence_flags;
	  break;
	}
      return vs;
    }

  public String getPath()
    {
      return entryPath;
    }

  public int getKey()
    {
      return key;
    }

  public void setDepositionDate(Date dt)
    {
      depositionDate = dt;
    }

  public Date getDepositionDate()
    {
      return depositionDate;
    }

  public byte[] get_presence_flags()
    throws DataAccessException
    {
      initEntry();
      return _presence_flags;
    }
  
  public Property[] get_subentry_list()
    throws DataAccessException
    {
      Property[] plist;
      Any a;
      
      try
	{
	  initEntry();
	  
	  // %% Sub-Modules are hard coded here. Should be done
	  // %% using defines ModuleTypes.java
	  plist = new Property[3];

	  plist[0] = new Property();
	  plist[0].property_name = "MmsReferenceEntry";
	  a = foundry.getOrb().create_any();
	  a.insert_Object(foundry.getRootPoa().servant_to_reference(ref));
	  plist[0].property_value = a;

	  plist[1] = new Property();
	  plist[1].property_name = "XRayCrystallographyEntry";
	  a = foundry.getOrb().create_any();
	  a.insert_Object(foundry.getRootPoa().servant_to_reference(xray));
	  plist[1].property_value = a;

	  plist[2] = new Property();
	  plist[2].property_name = "NMREntry";
	  a = foundry.getOrb().create_any();
	  a.insert_Object(foundry.getRootPoa().servant_to_reference(nmr));
	  plist[2].property_value = a;
	  
	}
      catch(Exception e)
	{
	  String err = "Error while reading entry: " + entryId 
	    + "\nException thrown during get_subentry_list():\n";
	  // Send debugging output to log file
	  if (debug > 0)
	    {
	      String msg = err + "\n" + e;
	      foundry.getMessageHandler().logMessage(msg);
	      System.err.println(msg);
	      e.printStackTrace();
	    }
	  // throw a Corba DataAccess exception
	  throw new DataAccessException
	    ("get_subentry_list",
	     "Exception in get_subentry_list()\n" + e);
	}
      return plist;
    }
  
  /**
   * Overide initEntry dummy method in MMSExpr generated
   * EntryMethodImpl superclass
   * Returns true if all variable values have been read when the
   * file was inited.
   */
  public boolean initEntry()
    throws DataAccessException
    {
      if ( ! CifFileRead)
	{
	  foundry.readEntryData(this);
	  CifFileRead = true;
	}
      return foundry.allVariablesRead();
    }

  public void setCompositeSeqIndexList(ArrayList sia)
    {
      for(int i = 0; i < sia.size(); i++)
	{
	  SeqIndex si = (SeqIndex) sia.get(i);
	  si.seq.index = computeCompositeSeqIndex(si.seq.id, si.comp.id,
						  si.asym.index);
	}
    }

  public void setCompositeAtomIndexList(ArrayList aia)
    {
      for(int i = 0; i < aia.size(); i++)
	{
	  AtomIndex ai = (AtomIndex) aia.get(i);
	  ai.seq.index = computeCompositeSeqIndex(ai.seq.id, ai.comp.id,
						   ai.asym.index);
	}
    }

  private int computeCompositeSeqIndex(String seqId, String monId,
				       int asymNdx)
    {
      if (asymNdx < 0 || _struct_asym_list == null)
	{
	  return -1;
	}
      try
	{
	  Integer ii 
	    = (Integer) EntityPolySeqCatLoader.hash_key_entity_poly_seq.get
	    (_struct_asym_list[asymNdx].entity.id + '&' + seqId 
	     + '&' + monId);
	  if (ii == null)
	    {
	      return -1;
	    }
	  else
	    {
	      return ii.intValue();
	    }
        }
      catch (Exception e)
        {
	  return -1;
	}
    }

  public Object[] getList(int sFlag)
    throws DataAccessException
    {
      Object[] oa = foundry.getList(this, ModuleTypes.MMS_CORE, sFlag);
      return oa;
    }

  public int getListSize(int sFlag)
    throws DataAccessException
    {
      return foundry.getListSize(this, ModuleTypes.MMS_CORE, sFlag);
    }

  public Object[] getListBlock(int sFlag, int from, int to)
    throws DataAccessException
    {
      return foundry.getListBlock(this, ModuleTypes.MMS_CORE,
				  sFlag, from, to);
    }

  public boolean cacheValue(Object[] var, int sFlag)
    {
      return foundry.cacheValue(this, ModuleTypes.MMS_CORE, sFlag, var);
    }
}

