//
// RDBEntryFoundry.java,v 1.1 2002/06/19 01:55:08 dsg Exp
//
// Copyright 2001 The Regents of the University of California
// All Rights Reserved
//
// OpenMMS was developed by Dr. Douglas S. Greer at the San Diego
// Supercomputer Center, a research unit of the University of California,
// San Diego.  Support for this effort was provided by NSF through the
// Protein Data Bank (Grant DBI-9814284) and the National Partnership for
// Advanced Computational Infrastructure (Grant ACI-9619020)
//
// Permission to use, copy, modify and distribute any part of OpenMMS for
// educational, research and non-profit purposes, without fee, and
// without a written agreement is hereby granted, provided that the above
// copyright notice, this paragraph and the following paragraphs appear
// in all copies.
//
// Those desiring to incorporate this OpenMMS into commercial products or
// use for commercial purposes should contact the Technology Transfer
// Office, University of California, San Diego, 9500 Gilman Drive, La
// Jolla, CA 92093-0910, Ph: (619) 534-5815, FAX: (619) 534-7345.
//
// In no event shall the University of California be liable to any party
// for direct, indirect, special, incidental, or consequential damages,
// including lost profits, arising out of the use of this OpenMMS, even
// if the University of California has been advised of the possibility of
// such damage.
//
// The OpenMMS provided herein is on an "as is" basis, and the
// University of California has no obligation to provide maintenance,
// support, updates, enhancements, or modifications.  The University of
// California makes no representations and extends no warranties of any
// kind, either implied or express, including, but not limited to, the
// implied warranties of merchantability or fitness for a particular
// purpose, or that the use of the OpenMMS will not infringe any patent,
// trademark or other rights.

package org.rcsb.openmms.entry;

import java.util.*;
import java.sql.*;

import org.rcsb.openmms.dbinsert.*;

import org.omg.CORBA.ORB;
import org.omg.DsLSRMacromolecularStructure.*;
import org.omg.ccm.BaseIDL.*;

import org.rcsb.openmms.util.*;
import org.rcsb.openmms.meta.*;
import org.rcsb.openmms.loader.*;

/**
 * Implements the EntryFactory for the MMS Corba reference server.
 *
 * @author Douglas S. Greer
 * @version 1.1
 */
public class RDBEntryFoundry extends EntryFoundry
  implements EntryDirectory, TypeNamesSql
{
  MessageHandler mh;

  // Entry Group data, Entries and ModificationDate structures
  boolean inited = false;
  String entries[];			// all entries
  ModificationDate[] modDates;		// all entries with mod dates
  HashMap entryList = new HashMap();

  Connection Conn = null;
  GeneralCategory genCatF;

  public RDBEntryFoundry(ServerHandler a, Connection cn)
    throws DataAccessException, SQLException
    {
      super(a);
      Conn = cn;
      mh = servh.getMessageHandler();

      SelectCategoryFinal selCatF = new SelectCategoryFinal(mh, Conn);
      genCatF = new GeneralCategory(mh, Conn, selCatF);
      checkDirectoryInit();
    }

  public void setDebug(int d)
    {
      super.setDebug(d);
    }

  protected void checkDirectoryInit()
    throws DataAccessException
    {
      if ( ! inited)
	{
	  checkModelAndVersion();
	  initEntryLists();
	  inited = true;
	}
    }

  final static String sentry
      = "SELECT " + ENTRY_TABLE_ID_NAME + ", "
      	+ ENTRY_TABLE_KEY_NAME + ", " + ENTRY_TABLE_DEP_DATE_NAME
        + " FROM " + ENTRY_TABLE_NAME; 
  /**
   * Need to initialize the lists: "entries", "modDates" and "entryList"
   * String entries[];		
   * ModificationDate[] modDates;	
   * HashMap entryList = new HashMap();
   */
  private void initEntryLists()
    throws DataAccessException
    {
      java.sql.Date prom;
      String id;

      // throw an exception if the database does not match our model
      // name and version number

      Statement stmt = null;
      try
	{
	  stmt = Conn.createStatement();
	  ResultSet rs = stmt.executeQuery(sentry);
	  while (rs.next())
	    {
	      KeyDate kd = new KeyDate();
	      id = rs.getString(1);
	      kd.key = rs.getInt(2);
	      prom = rs.getDate(3);
	      kd.date = prom.getTime();
	      entryList.put(id, kd);
	    }
	}
      catch (SQLException se)
	{
	  SQLException first = se;
	  StringBuffer errList = new StringBuffer();
	  errList.append("\nINIT ENTRY LIST FAILED\n\n");
	  errList.append("SQL Exception\n");
	  errList.append("RDBEntryFoundry.initEntryLists()\n");
	  while ( se != null)
	    {
	      errList.append("  SQL Message:  " + se.getMessage());
	      errList.append("  SQL State:  " + se.getSQLState());
	      errList.append("  SQL ErrorCode: " +se.getErrorCode());
	      se = se.getNextException();
	    }
	  servh.fatalError(errList.toString(), first); 
	}
      finally
	{
	  if (stmt != null)
	    {
	      try
		{
		  stmt.close();
		}
	      catch (SQLException se)
		{
		  servh.logException(se, "CLOSE JDBC CONNECTION FAILED",
				     "SQLException",
				     "RDBEntryFoundry.closeConnection()",
				     null, null, false);
		}
	    }
	}
      // create entries and modDates lists
      Set set = entryList.entrySet();
      int sz = set.size();
      entries = new String[sz];
      modDates = new ModificationDate[sz];
      Iterator it = set.iterator();
      for (int i = 0; it.hasNext(); i++)
	{
	  // Map.Entry and entry.Set() are defined in java.util.* and
	  // have nothing to do with MMS Entry classes.
	  Map.Entry em = (Map.Entry) it.next();
	  entries[i] = (String) em.getKey();
	  modDates[i] = new ModificationDate();
	  modDates[i].entry_id = entries[i];
	  modDates[i].date = ((KeyDate) em.getValue()).date;
	}
    }

  public void checkModelAndVersion()
    throws DataAccessException
    {
      String mod = null;
      String vers = null;
      Statement stmt = null;
      try
	{
	  stmt = Conn.createStatement();
	  String mv = "SELECT " + SYSTEM_MODEL_ID_NAME + ", "
	    + SYSTEM_REVISION_NUMBER_NAME
	    + " FROM " + SCHEMA_PREFIX + SYSTEM_TABLE_NAME ;

	    ResultSet rs = stmt.executeQuery(mv);
	    while (rs.next())
	      {
		mod = rs.getString(1);
		vers = rs.getString(2);
	      }
	}
      catch (SQLException se)
	{
	  throw new DataAccessException("checkModelAndVersion",
					"Error accessing MMS_SYSTEM table\n"
					+ se);
	}
      finally
	{
	  if (stmt != null)
	    {
	      try
		{
		  stmt.close();
		}
	      catch (SQLException se)
		{}
	    }
	}
      if (mod == null || vers == null)
	{
	  throw new DataAccessException
	    ("checkModelAndVersion",
	     "Null MMS Model or Version Number in MMS_SYSTEM table\n");
	}
      if ( ! mod.equals(EntryFactory.MODEL_IDENTIFIER)
	   || ! vers.equals(EntryFactory.REVISION_NUMBER))
	{
	  String err =
	    "\n *** Mismatched Database and Server Model_Version ***"
	    + "\n    Database Model = " + mod + ", Version=" + vers
	    + "\n    Server Model   = " + EntryFactory.MODEL_IDENTIFIER
	    + ", Version=" + EntryFactory.REVISION_NUMBER + "\n";
	  throw new DataAccessException("checkModelAndVersion", err);
	}
    }

  public boolean allVariablesRead()
    {
      // When backed up by a DB, variable are only read as needed.
      // (Compare FileEntryFoundry)
      return false;
    }

  public boolean cacheValue(EntryImpl ei, int modType, int sFlag,
			    Object[] var)
    {
      // in this version the Structure with PDB_ID equal to "4HHB"
      // is cached in RAM.
      // In all MMS Structures the Category "STRUCTURE" which contains
      // the title field-item " _struct.title" is cached.
      if (ei.getEntryId().equalsIgnoreCase("4HHB"))
	{
	  return true;
	}
      else if (modType == ModuleTypes.MMS_CORE && sFlag == Entry.S_STRUCTURE)
	{
	  return true;
	}
      else
	{
	  return false;
	}
    }

  public Object[] getList(EntryImpl ei, int modType, int sFlag)
    throws DataAccessException
    {
      Object oa[] = null;
      try
	{
	  oa = genCatF.getList(ei, modType, sFlag);
	}
      catch (SQLException se)
	{
	  throw new DataAccessException("RDBEntryFoundry.getList()",
		"Error accessing Entry=" + ei.getEntryId() 
		+ ", module=" + modType + ", StructFlag=" + sFlag	+ "\n"
					+ se);
	}
      return oa;
    }

  public int getListSize(EntryImpl ei, int modType, int sFlag)
    throws DataAccessException
    {
      int sz = -1;
      try
	{
	  sz = genCatF.getListSize(ei, modType, sFlag);
	}
      catch (SQLException se)
	{
	  throw new DataAccessException("RDBEntryFoundry.getListSize()",
		"Error accessing Entry=" + ei.getEntryId() 
		+ ", module=" + modType + ", StructFlag=" + sFlag	+ "\n"
					+ se);
	}
      return sz;
    }

  public Object[] getListBlock(EntryImpl ei, int modType, int sFlag,
			       int from, int to)
    throws DataAccessException
    {
      Object oa[] = null;
      try
	{
	  oa =  genCatF.getListBlock(ei, modType, sFlag, from, to);
	}
      catch (SQLException se)
	{
	  throw new DataAccessException("RDBEntryFoundry.getListBlock()",
		"Error accessing Entry=" + ei.getEntryId() 
		+ ", module=" + modType + ", StructFlag=" + sFlag	+ "\n"
		+ ", from" + from + ", to" + to + "\n" + se);
	}
      return oa;
    }

  public EntryImpl createEntryImpl(String id)
   throws DataAccessException
    {
      java.lang.Object o = entryList.get(id);
      if (o == null)
	{
	  // This Entry id is not in this Database.
	  // Try the next one in the list of Entry Foundries.
	  EntryFoundry n = getNext();
	  if (n == null)
	    {
	      // We're at the end of the foundry queue -> Give up
	      String err = "Entry " + id + " not found\n";
		throw new DataAccessException("createEntryImpl", err);
	    }
	  else
	    {
	      return n.createEntryImpl(id);
	    }
	}
      else
	{
	  // This does not actually read the data it just 
	  // creates the EntryImpl structure.  
	  // Data is read as requested.
	  KeyDate ekd = (KeyDate) o;
	  EntryImpl ei = new EntryImpl(id, this, ekd.key);
	  return ei;
	}
    }

  public void readEntryData(EntryImpl ei)
    throws DataAccessException
    {
      // A file based foundries would parse the whole file (all categories)
      // at this point.

      // Read the presence flags
      genCatF.readPresenceFlags(ei);
    }

  public String[] getEntryIdList()
    throws DataAccessException
    {
      return entries;
    }

  public ModificationDate[] getEntryModificationDates()
    throws DataAccessException
    {
      return modDates;
    }

  public String[] getEntryGroupList()
    throws DataAccessException
    {
      // No entry Groups are currently defined in the Database
      // Entry Foundry.
      String[] rval = {""};
      return rval;
    }

  public String[] getEntriesInGroup(String group)
    throws DataAccessException
    {
      // No entry Groups are currently defined in the Database
      // Entry Foundry.
      String[] rval = {""};
      return rval;
    }

  public String[] getNativeFormatsSupported()
    {
      // no native format representations are currently supported in the
      // DB version.
      // This could change by adding a directory where the cif files
      // are stored. See: FileEntryFoundry.java
      String[] r = {""};
      return r;
    }

  public byte[] getNativeEntryRepresentation(String format,
					     String entry_id)
    throws DataAccessException
    {
      // no native format representations are currently supported in the
      // DB version.
      // This could change by adding a directory where the cif files
      // are stored. See: FileEntryFoundry.java
      return new byte[1];
    }
}

/**
 * Local class to store data about each entry.  Indexed by the
 * structure-id string in the entryList hashtable.
 */
class KeyDate
{
  int key;
  long date;
}
  
