//
// SelectCategoryFinal.java,v 1.1 2002/06/19 02:27:46 dsg Exp
//
// Copyright 2002 The Regents of the University of California
// All Rights Reserved
//
// OpenMMS was developed by Dr. Douglas S. Greer at the San Diego
// Supercomputer Center, a research unit of the University of California,
// San Diego.  Support for this effort was provided by NSF through the
// Protein Data Bank (Grant DBI-9814284) and the National Partnership for
// Advanced Computational Infrastructure (Grant ACI-9619020)
//
// Permission to use, copy, modify and distribute any part of OpenMMS for
// educational, research and non-profit purposes, without fee, and
// without a written agreement is hereby granted, provided that the above
// copyright notice, this paragraph and the following paragraphs appear
// in all copies.
//
// Those desiring to incorporate this OpenMMS into commercial products or
// use for commercial purposes should contact the Technology Transfer
// Office, University of California, San Diego, 9500 Gilman Drive, La
// Jolla, CA 92093-0910, Ph: (619) 534-5815, FAX: (619) 534-7345.
//
// In no event shall the University of California be liable to any party
// for direct, indirect, special, incidental, or consequential damages,
// including lost profits, arising out of the use of this OpenMMS, even
// if the University of California has been advised of the possibility of
// such damage.
//
// The OpenMMS provided herein is on an "as is" basis, and the
// University of California has no obligation to provide maintenance,
// support, updates, enhancements, or modifications.  The University of
// California makes no representations and extends no warranties of any
// kind, either implied or express, including, but not limited to, the
// implied warranties of merchantability or fitness for a particular
// purpose, or that the use of the OpenMMS will not infringe any patent,
// trademark or other rights.

package org.rcsb.openmms.entry;

import java.util.*;
import java.sql.*;

// For definition of ORB functions
import org.omg.CORBA.ORB;
import org.omg.DsLSRMacromolecularStructure.*;
import org.omg.DsLSRXRayCrystallography.*;
import org.omg.DsLSRMmsReference.*;

import org.rcsb.openmms.util.*;
import org.rcsb.openmms.meta.*;
import org.rcsb.openmms.loader.*;
import org.rcsb.openmms.dbinsert.*;

/**
 * Base Class containing utility functions for the Relational
 * Database Entry JDBC insertion code.
 *
 * @author Douglas S. Greer
 * @version 1.1
 */
public class SelectCategoryFinal extends SelectCategory
  implements TypeNamesSql
{
  public SelectCategoryFinal(MessageHandler mh, Connection con)
    throws SQLException
    {
      super(mh, con);
    }

  public void readPresenceFlags(EntryImpl ei)
    throws DataAccessException
    {
      StringBuffer eFNames = new StringBuffer();
      for (int i = 0; i < ModuleTypes.NUMBER_OF_ENTRY_MODULES; i++)
	{
	  if (i > 0)
	    {
	      eFNames.append(", ");
	    }
	  eFNames.append(ENTRY_TABLE_FLAG_BASE_NAME);
	  eFNames.append(i);
	}
      String spf = "SELECT " + eFNames.toString()
	+ " FROM "+ SCHEMA_PREFIX + ENTRY_TABLE_NAME
	+ " WHERE " + ENTRY_TABLE_KEY_NAME + " = ?";

      PreparedStatement pst = null;
      try
	{
	  pst = Conn.prepareStatement(spf);
	  pst.setInt(1, ei.getKey());
	  ResultSet rs = pst.executeQuery();
	  rs.next();
	  for (int i = 0; i < ModuleTypes.NUMBER_OF_ENTRY_MODULES; i++)
	    {
	      byte[] v = rs.getBytes(i + 1);
	      if (v != null)
		{
		  ei.setPresenceFlags(i, v);
		}
	    }
	}
      catch (SQLException se)
	{
	  SQLException first = se;
	  StringBuffer errList = new StringBuffer();
	  while ( se != null)
	    {
	      errList.append("\n  SQL State:  " + se.getSQLState());
	      errList.append("  SQL ErrorCode: " +se.getErrorCode());
	      se = se.getNextException();
	    }
	  throw new DataAccessException("readEntryData",
					"Cannot access MMS_ENTRY table\n"
					+ first + errList.toString());
	}
      finally
	{
	  if (pst != null)
	    {
	      try
		{
		  pst.close();
		}
	      catch (SQLException se)
		{}
	    }
	}
    }

  public Object[] getList(EntryImpl ei, int mod, int flag)
    throws DataAccessException
    {
      Object[] oa;
      try
	{
	  readCategoryStats(ei.getKey(), flagToKey(mod, flag));
	  oa = readListData(ei, mod, flag, true, -1, -1);
	}
      catch (Exception e)
	{
	  throw new DataAccessException("SelectCategoryFinal.getList()",
					e.toString());
	}
      return oa;
    }

  public Object[] getListBlock(EntryImpl ei, int mod,
			       int flag, int from, int to)
    throws DataAccessException
    {
      Object[] oa;

      try
	{
	  readCategoryStats(ei.getKey(), flagToKey(mod, flag));
	}
      catch (Exception e)
	{
	  throw new DataAccessException
	    ("SelectCategoryFinal.getListBlock<readCategoryStats>()",
	     e.toString());
	}
      if (to < from || from < 0 || to > getCategoryLength())
	{
	  throw new DataAccessException("SelectCategoryFinal.getListBlock()",
		"Illegal Block size request..Category size=",
		+ getCategoryLength() + ", request=["
		+ from + ", " + to + "]");
	}
      try
	{
	  oa = readListData(ei, mod, flag, false, from, to);
	}
      catch (Exception e)
	{
	  throw new DataAccessException
	    ("SelectCategoryFinal.getListBlock<readList>()", e.toString());
	}
      return oa;
    }

  public int getListSize(EntryImpl ei, int mod, int flag)
    throws DataAccessException
    {
      try
	{
	  readCategoryStats(ei.getKey(), flagToKey(mod, flag));
	}
      catch (Exception e)
	{
	  throw new DataAccessException("SelectCategoryFinal.getListSize()",
					e.toString());
	}
      return categoryLength > 0 ? categoryLength : -1;
    }
}

