//
// ServerHandler.java,v 1.2 2002/10/11 22:41:20 dsg Exp
//
// Copyright 2001 The Regents of the University of California
// All Rights Reserved
//
// OpenMMS was developed by Dr. Douglas S. Greer at the San Diego
// Supercomputer Center, a research unit of the University of California,
// San Diego.  Support for this effort was provided by NSF through the
// Protein Data Bank (Grant DBI-9814284) and the National Partnership for
// Advanced Computational Infrastructure (Grant ACI-9619020)
//
// Permission to use, copy, modify and distribute any part of OpenMMS for
// educational, research and non-profit purposes, without fee, and
// without a written agreement is hereby granted, provided that the above
// copyright notice, this paragraph and the following paragraphs appear
// in all copies.
//
// Those desiring to incorporate this OpenMMS into commercial products or
// use for commercial purposes should contact the Technology Transfer
// Office, University of California, San Diego, 9500 Gilman Drive, La
// Jolla, CA 92093-0910, Ph: (619) 534-5815, FAX: (619) 534-7345.
//
// In no event shall the University of California be liable to any party
// for direct, indirect, special, incidental, or consequential damages,
// including lost profits, arising out of the use of this OpenMMS, even
// if the University of California has been advised of the possibility of
// such damage.
//
// The OpenMMS provided herein is on an "as is" basis, and the
// University of California has no obligation to provide maintenance,
// support, updates, enhancements, or modifications.  The University of
// California makes no representations and extends no warranties of any
// kind, either implied or express, including, but not limited to, the
// implied warranties of merchantability or fitness for a particular
// purpose, or that the use of the OpenMMS will not infringe any patent,
// trademark or other rights.

package org.rcsb.openmms.entry;

import java.io.*;
import java.awt.*;
import javax.swing.*;
import org.omg.CORBA.*;
import org.omg.PortableServer.*;
import org.omg.DsLSRMacromolecularStructure.*;

import org.rcsb.openmms.cifparse.*;
import org.rcsb.openmms.util.*;

/**
 * Top-level controller for handling messages to the user
 * and managing Entries
 *
 * @author Douglas S. Greer
 * @version 1.2
 */
public class ServerHandler implements MessageHandler
{
  int debug;
  MessageHandler messageh;
  ORB orb;
  POA rootpoa;

  EntryDirectory edir;
  EntryCache cache;
  EntryFoundry firstFoundry, lastFoundry;

  String fatalErrorMsgBegin = "\n***** A FATAL ERROR OCCURED  *****\n";
  String fatalErrorMsgEnd =     "***** FATAL ERROR -- EXITING *****\n";

  public ServerHandler(int d, ORB o)
    {
      debug = d;
      orb = o;
      try
	{
	  rootpoa = POAHelper.narrow
	    (orb.resolve_initial_references("RootPOA"));
	  rootpoa.the_POAManager().activate();
	}
      catch(org.omg.CORBA.UserException cue)
	{
	  fatalError("CORBA UserException in ServerHandler Constructor", cue);
	}
    }

  public void setMessageHandler(MessageHandler mh)
    {
      messageh = mh;
    }

  public void fatalError(String emsg, Exception e)
    {
      String err = fatalErrorMsgBegin + emsg + "\n";
      logMessage(err);
      System.err.println(err);

      if (e instanceof DataAccessException)
	{
	  DataAccessException dae = (DataAccessException) e;
	  String daerr = "DataAccessException thrown in method "
	    + dae.method_name
	    + "\n  Description: " + dae.description;
	  logMessage(daerr);
	  System.err.println(daerr);
	}

      StringWriter sw = new StringWriter();
      e.printStackTrace(new PrintWriter(sw));
      String msg = sw.toString();
      logMessage(msg);
      System.err.println(msg);

      logMessage(fatalErrorMsgEnd);
      System.err.println(fatalErrorMsgEnd);
      System.exit(1);
    }

  public EntryImpl getEntryFromId(String id)
    throws DataAccessException
    {
      EntryImpl e = null;
      if (cache != null)
	{
	  e = cache.fetchEntry(id);
	}
      if (e == null)
	{
	  // Cache Miss
	  e = firstFoundry.createEntryImpl(id);
	  if (cache != null)
	    {
	      // place in the cache for next time
	      cache.putEntry(id, e);
	    }
	}
      return e;
    }

  public ORB getOrb()
    {
      return orb;
    }

  public POA getRootPoa()
    {
      return rootpoa;
    }
  
  public void setEntryDirectory(EntryDirectory ed)
    {
      edir = ed;
    }

  public EntryDirectory getEntryDirectory()
    {
      return edir;
    }

  public void setEntryCache(EntryCache ec)
    {
      cache = ec;
    }

  public void addEntryFoundry(EntryFoundry ef)
    {
      if (firstFoundry == null)
	{
	  firstFoundry = ef;
	}
      else
	{
	  lastFoundry.setNext(ef);
	}
      lastFoundry = ef;
    }

  public MessageHandler getMessageHandler()
    {
      return messageh;
    }

  public void logString(String s)
    {
      if (messageh != null)
	{
	  messageh.logString(s);
	}
    }

  public void logMessage(String s)
    {
      if (messageh != null)
	{
	  messageh.logMessage(s);
	}
    }

  public void logException(Throwable t, String title,
			   String exceptionType, String where,
			   String cause, String other, boolean trace)
    {
      if (messageh != null)
	{
	  messageh.logException
	    (t, title, exceptionType, where, cause, other, trace);
	}
    }
}
