//
// CategoryTrans.java,v 1.4 2002/06/19 01:55:14 dsg Exp
//
// Copyright 2001 The Regents of the University of California
// All Rights Reserved
//
// OpenMMS was developed by Dr. Douglas S. Greer at the San Diego
// Supercomputer Center, a research unit of the University of California,
// San Diego.  Support for this effort was provided by NSF through the
// Protein Data Bank (Grant DBI-9814284) and the National Partnership for
// Advanced Computational Infrastructure (Grant ACI-9619020)
//
// Permission to use, copy, modify and distribute any part of OpenMMS for
// educational, research and non-profit purposes, without fee, and
// without a written agreement is hereby granted, provided that the above
// copyright notice, this paragraph and the following paragraphs appear
// in all copies.
//
// Those desiring to incorporate this OpenMMS into commercial products or
// use for commercial purposes should contact the Technology Transfer
// Office, University of California, San Diego, 9500 Gilman Drive, La
// Jolla, CA 92093-0910, Ph: (619) 534-5815, FAX: (619) 534-7345.
//
// In no event shall the University of California be liable to any party
// for direct, indirect, special, incidental, or consequential damages,
// including lost profits, arising out of the use of this OpenMMS, even
// if the University of California has been advised of the possibility of
// such damage.
//
// The OpenMMS provided herein is on an "as is" basis, and the
// University of California has no obligation to provide maintenance,
// support, updates, enhancements, or modifications.  The University of
// California makes no representations and extends no warranties of any
// kind, either implied or express, including, but not limited to, the
// implied warranties of merchantability or fitness for a particular
// purpose, or that the use of the OpenMMS will not infringe any patent,
// trademark or other rights.

package org.rcsb.openmms.meta;

import java.io.IOException;

/**
 * Class to represent "Categories" in Cif metamodel
 *
 * @author Douglas S. Greer
 * @version 1.4
 */
public class CategoryTrans extends Trans
{
  private String catClassPrefix;

  // Names used for corresponding SQL table
  protected String tablePrefix, tableName, tableKeyName;

  // Used in MMS_CATEGORY and MMS_ENTRY_CATEGORIES tables
  private int categoryKey;

  private int flags = 0;
  public static final int CONTAINS_STREAM_DATATYPES = 0x1;

  public CategoryTrans(String sname, String cpre)
    {
      super(sname, Trans.TYPE_CATEGORY);
      catClassPrefix = cpre;
    }

  public String getCatClassPrefix()
    {
      return catClassPrefix; 
    } 

  public void setTableName(String s)
    {
      tableName = s;
    }

  public String getTableName()
    {
      return tableName;
    }

  public void setTablePrefix(String pref)
    {
      tablePrefix = pref;
    }

  public String getFullTableName()
    {
      return tablePrefix + tableName;
    }

  public void setTableKeyName(String s)
    {
      tableKeyName = s;
    }

  public String getTableKeyName()
    {
      return tableKeyName;
    }

  public void setCategoryKey(int k)
    {
      categoryKey = k;
    }

  public int getCategoryKey()
    {
      return categoryKey;
    }

  public void setCategoryBit(int f)
    {
      flags = flags | f; 
    }

  public boolean isCategoryBitSet(int f)
    {
      return (flags & f) != 0;
    }

  public void accept(TransVisitor v)
    throws IOException, TransGenException
    {
      v.openCategory(this);
      // visit children
      Trans t;
      for (int i = 0; i < numberOfChildren(); i++)
	{
	  t = getChild(i);
	  int type = t.getTransType();
	  switch (type)
	    {
	    case Trans.TYPE_STRUCTURE:
	    case Trans.TYPE_VALUETYPE:
	      t.accept(v);
	      break;
	    default:
	      throw new TransGenException
		("Invalid CategoryTrans Child Type: " + type );
	    }
	}
      v.closeCategory(this);
    }
}
