//
// EntryWriter.java,v 1.8 2003/05/28 01:09:05 dsg Exp
//
// Copyright 2001 The Regents of the University of California
// All Rights Reserved
//
// OpenMMS was developed by Dr. Douglas S. Greer at the San Diego
// Supercomputer Center, a research unit of the University of California,
// San Diego.  Support for this effort was provided by NSF through the
// Protein Data Bank (Grant DBI-9814284) and the National Partnership for
// Advanced Computational Infrastructure (Grant ACI-9619020)
//
// Permission to use, copy, modify and distribute any part of OpenMMS for
// educational, research and non-profit purposes, without fee, and
// without a written agreement is hereby granted, provided that the above
// copyright notice, this paragraph and the following paragraphs appear
// in all copies.
//
// Those desiring to incorporate this OpenMMS into commercial products or
// use for commercial purposes should contact the Technology Transfer
// Office, University of California, San Diego, 9500 Gilman Drive, La
// Jolla, CA 92093-0910, Ph: (619) 534-5815, FAX: (619) 534-7345.
//
// In no event shall the University of California be liable to any party
// for direct, indirect, special, incidental, or consequential damages,
// including lost profits, arising out of the use of this OpenMMS, even
// if the University of California has been advised of the possibility of
// such damage.
//
// The OpenMMS provided herein is on an "as is" basis, and the
// University of California has no obligation to provide maintenance,
// support, updates, enhancements, or modifications.  The University of
// California makes no representations and extends no warranties of any
// kind, either implied or express, including, but not limited to, the
// implied warranties of merchantability or fitness for a particular
// purpose, or that the use of the OpenMMS will not infringe any patent,
// trademark or other rights.

package org.rcsb.openmms.meta;

import java.io.*;
import java.util.*;

import org.rcsb.openmms.cifparse.*;

/**
 * This class writes all the Java code that implements the Entry
 * and "Sub" Entry methods.
 *
 * @author Douglas S. Greer
 * @version 1.8
 */
public class EntryWriter extends TransVisitor
{
  String loaderPath;
  String lsrPackageName, msaPackageName;
  String loaderPackage;
  String entryBaseName;
  String catBaseName;
  String catClassName;

  String eStructName;

  boolean generateEntry;
  RootTrans inRoot;
  CategoryTrans inCat;
  boolean coreMod;
  String moduleEntryName;

  StringStruct  methodImplBuffer;
  int nLinks;

  public EntryWriter(String ldp, String lsr, String msa,
		     String ebName, String cname)
    {
      loaderPath = ldp;

      lsrPackageName = lsr;
      msaPackageName = msa;
      loaderPackage = "loader";
      entryBaseName = ebName;
      catBaseName = cname;
    }
  
  public void openRoot(RootTrans rt)
    throws IOException, TransGenException
    {
      inRoot = rt;
    }

  public void closeRoot(RootTrans rt)
    throws IOException, TransGenException
    {
    }

  private void initVars(FileTrans ft)
    {
      eStructName = ft.getExtensionName() + entryBaseName;

      // method Block
      methodImplBuffer = new StringStruct();
    }

  public void openFile(FileTrans ft)
    throws IOException, TransGenException
    {
      generateEntry = ft.getContainsEntry();
      if ( ! generateEntry)
	{
	  return;
	}
      initVars(ft);
      // check all the variables
      if (eStructName == null)
	{
	  throw new TransGenException("Null Entry structure name");
	}
      if (loaderPath == null)
	{
	  throw new TransGenException(
	      "loader target directoy path not specified");
	}
      String oFileName = eStructName + ".java";
      open(loaderPath + "/" + oFileName);

      Date dt = new Date();
      GregorianCalendar cal = new GregorianCalendar();
      cal.setTime(dt);

      // write preable
      writeStr("//");
      writeStr("// **** DERIVED FILE - DO NOT EDIT ****");
      writeStr("//");

      writeCopyright();

      String[] packagedef =
      {
	"",
	"package " + msaPackageName + "." + loaderPackage + ";",
	""
      };
      writeStr(packagedef);

      String[] importdefs =
      {
	"import java.util.*;",
	"import " + lsrPackageName + "." +  RootTrans.coreModuleName + ".*;",
	"import " + lsrPackageName + "." 
	    + RootTrans.baseModuleName + "MmsReference.*;",
	"import " + lsrPackageName + "."
	    + RootTrans.baseModuleName + "XRayCrystallography.*;",
	"import " + lsrPackageName + "."
	    + RootTrans.baseModuleName + "Nmr.*;"
      };
      writeStr(importdefs);


      // this ends the preamble portion that is written directly to the
      // file.  The import statements will  be written directly to the
      // file in openModule and the remainder including
      // the definitions are stored in the buffer "methodImplBuffer"
      // until the closeFile() method is called
      String[] classdef =
      {
	"",
	"/**",
	" * The Entry/Subentry classes contain the arrays of data structures",
	" * that store all of the information known about a particular entry",
	" * (i.e. an MMS structure) as well as the methods for accessing",
	" * those data structures.",
	" * <p>",
	" * Generated by the program MMSExpr. Model: "
	  + inRoot.getModelIdentifier() + ", Revision: "
	  + inRoot.getRevisionNumber(),
	" * <p>",
	" * Date: " + dt.toString(),
	" *",
	" * @author Douglas S. Greer",
	" * @version OpenMMS Release V_1_5_1",
	" */",
	"public abstract class " + eStructName,
	indent + " extends " + ft.getExtensionName() + "EntryPOA",
	indent + "{"
      };
      writeStr(methodImplBuffer, classdef, 0);

      String[] constructor =
      {
	"public " + eStructName + "()",
	indent + "{",
	indent + "}",
	""
      };
      writeStr(methodImplBuffer, constructor, 1);

      // methodImpl String buffer code starts here
      String[] initAbstractMethods =
      {
	"abstract public boolean initEntry()",
	indent + indent + "throws DataAccessException;",
	"abstract public Object[] getList(int sFlag)",
	indent + indent + "throws DataAccessException;",
	"abstract public int getListSize(int sFlag)",
	indent + indent + "throws DataAccessException;",
	"abstract public Object[] getListBlock(int sFlag, int from, int to)",
	indent + indent + "throws DataAccessException;",
	"abstract public boolean cacheValue"
	    + "(Object[] var, int sFlag)",
	indent + indent + "throws DataAccessException;",
	""
      };
      writeStr(methodImplBuffer, initAbstractMethods, 1);

      String[] present_flags =
      {
	"public byte[] _presence_flags",
	indent + indent + "= new byte[("	
	+ ft.getExtensionName() + "Entry.MAX_FLAG/8)+1];",
	""
      };
      writeStr(methodImplBuffer, present_flags, 1);
    }

  public void closeFile(FileTrans ft)
    throws IOException, TransGenException
    {
      if ( ! generateEntry)
	{
	  return;
	}
      // copy in Method Implementations
      writeBuffer(methodImplBuffer);
      methodImplBuffer = null;

      String[] closing =
      {
	indent + "}",
      };
      writeStr(closing);
      close();
    }

  public void openModule(ModuleTrans mt) 
    throws IOException, TransGenException
    {
      Stack scp;

      if ( ! generateEntry)
	{
	  return;
	}

      coreMod = mt.isCoreModule();
      moduleEntryName = mt.getEntryName();
      if (coreMod)
	{
	  // %% Need to create an array of sub-modules in the Core Module
	  // %% and use it to list these var names.
	  // %% using mt.getExtensionName() and mt.getVarName())
	  String[] subents =
	  {
	    "abstract public int getKey();",
	    "abstract public void setCompositeSeqIndexList(ArrayList sia);",
	    "abstract public void setCompositeAtomIndexList(ArrayList aia);",
	    "",
	    "public XRayCrystallographyEntryMethodImpl xray;",
	    "public NmrEntryMethodImpl nmr;",
	    "public MmsReferenceEntryMethodImpl ref;",
	    ""
	  };
	  writeStr(methodImplBuffer, subents, 1);
	}
    }

  public void closeModule(ModuleTrans mt) 
    throws IOException, TransGenException
    {
      if ( ! generateEntry)
	{
	  return;
	}
    }

  public void openCategory(CategoryTrans ct) 
    throws IOException, TransGenException
    {
      if ( ! generateEntry)
	{
	  return;
	}
      inCat = ct;
      catClassName = inCat.getCatClassPrefix() + catBaseName;
    }

  public void openGetListMethod(GetListMethodTrans glm) 
    throws IOException, TransGenException
    {
      if ( ! generateEntry)
	{
	  return;
	}
      if (glm.isSizeMethod())
	{
	  writeSizeMethod(glm);
	}
      else if (glm.isBlockMethod())
	{
	  writeBlockMethod(glm);
	}
      else
	{
	  writeListMethod(glm);
	}
    }

  private void writeSizeMethod(GetListMethodTrans glm)
    throws IOException, TransGenException
    {
      String s = "int " + glm.getName() + "()";
      String[] methodStart =
      {
	"// ______ "
	    + glm.getStructure().getCategory().getName().toUpperCase()
	    + " ______ //",
	"public " + glm.getStructure().getName() + "[] " 
	    + glm.getStructure().getListVarName()  + ";",
	"public " + s,
	indent + "throws DataAccessException",
	indent + "{"
      };
      writeStr(methodImplBuffer, methodStart, 1);

      String[] methodBody =
      {
	"boolean allVarsRead = initEntry();",
	"if (" + glm.getStructure().getListVarName() + " != null)",
	"{",
	indent + "return " + glm.getStructure().getListVarName() + ".length;",
	"}",
	"else",
	"{",
	indent + "return getListSize(" 
	    + moduleEntryName + "." + glm.getStructure().getFlagName() + ");",
	"}"
      };
      writeStr(methodImplBuffer, methodBody, 3);

      String[] methodFin =
      {
	indent + "}",
	""
      };
      writeStr(methodImplBuffer, methodFin, 1);
    }

  private void writeListMethod(GetListMethodTrans glm)
    throws IOException, TransGenException
    {
      // use mmCIF Category name for variable name;
      String s = glm.getStructure().getName() + "[] " + glm.getName() + "()";
      String[] methodStart =
      {
	"public " + s,
	indent + "throws DataAccessException",
	indent + "{"
      };
      writeStr(methodImplBuffer, methodStart, 1);

      String[] methodBody =
      {
	glm.getStructure().getName() + "[] var = null;",
	"boolean allVarsRead = initEntry();",
	"if (" + glm.getStructure().getListVarName() + " != null)",
	"{",
	indent + "var = " + glm.getStructure().getListVarName() + ";",
	"}",
	"else if ( ! allVarsRead)",
	"{",
	indent + "var = (" + glm.getStructure().getName() + "[]) getList("
	    + moduleEntryName + "." + glm.getStructure().getFlagName() + ");",
	indent + "if (cacheValue(var, "
	    + moduleEntryName + "." + glm.getStructure().getFlagName()+ "))",
	indent + "{",
	indent + indent + glm.getStructure().getListVarName() + " = var;",
	indent + "}",
	"}",
	"if (var == null)",
	"{",
	indent + "throw new DataAccessException(\"" + glm.getName() + "\",",
	indent + indent + "\"Requested data not present\");",
	"}",
	"return var;"
      };
      writeStr(methodImplBuffer, methodBody, 3);

      String[] methodFin =
      {
	indent + "}",
	""
      };
      writeStr(methodImplBuffer, methodFin, 1);
    }

  private void writeBlockMethod(GetListMethodTrans glm)
    throws IOException, TransGenException
    {
      String s = glm.getStructure().getName() + "[] " + glm.getName() +
	  "(int from, int to)";
      String[] methodStart =
      {
	"public " + s,
	indent + "throws DataAccessException",
	indent + "{"
      };
      writeStr(methodImplBuffer, methodStart, 1);

      String sz = glm.getStructure().getListVarName()  + ".length";
      String[] methodBody =
      {
	glm.getStructure().getName() + "[] var = null;",
	"boolean allVarsRead = initEntry();",
	"if (" + glm.getStructure().getListVarName() + " != null)",
	"{",
	indent + "try",
	indent + "{",
	indent + indent + "var = new " + glm.getStructure().getName()
	    + "[to-from+1];",
	indent + indent + "System.arraycopy(" + glm.getStructure()
		.getListVarName() + ", from,",
	indent + indent + indent + indent + "var, 0, to-from+1);",
	indent + "}",
	indent + "catch (Exception e)",
	indent + "{",
	indent + indent + "throw new DataAccessException(\""
		+ glm.getName() + "\",",
	indent + indent + "\"Requested block out of range\");",
	indent + "}",
	"}",
	"else if ( ! allVarsRead)",
	"{",
	indent + "var = (" + glm.getStructure().getName() + "[]) getListBlock("
	    + moduleEntryName + "." + glm.getStructure().getFlagName() + ",",
	indent + indent + "from, to);",
	"}",
	"if (var == null)",
	indent + "{",
	indent + "throw new DataAccessException(\"" + glm.getName() + "\",",
	indent + indent + "\"Requested data not present\");",
	indent + "}",
	"return var;"
      };
      writeStr(methodImplBuffer, methodBody, 3);

      String[] methodFin =
      {
	indent + "}",
	""
      };
      writeStr(methodImplBuffer, methodFin, 1);
    }
}  

