//
// FileTrans.java,v 1.4 2002/06/19 01:55:21 dsg Exp
//
// Copyright 2001 The Regents of the University of California
// All Rights Reserved
//
// OpenMMS was developed by Dr. Douglas S. Greer at the San Diego
// Supercomputer Center, a research unit of the University of California,
// San Diego.  Support for this effort was provided by NSF through the
// Protein Data Bank (Grant DBI-9814284) and the National Partnership for
// Advanced Computational Infrastructure (Grant ACI-9619020)
//
// Permission to use, copy, modify and distribute any part of OpenMMS for
// educational, research and non-profit purposes, without fee, and
// without a written agreement is hereby granted, provided that the above
// copyright notice, this paragraph and the following paragraphs appear
// in all copies.
//
// Those desiring to incorporate this OpenMMS into commercial products or
// use for commercial purposes should contact the Technology Transfer
// Office, University of California, San Diego, 9500 Gilman Drive, La
// Jolla, CA 92093-0910, Ph: (619) 534-5815, FAX: (619) 534-7345.
//
// In no event shall the University of California be liable to any party
// for direct, indirect, special, incidental, or consequential damages,
// including lost profits, arising out of the use of this OpenMMS, even
// if the University of California has been advised of the possibility of
// such damage.
//
// The OpenMMS provided herein is on an "as is" basis, and the
// University of California has no obligation to provide maintenance,
// support, updates, enhancements, or modifications.  The University of
// California makes no representations and extends no warranties of any
// kind, either implied or express, including, but not limited to, the
// implied warranties of merchantability or fitness for a particular
// purpose, or that the use of the OpenMMS will not infringe any patent,
// trademark or other rights.

package org.rcsb.openmms.meta;

import java.io.IOException;

/**
 * Class representing "Files" in Cif metamodel.
 * <br>
 * The FileTran class is used to designate MMS IDL files only.
 * TransVisitors other than IdlWriter should not rely on the
 * presence of any FileTrans classes.
 *
 * @author Douglas S. Greer
 * @version 1.4
 */
public class FileTrans extends Trans
{
  String baseName;
  String extName;
  String guardName;
  ModuleTrans coreMod;

  // files contain and XYZEntry method by default
  boolean containsEntry = true;

  public FileTrans(String bname, String ext, String idlSuffix,
		   ModuleTrans core)
    {
      super(bname + ext + idlSuffix, Trans.TYPE_FILE);

      coreMod = core;
      String name = bname + ext + idlSuffix;
      baseName = bname;
      extName = ext;
      guardName = generateGName(name);
    }

  public String getBaseName()
    {
      return baseName;
    }

  public String getBaseModuleName()
    {
      return baseName + extName;
    }

  public String getExtensionName()
    {
      if (coreMod == null)
	{
	  return "";
	}
      else
	{
	  return extName;
	}
    }

  public String getGuardName()
    {
      return guardName;
    }

  public String generateGName(String fname)
    {
      String seg;
      StringBuffer sb = new StringBuffer();
      char c;
      
      for (int i = 0; i < fname.length(); i++)
	{
	  if (i > 0 && i < fname.length()-1)
	    {
	      // special case capitalization rules for "LSR"
	      seg = fname.substring(i-1, i+2);
	      if (seg.equals("LSR"))
		{
		  sb.append("SR");
		  i += 2;
		}
	    }
	  c = fname.charAt(i);
	  if (c == '.')
	    {
	      sb.append("_");
	    }
	  else if (Character.isUpperCase(c))
	    {
	      sb.append('_');
	      sb.append(c);
	    }
	  else
	    {
	      sb.append(Character.toUpperCase(c));
	    }
	}
      sb.append("_");
      return sb.toString();
    }

  public void setContainsEntry(boolean ce)
    {
      containsEntry = ce;
    }

  public boolean getContainsEntry()
    {
      return containsEntry;
    }

  public boolean containsCoreModule()
    {
      return coreMod == null;
    }

  public ModuleTrans getCoreModule()
    {
      return coreMod;
    }

  public void accept(TransVisitor v)
    throws IOException, TransGenException
    {
      v.openFile(this);
      // visit children
      Trans t;
      for (int i = 0; i < numberOfChildren(); i++)
	{
	  t = getChild(i);
	  int type = t.getTransType();
	  switch (type)
	    {
	    case Trans.TYPE_DIRECTIVE:
	    case Trans.TYPE_MODULE:
	      t.accept(v);
	      break;
	    default:
	      throw new TransGenException
		("Invalid FileTrans Child Type: " + type );
	    }
	}
      v.closeFile(this);
    }
}

