//
// GenAccessMethods.java,v 1.3 2001/10/27 02:02:51 dsg Exp
//
// Copyright 2001 The Regents of the University of California
// All Rights Reserved
//
// OpenMMS was developed by Dr. Douglas S. Greer at the San Diego
// Supercomputer Center, a research unit of the University of California,
// San Diego.  Support for this effort was provided by NSF through the
// Protein Data Bank (Grant DBI-9814284) and the National Partnership for
// Advanced Computational Infrastructure (Grant ACI-9619020)
//
// Permission to use, copy, modify and distribute any part of OpenMMS for
// educational, research and non-profit purposes, without fee, and
// without a written agreement is hereby granted, provided that the above
// copyright notice, this paragraph and the following paragraphs appear
// in all copies.
//
// Those desiring to incorporate this OpenMMS into commercial products or
// use for commercial purposes should contact the Technology Transfer
// Office, University of California, San Diego, 9500 Gilman Drive, La
// Jolla, CA 92093-0910, Ph: (619) 534-5815, FAX: (619) 534-7345.
//
// In no event shall the University of California be liable to any party
// for direct, indirect, special, incidental, or consequential damages,
// including lost profits, arising out of the use of this OpenMMS, even
// if the University of California has been advised of the possibility of
// such damage.
//
// The OpenMMS provided herein is on an "as is" basis, and the
// University of California has no obligation to provide maintenance,
// support, updates, enhancements, or modifications.  The University of
// California makes no representations and extends no warranties of any
// kind, either implied or express, including, but not limited to, the
// implied warranties of merchantability or fitness for a particular
// purpose, or that the use of the OpenMMS will not infringe any patent,
// trademark or other rights.

package org.rcsb.openmms.meta;

import java.io.*;
import java.util.*;

import org.rcsb.openmms.cifparse.*;

/**
 * Generates the "list" accessor methods for a Corba interface.
 * E.g. for a sequence labeled ABC, it genterates the get_ABC_list()
 * and get_ABC_list_size() methods.
 *
 * @author Douglas S. Greer
 * @version 1.3
 */
public class GenAccessMethods extends TransVisitor
{
  protected Hashtable fieldNames = new Hashtable();

  ArrayList ltal = new ArrayList();

  RootTrans inRoot;
  ModuleTrans inMod;
  CategoryTrans inCat;
  CifDictionary cifDic;

  public GenAccessMethods()
    {
    }

  public void openRoot(RootTrans rt)
    throws IOException, TransGenException
    {
      inRoot = rt;
    }

  public void openModule(ModuleTrans mot)
    throws IOException, TransGenException
    {
      inMod = mot;
    }

  public void openCategory(CategoryTrans ct) 
    throws IOException, TransGenException
    {
      inCat = ct;
    }
      
  public void openInterface(InterfaceTrans iface) 
    throws IOException, TransGenException
    {
      ListTrans list;
      GetListMethodTrans glmt;
      
      if (iface.getName().endsWith("Entry"))
	{
	  // "List" methods all go into the entry interface
	  String[] atypes = {"in long", "in long"};
	  String[] anames = {"from", "to"};
	  for (int i = 0; i < ltal.size(); i++)
	    {
	      list = (ListTrans) ltal.get(i);
	      String stName 
		= list.convertToUnderbar(list.getStructure().getName());
	      glmt = new GetListMethodTrans
			(stName.substring(1) + "_list_size", "long",
			 // ("number" + stName + "_list", "long",
			 list,  null, null, iface.specialExceptions);
	      glmt.setIsSizeMethod(true);
	      iface.add(glmt);
	      if (i == 0)
		{
		  glmt.setBlankLines(1);
		}
	      glmt = new GetListMethodTrans
		("get" + stName + "_list", list.getFullyQualifiedName(inMod),
		 list, null, null, iface.specialExceptions);
	      iface.add(glmt);
	      if (list.getStructure().useBlockMethod())
		{
		  glmt = new GetListMethodTrans
		    ("get" + stName + "_block_n",
		     list.getFullyQualifiedName(inMod), list,  
		     atypes, anames,
		     iface.specialExceptions);
		  glmt.setIsBlockMethod(true);
		  iface.add(glmt);
		}
	    }
	  ltal.clear();
	}
    }

  public void createList(ListTrans lt) 
    throws IOException, TransGenException
    {
      ltal.add(lt);
    }
}  

