//
// GenCifParents.java,v 1.5 2003/05/30 18:57:01 dsg Exp
//
// Copyright 2001 The Regents of the University of California
// All Rights Reserved
//
// OpenMMS was developed by Dr. Douglas S. Greer at the San Diego
// Supercomputer Center, a research unit of the University of California,
// San Diego.  Support for this effort was provided by NSF through the
// Protein Data Bank (Grant DBI-9814284) and the National Partnership for
// Advanced Computational Infrastructure (Grant ACI-9619020)
//
// Permission to use, copy, modify and distribute any part of OpenMMS for
// educational, research and non-profit purposes, without fee, and
// without a written agreement is hereby granted, provided that the above
// copyright notice, this paragraph and the following paragraphs appear
// in all copies.
//
// Those desiring to incorporate this OpenMMS into commercial products or
// use for commercial purposes should contact the Technology Transfer
// Office, University of California, San Diego, 9500 Gilman Drive, La
// Jolla, CA 92093-0910, Ph: (619) 534-5815, FAX: (619) 534-7345.
//
// In no event shall the University of California be liable to any party
// for direct, indirect, special, incidental, or consequential damages,
// including lost profits, arising out of the use of this OpenMMS, even
// if the University of California has been advised of the possibility of
// such damage.
//
// The OpenMMS provided herein is on an "as is" basis, and the
// University of California has no obligation to provide maintenance,
// support, updates, enhancements, or modifications.  The University of
// California makes no representations and extends no warranties of any
// kind, either implied or express, including, but not limited to, the
// implied warranties of merchantability or fitness for a particular
// purpose, or that the use of the OpenMMS will not infringe any patent,
// trademark or other rights.

package org.rcsb.openmms.meta;

import java.io.*;
import java.util.*;

import org.rcsb.openmms.cifparse.*;

/**
 * Traverses the metamodel and fills in the parent node links.
 *
 * @author Douglas S. Greer
 * @version 1.5
 */
public class GenCifParents extends TransVisitor
{
  protected Hashtable fieldNames = new Hashtable();

  RootTrans inRoot;
  CategoryTrans inCat;
  CifDictionary cifDic;
  StructureTrans inStruct;

  public GenCifParents(CifDictionary d)
    {
      cifDic = d;
    }
  
  // helper function to set child/parent indices after
  // a GenCifParents visitor trace build up a HashTable with
  // a key of the parent index names and a value of the FieldTrans
  public void setCifParentIndices(CifDictionary cifDic)
    throws TransGenException
   {
      String parent, inm, t;
      FieldTrans ft, pt;
      Enumeration e = fieldNames.keys();

      for ( ; e.hasMoreElements() ; )
	{
	  inm = (String) e.nextElement();
	  ft = (FieldTrans) fieldNames.get(inm);
	  if (ft == null)
	    {
	      throw new TransGenException
		("GenCifParents: null child FieldTrans. ChildName: " + inm);
	    }
	  parent = cifDic.getParent(inm);
	  if (parent != null)
	    {
	      // find the "top-level grandparent"
	      t = parent;
	      while (t != null)
		{
		  parent = t;
		  t = cifDic.getParent(t);
		}
	      // Entry.id cannot be indexed
	      if (parent.equalsIgnoreCase("_entry.id"))
		{
		  continue;
		}
	      pt = (FieldTrans) fieldNames.get(parent);
	      if (pt == null)
		{
		  throw new TransGenException
		    ("GenCifParents: null parent FieldTrans. ParentName: "
		     + parent + " ChildName: " + inm);
		}
	      createIndexId(ft, pt);
	    }
	}
    }

  // create an IndexId sub-struct for this indexed field
  private void createIndexId(FieldTrans ft, FieldTrans pft)
    throws TransGenException
    {
      // create a subfield equal to the field
      SubfieldTrans sft = new SubfieldTrans(ft, "id");
      sft.setCifParentIndex(pft);

      // strip off "_id"
      String neuName;
      neuName = ft.getName();
      if (neuName.endsWith("_id"))
	{
	  neuName = neuName.substring(0, neuName.length() - 3);
	}
      // Exclude LSR-1.0 version for backward compatibility with
      // existing standard. Otherwise change _id_<Char> to _<Char>.
      else if ( ! (inRoot.getModelIdentifier().equalsIgnoreCase("LSR")
		&& inRoot.getRevisionNumber().equalsIgnoreCase("1.0"))
		&& neuName.substring(0, neuName.length()-1).endsWith("_id_"))
	{
	  neuName = neuName.substring(0, neuName.length() - 4)
	    + neuName.charAt(neuName.length() - 1);
	}

      FieldTrans nfst;
      if (ft instanceof SubfieldTrans)
	{
	  SubfieldTrans subt = new SubfieldTrans(inRoot.stIndexId, neuName);
	  subt.setContainingField(ft.getContainingField());
	  nfst = subt;
	}
      else
	{
	  nfst = new FieldTrans(inRoot.stIndexId, neuName);
	}
      nfst.add(sft);
      // have to re-compute names after setting containing field.
      nfst.setStructure(ft.getStructure());
      nfst.computeNames();

      sft.setContainingField(nfst);
      // have to re-compute names after setting containing field.
      sft.computeNames();

      // find container
      Trans t = ft.getContainingField();
      if (t == null)
	{
	  t = ft.getStructure();
	}
      if (t == null)
	{
	  throw new TransGenException
	    ("GenCifParents.createIndexId: cannot find containing field "
	     + "\n\tfield=" + ft.getName() + " pft=" + pft.getName());
	}
      // substitute new structure trans
      t.replace(ft, nfst);
    }

  public void openRoot(RootTrans rt)
    throws IOException, TransGenException
    {
      inRoot = rt;
    }

  public void openCategory(CategoryTrans ct) 
    throws IOException, TransGenException
    {
      inCat = ct;
    }
      
  public void openStructure(StructureTrans st) 
    throws IOException, TransGenException
    {
      // actual StructureTrans nodes are not embedded, only subfields
      inStruct = st;

      if (st.isCifStructure())
	{
	  String categoryName = inCat.getName();
	  DictionaryCategory dc = cifDic.getDictionaryCategoryList()
	    .findDictionaryCategory(categoryName);
	  st.setDictionaryCategory(dc);
	  if(dc == null)
	    {
	      throw new TransGenException
		("GenCifParents:openStructure Category "
		 + categoryName + " is not in a mmCIF dictionary");
	    }
	}
    }

  public void openValuetype(ValuetypeTrans vt) 
    throws IOException, TransGenException
    {
      openStructure(vt);
    }

  public void openField(FieldTrans ft) 
    throws IOException, TransGenException
    {
      // record which struct we're in for other TransVisitors
      // actual StructureTrans nodes are not embedded, only subfields
      ft.setStructure(inStruct);

      // record field in subfields for TransVisitors
      for (int i = 0; i < ft.numberOfChildren(); i++)
	{
	  Trans t = ft.getChild(i);
	  if (t instanceof SubfieldTrans)
	    {
	      SubfieldTrans sft = (SubfieldTrans) t;
	      sft.setContainingField(ft);
	      sft.computeNames();
	    }
	}

      // parent nodes for this field are now set so the TagName
      // can now be generated
      // Names generated for leaf and non-leaf fields
      ft.computeNames();

      if (ft.isCifField())
	{
	  String itemName = "_" + inCat.getName() + "." 
	    + ft.getCifItemName();
	  DictionaryItem di = 
	    cifDic.getDictionaryItemList().findDictionaryItem(itemName);
	  // store a pointer from FieldTrans to the Dictionary Item
	  ft.setDictionaryItem(di);
	  // construct mapping from item names to FieldTrans
	  fieldNames.put(itemName, ft);
	  if(di == null)
	    {
	      throw new TransGenException
		("GenCifParents:openField Field/Item "
		 + itemName + ", is not in an mmCIF dictionary");
	    }
	}
    }

  public void openSubfield(SubfieldTrans ft) 
    throws IOException, TransGenException
    {
      openField(ft);
    }

  public void openVector(VectorTrans vt) 
    throws IOException, TransGenException
    {
      openField(vt);
    }

  public void openMatrix(MatrixTrans mt) 
    throws IOException, TransGenException
    {
      openField(mt);
    }
}  

