//
// GenConstants.java,v 1.3 2001/10/27 02:02:51 dsg Exp
//
// Copyright 2001 The Regents of the University of California
// All Rights Reserved
//
// OpenMMS was developed by Dr. Douglas S. Greer at the San Diego
// Supercomputer Center, a research unit of the University of California,
// San Diego.  Support for this effort was provided by NSF through the
// Protein Data Bank (Grant DBI-9814284) and the National Partnership for
// Advanced Computational Infrastructure (Grant ACI-9619020)
//
// Permission to use, copy, modify and distribute any part of OpenMMS for
// educational, research and non-profit purposes, without fee, and
// without a written agreement is hereby granted, provided that the above
// copyright notice, this paragraph and the following paragraphs appear
// in all copies.
//
// Those desiring to incorporate this OpenMMS into commercial products or
// use for commercial purposes should contact the Technology Transfer
// Office, University of California, San Diego, 9500 Gilman Drive, La
// Jolla, CA 92093-0910, Ph: (619) 534-5815, FAX: (619) 534-7345.
//
// In no event shall the University of California be liable to any party
// for direct, indirect, special, incidental, or consequential damages,
// including lost profits, arising out of the use of this OpenMMS, even
// if the University of California has been advised of the possibility of
// such damage.
//
// The OpenMMS provided herein is on an "as is" basis, and the
// University of California has no obligation to provide maintenance,
// support, updates, enhancements, or modifications.  The University of
// California makes no representations and extends no warranties of any
// kind, either implied or express, including, but not limited to, the
// implied warranties of merchantability or fitness for a particular
// purpose, or that the use of the OpenMMS will not infringe any patent,
// trademark or other rights.

package org.rcsb.openmms.meta;

import java.io.*;
import java.util.*;

import org.rcsb.openmms.cifparse.*;

/**
 * Generates and IDL Constants required in the metamodel
 *
 * @author Douglas S. Greer
 * @version 1.3
 */
public class GenConstants extends TransVisitor
{
  ArrayList constal = new ArrayList();
  protected int Count = 1;

  RootTrans inRoot;
  CategoryTrans inCat;
  CifDictionary cifDic;
  StructureTrans inStruct;

  public GenConstants()
    {
    }

  public void openRoot(RootTrans rt)
    throws IOException, TransGenException
    {
      inRoot = rt;
    }

  public void openCategory(CategoryTrans ct) 
    throws IOException, TransGenException
    {
      inCat = ct;
    }
      
  public void openInterface(InterfaceTrans iface) 
    throws IOException, TransGenException
    {
      ConstantTrans contran;
      GetListMethodTrans glmt;
      
      if (iface.getName().endsWith("Entry"))
	{
	  // Structure/Valuetype flags
	  for (int i = 0; i < constal.size(); i++)
	    {
	      contran = (ConstantTrans) constal.get(i);
	      iface.add(contran);
	    }
	  contran = new ConstantTrans("short",
				      "MAX_FLAG",
				      Integer.toString(Count-1));
	  contran.setBlankLines(1);
	  iface.add(contran);
	  
	  // reset constants for Entry in next module
	  Count = 1;
	  constal.clear();
	}
    }

  public void openStructure(StructureTrans st) 
    throws IOException, TransGenException
    {
      // actual StructureTrans nodes are not embedded, only subfields
      inStruct = st;

      if (st.isCifStructure())
	{
	  DictionaryCategory dc = st.getDictionaryCategory();
	  int mand = dc.getCategoryMandatoryCode();
	  if (mand == DictionaryCategory.CATEGORY_MANDATORY_CODE_NO)
	    {
	      ConstantTrans ct = new ConstantTrans("short",
						   st.getFlagName(),
						   Integer.toString(Count++));
	      ct.setBlankLines(1);
	      constal.add(ct);
	    }
	}
    }

  public void openValuetype(ValuetypeTrans vt) 
    throws IOException, TransGenException
    {
      openStructure(vt);
    }

  public void openField(FieldTrans ft) 
    throws IOException, TransGenException
    {
      if (ft.isCifField())
	{
	  DictionaryItem di = ft.getDictionaryItem();

	  // Do not generate flags for all of the Vector/Matrix pseudo-fields
	  // ( Generate only one primary flag for the Matrix or Vector )
	  if ( ! ft.isPseudoField())
	    {
	      int mand = di.getItemMandatoryCode();
	      if (mand == DictionaryItem.ITEM_MANDATORY_CODE_NO)
		{
		  ConstantTrans ct = new ConstantTrans
		    ("short", ft.getFlagName(),
		     Integer.toString(Count++));
		  constal.add(ct);
		}
	    }
	}
    }

  public void openSubfield(SubfieldTrans ft) 
    throws IOException, TransGenException
    {
      openField(ft);
    }

  public void openVector(VectorTrans vt) 
    throws IOException, TransGenException
    {
      openField(vt);
    }

  public void openMatrix(MatrixTrans mt) 
    throws IOException, TransGenException
    {
      openField(mt);
    }
}  

