//
// IdlWriter.java,v 1.4 2003/05/30 18:57:02 dsg Exp
//
// Copyright 2001 The Regents of the University of California
// All Rights Reserved
//
// OpenMMS was developed by Dr. Douglas S. Greer at the San Diego
// Supercomputer Center, a research unit of the University of California,
// San Diego.  Support for this effort was provided by NSF through the
// Protein Data Bank (Grant DBI-9814284) and the National Partnership for
// Advanced Computational Infrastructure (Grant ACI-9619020)
//
// Permission to use, copy, modify and distribute any part of OpenMMS for
// educational, research and non-profit purposes, without fee, and
// without a written agreement is hereby granted, provided that the above
// copyright notice, this paragraph and the following paragraphs appear
// in all copies.
//
// Those desiring to incorporate this OpenMMS into commercial products or
// use for commercial purposes should contact the Technology Transfer
// Office, University of California, San Diego, 9500 Gilman Drive, La
// Jolla, CA 92093-0910, Ph: (619) 534-5815, FAX: (619) 534-7345.
//
// In no event shall the University of California be liable to any party
// for direct, indirect, special, incidental, or consequential damages,
// including lost profits, arising out of the use of this OpenMMS, even
// if the University of California has been advised of the possibility of
// such damage.
//
// The OpenMMS provided herein is on an "as is" basis, and the
// University of California has no obligation to provide maintenance,
// support, updates, enhancements, or modifications.  The University of
// California makes no representations and extends no warranties of any
// kind, either implied or express, including, but not limited to, the
// implied warranties of merchantability or fitness for a particular
// purpose, or that the use of the OpenMMS will not infringe any patent,
// trademark or other rights.

package org.rcsb.openmms.meta;

import java.io.*;

import org.rcsb.openmms.cifparse.*;

/**
 * Traverse metamodel instance and generate CORBA IDL specification
 *
 * @author Douglas S. Greer
 * @version 1.4
 */
public class IdlWriter extends TransVisitor
{
  private static boolean trace = false;

  private boolean insideValuetype = false;

  String idlPath;
  String oFileName;
  CifDictionary cifDic;

  ModuleTrans inMod;
  CategoryTrans inCat;
  int fieldNumInStruct = 0;

  public IdlWriter(CifDictionary d, String idlp)
    {
      cifDic = d;
      idlPath = idlp;
    }

  public void setTrace(boolean t)
    {
      trace = t;
    }

  public void openRoot(RootTrans rt)
    throws IOException, TransGenException
    {
      if (trace)
	{
	  System.out.println("IdlWriter.openRoot called");
	}
    }

  public void closeRoot(RootTrans rt)
    throws IOException, TransGenException
    {
      if (trace)
	{
	  System.out.println("IdlWriter.closeRoot called");
	}
    }

  public void openFile(FileTrans ft) 
    throws IOException, TransGenException
    {
      if (trace)
	{
	  System.out.println("IdlWriter.openFile called");
	}
      oFileName = ft.getName();
      if (oFileName == null)
	{
	  oFileName = "output.idl";
	}
      open(idlPath + "/" + oFileName);
    }

  public void closeFile(FileTrans ft) 
    throws IOException, TransGenException
    {
      close();
    }

  public void openModule(ModuleTrans mt) 
    throws IOException, TransGenException
    {
      if (trace)
	{
	  System.out.println("IdlWriter.openModule called");
	}
      inMod = mt;
      writeStr("");
      writeComment(mt);
      writeStr("module " + mt.getName());
      writeStr("{");
      indentLevel++;
    }
      
  public void closeModule(ModuleTrans mt) 
    throws IOException, TransGenException
    {
      indentLevel--;
      String closing[]=
      {
	"};",
      };
      writeStr(closing);
    }

  public void openInterface(InterfaceTrans it) 
    throws IOException, TransGenException
    {
      if (trace)
	{
	  System.out.println("IdlWriter.openInterface called");
	}
      writeStr("");
      writeComment(it);
      writeStr("interface " + it.getName());
      writeStr("{");
      indentLevel++;
    }
      
  public void closeInterface(InterfaceTrans it) 
    throws IOException, TransGenException
    {
      indentLevel--;
      String closing[]=
      {
	"};"
      };
      writeStr(closing);
    }

  public void openCategory(CategoryTrans ct) 
    throws IOException, TransGenException
    {
      inCat = ct;
    }
      
  public void closeCategory(CategoryTrans ct) 
    throws IOException, TransGenException
    {
    }

  public void openStructure(StructureTrans st) 
    throws IOException, TransGenException
    {
      if (trace)
	{
	  System.out.println("IdlWriter.openStructure called");
	}

      fieldNumInStruct = 0;
      writeStr("");
      writeComment(st);
      writeStr("struct " + st.getName());
      writeStr("{");
      indentLevel++;
    }
      
  public void closeStructure(StructureTrans st) 
    throws IOException, TransGenException
    {
      indentLevel--;
      String closing[]=
      {
	"};"
      };
      writeStr(closing);
    }

  public void openValuetype(ValuetypeTrans st) 
    throws IOException, TransGenException
    {
      if (trace)
	{
	  System.out.println("IdlWriter.openValuetype called");
	}
      insideValuetype = true;

      fieldNumInStruct = 0;
      writeStr("");
      if (inCat != null & st.isCifStructure)
	{
	  String categoryName = inCat.getName();
	  DictionaryCategory dc = st.getDictionaryCategory();
	  writeStructureCifComment(st, dc);
	}
      writeComment(st);
      writeStr(RootTrans.vTypeName + st.getName());
      writeStr("{");
      if (RootTrans.COMPILER_IMPLEMENTS_VALUETYPES)
	{
	  writeStr(indent + "factory create" + st.getName() + "();");
	  writeStr("");
	}
      indentLevel++;
    }
      
  public void closeValuetype(ValuetypeTrans st) 
    throws IOException, TransGenException
    {
      insideValuetype = false;

      indentLevel--;
      String closing[]=
      {
	"};"
      };
      writeStr(closing);
    }

  public void writeStructureCifComment(StructureTrans st,
				       DictionaryCategory dc)
    throws IOException, TransGenException
    {
      if (RootTrans.WRITE_IDL_COMMENTS)
	{
	  String s = dc.getCategoryDescription();
	  int mand = dc.getCategoryMandatoryCode();
	  
	  writeCifComment(s, st.descriptionParagraphs, false);
	  if (mand == DictionaryCategory.CATEGORY_MANDATORY_CODE_YES)
	    {
	      writeStr("// ");
	      writeStr("// The " + st.getName()
		       + " valuetype shall always be present for all Entries");
	    }
	  else if (mand == DictionaryCategory.CATEGORY_MANDATORY_CODE_NO)
	    {
	      writeStr("// ");
	      writeStr("// The existence of the " + st.getName()
		       + " valuetype in an");
	      writeStr
		("// Entry is optional.  Its presence can be determined");
	      writeStr("// using the " + st.getFlagName() + " flag.");
	    }
	  else
	    {
	      throw new TransGenException
		("IdlWriter.writeStructureCifComment: Category "
		 + dc.getCategoryName()
		 + "\n\tHas an undefined mandatory code field");
	    }
	}
    }

  public void openField(FieldTrans ft) 
    throws IOException, TransGenException
    {
      if (trace)
	{
	  System.out.println("IdlWriter.openField called");
	}

      // ignore Vector/Matrix pseudo-fields in IdlWriter
      if ( ! ft.isPseudoField())
	{
	  String accessModifier;
	  if (insideValuetype)
	    {
	      accessModifier  = RootTrans.vFieldAccess;
	    }
	  else
	    {
	      accessModifier  = "";
	    }
	  if (ft.isCifField())
	    {
	      DictionaryItem di = ft.getDictionaryItem();
	      String otype;

	      otype = cifType2Idl(di.getItemType());
	      writeFieldCifComment(ft, di);
	      writeComment(ft);
	      // all valuetype fields are public
	      writeStr(accessModifier
	               + otype + " " + ft.getName() + ";");
	      if (ft.isIndexField())
		{
		  otype = "long";
		  FieldTrans parent = ft.getCifParentIndex();

		  if (RootTrans.WRITE_IDL_COMMENTS)
		    {
		      writeStr("// " + ft.getName() + "_index"
			       + " is an index into the "
			       + parent.getStructure().getName() + " list");
		      writeStr("// list such that the above field ("
			       + ft.getName() + ")");
		      writeStr("// is equal to "
			       + parent.getStructure().getName() + "."
			       + parent.getName() + ".  An index value");
		      writeStr("// equal to -1 signifies that the"
			       + " referenced field is not present.");
		    }
		  writeStr(accessModifier
			   + otype + " " + ft.getName() + "_index;");
		}
	    }
	  else
	    {
	      writeComment(ft);
	      writeStr(accessModifier
		       + ft.getFieldType(inMod) + " " + ft.getName() + ";");
	    }
	}
    }

  public void openVector(VectorTrans vt) 
    throws IOException, TransGenException
    {
      String rtype;

      if (trace)
	{
	  System.out.println("IdlWriter.openVector called");
	}
      String accessModifier;
      if (insideValuetype)
	{
	  accessModifier  = RootTrans.vFieldAccess;
	}
      else
	{
	  accessModifier  = "";
	}
      if (inMod.isCoreModule())
	{
	  rtype = "Vector3 ";
	}
      else
	{
	  rtype = RootTrans.coreModuleName + "::Vector3 ";
	}
      DictionaryItem di = vt.getDictionaryItem();
      writeFieldCifComment(vt, di);
      writeComment(vt);
      writeStr(accessModifier + rtype + vt.getName() + ";");
    }

  public void closeVector(VectorTrans ft) 
    throws IOException, TransGenException
    {
    }

  public void openMatrix(MatrixTrans mt) 
    throws IOException, TransGenException
    {
      String rtype;

      if (trace)
	{
	  System.out.println("IdlWriter.openMatrix called");
	}
      String accessModifier;
      if (insideValuetype)
	{
	  accessModifier  = RootTrans.vFieldAccess;
	}
      else
	{
	  accessModifier  = "";
	}
      if (inMod.isCoreModule())
	{
	  rtype = "Matrix3 ";
	}
      else
	{
	  rtype = RootTrans.coreModuleName + "::Matrix3 ";
	}
      DictionaryItem di = mt.getDictionaryItem();
      writeFieldCifComment(mt, di);
      writeComment(mt);
      writeStr(accessModifier + rtype + mt.getName() + ";");
    }

  public void closeMatrix(MatrixTrans ft) 
    throws IOException, TransGenException
    {
    }

  public void writeFieldCifComment(FieldTrans ft, DictionaryItem di)
    throws IOException, TransGenException
    {
      if (RootTrans.WRITE_IDL_COMMENTS)
	{
	  StringBuffer sb = new StringBuffer(di.getItemDescription());
	  int mand = di.getItemMandatoryCode();
	  
	  substituteTerm(sb, "This data item", ft.getFullFieldName());
	  // don't put in a blank line on the first field 
	  // (fieldNumInStruct == 0) 
	  boolean blankLine = fieldNumInStruct++ > 0;
	  writeCifComment(sb.toString(),
			  ft.descriptionParagraphs, blankLine);
	  
	  if ( ft.descriptionParagraphs > 0)
	    {
	      writeStr("// ");
	    }
	  if (mand == DictionaryItem.ITEM_MANDATORY_CODE_YES)
	    {
	      writeStr("// " + ft.getStructure().getName() 
		       + "." + ft.getFullFieldName() 
		       + " is a mandatory field and");
	      writeStr("// will always be set to a valid value.");
	    }
	  else if (mand == DictionaryItem.ITEM_MANDATORY_CODE_NO)
	    {
	      writeStr("// " + ft.getStructure().getName() + 
		       "." + ft.getFullFieldName() 
		       + " is an optional field.");
	      writeStr("// The flag "  + ft.getFlagName());
	      writeStr
		("// can be used to determine if its value has been set.");
	    }
	  else
	    {
	      throw new TransGenException
		("IdlWriter.writeFieldCifComment: Item "
		 + di.getItemName()
		 + "\n\tHas an undefined mandatory code field = " + mand);
	    }
	}
    }

  // The CifTerms2Idl array contains translations of Cif
  // terminology into IDL terminology.  These translations
  // are used to modify the Structure and Field comments
  // the CIF term is on the left and the IDL term is on the right.
  String[] CifTerms2Idl = {
    "category",		"structure",
    "Category",		"Structure",
    "item",     	"field",
    "Item",		"Field",
    "[1][1] element",	"elements",
    "[1] element",	"elements",
    "[1][1]",		"[i][j]"
  };

  public void writeComment(Trans t)
    throws IOException
    {
      int i;

      int blanks = t.getBlankLines();
      for (i = 0; i < blanks; i++)
	{
	  writeStr("");
	}

      String[] sa = t.getComment();
      if (sa != null)
	{
	  for (i = 0; i < sa.length; i++)
	    {
	      writeStr("// " + sa[i]);
	    }
	}
    }

  public void writeCifComment(String s, int maxp, boolean blankline)
    throws IOException, TransGenException
    {
      if (s == null || s.length() == 0)
	{
	  return;
	}
      StringBuffer sb = new StringBuffer(s);

      // formula misspelled in mmCIF dictionary
      substituteTerm(sb, "forumula", "formula"); 

      // Change Category/Item names to those required by the OMG
      morphCifWords2Idl(sb);
      // Substitutions
      for (int i = 0; i < CifTerms2Idl.length; i += 2)
	{
	  substituteTerm(sb, CifTerms2Idl[i], CifTerms2Idl[i+1]);
	}

      LineNumberReader lnr = new LineNumberReader(new StringReader
						  (sb.toString()));
      if (maxp > 0 && blankline)
	{
	  writeStr("");
	}
      String line;
      int para = 0;
      while ((line = lnr.readLine()) != null)
	{
	  if (line.length() == 0)
	    {
	      para++;
	    }
	  if (para >= maxp)
	    {
	      break;
	    }
	  if (line.startsWith("               "))
	    {
	      writeStr("// " + line.substring(15));
	    }
	  else
	    {
	      writeStr("// " + line.trim());
	    }
	}
    }

  public void morphCifWords2Idl(StringBuffer sb)
    {
      String s, substitute;
      int i = 0;
      int start, fin;

      // break up into words and check each word
      done: while (true)
	{
	  while(Character.isWhitespace(sb.charAt(i)))
	    {
	      i++;
	      if (i >= sb.length())
		{
		  break done;
		}
	    }
	  start = i;
	  while ( ! Character.isWhitespace(sb.charAt(i)))
	    {
	      i++;
	      if (i >= sb.length())
		{
		  break;
		}
	    }
	  fin = i;
	  // if this word needs changing return the new substitution.
	  substitute = morphCifWord(sb.substring(start, fin));
	  if (substitute != null)
	    {
	      //System.err.println("CifComment: Replacing <"
	      //+ sb.substring(start, fin)
	      //   + "> with <" + substitute + ">");
	      sb.replace(start, fin, substitute);
	      i += substitute.length() - fin + start;
	    }
	  if (i >= sb.length())
	    {
	      break done;
	    }
	}
    }

  String[] CapsOkExceptions =
  {
    "CIF"
  };

  public String morphCifWord(String s)
    {
      // Change words in the Cif "underbar" notation  (e.g. xyz_abc )
      // to Idl Mixed case notation (e.g. xyzAbc)
      String rval;
      int i;
      boolean isUpperCase = s.equals(s.toUpperCase());
      int sindx = s.indexOf('_');

      for (i = 0; i < CapsOkExceptions.length; i++)
	{
	  if (s.equals(CapsOkExceptions[i]))
	    {
	      return null;
	    }
	}
      // count upper case letters; if less than two,
      // its not a Category name
      if (isUpperCase)
	{
	  int ups = 0;

	  for (i = 0; i < s.length(); i++)
	    {
	      if (Character.isUpperCase(s.charAt(i)))
		{
		  ups++;
		}
	    }
	  if (ups < 2)
	    {
	      isUpperCase = false;
	    }
	}
      if (isUpperCase)
	{
	  // assume uppercase names are Categories
	  rval = categoryToStructure(s);
	}
      else if (sindx == -1)
	{
	  // No "_" --> nothing to change
	  rval = null;
	}
      else
	{
	  int pindx = s.indexOf('.');
	  if (pindx != -1)
	    {
	      boolean proper = true;
	      // contains a Category and Item name
	      String cat = s.substring(0, pindx);
	      String itm = s.substring(pindx+1, s.length());

	      if ( itm.length() == 0)
		{
		  proper = false;
		}
	      else if (proper &&  ! cifDic.isCategory(cat))
		{
		  if ( itm.length() == 1 && itm.equals("'"))
		    {
		      // odd number of "'"s in a chemical formula
		      itm = "";
		      // don't convert it
		      proper = false;
		    }
		  else
		    {
		      System.err.println
			("WARNING: comment word <" + cat 
			 + "> from <" + s + "> is not a known Category");
		      // convert to a IDL name anyway
		    }
		}
// Too many exceptions (e.g. names followed by punctuation)
// for the following check to work
// 	      if (! cifDic.isItem(s))
// 		{
// 		  System.err.println
// 		    ("WARNING: comment word <" + s + 
// 		     "> is not an known Item");
// 		  cifDic.getDictionaryItemList().printItems();
// 		  // convert it anyway
// 		  // proper = false;
// 		}
	      if (proper)
		{
		  // do the category/item translations
		  cat = categoryToStructure(cat);
		  itm = itemToField(itm);
		  rval = cat + "." + itm;
		}
	      else
		{
		  rval = null;
		}
	    }
	  else
	    {
	      if (cifDic.isCategory(s))
		{
		  rval = categoryToStructure(s);
		}
	      else
		{
		  if ( ! cifDic.isItem(s))
		    {
		      //System.err.println
		      //("WARNING: comment word <" + s 
		      // + "> is not a known Category or Item name");
		      // convert it anyway
		    }
		  rval = itemToField(s);
		}
	    }
	}
      return rval;
    }

  public String categoryToStructure(String s)
    {
      StringBuffer sb = new StringBuffer(s);
      int i = 0;
      
      // march through the word replacing characters
      while ( ! Character.isWhitespace(sb.charAt(i)))
	{
	  if (sb.charAt(i) == '_')
	    {
	      sb.deleteCharAt(i);
	      sb.setCharAt(i, Character.toUpperCase(sb.charAt(i)));
	    }
	  else
	    {
	      if (i > 0)
		{
		  sb.setCharAt(i, Character.toLowerCase(sb.charAt(i)));
		}
	    }
	  i++;
	  if (i >= sb.length())
	    {
	      break;
	    }
	}
      return sb.toString();
    }

  public String itemToField(String s)
    {
      if (s == null || s.length() == 0)
	{
	  return s;
	}
      StringBuffer sb = new StringBuffer(s);
      int i = 0;
      
      if (sb.charAt(0) == '_')
	{
	  // skip leading "_"
	  sb.deleteCharAt(0);
	}
      // otherwise convert it to all lowercase and return
      s = sb.toString();
      return s.toLowerCase();
    }

  public void substituteTerm(StringBuffer sb, String from, String to)
    {
      String s;
      int i = 0;
      
      // find and replace *all* occurances
      while (true)
	{
	  s = sb.toString();
	  i = s.indexOf(from, i);
	  if (i == -1)
	    {
	      break;
	    }
	  sb.replace(i, i + from.length(), to);
	  i += to.length();
	}
    }

  public void openMethod(MethodTrans mt) 
    throws IOException, TransGenException
    {
      String s;

      if ( (mt.argTypes != null ^  mt.argNames != null) ||
	   (mt.argTypes != null && mt.argNames != null &&
	    mt.argTypes.length != mt.argNames.length))
	{
	  throw new TransGenException
	    ("IdlWriter.openMethod: " + mt.getName() +
	     "Arg Type/Name mismatch");
	}

      writeComment(mt);
      ExceptionTrans[] exs = mt.getExceptionsRaised();
      // terminate "noRaise" with a semicolon if there are
      // no exceptions thrown.
      String noRaise = "";
      if (exs == null || exs.length <= 0)
	{
	  noRaise = ";";
	}
      if (trace)
	{
	  System.out.println("IdlWriter.openMethod called");
	}
      if (mt.argTypes == null || mt.argTypes.length == 0)
	{
	  writeStr(mt.returnType + " " + mt.getName() + "()" + noRaise);
	}
      else if (mt.argTypes.length == 1)
	{
	  writeStr(mt.returnType + " " + mt.getName() + "("
		   + mt.argTypes[0] + " " + mt.argNames[0] + ")" + noRaise);
	}
      else
	{
	  writeStr(mt.returnType + " " + mt.getName() + "(");
	  indentLevel += 2;
	  for (int i = 0; i < mt.argTypes.length; i++)
	    {
	      s = mt.argTypes[i] + " " + mt.argNames[i];
	      if (i != mt.argTypes.length-1)
		{
		  s += ",";
		}
	      else
		{
		  s += ")" + noRaise;
		}
	      writeStr(s);
	    }
	  indentLevel -= 2;
	}

      // declare exceptions raised
      if (exs != null && exs.length > 0)
	{
	  indentLevel += 2;
	  StringBuffer thingsThrown = new StringBuffer("raises (");
	  for (int i = 0; i < exs.length; i++)
	    {
	      if (i >= 1)
		{
		  thingsThrown.append(", ");
		}
	      thingsThrown.append(exs[i].getFullyQualifiedName(inMod));
	    }
	  thingsThrown.append(");");
	  writeStr(thingsThrown.toString());
	  indentLevel -= 2;
	}
    }

  public void openGetListMethod(GetListMethodTrans glm) 
    throws IOException, TransGenException
    {
      // just use method method for idl files
      openMethod(glm);
    }

  public void createList(ListTrans lt) 
    throws IOException, TransGenException
    {
      if (trace)
	{
	  System.out.println("IdlWriter.createList called");
	}

      // typedef sequence<type> name;
      // e.g. typedef sequence<float> FloatList;
      writeComment(lt);
      writeStr("typedef sequence<" + lt.getStructure().getName() + "> " 
	       + lt.getName() + ";" );
    }

  public void createTypeDef(TypeDefTrans tdt) 
    throws IOException, TransGenException
    {
      if (trace)
	{
	  System.out.println("IdlWriter.createTypeDef called");
	}

      writeComment(tdt);
      // typedef sequence<type> name;
      // e.g. typedef sequence<float> FloatList;
      writeStr("typedef "+ tdt.getBaseType() + " " + tdt.getName() + ";" );
    }

  public void createDirective(DirectiveTrans dt) 
    throws IOException, TransGenException
    {
      writeComment(dt);
      String d = dt.getDirective();
      // null directives used for simple comments
      if (d != null)
	{
	  String def = dt.getDefinition();
	  if (def != null && def.length() > 0)
	    {
	      writeStr(d + " " + dt.getName() + " " + def);
	    }
	  else
	    {
	      writeStr(d + " " + dt.getName());
	    }
	}
    }

  public void createConstant(ConstantTrans ct) 
    throws IOException, TransGenException
    {
      writeComment(ct);
      writeStr("const " + ct.getConstantTypeName() + " "
	       + ct.getName() + " = " + ct.getValue() + ";");
    }

  public void createSequence(SequenceTrans st) 
    throws IOException, TransGenException
    {
      if (trace)
	{
	  System.out.println("IdlWriter.createSequence called");
	}

      writeComment(st);
      // typedef sequence<type> name;
      // e.g. typedef sequence<float> FloatList;
      writeStr("typedef sequence<" + st.getBaseType() + "> " 
	       + st.getName() + ";" );
    }

  public void openException(ExceptionTrans et) 
    throws IOException, TransGenException
    {
      if (trace)
	{
	  System.out.println("IdlWriter.openException called");
	}

      writeComment(et);
      writeStr("exception " + et.getName());
      writeStr("{");
      indentLevel++;
    }
      
  public void closeException(ExceptionTrans st) 
    throws IOException, TransGenException
    {
      if (trace)
	{
	  System.out.println("IdlWriter.closeException called");
	}

      indentLevel--;
      String closing[]=
      {
	"};"
      };
      writeStr(closing);
    }

  public void createExceptionField(ExceptionFieldTrans eft) 
    throws IOException, TransGenException
    {
      if (trace)
	{
	  System.out.println("IdlWriter.createExceptionField called");
	}

      writeComment(eft);
      writeStr(eft.getIdlType() + " " + eft.getName() + ";");
    }

  public String cifType2Idl(String ct) throws TransGenException
    {
      if (ct == null)
	{
	  return "string";
	}
      if (ct.compareToIgnoreCase("float") == 0)
	{
	  return "float";
	}
      else if (ct.compareToIgnoreCase("int") == 0)
	{
	  return "long";
	}
      else if (ct.compareToIgnoreCase("text") == 0 ||
	       ct.compareToIgnoreCase("name") == 0 ||
	       ct.compareToIgnoreCase("idname") == 0 ||
	       ct.compareToIgnoreCase("ucode") == 0 ||
	       ct.compareToIgnoreCase("code") == 0 ||
	       ct.compareToIgnoreCase("atcode") == 0 ||
	       ct.compareToIgnoreCase("yyyy-mm-dd") == 0 ||
	       ct.compareToIgnoreCase("line") == 0 ||
	       ct.compareToIgnoreCase("uline") == 0 ||
	       ct.compareToIgnoreCase("any") == 0 ||
	       ct.compareToIgnoreCase("uchar3") == 0 ||
	       ct.compareToIgnoreCase("uchar1") == 0 ||
	       ct.compareToIgnoreCase("symop") == 0 ||
	       ct.compareToIgnoreCase("float-range") == 0 ||
	       ct.compareToIgnoreCase("yyyy-mm-dd:hh:mm") == 0 ||
	       ct.compareToIgnoreCase("fax") == 0 ||
	       ct.compareToIgnoreCase("phone") == 0 ||
	       ct.compareToIgnoreCase("email") == 0)
	{
	  return "string";
	}
      else
	{
	  throw new TransGenException("cifType2Idl - Unknown type: " + ct);
	}
    }
}  

