//
// InitSqlWriter.java,v 1.4 2002/06/19 01:55:21 dsg Exp
//
// Copyright 2001 The Regents of the University of California
// All Rights Reserved
//
// OpenMMS was developed by Dr. Douglas S. Greer at the San Diego
// Supercomputer Center, a research unit of the University of California,
// San Diego.  Support for this effort was provided by NSF through the
// Protein Data Bank (Grant DBI-9814284) and the National Partnership for
// Advanced Computational Infrastructure (Grant ACI-9619020)
//
// Permission to use, copy, modify and distribute any part of OpenMMS for
// educational, research and non-profit purposes, without fee, and
// without a written agreement is hereby granted, provided that the above
// copyright notice, this paragraph and the following paragraphs appear
// in all copies.
//
// Those desiring to incorporate this OpenMMS into commercial products or
// use for commercial purposes should contact the Technology Transfer
// Office, University of California, San Diego, 9500 Gilman Drive, La
// Jolla, CA 92093-0910, Ph: (619) 534-5815, FAX: (619) 534-7345.
//
// In no event shall the University of California be liable to any party
// for direct, indirect, special, incidental, or consequential damages,
// including lost profits, arising out of the use of this OpenMMS, even
// if the University of California has been advised of the possibility of
// such damage.
//
// The OpenMMS provided herein is on an "as is" basis, and the
// University of California has no obligation to provide maintenance,
// support, updates, enhancements, or modifications.  The University of
// California makes no representations and extends no warranties of any
// kind, either implied or express, including, but not limited to, the
// implied warranties of merchantability or fitness for a particular
// purpose, or that the use of the OpenMMS will not infringe any patent,
// trademark or other rights.

package org.rcsb.openmms.meta;

import java.io.*;
import java.util.*;

import org.rcsb.openmms.cifparse.*;

/**
 * Visitor class to traverse the metamodel and generate the
 * code to initialize the RDB tables.
 *
 * @author Douglas S. Greer
 * @version 1.4
 */
public class InitSqlWriter extends SqlWriter
{
  CategoryTrans inCat;
  int fieldNumInCat = 0;
  int thisCatKey = 0;
  int nextItemKey = 0;

  String modelId;
  String revisionNumber;

  String tableName;
  StringStruct sysSS;
  
  final String indent = INDENT;

  public InitSqlWriter(CifDictionary d, String sqlp, String oBase)
    {
      super(d, sqlp, oBase);
    }

  public void openRoot(RootTrans rt)
    throws IOException, TransGenException
    {
      sysSS = new StringStruct();
      sysSS.setIndentString(indent);
      writeIntro(sysSS, " for loading system tables");
      writeSysSpecific(sysSS);
      modelId = rt.getModelIdentifier();
      revisionNumber = rt.getRevisionNumber();
      loadMmsSystemTable(sysSS);
    }

  public void closeRoot(RootTrans rt)
    throws IOException, TransGenException
    {
      sysSS.traverseToFile(dirPath + "/Init" + oFileBase + ".sql");
    }

  private void loadMmsSystemTable(StringStruct sst)
    {
      StringPairBlock sysInsert = new StringPairBlock
	(sst, "\nINSERT into " + SCHEMA_PREFIX + SYSTEM_TABLE_NAME + " ( ",
	" )\n" + sysSS.getIndentString() + "VALUES ( ", " ) ;", ", ");
      sysInsert.addStringPair(SYSTEM_DATA_BANK_NAME,
			      literal("RCSB-PDB IUCr/Core"));
      sysInsert.addStringPair(SYSTEM_MODEL_ID_NAME, literal(modelId));
      sysInsert.addStringPair(SYSTEM_REVISION_NUMBER_NAME,
			      literal(revisionNumber));
      sysInsert.addStringPair(SYSTEM_VERSION_NAME, 
			      literal(modelId + "_" + revisionNumber));
    }

  public void openModule(ModuleTrans mt) 
    throws IOException, TransGenException
    {
    }
      
  public void closeModule(ModuleTrans mt) 
    throws IOException, TransGenException
    {
    }

  public void openCategory(CategoryTrans ct) 
    throws IOException, TransGenException
    {
      String s;
      inCat = ct;
      fieldNumInCat = 0;

      StringPairBlock catInsert = new StringPairBlock
	(sysSS, "\nINSERT into " + 
	 SCHEMA_PREFIX + CATEGORY_TABLE_NAME + " ( ",
	 " )\n" + sysSS.getIndentString() + "VALUES ( ", " ) ;", ", ");
      ct.setCategoryKey(thisCatKey);
      catInsert.addStringPair(CATEGORY_TABLE_KEY_NAME,
			      String.valueOf(thisCatKey));

      tableName =  ct.getFullTableName();
      catInsert.addStringPair(CATEGORY_TABLE_TABLE_NAME, literal(tableName));

      String categoryName = ct.getName();
      catInsert.addStringPair(CATEGORY_TABLE_CIF_ID_NAME,
			      literal(categoryName));

      DictionaryCategory dc = cifDic.getDictionaryCategoryList()
	.findDictionaryCategory(categoryName);
      if(dc == null)
	{
	  throw new TransGenException
	    ("InitSqlWriter:openCategory Category "
		 + categoryName + " is not in a mmCIF dictionary");
	    }

      if (dc.getCategoryMandatoryCode()
	  == DictionaryCategory.CATEGORY_MANDATORY_CODE_YES)
	{
	  s = "Y";
	}
      else
	{
	  s = "N";
	}
      catInsert.addStringPair(CATEGORY_TABLE_MAND_NAME, literal(s));

      catInsert.addStringPair(CATEGORY_TABLE_NEXT_RECORD_NAME, "0");

      s = dc.getCategoryDescription();
      catInsert.addStringPair(CATEGORY_TABLE_DESC_NAME,
			      "\n"+indent+indent + literal(s) + "\n"+indent);
    }
      
  public void closeCategory(CategoryTrans ct) 
    throws IOException, TransGenException
    {
      thisCatKey++;

      inCat = null;
      fieldNumInCat = 0;
    }

  public void openField(FieldTrans ft) 
    throws IOException, TransGenException 
    {
      if (ft.isCifField())
	{
	  String s;

	  StringPairBlock itemInsert = new StringPairBlock
	    (sysSS, "\nINSERT into " + 
	     SCHEMA_PREFIX + ITEM_TABLE_NAME + " ( ",
	     " )\n" + sysSS.getIndentString() + " VALUES ( ", " ) ;", ", ");
	  itemInsert.addStringPair(ITEM_TABLE_KEY_NAME,
				   String.valueOf(nextItemKey));
	  nextItemKey++;
	  
	  itemInsert.addStringPair(ITEM_TABLE_COLUMN_NAME, 
				   literal(ft.getColumnName()));
	  
	  String itemName = ft.getName();
	  itemInsert.addStringPair(ITEM_TABLE_CIF_ID_NAME,
				   literal(itemName));

	  itemInsert.addStringPair(ITEM_TABLE_CAT_INDX_NAME,
				   String.valueOf(thisCatKey));

	  DictionaryItem di = ft.getDictionaryItem();
	  if(di == null)
	    {
	      throw new TransGenException
		("InitSqlWriter:openField Item "
		 + itemName + " is not in a mmCIF dictionary");
	    }

	  if (di.getItemMandatoryCode()
	      == DictionaryItem.ITEM_MANDATORY_CODE_YES)
	    {
	      s = "Y";
	    }
	  else
	    {
	      s = "N";
	    }
	  itemInsert.addStringPair(ITEM_TABLE_MAND_NAME, literal(s));

	  s = di.getItemDescription();
	  itemInsert.addStringPair(ITEM_TABLE_DESC_NAME, 
		   "\n"+indent+indent + literal(s) + "\n"+indent);
	}
    }

  public void closeField(SubfieldTrans ft) 
    throws IOException, TransGenException
    {
    }
}  

