//
// InsertWriter.java,v 1.10 2003/05/28 01:09:05 dsg Exp
//
// Copyright 2001 The Regents of the University of California
// All Rights Reserved
//
// OpenMMS was developed by Dr. Douglas S. Greer at the San Diego
// Supercomputer Center, a research unit of the University of California,
// San Diego.  Support for this effort was provided by NSF through the
// Protein Data Bank (Grant DBI-9814284) and the National Partnership for
// Advanced Computational Infrastructure (Grant ACI-9619020)
//
// Permission to use, copy, modify and distribute any part of OpenMMS for
// educational, research and non-profit purposes, without fee, and
// without a written agreement is hereby granted, provided that the above
// copyright notice, this paragraph and the following paragraphs appear
// in all copies.
//
// Those desiring to incorporate this OpenMMS into commercial products or
// use for commercial purposes should contact the Technology Transfer
// Office, University of California, San Diego, 9500 Gilman Drive, La
// Jolla, CA 92093-0910, Ph: (619) 534-5815, FAX: (619) 534-7345.
//
// In no event shall the University of California be liable to any party
// for direct, indirect, special, incidental, or consequential damages,
// including lost profits, arising out of the use of this OpenMMS, even
// if the University of California has been advised of the possibility of
// such damage.
//
// The OpenMMS provided herein is on an "as is" basis, and the
// University of California has no obligation to provide maintenance,
// support, updates, enhancements, or modifications.  The University of
// California makes no representations and extends no warranties of any
// kind, either implied or express, including, but not limited to, the
// implied warranties of merchantability or fitness for a particular
// purpose, or that the use of the OpenMMS will not infringe any patent,
// trademark or other rights.

package org.rcsb.openmms.meta;

import java.io.*;
import java.util.*;

import org.rcsb.openmms.cifparse.*;

/**
 * Visitor subclass that writes the java JDBC code for inserting
 * data into the relational database (dbinsert).
 *
 * @author Douglas S. Greer
 * @version 1.8
 */
public class InsertWriter extends SqlWriter
{
  final String indent = "    ";

  RootTrans inRoot;
  CategoryTrans inCat;
  String moduleEntryName;
  String subEntryVarName;
  String lsrPackageName, msaPackageName;

  // created by OpenRoot() and written out by CloseRoot()
  StringStruct insertFile;

  // written by OpenRoot() and used by OpenCategory()
  StringStruct insertCodeBody;
  StringStruct insertCodeBodyCatCalls;
  StringStruct insertCodeBodyUpdates;
  StringStruct insertCatMethods;
  StringStruct catVars;
  StringStruct initCatVars;

  // written by OpenCategory() and used by OpenField()
  StringStruct prepStateSetup;
  StringStruct forLoop;

  // written by OpenStructure() and used by OpenField()
  String structListVar;

  public InsertWriter(CifDictionary d, String insertp,
		       String lsr, String msa, String oBase)
    {
      super(d, insertp, oBase);

      lsrPackageName = lsr;
      msaPackageName = msa;
    }

  public void openRoot(RootTrans rt)
    throws IOException, TransGenException
    {
      inRoot = rt;

      insertFile = new StringStruct();
      insertFile.setIndentString(indent);
      
      StringStruct headerSS = new StringStruct();
      headerSS.setIndentString(indent);
      insertFile.writeStringStruct(headerSS);

      Date dt = new Date();
      GregorianCalendar cal = new GregorianCalendar();
      cal.setTime(dt);
      String[] toplines =
      {
	"//",
	"// **** DERIVED FILE - DO NOT EDIT ****",
	"//",
      };
      headerSS.writeLine(toplines);
      writeCopyright(headerSS);

      String[] opening =
      {
	"",
	"package " + msaPackageName + ".dbinsert;",
	"",
	"import java.io.*;",
	"import java.sql.*;",

	"import " + msaPackageName + ".util.*;",
	"import " + msaPackageName + ".loader.*;",
	"",
	"import org.omg.CORBA.*;",
	"import " + lsrPackageName + ".DsLSRMacromolecularStructure.*;",
	"import " + lsrPackageName + ".DsLSRMmsReference.*;",
	"import " + lsrPackageName + ".DsLSRXRayCrystallography.*;",
	"import " + lsrPackageName + ".DsLSRNmr.*;",
	"import " + lsrPackageName + ".DsLSRMmsDeposition.*;",
	"",
	"/**",
	" * Class to create the JDBC needed to insert data from the Entry",
	" * data structures into a relational database.",
	" * <p>",
	" * Generated by the program MMSExpr. Model: "
	  + inRoot.getModelIdentifier() + ", Revision: "
	  + inRoot.getRevisionNumber(),
	" * <p>",
	" * Date: " + dt.toString(),
	" *",
	" * @author Douglas S. Greer",
	" * @version OpenMMS Release V_1_2_12",
	" */",
	"public class InsertEntry extends InsertEntryBase"
      };

      insertFile.writeLine(opening);

      StringStruct body = insertFile.newBlock("{", "}");
      body.beginIndent();

      String[] constructor = 
	{
	  "public InsertEntry(MessageHandler ps, int dbug, Connection con)",
	  "  {",
	  indent + "super(ps, dbug, con);",
	  "  }",
	  ""
        };
      body.writeLine(constructor);

      // define and init <x>CatKey and <x>CatBase vars
      catVars = new StringStruct(body);
      initCatVars = body.newMethodBlock
	("public void initCategories()",
	 "throws MmsTranslationException, SQLException");

      // insertCodeBody contains the list of method calls to
      // insert<Category_Name>() that are coded in the insertCatMethods
      // StringStruct.
      insertCodeBody = body.newMethodBlock
	("public void insertEntryData(int entryKey, EntryMethodImpl ei)",
	 "throws MmsTranslationException, SQLException");
      insertCodeBodyCatCalls = new StringStruct(insertCodeBody);
      insertCodeBody.writeLine("");
      insertCodeBodyUpdates = new StringStruct(insertCodeBody);

      // insertCodeCats contains the actual Code to that inserts data
      // into DB
      insertCatMethods = new StringStruct(body);
    }

  public void closeRoot(RootTrans rt)
    throws IOException, TransGenException
    {
      insertFile.traverseToFile(dirPath + "/" + oFileBase + ".java");
    }

  public void openModule(ModuleTrans mt) 
    throws IOException, TransGenException
    {
      moduleEntryName = mt.getEntryName();
      if (mt.isCoreModule())
	{
	  subEntryVarName = "";
	}
      else
	{
	  subEntryVarName = mt.getVarName() + ".";
	}
    }
      
  public void closeModule(ModuleTrans mt) 
    throws IOException, TransGenException
    {
    }

  public void openCategory(CategoryTrans ct) 
    throws IOException, TransGenException
    {
      inCat = ct;
      Trans t;
      if (ct.numberOfChildren() == 0)
	{
 	  throw new TransGenException
	    ("InsertWriter.openCategory() " + ct.getName() +
	     " contains no stuctures");
 	}
      t = ct.getChild(0);
      if ( ! (t instanceof StructureTrans))
	{
 	  throw new TransGenException
	    ("InsertWriter.openCategory() " + ct.getName() +
				      " contains non-stuctures");
	}
      StructureTrans first = (StructureTrans) t;

      // When categories contain multiple structures they are
      // all the same size
      String methodName = "insert_" + inCat.getTableName();
      String methodParams = "(entryKey, ei)";
      String methodArgs = "(int entryKey, EntryMethodImpl ei)";

      // Key and Base vars init code
      String varBase = inCat.getTableName().toLowerCase() + "_";
      String catKeyName = varBase + "CatKey";
      String catBaseName = varBase + "CatBase";
      catVars.writeLine("int " + catKeyName + ";");
      catVars.writeLine("int " + catBaseName + ";");
      initCatVars.writeLine(catKeyName + " = getCategoryKey(\""
			    + inCat.getFullTableName() + "\");");
      initCatVars.writeLine(catBaseName + " = getCategoryBase(\""
			    + inCat.getFullTableName() + "\");");
      // Calling code
      DictionaryCategory dc = first.getDictionaryCategory();
      int mand = dc.getCategoryMandatoryCode();
      if (mand == DictionaryCategory.CATEGORY_MANDATORY_CODE_YES)
	{
	  insertCodeBodyCatCalls.writeLine
	    (methodName + methodParams + ";");
	}
      else
	{
	  insertCodeBodyCatCalls.writeLine
	    ("if (isFlagSet(ei." + subEntryVarName + "_presence_flags, ");
	  insertCodeBodyCatCalls.writeLine
	     ("  " + moduleEntryName + "." +  first.getFlagName() + "))");
	  insertCodeBodyCatCalls.writeLine
	    (indent + methodName + methodParams + ";");
	}

      String[] updateCode = 
      {
	"updateCategoryEntryKey(entryKey, "
	  + catKeyName + ",",
	indent + catBaseName + ", ei." + subEntryVarName 
	  + first.getListVarName()  + ".length" + ");",
	catBaseName + " +=  ei." + subEntryVarName 
	  + first.getListVarName()  + ".length" + ";"
      };
      if (mand == DictionaryCategory.CATEGORY_MANDATORY_CODE_YES)
	{
	  insertCodeBodyUpdates.writeLine(updateCode);
	}
      else
	{
	  insertCodeBodyUpdates.writeLine
	    ("if (isFlagSet(ei." + subEntryVarName + "_presence_flags, ");
	  insertCodeBodyUpdates.writeLine
	     ("  " + moduleEntryName + "." +  first.getFlagName() + "))");
	  insertCodeBodyUpdates.writeLine("  {");
	  insertCodeBodyUpdates.beginIndent();
	  insertCodeBodyUpdates.writeLine(updateCode);
	  insertCodeBodyUpdates.endIndent();
	  insertCodeBodyUpdates.writeLine("  }");
	}

      // Called code
      // methodBody contains code to insert data for current category
      StringStruct methodBody = insertCatMethods.newMethodBlock
	("void " + methodName + methodArgs,
	 "throws MmsTranslationException, SQLException");

      String[] psBegin =
      {
	"int catEntryKey = " + catBaseName + ";",
	"StringBuffer t = new StringBuffer(\"INSERT into "
	  + inCat.getFullTableName() + " ( \\n\"",
	indent + "+ \"" + inCat.getTableKeyName() + ", entry_key\");",
	"StringBuffer q = new StringBuffer(\" ) VALUES (?, ?\");",
      };
      String[] psEnd =
      {
	"q.append(\")\");"
      };
      prepStateSetup = methodBody.newBlock(psBegin, psEnd);

      String[] forBegin =
      {
	"PreparedStatement ps = null;",
	"try",
	"  {",
	indent + "ps = Conn.prepareStatement(t.toString() + q.toString());",
	indent + "for (int i = 0; i < ei." + subEntryVarName 
	  + first.getListVarName()  + ".length; i++)",
	indent + "  {",
	indent + indent + "ps.setInt(1, catEntryKey++);",
	indent + indent + "ps.setInt(2, entryKey);",
	indent + indent + "int j = 3;"
      };
      String[] forEnd =
      {
	indent + indent +
	  (ct.isCategoryBitSet(CategoryTrans.CONTAINS_STREAM_DATATYPES) ?
		  "ps.executeUpdate();"	: "ps.addBatch();"),
	indent + "  }"
      };
      forLoop = methodBody.newBlock(forBegin, forEnd);
      forLoop.beginIndent(2);

      if ( ! ct.isCategoryBitSet(CategoryTrans.CONTAINS_STREAM_DATATYPES))
	{
	  methodBody.writeLine(indent +
			       "int[] updateCounts = ps.executeBatch();");
	}
      String[] doit = 
      {
	"  }",
	"finally",
	"  {",
	indent + "if (ps != null)",
	indent + indent + "ps.close();",
	"  }"
      };
      methodBody.writeLine(doit);
    }
      
  public void closeCategory(CategoryTrans ct) 
    throws IOException, TransGenException
    {
      inCat = null;
    }

  public void openStructure(StructureTrans st) 
    throws IOException, TransGenException
    {
      structListVar = st.getListVarName();
    }

  public void openValuetype(ValuetypeTrans st) 
    throws IOException, TransGenException
    {
      structListVar = st.getListVarName();
    }

  public void openField(FieldTrans ft) 
    throws IOException, TransGenException 
    {
      // Only write Cif Data fields (and their indices)
      if ( ! ft.isCifField())
	{
	  return;
	}
      String setter = cifToSqlSetMethod(ft);

      String tAppendStr = "t.append(\", " + ft.getColumnName() + "\");";
      String qAppendStr = "q.append(\", ?\");";

      if (ft.isIndexField())
	{
	  tAppendStr = "t.append(\", "  + ft.getColumnName() + ", " 
	    + ft.getColumnIndexName() + "\");";
	  qAppendStr = "q.append(\", ?, ?\");";
	}
      if ( ! ft.isPseudoField())
	{
	  openValueGroupSet(ft);
	}

      String[] pss =
      {
	tAppendStr,
	qAppendStr
      };
      prepStateSetup.writeLine(pss);

      String fullVName = "ei." + subEntryVarName +
	structListVar + "[i]." + ft.getFullFieldName();

      if (ft.isFieldBitSet(FieldTrans.IS_A_STREAM_DATATYPE))
	{
	  String[] iCode =
	  {
	    "ps." + setter + "(j++, new ByteArrayInputStream",
	    indent + "(" + fullVName + ".getBytes()),",
	    indent + fullVName + ".length());"
	  };
	  forLoop.writeLine(iCode);
	}
      else
	{
	  String[] iCode =
	  {
	    "ps." + setter + "(j++,",
	    indent + fullVName + ");"
	  };
	  forLoop.writeLine(iCode);
	}

      if (ft.isIndexField())
	{
	  String parentModuleEntryName, parentSubEntryVarName;

	  StructureTrans parentStruct
	    = ft.getCifParentIndex().getStructure();
	  CategoryTrans parentCat = parentStruct.getCategory();
	  String parentCatBaseName = parentCat.getTableName().toLowerCase()
	    + "_CatBase";

	  ModuleTrans[] qualMods = parentStruct.getModuleQualifier();
	  if (qualMods == null)
	    {
	      parentModuleEntryName = "Entry";
	      parentSubEntryVarName = "";
	    }
	  else
	    {
	      ModuleTrans parentMod = qualMods[qualMods.length -1];
	      parentModuleEntryName = parentMod.getExtensionName() + "Entry";
	      parentSubEntryVarName = parentMod.getVarName() + ".";
	    }

	  String[] iCodeIndex =
	    {
	      "if (isFlagSet(ei." + parentSubEntryVarName + "_presence_flags,",
	      indent + parentModuleEntryName + "." 
	      +  parentStruct.getFlagName() + "))",
	      "  {",
	      indent + "ps.setInt(j++,",
	      indent + indent + "ei." + subEntryVarName 
		+ structListVar + "[i]."
		  + ft.getContainingField().getFullFieldName() + ".index",
		    indent + indent + "+ " + parentCatBaseName + ");",
	      "  }",
	      "else",
	      "  {",
	      indent + "ps.setNull(j++, java.sql.Types.INTEGER);",
	      "  }"
	    };
	  forLoop.writeLine(iCodeIndex);
	}
      if ( ! ft.isPseudoField())
	{
	  closeValueGroupSet(ft);
	}
    }

  public void closeField(SubfieldTrans ft) 
    throws IOException, TransGenException
    {
    }

  public void openSubfield(SubfieldTrans ft) 
    throws IOException, TransGenException
    {
      openField(ft);
    }

  public void closeSubfield(SubfieldTrans ft) 
    throws IOException, TransGenException
    {
      closeField(ft);
    }

  public void openVector(VectorTrans vt) 
    throws IOException, TransGenException
    {
      openValueGroupSet(vt);
    }

  public void closeVector(VectorTrans vt) 
    throws IOException, TransGenException
    {
      closeValueGroupSet(vt);
    }

  public void openMatrix(MatrixTrans mt) 
    throws IOException, TransGenException
    {
      openValueGroupSet(mt);
    }

  public void closeMatrix(MatrixTrans mt) 
    throws IOException, TransGenException
    {
      closeValueGroupSet(mt);
    }

  public void openValueGroupSet(FieldTrans ft) 
    throws IOException, TransGenException
    {
      if (ft.getDictionaryItem().getItemMandatoryCode()
	  == DictionaryItem.ITEM_MANDATORY_CODE_NO)
	{
	  String ifCond = "if (isFlagSet(ei." + subEntryVarName
	    + "_presence_flags, ";
	  String ifFlag = indent + moduleEntryName
	    + "." +  ft.getFlagName() + "))";

	  String[] optCode =
	  {
	    ifCond,
	    ifFlag,
	    "  {",
	  };

	  prepStateSetup.writeLine(optCode);
	  prepStateSetup.beginIndent();

	  forLoop.writeLine(optCode);
	  forLoop.beginIndent();
	}
    }

  public void closeValueGroupSet(FieldTrans ft) 
    throws IOException, TransGenException
    {
      if (ft.getDictionaryItem().getItemMandatoryCode()
	  == DictionaryItem.ITEM_MANDATORY_CODE_NO)
	{
	  prepStateSetup.endIndent();
	  prepStateSetup.writeLine("  }");

	  forLoop.endIndent();
	  forLoop.writeLine("  }");
	}
    }
}  
