//
// LinkWriter.java,v 1.4 2002/06/27 21:59:09 dsg Exp
//
// Copyright 2001 The Regents of the University of California
// All Rights Reserved
//
// OpenMMS was developed by Dr. Douglas S. Greer at the San Diego
// Supercomputer Center, a research unit of the University of California,
// San Diego.  Support for this effort was provided by NSF through the
// Protein Data Bank (Grant DBI-9814284) and the National Partnership for
// Advanced Computational Infrastructure (Grant ACI-9619020)
//
// Permission to use, copy, modify and distribute any part of OpenMMS for
// educational, research and non-profit purposes, without fee, and
// without a written agreement is hereby granted, provided that the above
// copyright notice, this paragraph and the following paragraphs appear
// in all copies.
//
// Those desiring to incorporate this OpenMMS into commercial products or
// use for commercial purposes should contact the Technology Transfer
// Office, University of California, San Diego, 9500 Gilman Drive, La
// Jolla, CA 92093-0910, Ph: (619) 534-5815, FAX: (619) 534-7345.
//
// In no event shall the University of California be liable to any party
// for direct, indirect, special, incidental, or consequential damages,
// including lost profits, arising out of the use of this OpenMMS, even
// if the University of California has been advised of the possibility of
// such damage.
//
// The OpenMMS provided herein is on an "as is" basis, and the
// University of California has no obligation to provide maintenance,
// support, updates, enhancements, or modifications.  The University of
// California makes no representations and extends no warranties of any
// kind, either implied or express, including, but not limited to, the
// implied warranties of merchantability or fitness for a particular
// purpose, or that the use of the OpenMMS will not infringe any patent,
// trademark or other rights.

package org.rcsb.openmms.meta;

import java.io.*;
import java.util.*;

import org.rcsb.openmms.cifparse.*;

/**
 * Create a table that contains all the bindings between a
 * category name and the category data loader
 *
 * @author Douglas S. Greer
 * @version 1.4
 */
public class LinkWriter extends TransVisitor
{
  String loaderPath;
  String genClassName;
  String lsrPackageName, msaPackageName;
  String loaderPackage;
  String moduleName;
  String catBaseName;
  String catClassName;

  RootTrans inRoot;
  CategoryTrans inCat;

  StringStruct  initBlockBuffer;
  
  int nLinks;

  public LinkWriter(String ldp, String lsr, String msa,
		     String gname, String cname)
    {
      loaderPath = ldp;

      lsrPackageName = lsr;
      msaPackageName = msa;
      loaderPackage = "loader";

      genClassName = gname;
      catBaseName = cname;

      // Typedef Block
      initBlockBuffer = new StringStruct();

    }
  
  public void openRoot(RootTrans rt)
    throws IOException, TransGenException
    {
      inRoot = rt;

      if (loaderPath == null)
	{
	  throw new TransGenException(
	      "loader target directoy path not specified");
	}
      String oFileName = genClassName + ".java";
      open(loaderPath + "/" + oFileName);

      Date dt = new Date();
      GregorianCalendar cal = new GregorianCalendar();
      cal.setTime(dt);

      // write preable
      writeStr("//");
      writeStr("// **** DERIVED FILE - DO NOT EDIT ****");
      writeStr("//");
      writeStr("// " + oFileName);
      writeStr("// Created " + dt.toString());
      writeStr("//    by MMSExpr");
      writeStr("//");

      writeCopyright();
          
      String opening[]=
      {
	"",
	"package " + msaPackageName + "." + loaderPackage + ";",
	"",
	"import " + msaPackageName + "." + "cifparse" + ".*;",
	"",
	"/**",
	" * This class specifies a table containing links that bind the Cif",
	" * Category/Item to the Cat Loader class which handles data for",
	" * that Category/Item",
	" * <p>",
	" * Generated by the program MMSExpr. Model: "
	  + inRoot.getModelIdentifier() + ", Revision: "
	  + inRoot.getRevisionNumber(),
	" * <p>",
	" * Date: " + dt.toString(),
	" *",
	" * @author Douglas S. Greer",
	" * @version OpenMMS Release V_1_5_1",
	" */",
	"public class " + genClassName,
	indent + "{"
      };
      writeStr(opening);
      indentLevel++;

      String constructor[]=
      {
	"public " + genClassName + "()",
	indent + "{",
	indent + "}",
	""
      };
      writeStr(constructor);

      String initOpening[]=
      {
	"public LoaderLink[] createLinkTable()",
	indent + "{",
      };
      writeStr(initOpening);
      // start writing to initBlock String Buffer

      beginInitBlock();
    }

  public void closeRoot(RootTrans rt)
    throws IOException, TransGenException
    {
      // copy in Init Block
      endInitBlock();

      // init code has been written to Block Buffer so nLinks
      // equals the total number of LoaderLinks to be created
      indentLevel++;
      writeStr("LoaderLink[] lLinks = new LoaderLink["
	       + nLinks + "];");
      writeBuffer(initBlockBuffer);

      indentLevel--;

      String closing[]=
      {
	"}",
	""
      };
      writeStr(closing);
      indentLevel--;

      close();
    }

  public void openModule(ModuleTrans mt) 
    throws IOException, TransGenException
    {
      moduleName = mt.getName();
    }

  private void beginInitBlock()
    throws IOException, TransGenException
    {
      writeStr(initBlockBuffer, "CatLoader catLoader;", 1);
    }

  private void endInitBlock()
    throws IOException, TransGenException
    {
      String initClosing[]=
      {
	"",
	"return lLinks;",
	"}"
      };
      writeStr(initBlockBuffer, initClosing, 1);
    }


  public void openCategory(CategoryTrans ct) 
    throws IOException, TransGenException
    {
      inCat = ct;
      catClassName = inCat.getCatClassPrefix() + catBaseName;

      writeStr(initBlockBuffer, "", 1);
      writeStr(initBlockBuffer,
	       "catLoader = new " + catClassName + "();", 1);
    }

  public void openField(FieldTrans ft) 
    throws IOException, TransGenException
    {
      if (ft.isCifField())
	{
	  writeStr(initBlockBuffer,
		   "lLinks[" + nLinks + "] = new LoaderLink(\"" +
		   inCat.getName() + "\", " +
		   "\"" + ft.getCifItemName() + "\",", 1);
	  writeStr(initBlockBuffer,
		   "catLoader, " + catClassName + "." 
		   + ft.getTagName() + ");", 3);
	  nLinks++;
	}
    }

  public void openSubfield(SubfieldTrans sft) 
    throws IOException, TransGenException
    {
      openField(sft);
    }
}  

