//
// ModelDtdWriter.java,v 1.2 2002/06/19 01:55:23 dsg Exp
//
// Copyright 2001 The Regents of the University of California
// All Rights Reserved
//
// OpenMMS was developed by Dr. Douglas S. Greer at the San Diego
// Supercomputer Center, a research unit of the University of California,
// San Diego.  Support for this effort was provided by NSF through the
// Protein Data Bank (Grant DBI-9814284) and the National Partnership for
// Advanced Computational Infrastructure (Grant ACI-9619020)
//
// Permission to use, copy, modify and distribute any part of OpenMMS for
// educational, research and non-profit purposes, without fee, and
// without a written agreement is hereby granted, provided that the above
// copyright notice, this paragraph and the following paragraphs appear
// in all copies.
//
// Those desiring to incorporate this OpenMMS into commercial products or
// use for commercial purposes should contact the Technology Transfer
// Office, University of California, San Diego, 9500 Gilman Drive, La
// Jolla, CA 92093-0910, Ph: (619) 534-5815, FAX: (619) 534-7345.
//
// In no event shall the University of California be liable to any party
// for direct, indirect, special, incidental, or consequential damages,
// including lost profits, arising out of the use of this OpenMMS, even
// if the University of California has been advised of the possibility of
// such damage.
//
// The OpenMMS provided herein is on an "as is" basis, and the
// University of California has no obligation to provide maintenance,
// support, updates, enhancements, or modifications.  The University of
// California makes no representations and extends no warranties of any
// kind, either implied or express, including, but not limited to, the
// implied warranties of merchantability or fitness for a particular
// purpose, or that the use of the OpenMMS will not infringe any patent,
// trademark or other rights.

package org.rcsb.openmms.meta;

import java.io.*;
import java.util.*;
import java.util.Date;

import org.rcsb.openmms.cifparse.*;

/**
 * TransVisitor subclass for writing XML DTD
 *
 * @author Douglas S. Greer
 * @version 1.2
 */
public class ModelDtdWriter extends TransVisitor
{
  String xmlPath;
  String dtdName;

  boolean inEntry;
  StringStruct  entryElementListBuffer;
  StringStruct  catElementListBuffer;

  public ModelDtdWriter(String xp, String dtdn)
    {
      xmlPath = xp;
      dtdName= dtdn;
    }
  
  public void openRoot(RootTrans rt)
    throws IOException, TransGenException
    {
      beginDoc(rt);
      createEntry(rt);
    }

  public void closeRoot(RootTrans rt)
    throws IOException, TransGenException
    {
      endDoc(rt);
    }

  public void openFile(FileTrans ft) 
    throws IOException, TransGenException
    {
    }

  public void closeFile(FileTrans ft) 
    throws IOException, TransGenException
    {
    }

  public void openModule(ModuleTrans mt) 
    throws IOException, TransGenException
    {
    }
      
  public void closeModule(ModuleTrans mt) 
    throws IOException, TransGenException
    {
    }

  public void openInterface(InterfaceTrans it) 
    throws IOException, TransGenException
    {
      inEntry = it.getName().endsWith("Entry");
    }
      
  public void closeInterface(InterfaceTrans it) 
    throws IOException, TransGenException
    {
      inEntry = false;
    }

  public void openCategory(CategoryTrans ct) 
    throws IOException, TransGenException
    {
    }
      
  public void closeCategory(CategoryTrans ct) 
    throws IOException, TransGenException
    {
    }

  public void openStructure(StructureTrans st) 
    throws IOException, TransGenException
    {
      beginStructure(st);
    }
      
  public void closeStructure(StructureTrans st) 
    throws IOException, TransGenException
    {
      endStructure(st);
    }

  public void openValuetype(ValuetypeTrans st) 
    throws IOException, TransGenException
    {
      beginStructure(st);
    }
      
  public void closeValuetype(ValuetypeTrans st) 
    throws IOException, TransGenException
    {
      endStructure(st);
    }

  public void openField(FieldTrans ft) 
    throws IOException, TransGenException
    {
      beginItem(ft);
    }

  public void closeField(FieldTrans ft) 
    throws IOException, TransGenException
    {
      endItem(ft);
    }

  public void openSubfield(SubfieldTrans ft) 
    throws IOException, TransGenException
    {
    }

  public void closeSubfield(SubfieldTrans ft) 
    throws IOException, TransGenException
    {
    }

  public void openVector(VectorTrans vt) 
    throws IOException, TransGenException
    {
      beginItem(vt);
    }

  public void closeVector(VectorTrans vt) 
    throws IOException, TransGenException
    {
      endItem(vt);
    }

  public void openMatrix(MatrixTrans mt) 
    throws IOException, TransGenException
    {
      beginItem(mt);
    }

  public void closeMatrix(MatrixTrans mt) 
    throws IOException, TransGenException
    {
      endItem(mt);
    }

  public void beginDoc(RootTrans rt)
    throws IOException, TransGenException
    {
      beginDtd();
      String[] doc =
      {
	"<!ELEMENT DOCUMENT (ENTRY*) >",
	""
      };
      writeStr(doc);
    }

  public void endDoc(RootTrans rt)
    throws IOException, TransGenException
    {
      endDtd();
    }

  protected void beginDtd()
    throws IOException, TransGenException
    {
      if (dtdName == null)
	{
	  throw new TransGenException("DTD name not specified");
	}
      open(xmlPath + "/" + dtdName);

      String header =
	"\nXMC.dtd" +
	" - The Macromolecular Crystallographic Information XML DTD" +
	"\n" +
	"\nTranslated from the IUCr Macromolecular CIF Dictionary" +
	"\n    on " + (new Date()).toString() + 
	"\n    by Douglas S. Greer" +
	"\n" +
	"\nCopyright 2001" +
	"\n    Research Collaboratory for Structural Bioinfomatics," +
	"\n    International Union of Crystallography" +
	"\n    All rights reserved" +
	"\n";
      writeComStr(header);
      writeStr("");
    }

  protected void endDtd()
    throws IOException, TransGenException
    {
      String[] closing =
      {
	"<--XMC_FIN-->",
	""
      };
      writeStr(closing);
      close();
    }

  public void createEntry(RootTrans rt)
    throws IOException, TransGenException
    {
      StringStruct entryBuffer = new StringStruct();
      writeBuffer(entryBuffer);

      entryBuffer.writeString("<!ELEMENT ENTRY\n");
      entryBuffer.writeString(indent + "(\n");

      entryElementListBuffer = new StringStruct();
      entryBuffer.writeStringStruct(entryElementListBuffer);

      entryBuffer.writeString(indent + ")\n");
      entryBuffer.writeString(">\n");
      entryBuffer.writeString("\n");
    }

  public void beginStructure(StructureTrans st)
    throws IOException, TransGenException
    {
      DictionaryCategory  dc = st.getDictionaryCategory();

      // output category in the Entry list
      entryElementListBuffer.writeString(indent + st.getName() + "?,\n");
      
      StringStruct catBuffer = new StringStruct();
      writeBuffer(catBuffer);

      catBuffer.writeString("<!ELEMENT " + st.getName() + "\n");
      catBuffer.writeString(indent + "(\n");

      catElementListBuffer = new StringStruct();
      catBuffer.writeStringStruct(catElementListBuffer);

      catBuffer.writeString(indent + ")\n");
      catBuffer.writeString(">\n");

      // Descriptions only exit for cif structures at this time
      if ( st.isCifStructure())
	{
	  // Category description
	  writeStr("<!ATTLIST " + st.getName() + " description CDATA #FIXED");
	  writeDescription(dc.getCategoryDescription());
	  writeStr("\">");
	  writeStr("");
	  return;
	}
    }

  public void endStructure(StructureTrans st)
    throws IOException, TransGenException
    {
    }

  public void beginItem(FieldTrans ft)
    throws IOException, TransGenException
    {
      DictionaryItem di;
      String type;

      di = ft.getDictionaryItem();
      if (inEntry)
	{
	  entryElementListBuffer.writeString
	    (indent + ft.getFullRefName() + ",\n");
	}
      else
	{
	  String optional;
	  if (di == null || di.getItemMandatoryCode()
	      == DictionaryItem.ITEM_MANDATORY_CODE_NO)
	    {
	      optional = "?";
	    }
	  else
	    {
	      optional = "";
	    }
	  catElementListBuffer.writeString
	    (indent + ft.getFullRefName() + optional + ",\n");
	}
      writeStr("<!ELEMENT " + ft.getFullRefName() + " (#PCDATA)>");
      // Write type 
      if (ft.isCifField())
	{
	  type = ft.getDictionaryItem().getItemType();
	}
      else if (ft.isIndexField())
	{
	  type = "long";
	}
      else
	{
	  type = ft.getFieldType();
	}
      if (type == null || type.length() == 0)
	{
	  // don't know the type; set to a string
	  type = "string";
	}
      writeStr("<!ATTLIST " + ft.getFullRefName() 
	       + " length CDATA \"1\">");
      // if no type is specified in mmCIF dictionary,
      // then one is not written to DTD
      if (type != null)
	{
	  writeStr("<!ATTLIST " + ft.getFullRefName() 
		   + " type CDATA #FIXED \"" + type + "\">");
	}

      if (ft.isCifField())
	{
	  // Write description
	  writeStr("<!ATTLIST " + ft.getFullRefName() 
		   + " description CDATA #FIXED");
	  writeDescription(ft.getDictionaryItem().getItemDescription());
	  writeStr("\">");
	  writeStr("");
	}
    }

  public void endItem(FieldTrans ft)
    throws IOException, TransGenException
    {
    }

  public void writeComStr(String s) throws IOException
    {
      writeStr("<!--" + s + "-->");
    }

  public void writeDescription(String s)
    throws IOException
    {
      StringBuffer sb = new StringBuffer();
      char c;

      sb.append('"');
      for (int i = 11; i < s.length(); i++)
	{
	  c = s.charAt(i);
	  switch (c)
	    {
	    case '<':
	      sb.append("&lt;");
	      break;
	    case '&':
	      sb.append("&amp;");
	      break;
	    case '"':
	      sb.append("&quot;");
	      break;
	    case '\n':
	      sb.append(c);
	      if (i+12 <= s.length() &&
		  s.substring(i+1, i+12).equals("           "))
		{
		  i += 11;
		}
	      break;
	    default:
	      sb.append(c);
	      break;
	    }
	}
      writeStr(sb.toString());
    }
}  


