//
// ModuleTrans.java,v 1.4 2002/06/19 01:55:23 dsg Exp
//
// Copyright 2001 The Regents of the University of California
// All Rights Reserved
//
// OpenMMS was developed by Dr. Douglas S. Greer at the San Diego
// Supercomputer Center, a research unit of the University of California,
// San Diego.  Support for this effort was provided by NSF through the
// Protein Data Bank (Grant DBI-9814284) and the National Partnership for
// Advanced Computational Infrastructure (Grant ACI-9619020)
//
// Permission to use, copy, modify and distribute any part of OpenMMS for
// educational, research and non-profit purposes, without fee, and
// without a written agreement is hereby granted, provided that the above
// copyright notice, this paragraph and the following paragraphs appear
// in all copies.
//
// Those desiring to incorporate this OpenMMS into commercial products or
// use for commercial purposes should contact the Technology Transfer
// Office, University of California, San Diego, 9500 Gilman Drive, La
// Jolla, CA 92093-0910, Ph: (619) 534-5815, FAX: (619) 534-7345.
//
// In no event shall the University of California be liable to any party
// for direct, indirect, special, incidental, or consequential damages,
// including lost profits, arising out of the use of this OpenMMS, even
// if the University of California has been advised of the possibility of
// such damage.
//
// The OpenMMS provided herein is on an "as is" basis, and the
// University of California has no obligation to provide maintenance,
// support, updates, enhancements, or modifications.  The University of
// California makes no representations and extends no warranties of any
// kind, either implied or express, including, but not limited to, the
// implied warranties of merchantability or fitness for a particular
// purpose, or that the use of the OpenMMS will not infringe any patent,
// trademark or other rights.

package org.rcsb.openmms.meta;

import java.io.IOException;

/**
 * Class for "Modules" in Cif to Idl Translation
 *
 * @author Douglas S. Greer
 * @version 1.4
 */
public class ModuleTrans extends Trans
{
  protected int number;
  protected ModuleTrans coreModule;
  protected String baseName, extName, varName;

  public ModuleTrans(int n, String base, String ext, String var,
		     ModuleTrans core)
    {
      super(base + ext, Trans.TYPE_MODULE);
      number = n;
      baseName = base;
      extName = ext;
      varName = var;
      coreModule = core;
    }

  public void accept(TransVisitor v)
    throws IOException, TransGenException
    {
      v.openModule(this);
      // visit children
      Trans t;
      for (int i = 0; i < numberOfChildren(); i++)
	{
	  t = getChild(i);
	  int type = t.getTransType();
	  switch (type)
	    {
	    case Trans.TYPE_MODULE:
	    case Trans.TYPE_INTERFACE:
	    case Trans.TYPE_CATEGORY:
	    case Trans.TYPE_STRUCTURE:
	    case Trans.TYPE_VALUETYPE:
	    case Trans.TYPE_LIST:
	    case Trans.TYPE_TYPEDEF:
	    case Trans.TYPE_SEQUENCE:
	    case Trans.TYPE_EXCEPTION:
	      t.accept(v);
	      break;
	    default:
	      throw new TransGenException
		("Invalid ModuleTrans Child Type: " + type );
	    }
	}

      v.closeModule(this);
    }

  public int getModuleNumber()
    {
      return number;
    }

  public String getBaseName()
    {
      return baseName;
    }

  public String getExtensionName()
    {
      return extName;
    }

  public String getEntryName()
    {
      String ename;
      if (isCoreModule())
	{
	  ename = "Entry";
	}
      else
	{
	  ename = getExtensionName() + "Entry";
	}
      return ename;
    }

  public String getVarName()
    {
      return varName;
    }

  /**
   * boolean isCoreModule() returns true if this is the core (required)
   * module where basic objects defined.  In other modules,
   * this variable should be false.
   *
   */
  public boolean isCoreModule()
    {
      return coreModule == null;
    }

  public ModuleTrans getCoreModule()
    {
      return coreModule;
    }
}
