//
// ModuleTypes.java,v 1.3 2003/05/28 01:09:06 dsg Exp
//
// Copyright 2001 The Regents of the University of California
// All Rights Reserved
//
// OpenMMS was developed by Dr. Douglas S. Greer at the San Diego
// Supercomputer Center, a research unit of the University of California,
// San Diego.  Support for this effort was provided by NSF through the
// Protein Data Bank (Grant DBI-9814284) and the National Partnership for
// Advanced Computational Infrastructure (Grant ACI-9619020)
//
// Permission to use, copy, modify and distribute any part of OpenMMS for
// educational, research and non-profit purposes, without fee, and
// without a written agreement is hereby granted, provided that the above
// copyright notice, this paragraph and the following paragraphs appear
// in all copies.
//
// Those desiring to incorporate this OpenMMS into commercial products or
// use for commercial purposes should contact the Technology Transfer
// Office, University of California, San Diego, 9500 Gilman Drive, La
// Jolla, CA 92093-0910, Ph: (619) 534-5815, FAX: (619) 534-7345.
//
// In no event shall the University of California be liable to any party
// for direct, indirect, special, incidental, or consequential damages,
// including lost profits, arising out of the use of this OpenMMS, even
// if the University of California has been advised of the possibility of
// such damage.
//
// The OpenMMS provided herein is on an "as is" basis, and the
// University of California has no obligation to provide maintenance,
// support, updates, enhancements, or modifications.  The University of
// California makes no representations and extends no warranties of any
// kind, either implied or express, including, but not limited to, the
// implied warranties of merchantability or fitness for a particular
// purpose, or that the use of the OpenMMS will not infringe any patent,
// trademark or other rights.

package org.rcsb.openmms.meta;

/**
 * Contains definitions for the module types used in Entry Implementations
 * and the Foundries.
 *
 * @author Douglas S. Greer
 * @version 1.3
 */
public interface ModuleTypes
{
  // enumerate from zero so these can be used as array indicies
  public final static int MMS_CORE                       = 0;
  public final static int MMS_XRAY_CRYSTALLOGRAPHY       = 1;
  public final static int MMS_NUCLEAR_MAGNETIC_RESONANCE = 2;
  public final static int MMS_REFERENCE                  = 3;
  public final static int MMS_DEPOSITION                 = 4;

  // modules that do no have an Entry/SubEntry (e.g. the deposition module) must
  // appear at the end of the lists.
  public final static int NUMBER_OF_ENTRY_MODULES  = 4;
  public final static int TOTAL_NUMBER_OF_MODULES  = 5;

  // all of the following arrays must have size MMS_TOTAL_MODULES

  final static String[] MODULE_IDENTIFIERS =
  {
    "MMS_CORE",
    "MMS_XRAY_CRYSTALLOGRAPHY",
    "MMS_NUCLEAR_MAGNETIC_RESONANCE",
    "MMS_REFERENCE",
    "MMS_DEPOSITION"
  };

  final static String[] MODULE_NAMES =
  {
    "MacromolecularStructure",
    "XRayCrystallography",
    "Nmr",
    "MmsReference",  
    "MmsDeposition"
  };

  final static String[] MODULE_VARS =
  {
    "",
    "xray",
    "nmr",
    "ref",
    "depo"
  };
}
