//
// SelectWriter.java,v 1.4 2003/05/28 01:09:06 dsg Exp
//
// Copyright 2001 The Regents of the University of California
// All Rights Reserved
//
// OpenMMS was developed by Dr. Douglas S. Greer at the San Diego
// Supercomputer Center, a research unit of the University of California,
// San Diego.  Support for this effort was provided by NSF through the
// Protein Data Bank (Grant DBI-9814284) and the National Partnership for
// Advanced Computational Infrastructure (Grant ACI-9619020)
//
// Permission to use, copy, modify and distribute any part of OpenMMS for
// educational, research and non-profit purposes, without fee, and
// without a written agreement is hereby granted, provided that the above
// copyright notice, this paragraph and the following paragraphs appear
// in all copies.
//
// Those desiring to incorporate this OpenMMS into commercial products or
// use for commercial purposes should contact the Technology Transfer
// Office, University of California, San Diego, 9500 Gilman Drive, La
// Jolla, CA 92093-0910, Ph: (619) 534-5815, FAX: (619) 534-7345.
//
// In no event shall the University of California be liable to any party
// for direct, indirect, special, incidental, or consequential damages,
// including lost profits, arising out of the use of this OpenMMS, even
// if the University of California has been advised of the possibility of
// such damage.
//
// The OpenMMS provided herein is on an "as is" basis, and the
// University of California has no obligation to provide maintenance,
// support, updates, enhancements, or modifications.  The University of
// California makes no representations and extends no warranties of any
// kind, either implied or express, including, but not limited to, the
// implied warranties of merchantability or fitness for a particular
// purpose, or that the use of the OpenMMS will not infringe any patent,
// trademark or other rights.

package org.rcsb.openmms.meta;

import java.io.*;
import java.util.*;

import org.rcsb.openmms.cifparse.*;

/**
 * Visitor subclass that writes the java JDBC code for reading
 * data from a relational database into the Entry Data Structures.
 *
 * @author Douglas S. Greer
 * @version 1.4
 */
public class SelectWriter extends SqlWriter
{
  final String indent = "    ";

  boolean containsEntry;
  RootTrans inRoot;
  ModuleTrans inMod;
  CategoryTrans inCat;
  boolean catIsMand;
  String moduleEntryName;
  String subEntryVarName;
  String lsrPackageName, msaPackageName;

  // created by OpenRoot() and written out by CloseRoot()
  StringStruct selectFile;

  // written by OpenRoot() and used by OpenCategory()
  StringStruct selectCatMethods;

  StringStruct getCatKeyDeclare;
  StringStruct getCatKeyBody;

  StringStruct readListDataDeclare;
  StringStruct readListDataBody;

  // written by OpenCategory() and used by OpenField()
  StringStruct selectStatementSetup;
  StringStruct whileLoop;

  // written by OpenStructure() and used by OpenField()
  String structListVar;

  // Declarations of <category>CatBase variables;
  StringStruct catBaseVars;
  // Initialization of <category>CatBase variables;
  StringStruct baseVarInits;

  public SelectWriter(CifDictionary d, String insertp,
		       String lsr, String msa, String oBase)
    {
      super(d, insertp, oBase);

      lsrPackageName = lsr;
      msaPackageName = msa;
    }

  public void openRoot(RootTrans rt)
    throws IOException, TransGenException
    {
      inRoot = rt;

      selectFile = new StringStruct();
      selectFile.setIndentString(indent);
      
      StringStruct headerSS = new StringStruct();
      headerSS.setIndentString(indent);
      selectFile.writeStringStruct(headerSS);

      Date dt = new Date();
      GregorianCalendar cal = new GregorianCalendar();
      cal.setTime(dt);
      String[] toplines =
      {
	"//",
	"// **** DERIVED FILE - DO NOT EDIT ****",
	"//",
      };
      headerSS.writeLine(toplines);
      writeCopyright(headerSS);

      String[] opening =
      {
	"",
	"package " + msaPackageName + ".dbinsert;",
	"",
	"import java.io.*;",
	"import java.sql.*;",

	"import " + msaPackageName + ".util.*;",
	"import " + msaPackageName + ".meta.*;",
	"import " + msaPackageName + ".loader.*;",
	"",
	"import org.omg.CORBA.ORB;",
	"import " + lsrPackageName + ".DsLSRMacromolecularStructure.*;",
	"import " + lsrPackageName + ".DsLSRMmsReference.*;",
	"import " + lsrPackageName + ".DsLSRXRayCrystallography.*;",
	"import " + lsrPackageName + ".DsLSRNmr.*;",
	"import " + lsrPackageName + ".DsLSRMmsDeposition.*;",
	"",
	"/**",
	" * Class to create the JDBC code needed to select data from the",
	" * relational database and store it in the Entry data structures.",
	" * <p>",
	" * Generated by the program MMSExpr. Model: "
	  + inRoot.getModelIdentifier() + ", Revision: "
	  + inRoot.getRevisionNumber(),
	" * <p>",
	" * Date: " + dt.toString(),
	" *",
	" * @author Douglas S. Greer",
	" * @version OpenMMS Release V_1_5_1",
	" */",
	"public class SelectCategory extends SelectCategoryBase"
      };
      selectFile.writeLine(opening);

      StringStruct body = selectFile.newBlock("{", "}");
      body.beginIndent();

      String[] constructor = 
	{
	  "public SelectCategory(MessageHandler ps, Connection con)",
	  "  throws SQLException",
	  "  {",
	  indent + "super(ps, con);",
	  "  }"
        };
      body.writeLine(constructor);

      catBaseVars = new StringStruct(body);
      catBaseVars.writeLine("");

      String[] flag2Key = 
	{
	  "",
	  "public int flagToKey(int module, int flag)",
	  "  throws DataAccessException",
	  "  {",
	  indent + "switch (module)",
	  indent + "  {"
	};
      body.writeLine(flag2Key);
      body.beginIndent(2);
      getCatKeyDeclare = new StringStruct(body);
      body.endIndent();
      String[] endFlag2Key = 
	{
	  "  }",
	  "throw new DataAccessException(\"flagToKey()\", \"Unknown flag\");"
	};
      body.writeLine(endFlag2Key);
      body.endIndent();
      body.writeLine("  }");

      // readListData* contains the list of method calls to
      // select<Category_Name>() that are coded in the selectCatMethods
      // StringStruct.
      String[] readListData = 
	{
	  "",
	  "public Object[] readListData(EntryMethodImpl ei,"
		     + " int module, int flag,",
	  indent + indent + "boolean all, int from, int to)",
	  "  throws MmsTranslationException, SQLException",
	  "  {",
	  indent + "Object[] oa = null;",
	  indent + "switch (module)",
	  indent + "  {"
	};
      body.writeLine(readListData);
      body.beginIndent(2);

      readListDataDeclare = new StringStruct(body);

      body.endIndent(2);
      String[] endReadListData = 
	{
	  indent + "  }",
	  indent + "return oa;",
	  "  }"
	};
      body.writeLine(endReadListData);

      // selectCodeCats contains the actual Code to that selects data
      // from DB
      selectCatMethods = new StringStruct(body);
    }

  public void closeRoot(RootTrans rt)
    throws IOException, TransGenException
    {
      selectFile.traverseToFile(dirPath + "/" + oFileBase + ".java");
    }

  public void openFile(FileTrans ft) 
    throws IOException, TransGenException
    {
      containsEntry = ft.getContainsEntry();
    }

  public void closeFile(FileTrans ft) 
    throws IOException, TransGenException
    {
    }

  public void openModule(ModuleTrans mt) 
    throws IOException, TransGenException
    {
      inMod = mt;
      moduleEntryName = mt.getEntryName();
      if (mt.isCoreModule())
	{
	  subEntryVarName = "";
	}
      else
	{
	  subEntryVarName = mt.getVarName() + ".";
	}
      
      if (containsEntry)
	{
	  String[] cbBegin =
	  {
	    "case ModuleTypes." 
	    + ModuleTypes.MODULE_IDENTIFIERS[mt.getModuleNumber()] + ":",
	    "  switch (flag)",
	    indent + "{",
	  };
	  String[] cbEnd =
	  {
	    indent + "}",
	    "  break;"
	  };
	  getCatKeyBody = getCatKeyDeclare.newBlock(cbBegin, cbEnd);
	  getCatKeyBody.beginIndent();

	  readListDataBody = readListDataDeclare.newBlock(cbBegin, cbEnd);
	  readListDataBody.beginIndent();
	}
    }
      
  public void closeModule(ModuleTrans mt) 
    throws IOException, TransGenException
    {
      if (containsEntry)
	{
	  getCatKeyBody.endIndent();
	  readListDataBody.endIndent();
	}
      inMod = null;
    }

  public void openCategory(CategoryTrans ct) 
    throws IOException, TransGenException
    {
      inCat = ct;

      // Key and Base vars init code
      String varBase = inCat.getTableName().toLowerCase() + "_";
      String catKeyName = varBase + "CatEntryKey";
      String catBaseName = varBase + "CatBase";
      catBaseVars.writeLine("int " + catKeyName + " = -1;");
      catBaseVars.writeLine("int " + catBaseName + ";");
    }
      
  public void closeCategory(CategoryTrans ct) 
    throws IOException, TransGenException
    {
      inCat = null;
    }

  public void openStructure(StructureTrans st) 
    throws IOException, TransGenException
    {
      structListVar = st.getListVarName();

      if (containsEntry && inCat != null)
	{
	  getCatKeyBody.writeLine("case " 
	     + inMod.getEntryName() + "." + st.getFlagName() + ":");
	  getCatKeyBody.writeLine
	    ("  return "+ String.valueOf(inCat.getCategoryKey()) + ";");

	  String methodName = "select" + st.getName();
	  String methodParams = "(ei, all, from, to)";
	  String methodArgs1 = "(EntryMethodImpl ei,";
	  String methodArgs2 = "boolean all, int from, int to)";
	  // Calling code
	  readListDataBody.writeLine("case " 
	     + inMod.getEntryName() + "." + st.getFlagName() + ":");
	  readListDataBody.writeLine("  oa = " + methodName 
				     + methodParams + ";");
	  readListDataBody.writeLine("  break;");

	  // Called code
	  // methodBody contains code to select data for current structure

	  StringStruct methodBody = selectCatMethods.newMethodBlock
	    (st.getTypeName() + "[] " + methodName + methodArgs1,
	     methodArgs2, "throws MmsTranslationException, SQLException");
	  String qline1 =  "q = \" FROM \" + SCHEMA_PREFIX";

	  String qline2 = "+ \"" + inCat.getFullTableName()
	    + " WHERE entry_key = \" + getEntryKey()";
	  String keyName = inCat.getTableKeyName();
	  String[] psBegin =
	  {
	    st.getTypeName() + "[] cata;",
	    "int len = all ? getCategoryLength() : to-from+1;",
	    "StringBuffer t = new StringBuffer(\"SELECT " + keyName + "\");",
	    "String q;",
	    "if (all)",
	    "  {",
	    indent + qline1,
	    indent + indent + qline2 + ";",
	    "  }",
	    "else",
	    "  {",
	    indent + qline1,
	    indent + indent + qline2,
	    indent + indent + "+ \" AND \" + (getCategoryBase() + from)",
	    indent + indent + "+ \" <= " + keyName 
	    	+ " AND " + keyName +" <= \"",
	    indent + indent + "+ (getCategoryBase() + to);",
	    "  }",
	  };
	  String[] psEnd =
	  {
	    ""
	  };
	  selectStatementSetup = methodBody.newBlock(psBegin, psEnd);

	  String[] tryBlockOpen =
	  {
	    "try",
	    "  {",
	    indent + "t.append(q);",
	  };
	  methodBody.writeLine(tryBlockOpen);
	  methodBody.beginIndent();
	  
	  // Init <category>CatBase variable code
	  baseVarInits = new StringStruct(methodBody);

	  String[] whileBegin =
	  {
	    "ResultSet rs = stmt.executeQuery(t.toString());",
	    "cata = new " + st.getTypeName() + "[len];",
	    "while (rs.next())",
	    "  {",
	    indent + st.getTypeName() + " ci = new "
	    		+ st.getTypeName() + "();"
	  };
	  
	  String[] whileEnd =
	  {
	    "  }"
	  };
	  whileLoop = methodBody.newBlock(whileBegin, whileEnd);
	  whileLoop.beginIndent();
	  methodBody.endIndent();

	  initStructChildren(whileLoop, st);
	  String[] whileInit =
	  {
	    "int k = rs.getInt(1) - getCategoryBase();",
	    "if ( ! all)",
	    indent + "k -= from;",
	    "cata[k] = ci;",
	    "int j = 2;"
	  };
	  whileLoop.writeLine(whileInit);

	  String[] fin = 
	  {
	    "  }",
	    "finally",
	    "  {",
	    "  }",
	    "return cata;"
	  };
	  methodBody.writeLine(fin);
	}
    }

  private void initStructChildren(StringStruct cb, Trans pt)
    throws IOException, TransGenException
    {
      String nameSoFar;

      for (int j = 0; j < pt.numberOfChildren(); j++)
	{
	  Trans t = pt.getChild(j);
	  if (t.getTransType() == Trans.TYPE_FIELD
	      || t.getTransType() == Trans.TYPE_SUBFIELD)
	    {
	      FieldTrans ft = (FieldTrans) t;
	      if (! ft.isLeaf())
		{
		  // containing structure
		  StructureTrans cst = ft.getStructure();
		  // structure declaration for this field
		  StructureTrans fstt = ft.getFieldStructure();
		  // create the sub-structure
		  nameSoFar = "ci." + ft.getFullFieldName();
		  cb.writeLine(nameSoFar + " = new "
			   + fstt.getTypeName() + "();");
		  // recurse structure subfields
		  StructureTrans fst = ft.getFieldStructure();
		  if (fst != null)
		    {
		      // recurse structure subfields
		      initSubstructure(cb, fst, nameSoFar);
		    }
		}
	      else
		{
		  // Leaf node
		  if (ft.isCifField())
		    {
		      DictionaryItem di = ft.getDictionaryItem();
		      if (di == null)
			{
			  throw new TransGenException
			    ("SelectWriter.initStructChildern()"
			     + "- No dictionary entry"
			     + "\n\tFullFieldName()=" + ft.getFullFieldName()
			     + "\n\tgetCifItemName()=" + ft.getCifItemName()
			     + "\n\tgetContainingField()="
			        + ft.getContainingField());
			}
		      // In *THEORY* only need to initialize optional
		      // strings, however in practice some mandatory
		      // fields are missing in the data files
		      // if ((di.getItemMandatoryCode()
		      //   == DictionaryItem.ITEM_MANDATORY_CODE_NO) ...
		      if (CatWriter.cifTypeConverter(di.getItemType())
			      == "cifString")
			{
			  // need to initialize all non-mandatory strings
			  // with a zero lenght string.  Otherwise Corba will
			  // throw a BAD_PARAM exception on the structure
			  cb.writeLine("ci." + ft.getFullFieldName()
				       + " = \"\";");
			}
		    }
		}
	    }
	  else if (t.getTransType() == Trans.TYPE_VECTOR)
	    {
	      VectorTrans vt = (VectorTrans) t;
	      cb.writeLine("ci." + vt.getFullFieldName()
			   + " = new float[3];");
	    }
	  else if (t.getTransType() == Trans.TYPE_MATRIX)
	    {
	      MatrixTrans mt = (MatrixTrans) t;
	      cb.writeLine("ci." + mt.getFullFieldName() 
			   + " = new float[3][3];");
	    }
	}
    }

  private void initSubstructure(StringStruct cb,
				StructureTrans st, String nameSoFar)
    throws IOException, TransGenException
    {
      for (int j = 0; j < st.numberOfChildren(); j++)
	{
	  Trans t = st.getChild(j);

	  if (t instanceof VectorTrans)
	    {
	      VectorTrans vt = (VectorTrans) t;
	      cb.writeLine(nameSoFar + vt.getName() + " = new float[3];");
	    }
	  else if (t instanceof MatrixTrans)
	    {
	      MatrixTrans mt = (MatrixTrans) t;
	      cb.writeLine(nameSoFar + mt.getName() + " = new float[3][3];");
	    }
	  else if (t instanceof FieldTrans)
	    {
	      FieldTrans ft = (FieldTrans) t;
	      // recurse structure subfields
	      StructureTrans fst = ft.getFieldStructure();
	      if (fst != null)
		{
		  cb.writeLine(nameSoFar + "." + ft.getName()
			   + " = new " + fst.getTypeName() + "();");
		  initSubstructure(cb, fst, nameSoFar + "." + ft.getName());
		}
	      else
		{
		  if (ft.getFieldType(inMod).equals("string"))
		    {
		      cb.writeLine(nameSoFar + "." + ft.getName()
			       + " = \"\";");
		    }
		}
	    }
	  else
	    {
	      throw new TransGenException
		("SelectWriter.initSubstructure()"
		 + " Unknown Structure field type:" + t.getTransType()
		 + "\n\tStruct name: " + st.getName()
		 + " Field name: " + t.getName());
	    }
	}
    }

  public void openValuetype(ValuetypeTrans st) 
    throws IOException, TransGenException
    {
      openStructure(st);
    }

  public void openField(FieldTrans ft) 
    throws IOException, TransGenException 
    {
      // Only write Cif Data fields (and their indices)
      if ( ! ft.isCifField())
	{
	  return;
	}
      String getter = cifToSqlGetMethod(ft);

      String tAppendStr;
      if ( ! ft.isIndexField())
	{
	  tAppendStr = "t.append(\", " + ft.getColumnName() + "\");";
	}
      else
	{
	  tAppendStr = "t.append(\", "  + ft.getColumnName() + ", " 
	    + ft.getColumnIndexName() + "\");";
	}
      if ( ! ft.isPseudoField())
	{
	  openValueGroupSet(ft);
	}
      selectStatementSetup.writeLine(tAppendStr);

      String fName = "ci." + ft.getFullFieldName();
      if (ft.isFieldBitSet(FieldTrans.IS_A_STREAM_DATATYPE))
	{
	  String[] iCode =
	  {
	    "StringBuffer sb = new StringBuffer();",
	    "char[] ca = new char[4096];",
	    "InputStreamReader isr = new InputStreamReader(rs."
	    	+ getter + "(j++));",
	    "try",
	    "  {",
	    indent + "for (int i ; (i = isr.read(ca)) > 0 ; )",
	    indent + indent + "sb.append(ca, 0, i);",
	    "  }",
	    "catch (Exception e)",
	    "  {",
	    indent + "throw new MmsTranslationException(e.toString());",
	    "  }",
	    fName + " = sb.toString();"
	  };
	  whileLoop.writeLine(iCode);
	}
      else
	{
	  String[] iCode =
	  {
	    fName + " = rs." + getter + "(j++);"
	  };
	  whileLoop.writeLine(iCode);
	}

      if (ft.isIndexField())
	{
	  String parentModuleEntryName, parentSubEntryVarName;

	  StructureTrans parentStruct
	    = ft.getCifParentIndex().getStructure();
	  CategoryTrans parentCat = parentStruct.getCategory();
	  String parentCatBaseName = parentCat.getTableName().toLowerCase()
	    + "_CatBase";
	  String parentCatEntryKeyName
	    = parentCat.getTableName().toLowerCase() + "_CatEntryKey";

	  ModuleTrans[] qualMods = parentStruct.getModuleQualifier();
	  if (qualMods == null)
	    {
	      parentModuleEntryName = "Entry";
	      parentSubEntryVarName = "";
	    }
	  else
	    {
	      ModuleTrans parentMod = qualMods[qualMods.length -1];
	      parentModuleEntryName = parentMod.getExtensionName() + "Entry";
	      parentSubEntryVarName = parentMod.getVarName() + ".";
	    }

	  // Example code:
	  //   if (citation_CatEntryKey != ei.getKey())
	  // 	 {
	  //       citation_CatBase = readCategoryBase(ei.getKey(), CatKey);
	  //       citation_CatEntryKey = ei.getKey();
	  //     }
	  String[] initIndexBase =
	    {
	      "if (" + parentCatEntryKeyName + " != ei.getKey())",
	      "  {",
	      indent + parentCatBaseName + " = readCategoryBase(ei.getKey(), "
	      	+ String.valueOf(parentCat.getCategoryKey()) + ");",
	      indent + parentCatEntryKeyName + " = ei.getKey();",
	      "  }",
	    };
	  baseVarInits.writeLine(initIndexBase);

	  // Example code:
	  //   if (isFlagSet(ei._presence_flags, Entry.S_CHEM_COMP))
	  //     ci.mon.index = rs.getInt(j++) - chem_comp_CatBase;  
	  //   else
	  //     ci.mon.index = -1;
	  String[] iCodeIndex =
	    {
	      "if (isFlagSet(ei."
	        + parentSubEntryVarName + "_presence_flags,",
	      indent + parentModuleEntryName + "." 
	        +  parentStruct.getFlagName() + "))",
	      "  {",
 	      indent + "ci."
	      	+ ft.getContainingField().getFullFieldName()
	      	+ ".index",
	      indent + indent + "= rs.getInt(j++) - " + parentCatBaseName + ";",
	      "  }",
	      "else",
	      "  {",
 	      indent + "j++ ; ci."
	      	+ ft.getContainingField().getFullFieldName() + ".index = -1;",
	      "  }"
	    };
	  whileLoop.writeLine(iCodeIndex);
	}
      if ( ! ft.isPseudoField())
	{
	  closeValueGroupSet(ft);
	}
    }

  public void closeField(SubfieldTrans ft) 
    throws IOException, TransGenException
    {
    }

  public void openSubfield(SubfieldTrans ft) 
    throws IOException, TransGenException
    {
      openField(ft);
    }

  public void closeSubfield(SubfieldTrans ft) 
    throws IOException, TransGenException
    {
      closeField(ft);
    }

  public void openVector(VectorTrans vt) 
    throws IOException, TransGenException
    {
      openValueGroupSet(vt);
    }

  public void closeVector(VectorTrans vt) 
    throws IOException, TransGenException
    {
      closeValueGroupSet(vt);
    }

  public void openMatrix(MatrixTrans mt) 
    throws IOException, TransGenException
    {
      openValueGroupSet(mt);
    }

  public void closeMatrix(MatrixTrans mt) 
    throws IOException, TransGenException
    {
      closeValueGroupSet(mt);
    }

  public void openValueGroupSet(FieldTrans ft) 
    throws IOException, TransGenException
    {
      if (ft.getDictionaryItem().getItemMandatoryCode()
	  == DictionaryItem.ITEM_MANDATORY_CODE_NO)
	{
	  String ifCond = "if (isFlagSet(ei." + subEntryVarName
	    + "_presence_flags, ";
	  String ifFlag = indent + moduleEntryName
	    + "." +  ft.getFlagName() + "))";

	  String[] optCode =
	  {
	    ifCond,
	    ifFlag,
	    "  {",
	  };

	  selectStatementSetup.writeLine(optCode);
	  selectStatementSetup.beginIndent();

	  whileLoop.writeLine(optCode);
	  whileLoop.beginIndent();
	}
    }

  public void closeValueGroupSet(FieldTrans ft) 
    throws IOException, TransGenException
    {
      if (ft.getDictionaryItem().getItemMandatoryCode()
	  == DictionaryItem.ITEM_MANDATORY_CODE_NO)
	{
	  selectStatementSetup.endIndent();
	  selectStatementSetup.writeLine("  }");

	  whileLoop.endIndent();
	  whileLoop.writeLine("  }");
	}
    }
}  
