//
// SubfieldTrans.java,v 1.4 2002/06/27 21:59:09 dsg Exp
//
// Copyright 2001 The Regents of the University of California
// All Rights Reserved
//
// OpenMMS was developed by Dr. Douglas S. Greer at the San Diego
// Supercomputer Center, a research unit of the University of California,
// San Diego.  Support for this effort was provided by NSF through the
// Protein Data Bank (Grant DBI-9814284) and the National Partnership for
// Advanced Computational Infrastructure (Grant ACI-9619020)
//
// Permission to use, copy, modify and distribute any part of OpenMMS for
// educational, research and non-profit purposes, without fee, and
// without a written agreement is hereby granted, provided that the above
// copyright notice, this paragraph and the following paragraphs appear
// in all copies.
//
// Those desiring to incorporate this OpenMMS into commercial products or
// use for commercial purposes should contact the Technology Transfer
// Office, University of California, San Diego, 9500 Gilman Drive, La
// Jolla, CA 92093-0910, Ph: (619) 534-5815, FAX: (619) 534-7345.
//
// In no event shall the University of California be liable to any party
// for direct, indirect, special, incidental, or consequential damages,
// including lost profits, arising out of the use of this OpenMMS, even
// if the University of California has been advised of the possibility of
// such damage.
//
// The OpenMMS provided herein is on an "as is" basis, and the
// University of California has no obligation to provide maintenance,
// support, updates, enhancements, or modifications.  The University of
// California makes no representations and extends no warranties of any
// kind, either implied or express, including, but not limited to, the
// implied warranties of merchantability or fitness for a particular
// purpose, or that the use of the OpenMMS will not infringe any patent,
// trademark or other rights.

package org.rcsb.openmms.meta;

import java.io.IOException;

import org.rcsb.openmms.cifparse.*;

/**
 * Class for representing "Sub-Fields" of a Struct-type field
 * 
 *
 * @author Douglas S. Greer
 * @version 1.4
 */
public class SubfieldTrans extends FieldTrans
{
  protected FieldTrans containingField = null;

  // constructor for embedded structs within embedded structs
  public SubfieldTrans(StructureTrans st, String varname)
    {
      this(varname, null);
      // setFieldStructure(st);
      structType = st;
      fieldType = st.getName();
      isCifField = false;
    }

  // constructor to create a subfield from a field
  public SubfieldTrans(FieldTrans ft, String vname)
    {
      this(vname, ft.getCifItemName());
      setStructure(ft.getStructure());
      setContainingField(ft.getContainingField());
      setDictionaryItem(ft.getDictionaryItem());
      setPseudoField(ft.isPseudoField());
      if (ft.isIndexField())
	{
	  setCifParentIndex(ft.getCifParentIndex());
	}
      isCifField = ft.isCifField();
      // setFieldStructure(ft.getFieldStructure());
      structType = ft.getFieldStructure();
      computeNames();
      // computeNames() should be called again on this subfield after
      // setting the correct ContainingField if this has changed.
    }

  public SubfieldTrans(String varname, String cifname)
    {
      super(varname, cifname, 0);
      setTransType(Trans.TYPE_SUBFIELD);
    }

  public void accept(TransVisitor v)
    throws IOException, TransGenException
    {
      v.openSubfield(this);
      // visit children
      Trans t;
      for (int i = 0; i < numberOfChildren(); i++)
	{
	  t = getChild(i);
	  int type = t.getTransType();
	  switch (type)
	    {
	    case Trans.TYPE_SUBFIELD:
	    case Trans.TYPE_VECTOR:
	    case Trans.TYPE_MATRIX:
	      t.accept(v);
	      break;
	    default:
	      throw new TransGenException
		("Invalid SubFieldTrans Child Type: " + type );
	    }
	}
      v.closeSubfield(this);
    }

  // This will return the name of a basic type only if
  // getStructType() returns null.  Otherwise this name has
  // type getStructType().getName()
  protected String computeFullName(char c)
    {
      String prefix = "";

      for (FieldTrans t = getContainingField();
	   t != null;  t = t.getContainingField())
	{
	  prefix = t.getName() + c + prefix;
	}
      return prefix + getRealName();
    }

  public void setContainingField(FieldTrans ft)
    {
      containingField = ft;
    }

  public FieldTrans getContainingField()
    {
      return containingField;
    }
}
