//
// TableWriter.java,v 1.9 2003/05/30 21:56:09 dsg Exp
//
// Copyright 2001 The Regents of the University of California
// All Rights Reserved
//
// OpenMMS was developed by Dr. Douglas S. Greer at the San Diego
// Supercomputer Center, a research unit of the University of California,
// San Diego.  Support for this effort was provided by NSF through the
// Protein Data Bank (Grant DBI-9814284) and the National Partnership for
// Advanced Computational Infrastructure (Grant ACI-9619020)
//
// Permission to use, copy, modify and distribute any part of OpenMMS for
// educational, research and non-profit purposes, without fee, and
// without a written agreement is hereby granted, provided that the above
// copyright notice, this paragraph and the following paragraphs appear
// in all copies.
//
// Those desiring to incorporate this OpenMMS into commercial products or
// use for commercial purposes should contact the Technology Transfer
// Office, University of California, San Diego, 9500 Gilman Drive, La
// Jolla, CA 92093-0910, Ph: (619) 534-5815, FAX: (619) 534-7345.
//
// In no event shall the University of California be liable to any party
// for direct, indirect, special, incidental, or consequential damages,
// including lost profits, arising out of the use of this OpenMMS, even
// if the University of California has been advised of the possibility of
// such damage.
//
// The OpenMMS provided herein is on an "as is" basis, and the
// University of California has no obligation to provide maintenance,
// support, updates, enhancements, or modifications.  The University of
// California makes no representations and extends no warranties of any
// kind, either implied or express, including, but not limited to, the
// implied warranties of merchantability or fitness for a particular
// purpose, or that the use of the OpenMMS will not infringe any patent,
// trademark or other rights.

package org.rcsb.openmms.meta;

import java.io.*;
import java.util.*;

import org.rcsb.openmms.cifparse.*;
import org.rcsb.openmms.util.*;

/**
 * Visitor class for generate SQL code that creates relation DB tables
 *
 * @author Douglas S. Greer
 * @version 1.9
 */
public class TableWriter extends SqlWriter
{
  final static int MAX_ATTR_NAME_LEN = 30;

  ModuleTrans inMod;
  CategoryTrans inCat;
  int fieldNumInCat = 0;
  boolean noMandItem;

  StringStruct baseSS, delAllSS, dropAllSS, createIndexSS, dropIndexSS, 
    synCreateSS, pdbAccountSS, synDropSS;

  public TableWriter(CifDictionary d, String sqlp, 
		     String oName, boolean nmi)
    {
      super(d, sqlp, oName);
      noMandItem = nmi;
    }

  public void openRoot(RootTrans rt)
    throws IOException, TransGenException
    {
      baseSS = new StringStruct();
      baseSS.setIndentString(INDENT);
      writeIntro(baseSS, " for creating tables");
      writeSysSpecific(baseSS);

      dropAllSS = new StringStruct();
      dropAllSS.setIndentString(INDENT);
      writeIntro(dropAllSS, " for dropping tables");
      // dropAllSS not DB type specific
      
      delAllSS = new StringStruct();
      delAllSS.setIndentString(INDENT);
      writeIntro(delAllSS, " for deleting tables");
      // deleteSS not DB type specific

      createIndexSS = new StringStruct();
      createIndexSS.setIndentString(INDENT);
      writeIntro(createIndexSS, " for creating indices");
      // createIndexSS not DB type specific
      
      dropIndexSS = new StringStruct();
      dropIndexSS.setIndentString(INDENT);
      writeIntro(dropIndexSS, " for dropping indices");
      // dropIndexSS not DB type specific
      
      synCreateSS = new StringStruct();
      synCreateSS.setIndentString(INDENT);
      writeIntro(synCreateSS, " for creating synonyms to PDB_DATA tables");

      pdbAccountSS = new StringStruct();
      pdbAccountSS.setIndentString(INDENT);
      writeIntro(pdbAccountSS, " for setting up PDB@PDB tables");

      synDropSS = new StringStruct();
      synDropSS.setIndentString(INDENT);
      writeIntro(synDropSS, " for dropping synonyms");

      writeSysTables();
    }

  public void closeRoot(RootTrans rt)
    throws IOException, TransGenException
    {
      for (int i = 0; i < NUMBER_OF_FLAVORS; i++)
	{
	  baseSS.setSelector(i);
	  baseSS.traverseToFile(dirPath + "/Create" + oFileBase 
				+ dbTypeNames[i] + ".sql");
	}
      dropAllSS.traverseToFile(dirPath + "/DropAll.sql");
      delAllSS.traverseToFile(dirPath + "/DeleteAll.sql");
      dropIndexSS.traverseToFile(dirPath + "/DropIndices.sql");
      createIndexSS.traverseToFile(dirPath + "/CreateIndices.sql");
      synCreateSS.traverseToFile(dirPath + "/CreateSynonym.sql");
      pdbAccountSS.traverseToFile(dirPath +  "/PdbAccount.sql");
      synDropSS.traverseToFile(dirPath + "/DropSynonym.sql");
    }

  private void writeSysTables()
    {
      StringStruct b;
  
      b = sysTable(SCHEMA_PREFIX + SYSTEM_TABLE_NAME);
      sysAttribute(b, SYSTEM_DATA_BANK_NAME, STD_NAME_TYPE, true,
		   null, false);
      sysAttribute(b, SYSTEM_VERSION_NAME, STD_NAME_TYPE, true, null, false);
      sysAttribute(b, SYSTEM_MODEL_ID_NAME, STD_NAME_TYPE, true, null, false);
      sysAttribute(b, SYSTEM_REVISION_NUMBER_NAME, STD_NAME_TYPE, 
		   true, null, true);

      b = sysTable(SCHEMA_PREFIX + ENTRY_TABLE_NAME);
      sysAttribute(b, ENTRY_TABLE_KEY_NAME, STD_KEY_TYPE,
		   true, " PRIMARY KEY", false);
      sysAttribute(b, ENTRY_TABLE_ID_NAME, STD_NAME_TYPE, true, null, false);
      sysAttribute(b, ENTRY_TABLE_DEP_DATE_NAME, STD_DATE_TYPE,
		   true, null, false);
      sysAttribute(b, ENTRY_TABLE_LOAD_DATE_NAME, STD_DATE_TYPE,
		   true, null, false);
      sysAttribute(b, ENTRY_TABLE_LOAD_STATUS_NAME, STD_KEY_TYPE,
		   true, null, false);
      for (int i = 0; i < ModuleTypes.NUMBER_OF_ENTRY_MODULES; i++)
	{
	  sysAttribute(b, ENTRY_TABLE_FLAG_BASE_NAME + i, smallBinaryType,
	       false, null, (i == ModuleTypes.NUMBER_OF_ENTRY_MODULES-1));
	}
      baseSS.writeLine("\nCREATE UNIQUE INDEX " 
		    + SCHEMA_PREFIX + ENTRY_TABLE_NAME + "_INDEX on "
		    + SCHEMA_PREFIX + ENTRY_TABLE_NAME + " ("
		    + ENTRY_TABLE_ID_NAME + ") ;");
      b = sysTable(SCHEMA_PREFIX + CATEGORY_TABLE_NAME);
      sysAttribute(b, CATEGORY_TABLE_KEY_NAME, STD_KEY_TYPE,
		   true, " PRIMARY KEY", false);
      sysAttribute(b, CATEGORY_TABLE_CIF_ID_NAME, STD_NAME_TYPE,
		   true, null, false);
      sysAttribute(b, CATEGORY_TABLE_TABLE_NAME, STD_NAME_TYPE,
		   true, null, false);
      sysAttribute(b, CATEGORY_TABLE_DESC_NAME, bigTextType,
		   false, null, false);
      sysAttribute(b, CATEGORY_TABLE_MAND_NAME, "CHAR(1)",
		   true, null, false);
      sysAttribute(b, CATEGORY_TABLE_NEXT_RECORD_NAME, STD_KEY_TYPE,
		   true, null, true);

      baseSS.writeLine("\nCREATE UNIQUE INDEX " 
		    + SCHEMA_PREFIX + CATEGORY_TABLE_NAME + "_INDEX on "
		    + SCHEMA_PREFIX + CATEGORY_TABLE_NAME + " ("
		    + CATEGORY_TABLE_CIF_ID_NAME + ") ;");

      b = sysTable(SCHEMA_PREFIX + ITEM_TABLE_NAME);
      sysAttribute(b, ITEM_TABLE_KEY_NAME, STD_KEY_TYPE,
		   true, " PRIMARY KEY", false);
      sysAttribute(b, ITEM_TABLE_CIF_ID_NAME, STD_NAME_TYPE,
		   true, null, false);
      sysAttribute(b, ITEM_TABLE_COLUMN_NAME, STD_NAME_TYPE,
		   true, null, false);
      sysAttribute(b, ITEM_TABLE_CAT_INDX_NAME, STD_KEY_TYPE,
		   true, null, false);
      sysAttribute(b, ITEM_TABLE_DESC_NAME, bigTextType, false, null, false);
      sysAttribute(b, ITEM_TABLE_MAND_NAME, "CHAR(1)", true, null, true);
      baseSS.writeLine("\nCREATE UNIQUE INDEX " 
		    + SCHEMA_PREFIX + ITEM_TABLE_NAME + "_INDEX on "
		    + SCHEMA_PREFIX + ITEM_TABLE_NAME + " ("
		    + ITEM_TABLE_CAT_INDX_NAME + ", "
		    + ITEM_TABLE_CIF_ID_NAME + ") ;");

      b = sysTable(SCHEMA_PREFIX + ENTRY_CATS_TABLE_NAME);
      sysAttribute(b, ENTRY_CATS_ENTRY_NAME, STD_KEY_TYPE,
		   true, null, false);
      sysAttribute(b, ENTRY_CATS_CATEGORY_NAME, STD_KEY_TYPE,
		   true, null, false);
      sysAttribute(b, ENTRY_CATS_FIRST_KEY_NAME, STD_KEY_TYPE,
		   true, null, false);
      sysAttribute(b, ENTRY_CATS_LEN_NAME, STD_KEY_TYPE, true, null, true);

      baseSS.writeLine("\nCREATE UNIQUE INDEX " 
		    + SCHEMA_PREFIX + ENTRY_CATS_TABLE_NAME + "_INDEX");
      baseSS.writeLine(indent + "on "
		    + SCHEMA_PREFIX + ENTRY_CATS_TABLE_NAME + " ("
		    + ENTRY_CATS_ENTRY_NAME + " , "
		    + ENTRY_CATS_CATEGORY_NAME + " ) ;");
    }

  private StringStruct sysTable(String name)
    {
      StringStruct nbs;
      String[] header =
      {
	"",
	"",
	"--",
	"-- SYSTEM TABLE: " + name,
	"--",
	"",
	"CREATE TABLE " + name + "("
      };
      nbs = baseSS.newBlock(header, ") ;");
      nbs.beginIndent();
      // "GRANT SELECT ... " is helpful on Oracle systems but not on others.
      // baseSS.writeLine("GRANT SELECT ON " + name + " TO PUBLIC;");
      dropAllSS.writeLine("DROP TABLE " + name + " ;");
      delAllSS.writeLine("DELETE " + name + " ;");

      synCreateSS.writeLine("CREATE SYNONYM " + name + " for PDB_DATA."
			    + name + " ;");
      pdbAccountSS.writeLine("CREATE SYNONYM PDB." + name + " for "
			    + name + " ;");
      synDropSS.writeLine("DROP SYNONYM " + name + " ;");

      return nbs;
    }

  private void sysAttribute(StringStruct bst,
			    String name, String type, boolean notNull, 
			    String other, boolean last)
    {
      String os;
      os = padString(name) + " ";
      if (notNull)
	{
	  os += padString(type, TYPE_FIELD_LEN) 
	    + " " + MANDATORY;
	}
      else
	{
	  os += type;
	}
      if (other != null)
	{
	  os += other;
	}
      if ( ! last)
	{
	  os += ",";
	}
      bst.writeLine(os);
    }

  private void sysAttribute(StringStruct bst,
			    String name, String[] types, boolean notNull, 
			    String other, boolean last)
    {
      String os;
      os = padString(name) + " ";
      bst.writeIndentedString(os, 0);
      bst.writeSelection(types);
      os = "";
      if (notNull)
	{
	  os += " " + MANDATORY;
	}
      if (other != null)
	{
	  os += other;
	}
      if ( ! last)
	{
	  os += ",";
	}
      os += "\n";
      bst.writeString(os);
    }
				    
  public void openModule(ModuleTrans mt) 
    throws IOException, TransGenException
    {
      inMod = mt;
    }
      
  public void closeModule(ModuleTrans mt) 
    throws IOException, TransGenException
    {
      inMod = null;
    }

  public void openCategory(CategoryTrans ct) 
    throws IOException, TransGenException
    {
      String t, fullTableName;

      t = categoryNameToTableName(ct);
      ct.setTableName(t);
      ct.setTablePrefix(SCHEMA_PREFIX);
      fullTableName = ct.getFullTableName();

      inCat = ct;
      fieldNumInCat = 0;

      String[] tableHeader =
      {
	"",
	"",
	"--",
	"-- TABLE: " + fullTableName,
	"--",
	"",
	"CREATE TABLE " + fullTableName + "("
      };
      baseSS.writeLine(tableHeader);
      baseSS.beginIndent();

      dropAllSS.writeLine("DROP TABLE " + fullTableName + " ;");
      delAllSS.writeLine("DELETE " + fullTableName + " ;");

      synCreateSS.writeLine("CREATE SYNONYM " + ct.getTableName() 
			    + " for PDB_DATA." + fullTableName + " ;");
      pdbAccountSS.writeLine("CREATE SYNONYM PDB." + ct.getTableName() 
			    + " for " + fullTableName + " ;");
      synDropSS.writeLine("DROP SYNONYM " + fullTableName + " ;");

      String tableKeyName = ct.getTableName().toLowerCase();
      if (tableKeyName.length() > MAX_ATTR_NAME_LEN - KEY_ID_SUFFIX.length())
	{
	  // strip of some chars from table name if too long.
	  tableKeyName = tableKeyName.substring
	    (0, MAX_ATTR_NAME_LEN - KEY_ID_SUFFIX.length());
	}
      tableKeyName = tableKeyName + KEY_ID_SUFFIX;
      ct.setTableKeyName(tableKeyName);
      // add Entry.id column for each table
      buffer(baseSS, padString(tableKeyName)
	     + " " + padString(STD_KEY_TYPE, TYPE_FIELD_LEN) 
	     + " " +  MANDATORY + "  PRIMARY KEY");
      buffer(baseSS, padString(ENTRY_TABLE_KEY_NAME)
	     + " " + padString(STD_KEY_TYPE, TYPE_FIELD_LEN)
	     + " " + MANDATORY);
    }
      
  public void closeCategory(CategoryTrans ct) 
    throws IOException, TransGenException
    {
      String s;
      String fullTableName = ct.getFullTableName();

      flush(baseSS, true); 

      baseSS.endIndent();
      baseSS.writeIndentedString(")", 0);
      if (fullTableName.startsWith("ATOM_SITE"))
	{
	  baseSS.writeSelection(largeTableQualifier);
	}
      baseSS.writeLine(" ;");
      // "GRANT SELECT ... " is helpful on Oracle systems but not on others.
      // baseSS.writeLine("GRANT SELECT ON " 
      //		    + fullTableName + " TO PUBLIC;");

      String iName = fullTableName;
      String ndxStr = "_NDX";
      if (iName.length() > MAX_ATTR_NAME_LEN - ndxStr.length())
	{
	  iName = iName.substring(0, MAX_ATTR_NAME_LEN - ndxStr.length());
	}
      baseSS.writeLine("");
      createIndexSS.writeLine("");
      s = "CREATE INDEX " + iName + ndxStr;
      baseSS.writeLine(s);
      createIndexSS.writeLine(s);
      s = indent + "on " + fullTableName + "(" + ENTRY_TABLE_KEY_NAME +") ;";
      baseSS.writeLine(s);
      createIndexSS.writeLine(s);

      dropIndexSS.writeLine("DROP INDEX " + iName + ndxStr + " ;");

      inCat = null;
      fieldNumInCat = 0;
    }

  public void openField(FieldTrans ft) 
    throws IOException, TransGenException 
   {
      String attrName, paddedName;

      if (inCat != null)
	{
	  // SPECIAL CASE - NAMES
	  // some names must be caught and modified here
	  attrName = itemNameToAttributeName(ft);
	  if (attrName.equalsIgnoreCase("id_id"))
	    {
	      // remove redundant "ids" introduced from IndexId struct
	      attrName = "id";
	    }
	  else if (attrName.equalsIgnoreCase("date") ||
	      attrName.equalsIgnoreCase("number") ||
	      attrName.equalsIgnoreCase("size") ||
	      attrName.equalsIgnoreCase("component") ||
	      attrName.equalsIgnoreCase("current"))
	    {
	      attrName = attrName + "2";
	    }
	  if (attrName.length() > MAX_ATTR_NAME_LEN)
	    {
	      attrName = attrName.substring(0, MAX_ATTR_NAME_LEN);
	    }
	  ft.setColumnName(attrName);
	  paddedName = padString(attrName);

	  if (ft.isCifField())
	    {
	      DictionaryItem di = ft.getDictionaryItem();
	      String otype, suf;
	      String[] sel;

	      otype = cifToSqlType(di.getItemType(), 0);
	      if (otype.equalsIgnoreCase("TEXT"))
		{
		  // "TEXT" SQL type varies for different DB vendors
		  if ( ! noMandItem &&
		      (di.getItemMandatoryCode() 
		      == DictionaryItem.ITEM_MANDATORY_CODE_YES))
		    {
		      sel = padLongTextType;
		      suf = " " + MANDATORY;
		    }
		  else
		    {
		      sel = bigTextType;
		      suf = "";
		      // SPECIAL CASE - TYPES

		      // catch needed huge types here and modify
		      if (inCat.getTableName().equalsIgnoreCase
			  ("DATABASE_PDB_REMARK") &&
			  ft.getColumnName().equalsIgnoreCase("text"))
			{
			  // DATABASE_PDB_REMARK'S can be huge
			  // need to use stream methods to load into DB.
			  ft.setFieldBit(FieldTrans.IS_A_STREAM_DATATYPE);
			  inCat.setCategoryBit
			    (CategoryTrans.CONTAINS_STREAM_DATATYPES);
			  sel = hugeTextType;
			}
		    }
		  buffer(baseSS, paddedName + " ", sel, suf);
		}
	      else
		{
		  // entry_id fields are sometime not present in
		  // data files so do not mark as mandatory.
		  if ( ! noMandItem &&
		       (di.getItemMandatoryCode() 
		      == DictionaryItem.ITEM_MANDATORY_CODE_YES)
		      && ! ft.getName().equals("entry_id"))
		    {
		      otype = padString(otype, TYPE_FIELD_LEN) 
			+ " " + MANDATORY;
		    }
		  buffer(baseSS, paddedName + " " + otype);
		}
	      if (ft.isIndexField())
		{
		  // strip "_id" and when replacing with "_key"
		  if (attrName.endsWith("_id"))
		    {
		      attrName = attrName.substring(0, attrName.length() - 3);
		    }
		  attrName = attrName + KEY_ID_SUFFIX;
		  if (attrName.length() > MAX_ATTR_NAME_LEN)
		    {
		      attrName = attrName.substring(0, MAX_ATTR_NAME_LEN);
		    }
		  ft.setColumnIndexName(attrName);
		  paddedName = padString(attrName);
		  // Indices may be null ( foreign table missing ) even
		  // if there base cif type is mandatory
		  otype = " " + STD_KEY_TYPE;
		  buffer(baseSS, paddedName + otype);
		}
	      fieldNumInCat++;
	    }
	}
    }

  public void closeField(SubfieldTrans ft) 
    throws IOException, TransGenException
    {
    }

  public void openSubfield(SubfieldTrans ft) 
    throws IOException, TransGenException
    {
      openField(ft);
    }

  public void closeSubfield(SubfieldTrans ft) 
    throws IOException, TransGenException
    {
      closeField(ft);
    }
}  

