//
// TestRootTrans.java,v 1.8 2003/05/28 01:09:07 dsg Exp
//
// Copyright 2001 The Regents of the University of California
// All Rights Reserved
//
// OpenMMS was developed by Dr. Douglas S. Greer at the San Diego
// Supercomputer Center, a research unit of the University of California,
// San Diego.  Support for this effort was provided by NSF through the
// Protein Data Bank (Grant DBI-9814284) and the National Partnership for
// Advanced Computational Infrastructure (Grant ACI-9619020)
//
// Permission to use, copy, modify and distribute any part of OpenMMS for
// educational, research and non-profit purposes, without fee, and
// without a written agreement is hereby granted, provided that the above
// copyright notice, this paragraph and the following paragraphs appear
// in all copies.
//
// Those desiring to incorporate this OpenMMS into commercial products or
// use for commercial purposes should contact the Technology Transfer
// Office, University of California, San Diego, 9500 Gilman Drive, La
// Jolla, CA 92093-0910, Ph: (619) 534-5815, FAX: (619) 534-7345.
//
// In no event shall the University of California be liable to any party
// for direct, indirect, special, incidental, or consequential damages,
// including lost profits, arising out of the use of this OpenMMS, even
// if the University of California has been advised of the possibility of
// such damage.
//
// The OpenMMS provided herein is on an "as is" basis, and the
// University of California has no obligation to provide maintenance,
// support, updates, enhancements, or modifications.  The University of
// California makes no representations and extends no warranties of any
// kind, either implied or express, including, but not limited to, the
// implied warranties of merchantability or fitness for a particular
// purpose, or that the use of the OpenMMS will not infringe any patent,
// trademark or other rights.

package org.rcsb.openmms.meta;

import java.io.IOException;

import org.rcsb.openmms.cifparse.*;

/**
 * Generate a small "toy" Cif metamodel Translation Hierarchary for 
 * development and testing purposes.
 *
 * @author Douglas S. Greer
 * @version 1.8
 */
public class TestRootTrans extends RootTrans
{
  public TestRootTrans(String modName)
    {
      super(modName);
    }

  public String getModelIdentifier()
    {
      return "Test";
    }

  // Must be a value of the form "x.y" that can be converted to a float
  // for comparison purposes.
  // Additions to the model/schema can be done with a minor release
  // i.e incrementing "x.y" to "x.y+1".  Subtractions or substitutions
  // require a major release i.e changing "x.y" to "x+1.y".
  public String getRevisionNumber()
    {
      return "2.4";
    }

  // Use a much smaller version of the IDL definition
  // and implementation for code development
  public void doCoreModDefs(ModuleTrans cmod)
    {
      Trans t;
      FieldTrans ft;
      CategoryTrans cat;
      StructureTrans strk;
      ListTrans list;
      FieldTrans entityIdField;

      //___________________________________________________________
      // ATOM_SITE
      CategoryTrans atomSiteCat = 
	new CategoryTrans("atom_site", "AtomSite");
      cmod.add(atomSiteCat);
      StructureTrans atomSiteStrk = 
	defaultContainer("AtomSite", atomSiteCat);
      atomSiteStrk.setUseBlockMethod(true);
      atomSiteCat.add(atomSiteStrk);
      {
	atomSiteStrk.add(new FieldTrans("id", "id", 2));
	atomSiteStrk.add(new FieldTrans("type_symbol"));

	ft = new FieldTrans(atomIndex, "label");
	atomSiteStrk.add(ft);
	ft.add(new SubfieldTrans("atom", "label_atom_id"));
	ft.add(new SubfieldTrans("seq", "label_seq_id"));
	ft.add(new SubfieldTrans("comp", "label_comp_id"));
	ft.add(new SubfieldTrans("asym", "label_asym_id"));
	//	ft.add(new SubfieldTrans("alt", "label_alt_id"));

	ft = new FieldTrans("label_entity_id");
	atomSiteStrk.add(ft);

	ft = new FieldTrans(stVectorXYZ, "cartn");
	atomSiteStrk.add(ft);
	ft.add(new SubfieldTrans("x", "cartn_x"));
	ft.add(new SubfieldTrans("y", "cartn_y"));
	ft.add(new SubfieldTrans("z", "cartn_z"));
      }

      ListTrans atomSiteList = new ListTrans(atomSiteStrk);
      cmod.add(atomSiteList);
	    
      StructureTrans atomSiteMiscStrk = 
	defaultContainer("AtomSiteExt", atomSiteCat, 0);
      atomSiteMiscStrk.setUseBlockMethod(true);
      atomSiteCat.add(atomSiteMiscStrk);
      {
	atomSiteMiscStrk.add(new FieldTrans("occupancy"));
	atomSiteMiscStrk.add(new FieldTrans("constraints"));
	atomSiteMiscStrk.add(new FieldTrans("b_iso_or_equiv",
					    "B_iso_or_equiv"));
	atomSiteMiscStrk.add(new MatrixTrans("aniso_u", "aniso_U",
					     "_esd", true));
      }
      ListTrans atomSiteMiscList =
	new ListTrans(atomSiteMiscStrk);
      cmod.add(atomSiteMiscList);

      //___________________________________________________________
      // ATOM_TYPE
      // needed for reference by atom_site.type_symbol
      cat = new CategoryTrans("atom_type", "AtomType");
      cmod.add(cat);
      strk = defaultContainer("AtomType", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("symbol");
	strk.add(ft);
      }
      list = new ListTrans(strk);
      cmod.add(list);

      //___________________________________________________________
      // CHEM_COMP
      // needed for reference by entity_poly_seq.mon.id
      cat = new CategoryTrans("chem_comp", "ChemComp");
      cmod.add(cat);
      strk = defaultContainer("ChemComp", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("formula");
	strk.add(ft);
	ft = new FieldTrans("formula_weight");
	strk.add(ft);
	ft = new FieldTrans("id");
	strk.add(ft);
	ft = new FieldTrans("model_details");
	strk.add(ft);
	ft = new FieldTrans("name");
	strk.add(ft);
	ft = new FieldTrans("number_atoms_all");
	strk.add(ft);
	ft = new FieldTrans("number_atoms_nh");
	strk.add(ft);
	ft = new FieldTrans("one_letter_code");
	strk.add(ft);
	ft = new FieldTrans("three_letter_code");
	strk.add(ft);
	ft = new FieldTrans("type");
	strk.add(ft);
      }
      list = new ListTrans(strk);
      cmod.add(list);

    //___________________________________________________________
    // CHEM_COMP_ATOM
    // need for reference by atom_site.label_atom_id
      cat = new CategoryTrans("chem_comp_atom", "ChemCompAtom");
      cmod.add(cat);
      strk = defaultContainer("ChemCompAtom", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("atom_id");
	strk.add(ft);
      }
      list = new ListTrans(strk);
      cmod.add(list);

      //___________________________________________________________
      // ENTITY
      CategoryTrans entityCat = 
	new CategoryTrans("entity", "Entity");
      cmod.add(entityCat);
      StructureTrans entityStrk = 
	defaultContainer("Entity", entityCat, 3);
      entityCat.add(entityStrk);
      {
	entityIdField = new FieldTrans("id");
	entityStrk.add(entityIdField);
	entityStrk.add(new FieldTrans("details"));
	entityStrk.add(new FieldTrans("type"));
      }

      ListTrans entityList = new ListTrans(entityStrk);
      cmod.add(entityList);

      //___________________________________________________________
      // ENTITY_POLY_SEQ
      CategoryTrans entityPolySeqCat = 
	new CategoryTrans("entity_poly_seq", "EntityPolySeq");
      cmod.add(entityPolySeqCat);
      StructureTrans entityPolySeqStrk = 
	defaultContainer("EntityPolySeq", entityPolySeqCat);
      entityPolySeqStrk.setUseBlockMethod(true);
      entityPolySeqCat.add(entityPolySeqStrk);
      {
	ft = new FieldTrans("entity_id");
	// ft.setIndexParent(entityIdField);
	entityPolySeqStrk.add(ft);
	      
	entityPolySeqStrk.add(new FieldTrans("num"));
	entityPolySeqStrk.add(new FieldTrans("mon_id"));
      }

      ListTrans entityPolySeqList = new ListTrans(entityPolySeqStrk);
      cmod.add(entityPolySeqList);

      //___________________________________________________________
      // STRUCT
      CategoryTrans structCat = new CategoryTrans("struct",
					    "Struct");
      cmod.add(structCat);
      StructureTrans structStrk = defaultContainer("Structure", structCat);
      structCat.add(structStrk);
      {
	ft = new FieldTrans("entry_id");
	structStrk.add(ft);
	ft = new FieldTrans("title");
	structStrk.add(ft);
      }
      list = new ListTrans(structStrk);
      cmod.add(list);

      //___________________________________________________________
      // STRUCT_ASYM
      CategoryTrans structAsymCat = new CategoryTrans("struct_asym",
					    "StructAsym");
      cmod.add(structAsymCat);
      StructureTrans structAsymStrk 
	= defaultContainer("StructAsym", structAsymCat);
      structAsymCat.add(structAsymStrk);
      {
	ft = new FieldTrans("details");
	structAsymStrk.add(ft);
	ft = new FieldTrans("entity_id");
	structAsymStrk.add(ft);
	ft = new FieldTrans("id");
	structAsymStrk.add(ft);
      }
      list = new ListTrans(structAsymStrk);
      cmod.add(list);
    }

  public void doReferModDefs(ModuleTrans mod)
    {
      //___________________________________________________________
      // MMS Reference
      //
      // Begin DsLsrMmsReference module
      ModuleTrans[] referModQual = {mod};
      FieldTrans ft;
      ListTrans list;

      //___________________________________________________________
      // CITATION
      CategoryTrans citationCat = 
	new CategoryTrans("citation", "Citation");
      mod.add(citationCat);
      StructureTrans citationStrk = 
	defaultContainer("Citation", citationCat, referModQual);
      citationCat.add(citationStrk);
      {
	citationStrk.add(new FieldTrans("id"));
	citationStrk.add(new FieldTrans("title"));
      }
      list = new ListTrans(citationStrk);
      mod.add(list);

      //___________________________________________________________
      // CITATION_AUTHOR
      CategoryTrans citationAuthorCat = new CategoryTrans("citation_author",
					    "CitationAuthor");
      mod.add(citationAuthorCat);
      StructureTrans citationAuthorStrk = defaultContainer("CitationAuthor",
					     citationAuthorCat, referModQual);
      citationAuthorCat.add(citationAuthorStrk);
      {
	ft = new FieldTrans("citation_id");
	citationAuthorStrk.add(ft);
	ft = new FieldTrans("name");
	citationAuthorStrk.add(ft);
	ft = new FieldTrans("ordinal");
	citationAuthorStrk.add(ft);
      }
      list = new ListTrans(citationAuthorStrk);
      mod.add(list);

      //___________________________________________________________
      // SOFTWARE
      CategoryTrans softCat = new CategoryTrans("software",
					    "Software");
      mod.add(softCat);
      StructureTrans softStrk = defaultContainer("Software",
					       softCat, referModQual);
      softCat.add(softStrk);
      {
	ft = new FieldTrans("citation_id");
	softStrk.add(ft);
	ft = new FieldTrans("classification");
	softStrk.add(ft);
	ft = new FieldTrans("contact_author");
	softStrk.add(ft);
	ft = new FieldTrans("contact_author_email");
	softStrk.add(ft);
	ft = new FieldTrans("location");
	softStrk.add(ft);
	ft = new FieldTrans("name");
	softStrk.add(ft);
	ft = new FieldTrans("version");
	softStrk.add(ft);
      }
      list = new ListTrans(softStrk);
      mod.add(list);
    }

  public void doDepoModDefs(ModuleTrans mod)
    {
      //___________________________________________________________
      // MMS Deposition
      //
      ModuleTrans[] modQual = {mod};

      doDeposition(mod, modQual);
    }

  public void doDeposition(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // Deposition Interface
      Trans iface, t;

      TypeDefTrans eld = new TypeDefTrans("ErrorList",
					  "sequence<string>");
      String[] eldCom = {
	"Error List returned by deposition checking software"
      };
      eld.setComment(eldCom);
      cmod.add(eld);

      iface = new InterfaceTrans("Deposition");
      String[] dCom = {
	"Interface for the deposition of new entries."
      };
      iface.setComment(dCom);
      cmod.add(iface);

      t = new MethodTrans(coreModuleName + "::FormatTypeList",
			  "deposition_formats_supported",
			  null, null, basicExcepts);
      String[] nfsCom = {
	"Retrieve a list of deposition formats supported."
      };
      t.setComment(nfsCom);
      iface.add(t);
      
      String[] dprTypes= {"in string", "in string", "in string",
			  "in " + coreModuleName + "::EntryRepresentation"};
      String[] dprNames= {"user", "password", "format", "entry"};
      t = new MethodTrans("ErrorList",
			  "deposit_entry",
			  dprTypes, dprNames, basicExcepts);
      String[] dprCom = {
	"Deposit a new entry for error checking and databank inclusion."
      };
      t.setComment(dprCom);
      t.setBlankLines(1);
      iface.add(t);
    }

  public void doXRayModDefs(ModuleTrans mod)
    {
      FieldTrans ft;

      //___________________________________________________________
      // X-Ray Crystllograpy Module
      //
      // Begin XRayCrystallograpy module
      ModuleTrans[] modQual = {mod};
      
      doXRayTypeDefs(mod, modQual);
      
      //___________________________________________________________
      // ATOM_SITES
      CategoryTrans atomSitesCat = 
	new CategoryTrans("atom_sites", "AtomSites");
      mod.add(atomSitesCat);
      StructureTrans atomSitesStrk = 
	defaultContainer("AtomSites", atomSitesCat, modQual, 3);
      atomSitesCat.add(atomSitesStrk);
      {
	atomSitesStrk.add(new FieldTrans("cartn_transform_axes"));
	atomSitesStrk.add(new FieldTrans("solution_hydrogens"));
	atomSitesStrk.add(new VectorTrans("fract_transf_vector"));
	atomSitesStrk.add(new MatrixTrans("fract_transf_matrix"));
      }

    ListTrans atomSitesList = new ListTrans(atomSitesStrk);
    mod.add(atomSitesList);

      //___________________________________________________________
      // CELL
      CategoryTrans cellCat = 
	new CategoryTrans("cell", "Cell");
      mod.add(cellCat);
      StructureTrans cellStrk = 
	defaultContainer("Cell", cellCat, modQual);
      cellCat.add(cellStrk);
      {
	ft = new FieldTrans(unitCell, "cell");
	cellStrk.add(ft);
	ft.add(new SubfieldTrans("length_a", "length_a"));
	ft.add(new SubfieldTrans("length_b", "length_b"));
	ft.add(new SubfieldTrans("length_c", "length_c"));
	ft.add(new SubfieldTrans("angle_alpha", "angle_alpha"));
	ft.add(new SubfieldTrans("angle_beta", "angle_beta"));
	ft.add(new SubfieldTrans("angle_gamma", "angle_gamma"));

	ft = new FieldTrans("volume");
	cellStrk.add(ft);
      }
      ListTrans cellList = new ListTrans(cellStrk);
      mod.add(cellList);
      
      // END X-Ray Crystllograpy Module
      //___________________________________________________________
    }

  public void doNmrModDefs(ModuleTrans mod)
    {
      //___________________________________________________________
      // Nuclear Magnetic Resonance Module
      //
      // Begin NMR module
      ModuleTrans[] modQual = {mod};

      doNmrTypeDefs(mod, modQual);
    }
}
