//
// Trans.java,v 1.3 2001/10/27 02:02:53 dsg Exp
//
// Copyright 2001 The Regents of the University of California
// All Rights Reserved
//
// OpenMMS was developed by Dr. Douglas S. Greer at the San Diego
// Supercomputer Center, a research unit of the University of California,
// San Diego.  Support for this effort was provided by NSF through the
// Protein Data Bank (Grant DBI-9814284) and the National Partnership for
// Advanced Computational Infrastructure (Grant ACI-9619020)
//
// Permission to use, copy, modify and distribute any part of OpenMMS for
// educational, research and non-profit purposes, without fee, and
// without a written agreement is hereby granted, provided that the above
// copyright notice, this paragraph and the following paragraphs appear
// in all copies.
//
// Those desiring to incorporate this OpenMMS into commercial products or
// use for commercial purposes should contact the Technology Transfer
// Office, University of California, San Diego, 9500 Gilman Drive, La
// Jolla, CA 92093-0910, Ph: (619) 534-5815, FAX: (619) 534-7345.
//
// In no event shall the University of California be liable to any party
// for direct, indirect, special, incidental, or consequential damages,
// including lost profits, arising out of the use of this OpenMMS, even
// if the University of California has been advised of the possibility of
// such damage.
//
// The OpenMMS provided herein is on an "as is" basis, and the
// University of California has no obligation to provide maintenance,
// support, updates, enhancements, or modifications.  The University of
// California makes no representations and extends no warranties of any
// kind, either implied or express, including, but not limited to, the
// implied warranties of merchantability or fitness for a particular
// purpose, or that the use of the OpenMMS will not infringe any patent,
// trademark or other rights.

package org.rcsb.openmms.meta;

import java.util.*;
import java.io.IOException;

/**
 * Base class for Cif metamodel Translation elements
 * 
 * @author Douglas S. Greer
 * @version 1.3
 */
public abstract class Trans
{
  private String name;
  private int transType;
  private Vector children;
  private int blankLines;
  private String[] comment;
  
  static final int TYPE_ROOT = 0;
  static final int TYPE_FILE = 1;
  static final int TYPE_MODULE = 2;
  static final int TYPE_INTERFACE = 3;
  static final int TYPE_METHOD = 4;
  static final int TYPE_CATEGORY = 5;
  static final int TYPE_STRUCTURE = 6;
  static final int TYPE_LIST = 7;
  static final int TYPE_FIELD = 8;
  static final int TYPE_VECTOR = 9;
  static final int TYPE_MATRIX = 10;
  static final int TYPE_SEQUENCE = 11;
  static final int TYPE_TYPEDEF = 12;
  static final int TYPE_CONSTANT = 14;
  static final int TYPE_VALUETYPE = 15;
  static final int TYPE_SUBFIELD = 16;
  static final int TYPE_DIRECTIVE = 17;

  static final int TYPE_EXCEPTION = 20;
  static final int TYPE_EXCEPTION_FIELD = 21;

  public Trans(String n, int t)
    {
      name = n;
      transType = t;
      children = new Vector();
    }
  
  public String getName()
    {
      return name;
    }

  public int getTransType()
    {
      return transType;
    }

  protected void setTransType(int t)
    {
      transType = t;
    }

  public int numberOfChildren()
    {
      return children.size();
    }

  public void add(Trans t)
    {
      children.add(t);
    }

  public void replace(Trans old, Trans neu)
    throws TransGenException
    {
      int i = children.indexOf(old);
      if (i < 0)
	{
	  throw new TransGenException
	    ("Trans.replace: cannot find old element=" + old.getName());
	}
      children.set(i, neu);
    }

  public Trans getChild(int i)
    {
      return (Trans) children.get(i);
    }

  public void setBlankLines(int b)
    {
      blankLines = b;
    }

  public int getBlankLines()
    {
      return blankLines;
    }

  public void setComment(String[] cmt)
    {
      comment = cmt;
    }

  public String[] getComment()
    {
      return comment;
    }

  public abstract void accept(TransVisitor t)
    throws IOException, TransGenException;

  public String convertToUnderbar(String sname)
    {
      StringBuffer sb = new StringBuffer();
      char c;

      for (int i = 0; i < sname.length(); i++)
	{
	  c = sname.charAt(i);
	  if (Character.isLowerCase(c))
	    {
	      sb.append(c);
	    }
	  else
	    {
	      sb.append('_');
	      sb.append(Character.toLowerCase(c));
	    }
	}
      return sb.toString();
    }

  public String convertToFlagName(String sname)
    {
      return convertToUnderbar(name).toUpperCase();
    }
}
