//
// VImplWriter.java,v 1.4 2002/06/27 21:59:10 dsg Exp
//
// Copyright 2001 The Regents of the University of California
// All Rights Reserved
//
// OpenMMS was developed by Dr. Douglas S. Greer at the San Diego
// Supercomputer Center, a research unit of the University of California,
// San Diego.  Support for this effort was provided by NSF through the
// Protein Data Bank (Grant DBI-9814284) and the National Partnership for
// Advanced Computational Infrastructure (Grant ACI-9619020)
//
// Permission to use, copy, modify and distribute any part of OpenMMS for
// educational, research and non-profit purposes, without fee, and
// without a written agreement is hereby granted, provided that the above
// copyright notice, this paragraph and the following paragraphs appear
// in all copies.
//
// Those desiring to incorporate this OpenMMS into commercial products or
// use for commercial purposes should contact the Technology Transfer
// Office, University of California, San Diego, 9500 Gilman Drive, La
// Jolla, CA 92093-0910, Ph: (619) 534-5815, FAX: (619) 534-7345.
//
// In no event shall the University of California be liable to any party
// for direct, indirect, special, incidental, or consequential damages,
// including lost profits, arising out of the use of this OpenMMS, even
// if the University of California has been advised of the possibility of
// such damage.
//
// The OpenMMS provided herein is on an "as is" basis, and the
// University of California has no obligation to provide maintenance,
// support, updates, enhancements, or modifications.  The University of
// California makes no representations and extends no warranties of any
// kind, either implied or express, including, but not limited to, the
// implied warranties of merchantability or fitness for a particular
// purpose, or that the use of the OpenMMS will not infringe any patent,
// trademark or other rights.

package org.rcsb.openmms.meta;

import java.util.*;
import java.io.*;
import java.util.*;

import org.rcsb.openmms.cifparse.*;

/**
 * Generates the initialization code for IDL generated valuetypes
 *
 * @author Douglas S. Greer
 * @version 1.4
 */
public class VImplWriter extends TransVisitor
{
  private static boolean trace = false;

  String vtypePath;

  String BaseName;
  String lsrPackageName, msaPackageName;

  RootTrans inRoot;
  String moduleName;
  String moduleDir;
  String baseModuleName = "";
  Stack moduleNameStack = new Stack();

  String oClassName;
  String oClassFilename;

  public VImplWriter(String vp, String lsr, String msa)
    {
      setIndentString("   ");  // set indent size to three spaces
      
      vtypePath = vp;

      lsrPackageName = lsr;
      msaPackageName = msa;
    }
  
  public void setTrace(boolean t)
    {
      trace = t;
    }

  public void openRoot(RootTrans rt)
    throws IOException, TransGenException
    {
      inRoot = rt;

      // check all the variables
      if (vtypePath == null)
	{
	  throw new TransGenException(
	      "VImplWriter: vtype target directoy path not specified");
	}
    }

  public void openModule(ModuleTrans mt) 
    throws IOException, TransGenException
    {

      if (moduleNameStack.size() == 0)
	{
	  baseModuleName = mt.getName();
	}
      moduleNameStack.push(mt.getName());
      initModuleName();
    }
      
  public void closeModule(ModuleTrans mt) 
    throws IOException, TransGenException
    {
      moduleNameStack.pop();
      initModuleName();
    }
  
  protected void initModuleName()
    {
      String smn;
      moduleName = "";
      moduleDir = "";
      Stack scp;

      scp = (Stack) moduleNameStack.clone();
      
      while ( ! scp.empty())
	{
	  smn = (String) scp.pop();
	  moduleName = "." + smn + moduleName;
	  moduleDir = "/" + smn + moduleDir;
	}
    }

  public void openCategory(CategoryTrans ct) 
    throws IOException, TransGenException
    {
      if (trace)
	{
	  System.out.println("VImplWriter.openCategory called");
	}
    }

  public void openValuetype(ValuetypeTrans st) 
    throws IOException, TransGenException
    {
      if (trace)
	{
	  System.out.println("VImplWriter.openValuetype called");
	}
      BaseName = st.getName();
      initCodeFile();
      writeVImplFileOpening();

      if (st.isCifStructure())
	{
	  // catStructs.add(st);
	}
    }

  // Called when the Valuetype is closed, this method does
  // most of the work writing out the init constructors
  // from fields collected during Trans structure traversal.
  public void closeValuetype(ValuetypeTrans st) 
    throws IOException, TransGenException
    {
      writeConstructors();
      writeFin();
      close();
      indentLevel = 0;
    }

  public void openField(FieldTrans ft) 
    throws IOException, TransGenException
    {
    }

  public void openVector(VectorTrans vt) 
    throws IOException, TransGenException
    {
    }

  public void openMatrix(MatrixTrans vt) 
    throws IOException, TransGenException
    {
    }

  private void initCodeFile()
    throws IOException, TransGenException
    {
      File pfd;

      if (trace)
	{
	  System.out.println("VImplWriter.initCodeFile called");
	}

      if (BaseName == null)
	{
	  throw new TransGenException("VImplWriter: Null VImpl name");
	}
      oClassName = BaseName + "Impl";
      oClassFilename = oClassName + ".java";
      pfd = new File(vtypePath + moduleDir);
      if (! pfd.exists())
	{
	  pfd.mkdirs();
	}
      open(vtypePath + moduleDir + "/" + oClassFilename);
    }

  private void writeVImplFileOpening()
    throws IOException, TransGenException
    {
      Date dt = new Date();
      GregorianCalendar cal = new GregorianCalendar();
      cal.setTime(dt);

      String[] preamble =
      {
	"//",
	"// **** DERIVED FILE - DO NOT EDIT ****",
	"//"
      };
      writeStr(preamble);
      writeCopyright();
      String[] packagestr =
      {
	"",
	"package " + lsrPackageName + moduleName + ";",
	""
      };
      writeStr(packagestr);
      // if (moduleNameStack.size() > 1 )
      //   {
      //      writeStr("import " + lsrPackageName + moduleName + ".*;");
      //   }
    }
      
  private void writeConstructors()
    throws IOException, TransGenException
    {
      Date dt = new Date();
      String[] defConstruct =
      {

	"/**",
	" * Valuetype Constuctor class",
	" * <p>",
	" * Generated by the program MMSExpr. Model: "
	  + inRoot.getModelIdentifier() + ", Revision: "
	  + inRoot.getRevisionNumber(),
	" * <p>",
	" * Date: " + dt.toString(),
	" *",
	" * @author Douglas S. Greer",
	" * @version OpenMMS Release V_1_5_1",
	" */",
	"public class " + oClassName + " extends " + BaseName,
	"{",
	indent + "public " + oClassName + "()",
	indent + indent + "{",
	indent + indent + "}",
      };
      writeStr(defConstruct);
    }
      
  private void writeFin()
    throws IOException, TransGenException
    {
      String[] closing =
      {
	"}"
      };
      writeStr(closing);
    }
}  


