//
// VectorTrans.java,v 1.3 2001/10/27 02:02:53 dsg Exp
//
// Copyright 2001 The Regents of the University of California
// All Rights Reserved
//
// OpenMMS was developed by Dr. Douglas S. Greer at the San Diego
// Supercomputer Center, a research unit of the University of California,
// San Diego.  Support for this effort was provided by NSF through the
// Protein Data Bank (Grant DBI-9814284) and the National Partnership for
// Advanced Computational Infrastructure (Grant ACI-9619020)
//
// Permission to use, copy, modify and distribute any part of OpenMMS for
// educational, research and non-profit purposes, without fee, and
// without a written agreement is hereby granted, provided that the above
// copyright notice, this paragraph and the following paragraphs appear
// in all copies.
//
// Those desiring to incorporate this OpenMMS into commercial products or
// use for commercial purposes should contact the Technology Transfer
// Office, University of California, San Diego, 9500 Gilman Drive, La
// Jolla, CA 92093-0910, Ph: (619) 534-5815, FAX: (619) 534-7345.
//
// In no event shall the University of California be liable to any party
// for direct, indirect, special, incidental, or consequential damages,
// including lost profits, arising out of the use of this OpenMMS, even
// if the University of California has been advised of the possibility of
// such damage.
//
// The OpenMMS provided herein is on an "as is" basis, and the
// University of California has no obligation to provide maintenance,
// support, updates, enhancements, or modifications.  The University of
// California makes no representations and extends no warranties of any
// kind, either implied or express, including, but not limited to, the
// implied warranties of merchantability or fitness for a particular
// purpose, or that the use of the OpenMMS will not infringe any patent,
// trademark or other rights.

package org.rcsb.openmms.meta;

import java.io.IOException;

import org.rcsb.openmms.cifparse.*;

/**
 * Class for Vectors in Cif to Idl Translation
 *
 * @author Douglas S. Greer
 * @version 1.3
 */
public class VectorTrans extends FieldTrans
{
  final static int VEC_LEN = 3;
  
  public VectorTrans(String n)
    {
      this(n, n);
    }

  public VectorTrans(String varname, String cifname)
    {
      super(varname, cifname);
      setTransType(TYPE_VECTOR);
      FieldTrans ft;
      for (int i = 0; i < VEC_LEN; i++)
	{
	  ft = new FieldTrans(cifname + "[" + (i+1) + "]");
	  ft.setPseudoField(true);
	  // mmCIF files use "i" for index , Java/C/C++ use "i-1"
	  ft.setRealName(varname + "[" + i + "]");
	  add(ft);
	}
    }

  // overides FieldTrans method
  // This method must return a valid mmCIF dictionary reference
  public String getCifItemName()
    {
      // use first element in vector for mmCIF dictionary work
      return super.getCifItemName() + "[1]";
    }

  // overides FieldTrans method
  // Vector is defined by its first element in the mmCIF file
  public String getTagName()
    {
      return super.getTagName() + "_0";
    }

  public void accept(TransVisitor v)
    throws IOException, TransGenException
    {
      v.openVector(this);

      // visit children
      Trans t;
      for (int i = 0; i < numberOfChildren(); i++)
	{
	  t = getChild(i);
	  int type = t.getTransType();
	  switch (type)
	    {
	    case Trans.TYPE_FIELD:
	      t.accept(v);
	      break;
	    default:
	      throw new TransGenException
		("Invalid VectorTrans Child Type: " + type );
	    }
	}

      v.closeVector(this);
    }
}
