//
// BaseFrame.java,v 1.6 2003/05/02 23:33:38 dsg Exp
//
// Copyright 2001 The Regents of the University of California
// All Rights Reserved
//
// OpenMMS was developed by Dr. Douglas S. Greer at the San Diego
// Supercomputer Center, a research unit of the University of California,
// San Diego.  Support for this effort was provided by NSF through the
// Protein Data Bank (Grant DBI-9814284) and the National Partnership for
// Advanced Computational Infrastructure (Grant ACI-9619020)
//
// Permission to use, copy, modify and distribute any part of OpenMMS for
// educational, research and non-profit purposes, without fee, and
// without a written agreement is hereby granted, provided that the above
// copyright notice, this paragraph and the following paragraphs appear
// in all copies.
//
// Those desiring to incorporate this OpenMMS into commercial products or
// use for commercial purposes should contact the Technology Transfer
// Office, University of California, San Diego, 9500 Gilman Drive, La
// Jolla, CA 92093-0910, Ph: (619) 534-5815, FAX: (619) 534-7345.
//
// In no event shall the University of California be liable to any party
// for direct, indirect, special, incidental, or consequential damages,
// including lost profits, arising out of the use of this OpenMMS, even
// if the University of California has been advised of the possibility of
// such damage.
//
// The OpenMMS provided herein is on an "as is" basis, and the
// University of California has no obligation to provide maintenance,
// support, updates, enhancements, or modifications.  The University of
// California makes no representations and extends no warranties of any
// kind, either implied or express, including, but not limited to, the
// implied warranties of merchantability or fitness for a particular
// purpose, or that the use of the OpenMMS will not infringe any patent,
// trademark or other rights.

package org.rcsb.openmms.apps.rdb;

import java.awt.*;
import javax.swing.*;

import org.rcsb.openmms.util.*;
import org.rcsb.openmms.entry.*;

/**
 * Java Swing top-level Frame with a constructor for
 * creating the panels it contains.
 *
 * @author Douglas S. Greer
 * @version 1.6
 */
public class BaseFrame extends JFrame implements MessageHandler
{
  static public Color backgroundColor = new Color(195, 200, 210);
  static public Color stopColor = new Color(215, 220, 230);
  PanelSet ps;
  private int debug;

  public BaseFrame(String name, ServerHandler ah, DBLoader dbl,
		   String dataPath, String manifest, String exclude,
		   String logFile)
    {
      super(name);
      createFrame(dbl, dataPath, manifest, exclude, logFile);

      ah.setMessageHandler((MessageHandler) this);
    }

  public void createFrame(DBLoader dbl, String dataPath,
			  String manifest, String exclude,
			  String logFile)
    {
      java.awt.Container fcp = getContentPane();
      
      ps = new PanelSet(dbl, dataPath, manifest, exclude, logFile);
      fcp.add(ps, BorderLayout.CENTER);
      ps.setBackground(backgroundColor);
    }
  
  public void setDebug(int d)
    {
      debug = d;
      ps.setDebug(debug);
    }

  public void logString(String s)
    {
      ps.logString(s);
    }

  public void logMessage(String s)
    {
      ps.logMessage(s);
    }

  public void logException(Throwable t, String title,
			   String exceptionType, String where,
			   String cause, String other, boolean trace)
    {
      ps.logException(t, title, exceptionType, where, cause, other, trace);
    }
}
