//
// InsertEntryFinal.java,v 1.2 2003/04/05 01:40:04 dsg Exp
//
// Copyright 2001 The Regents of the University of California
// All Rights Reserved
//
// OpenMMS was developed by Dr. Douglas S. Greer at the San Diego
// Supercomputer Center, a research unit of the University of California,
// San Diego.  Support for this effort was provided by NSF through the
// Protein Data Bank (Grant DBI-9814284) and the National Partnership for
// Advanced Computational Infrastructure (Grant ACI-9619020)
//
// Permission to use, copy, modify and distribute any part of OpenMMS for
// educational, research and non-profit purposes, without fee, and
// without a written agreement is hereby granted, provided that the above
// copyright notice, this paragraph and the following paragraphs appear
// in all copies.
//
// Those desiring to incorporate this OpenMMS into commercial products or
// use for commercial purposes should contact the Technology Transfer
// Office, University of California, San Diego, 9500 Gilman Drive, La
// Jolla, CA 92093-0910, Ph: (619) 534-5815, FAX: (619) 534-7345.
//
// In no event shall the University of California be liable to any party
// for direct, indirect, special, incidental, or consequential damages,
// including lost profits, arising out of the use of this OpenMMS, even
// if the University of California has been advised of the possibility of
// such damage.
//
// The OpenMMS provided herein is on an "as is" basis, and the
// University of California has no obligation to provide maintenance,
// support, updates, enhancements, or modifications.  The University of
// California makes no representations and extends no warranties of any
// kind, either implied or express, including, but not limited to, the
// implied warranties of merchantability or fitness for a particular
// purpose, or that the use of the OpenMMS will not infringe any patent,
// trademark or other rights.

package org.rcsb.openmms.apps.rdb;

import java.util.*;
import java.sql.*;

// For definition of ORB functions
import org.omg.CORBA.*;
// For definition of DataAccessException
import org.omg.DsLSRMacromolecularStructure.*;

import org.rcsb.openmms.util.*;
import org.rcsb.openmms.entry.*;
import org.rcsb.openmms.meta.*;
import org.rcsb.openmms.loader.*;
import org.rcsb.openmms.dbinsert.*;

/**
 * Final subclass of InsertEntry with Entry Table create and
 * delete methods.
 *
 * @author Douglas S. Greer
 * @version 1.2
 */
public class InsertEntryFinal extends InsertEntry
{
  private static final int ENTRY_STATUS_AT_CREATION    = 0x00;
  private static final int ENTRY_STATUS_COMPLETION_BIT = 0x01;

  public InsertEntryFinal(MessageHandler ps, int dbug, Connection con)
    {
      super(ps, dbug, con);
    }

  public void initLoader()
    throws MmsTranslationException, SQLException
    {
      entryKey = getNextEntryKey();
      if (entryKey < 0)
	{
	  throw new MmsTranslationException
	    ("Cannot retrieve first Entry Key");
	}
      // get base and key values for all the categories
      initCategories();
    }

  protected void dbCheck(MessageHandler mh)
      throws SQLException, MmsTranslationException
    {
      class BadEntry
	  {
	    public String name;
	    public int key;
	  };

      ArrayList badList = new ArrayList();

      stmt = Conn.createStatement();
      if (entryKey < 0)
	{
	  initLoader();
	}
      final String se = "SELECT " +  ENTRY_TABLE_KEY_NAME
	  + ", " + ENTRY_TABLE_ID_NAME 
	  + ", " + ENTRY_TABLE_LOAD_STATUS_NAME 
	  + " FROM " + SCHEMA_PREFIX + ENTRY_TABLE_NAME;
      try
	{
	  ResultSet rs = stmt.executeQuery(se); 
	  while (rs.next())
	    {
	      int status = rs.getInt(3);
	      if ((status & ENTRY_STATUS_COMPLETION_BIT) == 0)
		{
		  BadEntry be = new BadEntry();
		  be.key = rs.getInt(1);
		  be.name = rs.getString(2);
		  badList.add(be);
		}
	    }
	}
      finally
	{
	  if (stmt != null)
	    {
	      stmt.close();
	      stmt = null;
	    }
	}
      for (int i = 0; i < badList.size(); i++)
	{
	  BadEntry be = (BadEntry) badList.get(i);
	  mh.logMessage("Entry: " + be.name 
			+ "; Appears to be incompletely loaded -- Deleting");
	  removeEntry(be.key, be.name);
	}
    }

  public int buildAndInsertEntry(String ename, EntryImpl ei)
    throws MmsTranslationException, SQLException
    {
      stmt = Conn.createStatement();
      if (entryKey < 0)
	{
	  initLoader();
	}
      if (ei == null ||
	  ei.ref == null ||
	  ei.xray == null)
	{
	  throw new MmsTranslationException
	    ("Null Entry, or Sub-Entries in EntryImpl");
	}

      try
	{
	  createEntryRecord(entryKey, ename, ei);
	  insertEntryData(entryKey, ei);
 	  markEntryComplete(entryKey, ename, ei);
	}
      finally
	{
	  entryKey++;
	  stmt.close();
	  stmt = null;
	}
      return entryKey-1;
    }
  
  protected int getNextEntryKey()
    throws SQLException
    {
      String gnek = "SELECT MAX(" + ENTRY_TABLE_KEY_NAME 
      + " ) FROM " + SCHEMA_PREFIX + ENTRY_TABLE_NAME ;

      int rval = 0;
      ResultSet rs = stmt.executeQuery(gnek);
      while (rs.next())
	{
	  rval = rs.getInt(1);
	}
      // first entry_key is "1".
      return rval + 1;
    }

  protected void createEntryRecord(int eKey, String ename,
				  EntryImpl ei)
    throws SQLException
    {
      StringBuffer eFNames = new StringBuffer();
      StringBuffer eFValues = new StringBuffer();

      for (int i = 0; i < ModuleTypes.NUMBER_OF_ENTRY_MODULES; i++)
	{
	  eFNames.append(", ");
	  eFNames.append(ENTRY_TABLE_FLAG_BASE_NAME);
	  eFNames.append(i);
	  eFValues.append(", ?");
	}

      String cer = "INSERT INTO " + SCHEMA_PREFIX + ENTRY_TABLE_NAME
	+ " ( " +	ENTRY_TABLE_KEY_NAME + ", " + ENTRY_TABLE_ID_NAME
	+ ", " + ENTRY_TABLE_DEP_DATE_NAME 
	+ ", " + ENTRY_TABLE_LOAD_DATE_NAME
	+ ", " + ENTRY_TABLE_LOAD_STATUS_NAME
	+ eFNames.toString()
	+ " ) VALUES ( ?, ?, ?, ?, ?" + eFValues.toString() + " )";

      PreparedStatement epst = Conn.prepareStatement(cer);
      epst.setInt(1, eKey);
      epst.setString(2, ename);

      java.sql.Date mdt = new java.sql.Date
	(ei.getDepositionDate().getTime());
      epst.setDate(3, mdt);

      java.util.Date dt = new java.util.Date();
      java.sql.Date ldt = new java.sql.Date(dt.getTime());
      epst.setDate(4, ldt);

      epst.setInt(5, ENTRY_STATUS_AT_CREATION);

      for (int i = 0; i < ModuleTypes.NUMBER_OF_ENTRY_MODULES; i++)
	{
	  epst.setBytes(6 + i, ei.getPresenceFlags(i));
	}
      epst.executeUpdate();
      epst.close();
    }

  protected void markEntryComplete(int eKey, String ename, EntryImpl ei)
      throws SQLException, MmsTranslationException
    {
      int rval = -1;

      String etu = "UPDATE " + SCHEMA_PREFIX + ENTRY_TABLE_NAME
	  + " SET "+ ENTRY_TABLE_LOAD_STATUS_NAME + " = ? "
	  + " WHERE " + ENTRY_TABLE_KEY_NAME + " = " + " ? ";
      PreparedStatement ps = Conn.prepareStatement(etu);
      ps.setInt(1, ENTRY_STATUS_AT_CREATION | ENTRY_STATUS_COMPLETION_BIT);
      ps.setInt(2, eKey);
      try
	{
	  if (ps.executeUpdate() != 1)
	    {
	      throw new MmsTranslationException
		  ("markEntryComplete():"
		   + "  Could not update entry table" 
		   + "  Entry = " + ename);
	    }
	}
      finally
	{
	  ps.close();
	}
    }

  public String getTableNameFromKey(int key)
    throws MmsTranslationException, SQLException
    {
      String tab = null;

      String gtn = "SELECT " + CATEGORY_TABLE_TABLE_NAME + 
	" FROM " + SCHEMA_PREFIX + CATEGORY_TABLE_NAME +
	" WHERE " + CATEGORY_TABLE_KEY_NAME + " = ?";
      PreparedStatement pst = null;
      try
	{
	  pst = Conn.prepareStatement(gtn);
	  pst.setInt(1, key);
	  ResultSet rs = pst.executeQuery();
	  
	  while (rs.next())
	    {
	      tab = rs.getString(1);
	    }
	  if (tab == null)
	    {
	      throw new MmsTranslationException
		("getTableNameFormKey() Cannot find Category for key " + key);
	    }
	}
      finally
	{
	  pst.close();
	}
      return tab;
    }

  public void removeEntry(int key, String ename)
    throws MmsTranslationException, SQLException
    {
      int catKey;
      ArrayList l = new ArrayList();
      String tableName;

      stmt = Conn.createStatement();

      if (entryKey < 0)
	{
	  initLoader();
	}

      // Get a list of all of the tables
      final String cs = "SELECT " +  CATEGORY_TABLE_KEY_NAME +
	" FROM " + SCHEMA_PREFIX + CATEGORY_TABLE_NAME;

      ResultSet rs = stmt.executeQuery(cs); 
      while (rs.next())
	{
	  catKey = rs.getInt(1);
	  tableName = getTableNameFromKey(catKey);
	  l.add(tableName);
	}

      String keyStr = Integer.toString(key);

      for (int i = 0; i < l.size(); i++)
	{
 	  tableName = (String) l.get(i);
	  String dels = "DELETE FROM " + tableName +
	    " WHERE " + ENTRY_TABLE_KEY_NAME + " = " + keyStr;
      }

      final String dct = "DELETE FROM " + 
	SCHEMA_PREFIX + ENTRY_CATS_TABLE_NAME +
	" WHERE " + ENTRY_CATS_ENTRY_NAME + " = ";
      if ( stmt.executeUpdate(dct + keyStr) <= 0)
	{
	  System.err.println("WARNING:  Entry " + ename +
			     " did not contain any Tables (Categories)");
	}
      final String det = "DELETE FROM " + SCHEMA_PREFIX + ENTRY_TABLE_NAME +
	" WHERE " + ENTRY_TABLE_KEY_NAME + " = ";
      stmt.executeUpdate(det + keyStr);
      stmt.close();
      stmt = null;
     }
}
