//
// PDBase.java,v 1.7 2003/05/02 23:33:38 dsg Exp
//
// Copyright 2001 The Regents of the University of California
// All Rights Reserved
//
// OpenMMS was developed by Dr. Douglas S. Greer at the San Diego
// Supercomputer Center, a research unit of the University of California,
// San Diego.  Support for this effort was provided by NSF through the
// Protein Data Bank (Grant DBI-9814284) and the National Partnership for
// Advanced Computational Infrastructure (Grant ACI-9619020)
//
// Permission to use, copy, modify and distribute any part of OpenMMS for
// educational, research and non-profit purposes, without fee, and
// without a written agreement is hereby granted, provided that the above
// copyright notice, this paragraph and the following paragraphs appear
// in all copies.
//
// Those desiring to incorporate this OpenMMS into commercial products or
// use for commercial purposes should contact the Technology Transfer
// Office, University of California, San Diego, 9500 Gilman Drive, La
// Jolla, CA 92093-0910, Ph: (619) 534-5815, FAX: (619) 534-7345.
//
// In no event shall the University of California be liable to any party
// for direct, indirect, special, incidental, or consequential damages,
// including lost profits, arising out of the use of this OpenMMS, even
// if the University of California has been advised of the possibility of
// such damage.
//
// The OpenMMS provided herein is on an "as is" basis, and the
// University of California has no obligation to provide maintenance,
// support, updates, enhancements, or modifications.  The University of
// California makes no representations and extends no warranties of any
// kind, either implied or express, including, but not limited to, the
// implied warranties of merchantability or fitness for a particular
// purpose, or that the use of the OpenMMS will not infringe any patent,
// trademark or other rights.

package org.rcsb.openmms.apps.rdb;

import java.io.*;
import java.awt.*;
import javax.swing.*;
import java.util.Date;

import org.rcsb.openmms.cifparse.*;
import org.rcsb.openmms.util.*;
import org.rcsb.openmms.entry.*;
import org.rcsb.openmms.loader.*;

import org.omg.CORBA.*;
import org.omg.DsLSRMacromolecularStructure.*;
import org.omg.DsLSRXRayCrystallography.*;
import org.omg.DsLSRMmsReference.*;
import org.omg.DsLSRMmsDeposition.*;

/**
 * PDBase, relational database main program
 *
 * @author Douglas S. Greer
 * @version 1.7
 */
public class PDBase
{
  // basic status messages
  public static int debug = 1;

  String frameName;
  BaseFrame bf;
  String dataPath;
  String manifest;
  String exclude;
  DataItemList dilist;
  String logFile = "MESSAGE.LOG";
  boolean lenient;

  ServerHandler servh;
  private static ORB orb;

  public static void main(String args[])
    {
      PDBase tc = new PDBase
	("PDBase - Macromolecular Structure Database Loader");
      tc.execute(args);
    }

  public PDBase(String name)
    {
      frameName = name;
    }

  public void execute(String[] args)
    {
      try
	{
	  orb = ORB.init(args, null);

	  logFile = parseArguments("log", args);
	  lenient = parseArgumentsBool("LenientParse", args);
	  CatUtil.setLenientParse(lenient);
	  dataPath = parseArguments("data", args);
	  manifest = parseArguments("manifest", args);
	  exclude = parseArguments("exclude", args);
	  if(dataPath == null)
	    {
	      throw new CifParseException(
		  "PDBase: Must specify data path - \"data=<path>\"");
	    }

	  String debugStr = parseArguments("debug", args);
	  if(debugStr != null)
	    {
	      debug = Integer.parseInt(debugStr);
	    }

	  // Bind DataItems to CatLoaders
	  LinkTable ltable = new LinkTable();
	  LoaderLink[] links = ltable.createLinkTable();
	  dilist = new DataItemList();
	  buildDataItemList(dilist, links);

 	  servh = new ServerHandler(debug, orb);

	  DBLoader dbloader = new DBLoader(servh, dilist);
	  dbloader.setDebug(debug);
	  bf = new BaseFrame(frameName, servh, dbloader, 
			     dataPath, manifest, exclude, logFile);
	}
      catch(CifParseException e)
	{
	  System.out.println("Fatal Error During Setup:");
	  e.printStackTrace();
	  System.exit(1);
	}
      bf.setDebug(debug);
      bf.pack();
      bf.show();
    }

  private void buildDataItemList(DataItemList dilist, LoaderLink[] links)
    throws CifParseException
    {
      DataItem di;
      String itemName;

      for (int i = 0; i < links.length; i++)
	{
	  itemName = "_" + links[i].getCatName() + 
	    "." + links[i].getItemName();
	  di = new DataItem(itemName);
	  di.setFieldCode(links[i].getFieldCode());
	  di.setCatLoader(links[i].getCatLoader());
	  dilist.add(di);
	}
    }

  public boolean parseArgumentsBool(String param, String[] argv)
    {
      for(int i=0; i<argv.length; i++)
	if(argv[i].compareTo(param)==0) return true;

      return false;
    }

  public String parseArguments(String param, String[] argv)
    {
      for(int i=0; i<argv.length; i++)
	{
	  if(argv[i].startsWith(param))
	    {
	      int index=argv[i].indexOf('=');
	      if(index!=-1) return (argv[i].substring(index+1));
	    }
	}
      return null;
    }
}

