//
// PanelSet.java,v 1.11 2003/05/05 20:58:17 dsg Exp
//
// Copyright 2001 The Regents of the University of California
// All Rights Reserved
//
// OpenMMS was developed by Dr. Douglas S. Greer at the San Diego
// Supercomputer Center, a research unit of the University of California,
// San Diego.  Support for this effort was provided by NSF through the
// Protein Data Bank (Grant DBI-9814284) and the National Partnership for
// Advanced Computational Infrastructure (Grant ACI-9619020)
//
// Permission to use, copy, modify and distribute any part of OpenMMS for
// educational, research and non-profit purposes, without fee, and
// without a written agreement is hereby granted, provided that the above
// copyright notice, this paragraph and the following paragraphs appear
// in all copies.
//
// Those desiring to incorporate this OpenMMS into commercial products or
// use for commercial purposes should contact the Technology Transfer
// Office, University of California, San Diego, 9500 Gilman Drive, La
// Jolla, CA 92093-0910, Ph: (619) 534-5815, FAX: (619) 534-7345.
//
// In no event shall the University of California be liable to any party
// for direct, indirect, special, incidental, or consequential damages,
// including lost profits, arising out of the use of this OpenMMS, even
// if the University of California has been advised of the possibility of
// such damage.
//
// The OpenMMS provided herein is on an "as is" basis, and the
// University of California has no obligation to provide maintenance,
// support, updates, enhancements, or modifications.  The University of
// California makes no representations and extends no warranties of any
// kind, either implied or express, including, but not limited to, the
// implied warranties of merchantability or fitness for a particular
// purpose, or that the use of the OpenMMS will not infringe any patent,
// trademark or other rights.

package org.rcsb.openmms.apps.rdb;
 
import java.io.*;
import java.sql.*;
import java.text.*;
import java.awt.*;
import java.awt.event.*;
import java.util.*;

import javax.swing.*;
import javax.swing.text.*;
import javax.swing.border.*;

import org.rcsb.openmms.util.*;
import org.omg.DsLSRMacromolecularStructure.*;

/**
 * Java Swing top-level panel with a constructor for
 * creating sub-panels.
 *
 * @author Douglas S. Greer
 * @version 1.11
 */
public class PanelSet extends JPanel
  implements TypeNamesSql, MessageHandler
{
  private static int debug = 0;

  private static final int VERTICAL_STRUT_BUTTON = 20;
  private static final int VERTICAL_STRUT_TEXT = 8;

  private BufferedWriter logFileWriter = null;
  private DBLoader dbLoader;
  private String dataPath;
  private String manifest;
  private String exclude;

  private Connection con;

  private Font dFont;
  private Font bdFont;
  private Font tFont;
  private JTextArea msgs;

  private JTextField DataDirTF, DataManifestTF, ExcludeTF, UrlTF, DriverTF,
      UserTF, PasswdTF;
  private JTextField FilenameTF, EntriesTF;

  private JButton loadListButton, manifestButton, singleLoadButton;
  private JButton deleteButton, stopButton;

  private SwingWorker worker;

  public PanelSet(DBLoader dbl, String dPath,
		  String mnfst, String excl, String logFile)
    {
      dbLoader = dbl;

      dataPath = dPath;
      manifest = mnfst;
      exclude = excl;

      dFont = new Font("Dialog", Font.BOLD, 12);
      bdFont = new Font("Dialog", Font.BOLD, 14);
      tFont = new Font("Monospaced", Font.PLAIN, 12);

      createPanel();
      try
	{
	  if (logFile != null)
	    {
	      logFileWriter = new BufferedWriter(new FileWriter(logFile));
	    }
	  else
	    {
	      logFileWriter = null;
	    }
	}
      catch(IOException e)
	{
	  System.out.println("Cannot open MESSAGE.LOG file: " + e);
	}
    }

  public void setDebug(int d)
    {
      debug = d;
    }

  public void createPanel()
    {
      setLayout(new BorderLayout());

      setBorder( new EmptyBorder(20, 50, 20 ,50));
      Box bx = Box.createVerticalBox();
      add(bx);

      // For Oracle database default use to the following
      // UrlTF = addTextField(bx, "Database URL:",
      //     "jdbc:oracle:thin:@kahuna.sdsc.edu:1549:pdb", false);
      // String dbURL = "jdbc:mysql://kahuna.sdsc.edu:3306/DB"
      //     + "_" + EntryFactory.MODEL_IDENTIFIER 
      //     + "_" + EntryFactory.REVISION_NUMBER;
      String dbURL = "jdbc:mysql://kahuna.sdsc.edu:3306/_DATABASE_NAME_";

      UrlTF = addTextField(bx, "Database URL:", dbURL, false);
      // For Oracle database default use to the following
      // DriverTF = addTextField(bx,
      //     "JDBC Driver:", "oracle.jdbc.driver.OracleDriver", false);
      DriverTF = addTextField(bx,
		   "JDBC Driver:", "com.mysql.jdbc.Driver", false);
      UserTF = addTextField(bx,"Account:", "openmmsadmin", false);
      PasswdTF = addTextField(bx, "Password:", "", true);

      JButton conButton = new JButton("  Connect to Database  ");
      conButton.setBackground(BaseFrame.backgroundColor);
      conButton.setBorder( new BevelBorder(BevelBorder.RAISED));
      conButton.setFont(bdFont);
      conButton.addActionListener(new ConnectButtonObserver());
      Box conb = Box.createHorizontalBox();
      conb.add(conButton);
      conb.add(Box.createHorizontalGlue());
      bx.add(conb);

      bx.add(Box.createVerticalStrut(VERTICAL_STRUT_BUTTON));

      DataDirTF = addTextField(bx,
	       "mmCIF Data Dir:", dataPath, false);
      bx.add(Box.createVerticalStrut(VERTICAL_STRUT_TEXT));

      DataManifestTF = addTextField(bx,
	       "FTP Manifest:", manifest, false);
      ExcludeTF = addTextField(bx,
	       "Exclude List:", exclude, false);

      manifestButton = new JButton("  Load All Entries In Manifest  ");
      manifestButton.setBackground(BaseFrame.backgroundColor);
      manifestButton.setBorder( new BevelBorder(BevelBorder.RAISED));
      manifestButton.setFont(bdFont);
      manifestButton.addActionListener(new LoadManifestButtonObserver());
      Box manib = Box.createHorizontalBox();
      manib.add(manifestButton);
      manib.add(Box.createHorizontalGlue());
      bx.add(manib);

      bx.add(Box.createVerticalStrut(VERTICAL_STRUT_BUTTON));

      FilenameTF = addTextField(bx, "Filename:",
			"../dev/openmms/data/lists/StructureIDs.list", false);

      loadListButton = new JButton("  Load Entries in File  ");
      loadListButton.setBackground(BaseFrame.backgroundColor);
      loadListButton.setBorder( new BevelBorder(BevelBorder.RAISED));
      loadListButton.setFont(bdFont);
      loadListButton.addActionListener(new LoadListButtonObserver());

      stopButton = new JButton("  Stop  ");
      stopButton.setBackground(BaseFrame.stopColor);
      stopButton.setBorder( new BevelBorder(BevelBorder.RAISED));
      stopButton.setFont(bdFont);
      stopButton.addActionListener(new stopButtonObserver());
      stopButton.setEnabled(false);

      Box llb = Box.createHorizontalBox();
      llb.add(loadListButton);
      llb.add(Box.createHorizontalGlue());
      llb.add(stopButton);
      llb.add(Box.createHorizontalStrut(50));
      bx.add(llb);

      bx.add(Box.createVerticalStrut(VERTICAL_STRUT_BUTTON));

      EntriesTF = addTextField(bx, "List of Entry Names:", "3ebx", false);

      singleLoadButton = 
	new JButton("   Load this List of Entries   ");
      singleLoadButton.setBackground(BaseFrame.backgroundColor);
      singleLoadButton.setBorder( new BevelBorder(BevelBorder.RAISED));
      singleLoadButton.setFont(bdFont);
      singleLoadButton.addActionListener(new SingleLoadButtonObserver());

      deleteButton = new JButton("  Delete this List of Entries  ");
      deleteButton.setBackground(BaseFrame.backgroundColor);
      deleteButton.setBorder( new BevelBorder(BevelBorder.RAISED));
      deleteButton.setFont(bdFont);
      deleteButton.addActionListener(new deleteButtonObserver());

      Box slb = Box.createHorizontalBox();
      slb.add(singleLoadButton);
      slb.add(Box.createHorizontalGlue());
      slb.add(Box.createHorizontalStrut(100));
      slb.add(deleteButton);
      slb.add(Box.createHorizontalStrut(100));
      bx.add(slb);

      bx.add(Box.createVerticalStrut(VERTICAL_STRUT_BUTTON));

      JLabel jl = new JLabel("Message Log");
      jl.setFont(bdFont);
      jl.setForeground(Color.black);
      Box mlb = Box.createHorizontalBox();
      mlb.add(jl);
      mlb.add(Box.createHorizontalGlue());
      bx.add(mlb);

      bx.add(Box.createVerticalStrut(VERTICAL_STRUT_TEXT));
      
      msgs = new JTextArea(15, 70);
      msgs.setFont(tFont);
      bx.add(new JScrollPane(msgs));
      
      bx.add(Box.createVerticalStrut(VERTICAL_STRUT_BUTTON));

      JButton exitButton = new JButton("  Exit  ");
      exitButton.setBackground(BaseFrame.backgroundColor);
      exitButton.setBorder( new BevelBorder(BevelBorder.RAISED));
      exitButton.setFont(bdFont);
      exitButton.addActionListener(new ExitButtonObserver());
      Box elb = Box.createHorizontalBox();
      elb.add(exitButton);
      elb.add(Box.createHorizontalGlue());
      bx.add(elb);
    }

  protected JTextField addTextField(Box bvert, String name,
			     String value, boolean passwd)
    {
      int textWidth = 56;

      JPanel bh = new JPanel();
      bh.setLayout( new BorderLayout());

      bvert.add(bh);
      bvert.add(Box.createVerticalStrut(VERTICAL_STRUT_TEXT));

      JPanel lp = new JPanel();
      lp.setLayout(new BorderLayout());
      JLabel lab = new JLabel(name + "  ", JLabel.RIGHT);
      lab.setFont(dFont);
      lab.setForeground(Color.black);
      
      Dimension d = lab.getPreferredSize();
      // should go through all the labels and find the max rather than use 180
      lp.setPreferredSize(new Dimension(180, (int) d.getHeight()));
      lp.setBackground(BaseFrame.backgroundColor);
      lp.add(lab, BorderLayout.EAST);
      bh.add(lp, BorderLayout.WEST);

      JTextField text;
      if (passwd)
	{
	  text = new JPasswordField(value, textWidth);
	}
      else
	{
	  text = new JTextField(value, textWidth);
	}
      text.setFont(tFont);
      text.setEditable(true);
      bh.add(text);
      return text;
    }

  public void logMessage(String s)
    {
      logString(s + "\n");
    }

  public void logString(String s)
    {
      panelWrite(s);
      try
	{
	  if (logFileWriter != null)
	    {
	      logFileWriter.write(s);
	      logFileWriter.flush();
	    }
	}
      catch(IOException e)
	{
	  // CANNOT call logException() FROM HERE (recursion)
	  System.out.println("********** MESSAGE LOG ERROR **********");
	  System.out.println("ERROR WRITING TO MESSAGE.LOG FILE: " + e);
	  e.printStackTrace();
	}
    }

  // This routine may be called from both the Event handling and
  // the Worker threads
  synchronized private void panelWrite(final String s)
    {
      Runnable doWrite = new Runnable()
	{
	  public void run()
	    {
	      msgs.append(s);
	    }
	};
      SwingUtilities.invokeLater(doWrite);
    }

  public void logException(Throwable t, String title,
			   String exceptionType, String where,
			   String cause, String other,
			   boolean doStackTrace)
    {
      StringBuffer m = new StringBuffer();
      m.append("\n\n********** " + title + " **********");
      m.append("\n  " + exceptionType + " in " + where);
      if (cause != null)
	{
	  m.append("\n  " + cause);
	}
      m.append("\n  Exception Description: " + t.toString());
      if (other != null)
	{
	  m.append("\n  " + other);
	}
      if (doStackTrace)
	{
	  m.append("\n  Stack Trace\n");
	  StringWriter sw = new StringWriter();
	  t.printStackTrace(new PrintWriter(sw));
	  m.append(sw.toString());
	}
      m.append("\n********** end of exception report **********\n");
      logString(m.toString());
    }

  class ExitButtonObserver implements ActionListener, Serializable
  {
    public void actionPerformed(ActionEvent e)
      {
	dbLoader.closeConnection();
	System.exit(0);
      }
  }

  class ConnectButtonObserver implements ActionListener, Serializable
  {
    public void actionPerformed(ActionEvent e)
      {
	String url = UrlTF.getText();
	String driver = DriverTF.getText();
	String user = UserTF.getText();
	String pswd = PasswdTF.getText();
	
	logMessage("Attempting to connect to database");
	logMessage("    At URL: " + url);
	logMessage("    Using driver: " + driver);
	logMessage("    User Name: " + user);

	try
	  {
	    con = dbLoader.connect(url, driver, user, pswd);
	  }
	catch (Exception exc)
	  {
	    // could just be a bad user password
	    logMessage("*** FAILED TO ESTABLISH DB CONNECTION ***");
	    logMessage(exc.toString());
	    return;
	  }
	logMessage("Connected to database");

	Statement stmt = null;
	try
	  {
	    boolean versionFound = false;
	    stmt = con.createStatement();
 	    String sstr = "SELECT "  + SYSTEM_DATA_BANK_NAME + ", " 
	      + SYSTEM_VERSION_NAME + " FROM " + SYSTEM_TABLE_NAME;
	    ResultSet rs = stmt.executeQuery(sstr);
	    while (rs.next())
	      {
		String dbn = rs.getString(SYSTEM_DATA_BANK_NAME);
		String svn = rs.getString(SYSTEM_VERSION_NAME);
		logMessage("Databank " + dbn + " version " + svn);
		versionFound = true;
	      }
	    if ( ! versionFound)
	      {
		logMessage("*** DATABANK VERSION NOT FOUND ***");
		logMessage
		  ("\tMMS System may not have been initialized, or DB may"
		   + "\n\tbe locked by another connection");
	      }
	    // Make sure we have a consistant database.
	    dbLoader.dbCheck();
	  }
	catch (Exception exc)
	  {
	    logMessage("CANNOT access MMS System tables");
	    logMessage
	      ("\tMMS Schema has probably not been created and initialized");
	    logMessage(exc.toString());
	    con = null;
	  }
	finally
	  {
	    if (stmt != null)
	      {
		try
		  {
		    stmt.close();
		  }
		catch (SQLException exc)
		  {
		    logMessage("SQLException while closing JDBC statement ");
		    logMessage(exc.toString());
		  }
	      }
	  }
      }
  }

  class LoadManifestButtonObserver implements ActionListener, Serializable
  {
    public void actionPerformed(ActionEvent e)
      {
	if (con == null)
	  {
	    logMessage("LOAD ERROR: Not connected to database");
	    return;
	  }
	final String useURL = DataDirTF.getText();
	final String manifest = DataManifestTF.getText();
	logMessage("Reading data files listed in the manifest:\n  "
		   + manifest);
	logMessage("Reading data from URL:\n  " + useURL);

	String excludefilename = ExcludeTF.getText();
	try
	  {
	    HashSet exclude = readExcludeList(excludefilename);
	    final String[] list = dbLoader.readManifest(manifest, exclude);

	    setLoadInProgress(true);
	    worker = new SwingWorker()
	      {
		public Object construct()
		  {
		    return dbLoader.loadEntries(list, useURL);
		  }
		public void finished()
		  {
		    setLoadInProgress(false);
		    logMessage("Load list_file Done.\n");
		  }
	      };
	    worker.start();
	  }
	catch (Exception exc)
	  {
	    logException(exc, "LOAD ENTRY LIST FROM MANIFEST FAILED",
			 "(General) Exception",
			 "PanelSet.ManifestButtonObserver",
			 null, null, true);
	  }
      }

    private HashSet readExcludeList(String exfile)
	throws IOException
      {
	HashSet hs = new HashSet();
	File f = new File(exfile);
	if( ! f.exists())
	  {
	    logMessage("Exclude File: " + exfile + " not found.");
	  }
	else
	  {
	    final FileReader fr = new FileReader(f);
	    StreamTokenizer st = new StreamTokenizer(fr);
	    st.resetSyntax();
	    st.wordChars('A', 'Z');
	    st.wordChars('a', 'z');
	    // numbers are treated as words
	    st.wordChars('0', '9');
	    st.wordChars('_', '_');  // underscore allowed
	    st.wordChars('.', '.');  // dot allowed
	    st.whitespaceChars(',', ',');
	    st.commentChar('#');     // file may have comment lines
	    
	    int ttype;
	      eof_found:
	    while (true)
	      {
		ttype = st.nextToken();
		switch(ttype)
		  {
		  case StreamTokenizer.TT_EOF:
		    break eof_found;
		  case StreamTokenizer.TT_WORD:
		    hs.add(st.sval);
		    break;
		  }
	      }
	  }
	return hs;
      }
  }

  class LoadListButtonObserver implements ActionListener, Serializable
  {
    public void actionPerformed(ActionEvent e)
      {
	if (con == null)
	  {
	    logMessage("LOAD ERROR: Not connected to database");
	    return;
	  }
	String filename = FilenameTF.getText();
	File f = new File(filename);
	if( ! f.exists())
	  {
	    logMessage("File: " + filename + " not found.");
	    return;
	  }
	final String useURL = DataDirTF.getText();
	final String manifest = DataManifestTF.getText();
	logMessage("Reading data files from directory:\n  " + useURL);
	logMessage("Using data manifest:\n  " + manifest);
	logMessage("Reading entry list from file:\n  " 
		   + f.getAbsolutePath());
	try
	  {
	    final FileReader fr = new FileReader(f);
	    setLoadInProgress(true);

	    worker = new SwingWorker()
	      {
		public Object construct()
		  {
		    return dbLoader.loadEntries(fr, useURL, manifest);
		  }
		public void finished()
		  {
		    setLoadInProgress(false);
		    logMessage("Load list_file Done.\n");
		  }
	      };
	    worker.start();
	  }
	catch (Exception exc)
	  {
	    logException(exc, "LOAD ENTRY LIST FROM FILE FAILED",
			 "(General) Exception",
			 "PanelSet.LoadListButtonObserver",
			 "while loading entry list file:" + filename,
			 null, true);
	  }
      }
  }

  class SingleLoadButtonObserver implements ActionListener, Serializable
  {
    public void actionPerformed(ActionEvent e)
      {
	if (con == null)
	  {
	    logMessage("Load ERROR: Not connected to database");
	    return;
	  }
	String entries = EntriesTF.getText();
	logMessage("Loading Entry List");
	final Reader sr = new StringReader(entries);
	try
	  {
	    final String useURL = DataDirTF.getText();
	    final String manifest = DataManifestTF.getText();
	    setLoadInProgress(true);

	    worker = new SwingWorker()
	      {
		public Object construct()
		  {
		    String rv = dbLoader.loadEntries(sr, useURL, manifest);
		    return rv;
		  }
		public void finished()
		  {
		    setLoadInProgress(false);
		    logMessage("\nLoads Done.\n");
		  }
	      };
	    worker.start();
	  }
	catch (Exception exc)
	  {
	    logException(exc, "LOAD ENTRY LIST FAILED",
				      "(General) Exception",
				      "PanelSet.SingleLoadButtonObserver",
				      "while loading entry list:" + entries,
				      null, true);
	  }
      }
  }

  class deleteButtonObserver implements ActionListener, Serializable
  {
    public void actionPerformed(ActionEvent e)
      {
	if (con == null)
	  {
	    logMessage("Delete Error: Not connected to database");
	    return;
	  }
	String entries = EntriesTF.getText();
	logMessage("Deleting Entrys");
	final Reader sr = new StringReader(entries);
	try
	  {
	    setLoadInProgress(true);
	    worker = new SwingWorker()
	      {
		public Object construct()
		  {
		    return dbLoader.deleteEntries(sr);
		  }
		public void finished()
		  {
		    setLoadInProgress(false);
		    logMessage("Deletes Done.\n");
		  }
	      };
	    worker.start();
	  }
	catch (Exception exc)
	  {
	    logException(exc, "DELETE ENTRY LIST FAILED",
			 "(General) Exception",
			 "PanelSet.DeleteButtonObserver",
			 "while deleting entry list: " + entries,
			 null, true);
	  }
      }
  }

  class stopButtonObserver implements ActionListener, Serializable
  {
    public void actionPerformed(ActionEvent e)
      {
	dbLoader.setStop(true);
	logMessage("Stop requested (after current load_entry completed)");
      }
  }

  private boolean loadInProgress = false;

  public void setLoadInProgress(boolean lip)
    {
      if (lip == loadInProgress)
	{
	  return;
	}
      loadInProgress = lip;

      deleteButton.setEnabled( ! lip);
      singleLoadButton.setEnabled( ! lip);
      loadListButton.setEnabled( ! lip);
      manifestButton.setEnabled( ! lip);

      stopButton.setEnabled(lip);
    }
}


