//
// DBServ.java,v 1.3 2003/05/09 00:44:12 dsg Exp
//
// Copyright 2001 The Regents of the University of California
// All Rights Reserved
//
// OpenMMS was developed by Dr. Douglas S. Greer at the San Diego
// Supercomputer Center, a research unit of the University of California,
// San Diego.  Support for this effort was provided by NSF through the
// Protein Data Bank (Grant DBI-9814284) and the National Partnership for
// Advanced Computational Infrastructure (Grant ACI-9619020)
//
// Permission to use, copy, modify and distribute any part of OpenMMS for
// educational, research and non-profit purposes, without fee, and
// without a written agreement is hereby granted, provided that the above
// copyright notice, this paragraph and the following paragraphs appear
// in all copies.
//
// Those desiring to incorporate this OpenMMS into commercial products or
// use for commercial purposes should contact the Technology Transfer
// Office, University of California, San Diego, 9500 Gilman Drive, La
// Jolla, CA 92093-0910, Ph: (619) 534-5815, FAX: (619) 534-7345.
//
// In no event shall the University of California be liable to any party
// for direct, indirect, special, incidental, or consequential damages,
// including lost profits, arising out of the use of this OpenMMS, even
// if the University of California has been advised of the possibility of
// such damage.
//
// The OpenMMS provided herein is on an "as is" basis, and the
// University of California has no obligation to provide maintenance,
// support, updates, enhancements, or modifications.  The University of
// California makes no representations and extends no warranties of any
// kind, either implied or express, including, but not limited to, the
// implied warranties of merchantability or fitness for a particular
// purpose, or that the use of the OpenMMS will not infringe any patent,
// trademark or other rights.

package org.rcsb.openmms.apps.dbserv;

import java.io.*;
import java.util.*;
import java.awt.*;
import java.awt.event.*;
import java.sql.*;
import javax.swing.*;
import javax.swing.text.*;
import javax.swing.border.*;
import javax.naming.*;

import org.omg.CORBA.ORB;
import org.omg.PortableServer.POAPackage .*;
import org.omg.DsLSRMacromolecularStructure.*;

import org.rcsb.openmms.cifparse.*;
import org.rcsb.openmms.util.*;
import org.rcsb.openmms.entry.*;
import org.rcsb.openmms.loader.*;


/**
 * Top-level main program for MMS Corba relational database server.
 *
 * @author Douglas S. Greer
 * @version 1.3
 */
public class DBServ
{
  // basic status debug messages
  public static int debug = 3;

  public static ORB orb;

  String frameName;
  ServFrame sframe;

  ServerHandler servh;
  DataItemList dilist;

  String iorFileName = "DBServ.ior";
  String iorFilePath;

  String logDir;
  String logFile;
  String nameServURL;
  String serviceName;
  boolean useGUI;
  String dbAccount;
  String dbDriver;
  String dbPassword;
  String dbURL;

  Connection Conn = null;

  public static void main(String args[])
    {
      DBServ cfs = new DBServ("MMS/Database Server");
      cfs.init(args);
      // Must be last call; does not return
      cfs.eventLoop();
    }

  public DBServ(String name)
    {
      frameName = name;
    }

  public void init(String[] args)
    {
      try
	{
	  logDir = parseArguments("logdir", args);
	  logFile = parseArguments("logfile", args);
	  useGUI = parseArgumentsBool("GUI", args);
	  dbAccount = parseArguments("DatabaseAccount", args);
	  dbURL = parseArguments("DatabaseURL", args);
	  dbDriver = parseArguments("DatabaseDriver", args);
	  dbPassword = parseArguments("DatabasePassword", args);

	  nameServURL = parseArguments("nameserv", args);
	  if (nameServURL == null)
	    {
	      nameServURL = "iiopname://corba.sdsc.edu:5001";
	    }
	  serviceName = parseArguments("servicename", args);
	  if (serviceName == null)
	    {
	      serviceName = "OpenMMS_Server";
	    }

	  String debugStr = parseArguments("debug", args);
	  if (debugStr != null)
	    {
	      // debug <= 0 report only fatal errors
	      // debug >= 1 report recoverable error messages
	      // debug >= 3 basic status messages
	      // debug >= 5 trace
	      // debug >= 7 dump various data structures
	      debug = Integer.parseInt(debugStr);
	    }

	  // Bind DataItems to CatLoaders
	  LinkTable ltable = new LinkTable();
	  LoaderLink[] links = ltable.createLinkTable();
	  dilist = new DataItemList();
	  buildDataItemList(dilist, links);

	  initOrb(args);
 	  servh = new ServerHandler(debug, orb);

	  // No messages can be logged until GUI is created.
	  initGUI(servh);

	  servh.logMessage("Reference MMS Corba Server Started at "
			  + (new java.util.Date()).toString());
	  EntryCache ec = new BasicRAMEntryCache();
	  ec.setDebug(debug);
	  servh.setEntryCache(ec);
	}
      catch(CifParseException e)
	{
	  servh.fatalError
	    ("Parse Exception during DBServ.init()", e);
	}
      try
	{
	  String msg = "\nAttempting to connect to database using"
	    + "\n    URL: " + dbURL
	    + "\n    Driver: " + dbDriver
	    + "\n    Account: " + dbAccount;
	  servh.logMessage(msg);
	  System.out.println(msg);

	  Conn = connectToDatabase(dbURL, dbDriver, dbAccount, dbPassword);

	  msg = "Database Connection Established";
	  servh.logMessage(msg);
	  System.out.println(msg);
	}
      catch (Exception e)
	{
	  String msg = "\nFAILED TO CONNECT TO DATABASE\n";
	  servh.fatalError(msg, e);
	}
      try
	{
	  // Where to find find files on cache misses
 	  RDBEntryFoundry efed 
 	    = new RDBEntryFoundry(servh, Conn);
 	  efed.setDebug(debug);
 	  servh.addEntryFoundry(efed);
	  servh.setEntryDirectory(efed);

	  String msg = "DB Entry Foundry Created.\n    Model: "
	    + EntryFactory.MODEL_IDENTIFIER
	    + "\n    Revision_number: " + EntryFactory.REVISION_NUMBER;
          servh.logMessage(msg);
	  System.out.println(msg);
	}
      catch (Exception e)
	{
	  servh.fatalError("FAILED TO CREATE RDB FOUNDRY", e);
	}
      try
	{
	  // Initialize Corba Server
	  startCorbaServer(args);
	  String msg = "Cif Corba Server Ready";
	  servh.logMessage(msg);
	  System.out.println(msg);
	}
      catch (Exception e)
	{
	  servh.fatalError("\nFAILED TO START CORBA SERVER\n", e);
	}
    }

  private void buildDataItemList(DataItemList dilist, LoaderLink[] links)
    throws CifParseException
    {
      DataItem di;
      String itemName;

      for (int i = 0; i < links.length; i++)
	{
	  itemName = "_" + links[i].getCatName() + 
	    "." + links[i].getItemName();
	  di = new DataItem(itemName);
	  di.setFieldCode(links[i].getFieldCode());
	  di.setCatLoader(links[i].getCatLoader());
	  dilist.add(di);
	}
    }

  public void initGUI(ServerHandler ah)
    {
      if (useGUI)
	{
	  sframe = new ServFrame(frameName, ah, logDir, logFile);
	  sframe.pack();
	  sframe.setVisible(true);
	}
      else
	{
	  ServPanel sp = new ServPanel(false, logDir, logFile);
	  ah.setMessageHandler(sp);
	}
    }
  
  public void initOrb(String args[])
    {
      // create and initialize Default ORB
      orb = ORB.init(args, null);
    }

  public void startCorbaServer(String args[])
    throws DataAccessException, NamingException, ServantNotActive,
	   WrongPolicy
    {
      RDBEntryFactoryImpl si = null;
      org.omg.CORBA.Object ref = null;
      // create servant and register it with the ORB
      si = new RDBEntryFactoryImpl(servh, debug);
      ref = servh.getRootPoa().servant_to_reference(si);

      // If no exceptions have been thrown so far we are
      // ready to advertise the MMS service
      bindNameServer(ref, nameServURL, serviceName);
    }

  public Connection connectToDatabase(String url, String driver,
				    String user, String passwd)
    throws SQLException, ClassNotFoundException
    {
      if (Conn != null)
	{
	  closeConnection();
	}
      Class.forName(driver);
      return DriverManager.getConnection(url, user, passwd);
    }

  public void closeConnection()
    {
      try
	{
	  if (Conn != null)
	    {
	      Conn.close();
	      Conn = null;
	    }
	}
      catch (SQLException se)
	{
	  servh.logException(se, "CLOSE JDBC CONNECTION FAILED",
		       "SQLException", "DBLoader.closeConnection()",
		       null, null, false);
	}
    }
  
  private void bindNameServer(org.omg.CORBA.Object ref,
			      String nsurl, String sname)
    throws NamingException
    {
	  Hashtable nameEnv = new Hashtable(11);
	  
     	  nameEnv.put("java.naming.provider.url", nsurl);
     	  nameEnv.put("java.naming.factory.initial",
     		  "com.sun.jndi.cosnaming.CNCtxFactory");
	  Context ctx = new InitialContext(nameEnv);
	  ctx.rebind(sname, ref);
	  String msg = "Bind to JNDI URL:" + nsurl
			  + "\n\twith name " + sname + " Successful";
	  servh.logMessage(msg);
	  System.out.println(msg);
    }

  private void writeIorFile(org.omg.CORBA.Object ref)
    throws IOException
    {
      // Remove the old ior file and create a new one.
      File f = new File(iorFilePath);
      if(f.exists())
	{
	  f.delete();
	}
      
      FileWriter fout = new FileWriter(f);
      
      // create the IOR string
      String ior = orb.object_to_string(ref);
      servh.logMessage(ior);
      // write the IOR string out
      fout.write(ior);
      fout.close();
    }

  public String parseArguments(String param, String[] argv)
    {
      for(int i=0; i<argv.length; i++)
	{
	  if(argv[i].startsWith(param))
	    {
	      int index=argv[i].indexOf('=');
	      if(index!=-1) return (argv[i].substring(index+1));
	    }
	}
      return null;
    }

  public boolean parseArgumentsBool(String param, String[] argv)
    {
      for(int i=0; i<argv.length; i++)
	if(argv[i].equalsIgnoreCase(param)) return true;

      return false;
    }

  public void eventLoop()
    {
      try
	{
	  // wait for invocations from clients
	  java.lang.Object sync = new java.lang.Object();
	  synchronized (sync) {
	    sync.wait();
	  }
	}
      catch (Exception e)
	{
	  servh.fatalError("Event Loop Error", e);
	}
    }
}

class ServFrame extends JFrame implements MessageHandler
{
  static public Color backgroundColor = new Color(205, 190, 240);

  ServPanel tp;

  public ServFrame(String name, ServerHandler servh,
		   String logDir, String logName)
    {
      super(name);
      createFrame(logDir, logName);

      servh.setMessageHandler(this);
    }

  public void createFrame(String logDir, String logName)
    {
      java.awt.Container fcp = getContentPane();
      
      tp = new ServPanel(true, logDir, logName);
      JPanel pn = tp.getPanel();
      pn.setBackground(backgroundColor);
      fcp.add(pn);
    }
  
  public void logString(String s)
    {
      tp.logString(s);
    }

  public void logMessage(String s)
    {
      tp.logMessage(s);
    }
  public void logException(Throwable t, String title,
			   String exceptionType, String where,
			   String cause, String other, boolean doStackTrace)
    {
      tp.logException(t, title, exceptionType, where,
		      cause, other, doStackTrace);
    }
}

class ServPanel implements MessageHandler
{
  boolean haveGUI;
  JTextArea msgs;
  JPanel panel;

  BufferedWriter debugFileWriter;

  public ServPanel(boolean initGUI, String logDir, String logName)
    {
      haveGUI = initGUI;
      if (haveGUI)
	{
	  createPanel();
	}
      if (logDir == null)
	{
	  logDir = "";
	}
      else if (logDir.length() > 0 && ! logDir.endsWith("/"))
	{
	  logDir = logDir + "/";
	}

      if (logName == null || logName.length() == 0)
	{
	  logName = "DBSERV.LOG";
	}
      try
	{
	  debugFileWriter = new BufferedWriter(new FileWriter
					       (logDir + logName));
	}
      catch(IOException e)
	{
	  System.out.println("Cannot open Log file: " + e);
	}
    }

  public JPanel getPanel()
    {
      return panel;
    }

  public void createPanel()
    {
      panel = new JPanel();
      panel.setLayout(new BorderLayout());

      panel.setBorder( new EmptyBorder(20, 40, 20 ,40));
      Box bigb = Box.createVerticalBox();
      panel.add(bigb);

      JLabel jl = new JLabel("MMS Database Server Log Messages");
      jl.setFont(new Font("Dialog", Font.BOLD, 14));
      jl.setForeground(Color.black);
      bigb.add(jl);

      bigb.add(Box.createVerticalStrut(5));

      msgs = new JTextArea(6, 30);
      msgs.setFont(new Font("Serif", Font.PLAIN, 12));
      bigb.add(new JScrollPane(msgs));
      
      bigb.add(Box.createVerticalStrut(20));

      JButton exit_button = new JButton("  Exit  ");
      exit_button.setBackground(ServFrame.backgroundColor);
      exit_button.setBorder( new BevelBorder(BevelBorder.RAISED));
      exit_button.setFont(new Font("Dialog", Font.PLAIN, 14));
      exit_button.addActionListener(new ExitButtonObserver());
      bigb.add(exit_button);}

  public void logMessage(String s)
    {
      
      logString(s + "\n");
    }

  public void logString(String s)
    {
      if (haveGUI)
	{
	  msgs.append(s);
	}
      try
	{
	  debugFileWriter.write(s);
	  debugFileWriter.flush();
	}
      catch(IOException e)
	{
	  System.out.println("Error writing to debug log file: " + e);
	}
    }

  public void logException(Throwable t, String title,
			   String exceptionType, String where,
			   String cause, String other, boolean doStackTrace)
    {
      StringBuffer m = new StringBuffer();
      m.append("\n********** " + title + " **********");
      m.append("\n  " + exceptionType + " in " + where);
      if (cause != null)
	{
	  m.append("\n  " + cause);
	}
      m.append("\n  Exception Description: " + t.toString());
      if (other != null)
	{
	  m.append("\n  " + other);
	}
      m.append("\n  Stack Trace\n");

      if (doStackTrace)
	{
	  StringWriter sw = new StringWriter();
	  t.printStackTrace(new PrintWriter(sw));
	  m.append(sw.toString());
	}
      m.append("\n********** end of exception report **********\n");
      logMessage(m.toString());
    }

  class ExitButtonObserver implements ActionListener, Serializable
  {
    public void actionPerformed(ActionEvent e)
      {
	System.exit(0);
      }
  }
}
