//
// ServPanel.java,v 1.6 2002/03/22 21:31:10 dsg Exp
//
// Copyright 2001 The Regents of the University of California
// All Rights Reserved
//
// OpenMMS was developed by Dr. Douglas S. Greer at the San Diego
// Supercomputer Center, a research unit of the University of California,
// San Diego.  Support for this effort was provided by NSF through the
// Protein Data Bank (Grant DBI-9814284) and the National Partnership for
// Advanced Computational Infrastructure (Grant ACI-9619020)
//
// Permission to use, copy, modify and distribute any part of OpenMMS for
// educational, research and non-profit purposes, without fee, and
// without a written agreement is hereby granted, provided that the above
// copyright notice, this paragraph and the following paragraphs appear
// in all copies.
//
// Those desiring to incorporate this OpenMMS into commercial products or
// use for commercial purposes should contact the Technology Transfer
// Office, University of California, San Diego, 9500 Gilman Drive, La
// Jolla, CA 92093-0910, Ph: (619) 534-5815, FAX: (619) 534-7345.
//
// In no event shall the University of California be liable to any party
// for direct, indirect, special, incidental, or consequential damages,
// including lost profits, arising out of the use of this OpenMMS, even
// if the University of California has been advised of the possibility of
// such damage.
//
// The OpenMMS provided herein is on an "as is" basis, and the
// University of California has no obligation to provide maintenance,
// support, updates, enhancements, or modifications.  The University of
// California makes no representations and extends no warranties of any
// kind, either implied or express, including, but not limited to, the
// implied warranties of merchantability or fitness for a particular
// purpose, or that the use of the OpenMMS will not infringe any patent,
// trademark or other rights.

package org.rcsb.openmms.apps.refserv;

import java.io.*;
import java.awt.*;
import java.awt.event.*;

import javax.swing.*;
import javax.swing.text.*;
import javax.swing.border.*;

import org.rcsb.openmms.util.*;

/**
 * Java Swing JPanel for the MMS Corba reference server.  Contains a
 * constructor which generates all GUI objects for this application.
 *
 * @author Douglas S. Greer
 * @version 1.6
 */
public class ServPanel implements MessageHandler
{
  boolean haveGUI;
  JTextArea msgs;
  JPanel panel;

  BufferedWriter debugFileWriter;

  public ServPanel(boolean initGUI, String logDir, String logName)
    {
      haveGUI = initGUI;
      if (haveGUI)
	{
	  createPanel();
	}
      if (logDir == null)
	{
	  logDir = "";
	}
      else if (logDir.length() > 0 && ! logDir.endsWith("/"))
	{
	  logDir = logDir + "/";
	}

      if (logName == null || logName.length() == 0)
	{
	  logName = "REFSERV.LOG";
	}
      try
	{
	  debugFileWriter = new BufferedWriter(new FileWriter
					       (logDir + logName));
	}
      catch(IOException e)
	{
	  System.out.println("Cannot open Log file: " + e);
	}
    }

  public JPanel getPanel()
    {
      return panel;
    }

  public void createPanel()
    {
      panel = new JPanel();
      panel.setLayout(new BorderLayout());

      panel.setBorder( new EmptyBorder(20, 50, 20 ,50));
      Box bigb = Box.createVerticalBox();
      panel.add(bigb);

      JLabel jl = new JLabel("MMS Cif File Server Log Messages");
      jl.setFont(new Font("Dialog", Font.BOLD, 20));
      jl.setForeground(Color.black);
      bigb.add(jl);

      bigb.add(Box.createVerticalStrut(5));

      msgs = new JTextArea(6, 30);
      msgs.setFont(new Font("Serif", Font.PLAIN, 16));
      bigb.add(new JScrollPane(msgs));
      
      bigb.add(Box.createVerticalStrut(20));

      JButton exit_button = new JButton("  Exit  ");
      exit_button.setBackground(ServFrame.backgroundColor);
      exit_button.setBorder( new BevelBorder(BevelBorder.RAISED));
      exit_button.setFont(new Font("Dialog", Font.PLAIN, 20));
      exit_button.addActionListener(new ExitButtonObserver());
      bigb.add(exit_button);}

  public void logMessage(String s)
    {
      
      logString(s + "\n");
    }

  public void logString(String s)
    {
      if (haveGUI)
	{
	  msgs.append(s);
	}
      try
	{
	  debugFileWriter.write(s);
	  debugFileWriter.flush();
	}
      catch(IOException e)
	{
	  System.out.println("Error writing to debug log file: " + e);
	}
    }

  public void logException(Throwable t, String title,
			   String exceptionType, String where,
			   String cause, String other, boolean doStackTrace)
    {
      StringBuffer m = new StringBuffer();
      m.append("\n********** " + title + " **********");
      m.append("\n  " + exceptionType + " in " + where);
      if (cause != null)
	{
	  m.append("\n  " + cause);
	}
      m.append("\n  Exception Description: " + t.toString());
      if (other != null)
	{
	  m.append("\n  " + other);
	}
      m.append("\n  Stack Trace\n");

      if (doStackTrace)
	{
	  StringWriter sw = new StringWriter();
	  t.printStackTrace(new PrintWriter(sw));
	  m.append(sw.toString());
	}
      m.append("\n********** end of exception report **********\n");
      logMessage(m.toString());
    }

  class ExitButtonObserver implements ActionListener, Serializable
  {
    public void actionPerformed(ActionEvent e)
      {
	System.exit(0);
      }
  }
}



