//
// CatUtil.java,v 1.6 2003/03/21 23:59:01 dsg Exp
//
// Copyright 2001 The Regents of the University of California
// All Rights Reserved
//
// OpenMMS was developed by Dr. Douglas S. Greer at the San Diego
// Supercomputer Center, a research unit of the University of California,
// San Diego.  Support for this effort was provided by NSF through the
// Protein Data Bank (Grant DBI-9814284) and the National Partnership for
// Advanced Computational Infrastructure (Grant ACI-9619020)
//
// Permission to use, copy, modify and distribute any part of OpenMMS for
// educational, research and non-profit purposes, without fee, and
// without a written agreement is hereby granted, provided that the above
// copyright notice, this paragraph and the following paragraphs appear
// in all copies.
//
// Those desiring to incorporate this OpenMMS into commercial products or
// use for commercial purposes should contact the Technology Transfer
// Office, University of California, San Diego, 9500 Gilman Drive, La
// Jolla, CA 92093-0910, Ph: (619) 534-5815, FAX: (619) 534-7345.
//
// In no event shall the University of California be liable to any party
// for direct, indirect, special, incidental, or consequential damages,
// including lost profits, arising out of the use of this OpenMMS, even
// if the University of California has been advised of the possibility of
// such damage.
//
// The OpenMMS provided herein is on an "as is" basis, and the
// University of California has no obligation to provide maintenance,
// support, updates, enhancements, or modifications.  The University of
// California makes no representations and extends no warranties of any
// kind, either implied or express, including, but not limited to, the
// implied warranties of merchantability or fitness for a particular
// purpose, or that the use of the OpenMMS will not infringe any patent,
// trademark or other rights.

package org.rcsb.openmms.util;

import java.util.*;
import java.text.*;

import org.rcsb.openmms.cifparse.*;

/**
 * Base class for mmCIF Category loaders
 *
 * @author Douglas S. Greer
 * @version 1.6
 */
public abstract class CatUtil
{
  static DecimalFormat df = new DecimalFormat();

  static boolean LenientParse = true;

  public static void setLenientParse(boolean lp)
    {
      LenientParse = lp;
    }

  public float cifFloat(String v)
    {
      float fr;

      try
	{
	  fr = Float.parseFloat(v);
	}
      catch (NumberFormatException e)
	{
	  if (v.equals(".") || v.equals("?"))
	    {
	      // The Java static float NaN (Not-a-Number) is used to denote
	      // "." and "?" (not-appropriate or unknown) float item values.
	      // Some database implementations (e.g. mySQL) do not
	      // understand IEEE 754 NaN data types. Therefore
	      // the largest (or smallest) floating point number should be
	      // used instead. In such cases replace the Float.NaN below with:
	      // fr = Float.MAX_VALUE;
	      // For systems that suport NaN's use the following line:
	      // fr = Float.NaN;
	      fr = Float.MAX_VALUE;
	    }
	  else if ( ! LenientParse)
	    {
	      // If we are not in lenient parsing mode, thats it
	      throw e;
	    }
	  else
	    {
	      try
		{
		  Number numb;
		  // trim string
		  String t = clipString(v);
		  if (t.equalsIgnoreCase("INFINITY")
		      || t.equalsIgnoreCase("INFINITE")
		      || t.equalsIgnoreCase("INFINIT")
		      || t.equalsIgnoreCase("INFINI"))
		    {
		      fr = Float.POSITIVE_INFINITY;
		    }
		  else
		    {
		      try
			{
			  numb = getNumber(t);
			  fr = numb.floatValue();
			}
		      catch (ParseException e2)
			{
			  // Extreme lenient parse
			  // When all else fails, set bad strings to zero
			  fr = 0.0f;
			  // throw new NumberFormatException(e2.getMessage());
			}
		    }
		}
	      catch (NumberFormatException e2)
		{
		  // TBD
		  throw e2;
		}
	    }
	}
      return fr;
    }

  public int cifInt(String v)
    {
      int ir = 0;

      try
	{
	  ir = Integer.parseInt(v);
	}
      catch (NumberFormatException e)
	{
	  // check for "." and "?" values
	  if (v.equals(".") || v.equals("?"))
	    {
	      // Java static int MIN_VALUE used to denote
	      // "." and "?" item values.
	      ir = Integer.MIN_VALUE;
	    }	  
	  else if ( ! LenientParse)
	    {
	      throw e;
	    }
	  else
	    {
	      try
		{
		  Number numb;
		  // trim string
		  String t = clipString(v);
		  try
		    {
		      numb = getNumber(t);
		      ir = numb.intValue();
		    }
		  catch (ParseException e2)
		    {
		      // Extreme lenient parse
		      // When all else fails, set bad strings to zero
		      ir = 0;

		      // throw new NumberFormatException(e2.getMessage());
		    }
		}
	      catch (NumberFormatException e2)
		{
		  // TBD
		  throw e2;
		}
	    }
	}
      return ir;
    }

  public String clipString(String v)
    {
      String t = v.trim();

      int sp = t.indexOf(' ');
      if (sp > 0)
	{
	  t = t.substring(0, sp);
	}
      if (t.length() > 1 && 
	  (t.charAt(0) == '+') || (t.charAt(0) == '~'))
	{
	  t = t.substring(1);
	}
      return t;
    }

  public Number getNumber(String v)
    throws ParseException
    {
      String t = v;

      int sl = t.length() - 1;
      if (t.charAt(sl) == 'K')
	{
	  // K is usually for Kelvin not Kilo
	  t = t.substring(0, sl);
	}
      else if (t.charAt(sl) == '%')
	{
	  // this is usually in a category requesting a percent
	  // e.g. _reflns_shell.percent_possible_all
	  t = t.substring(0, sl);
	}
      Number n = df.parse(t);
      return n;
    }

  public String cifString(String v)
    {
      // check for "." values ?
      return v;
    }

  private int searchAll(Object xe, String s,
			int len, StringToIndex sti) throws CifParseException
    {
      int ndx = -1;
 
      // Assumes that "sti.setFindValue(s)" has already been called
      for (int i = 0; i < len; i++)
	{
	  if (sti.compareToParent(xe, i))
	    {
	      ndx = i;
	      break;
	    }
	}
      return ndx;
    }

  public void setChildIndex(Object xe, ArrayList a,
			    StringToIndex sti)
    throws CifParseException
    {
      String s;
      int ndx, tx;

      if (a.size() == 0)
	{
	  return;
	}
      int len = sti.getParentSize(xe);
      for (int i = 0; i < a.size(); i++)
	{
	  if (len < 0)
	    {
	      // Parent list missing, mark all child indices with -1.
	      ndx = -1;
	    }
	  else
	    {
	      s = (String) a.get(i);
	      sti.setFindValue(s);
	      // This is a partial optimization based on the fact that
	      // most parent indices are integer lists starting from "1".
	      // So try converting the string to an int and search
	      // that approx. location in parent list before searching
	      // the entire parent list.
	      try
		{
		  tx = Integer.parseInt(s);
		  if (tx > 1 && tx <= len &&
		      sti.compareToParent(xe, tx - 1 ))
		    {
		      ndx = tx - 1;
		    }
		  else if (tx > 0 && tx < len &&
			   sti.compareToParent(xe, tx))
		    {
		      ndx = tx;
		    }
		  else
		    {
		      // optimization failed, must search the entire list
		      ndx = searchAll(xe, s, len, sti);
		    }
		}
	      catch (NumberFormatException e)
		{
		  // Index is not an Integer string 
		  // => must search the entire list
		  ndx = searchAll(xe, s, len, sti);
		}
	    }
	  sti.insertIndex(xe, i, ndx);
	}
      // If this point is reached - the entire ArrayList was found in
      // the parent list since no CifParseExceptions were thrown.
    }
}

