//
// InsertEntryBase.java,v 1.4 2002/06/19 01:55:35 dsg Exp
//
// Copyright 2001 The Regents of the University of California
// All Rights Reserved
//
// OpenMMS was developed by Dr. Douglas S. Greer at the San Diego
// Supercomputer Center, a research unit of the University of California,
// San Diego.  Support for this effort was provided by NSF through the
// Protein Data Bank (Grant DBI-9814284) and the National Partnership for
// Advanced Computational Infrastructure (Grant ACI-9619020)
//
// Permission to use, copy, modify and distribute any part of OpenMMS for
// educational, research and non-profit purposes, without fee, and
// without a written agreement is hereby granted, provided that the above
// copyright notice, this paragraph and the following paragraphs appear
// in all copies.
//
// Those desiring to incorporate this OpenMMS into commercial products or
// use for commercial purposes should contact the Technology Transfer
// Office, University of California, San Diego, 9500 Gilman Drive, La
// Jolla, CA 92093-0910, Ph: (619) 534-5815, FAX: (619) 534-7345.
//
// In no event shall the University of California be liable to any party
// for direct, indirect, special, incidental, or consequential damages,
// including lost profits, arising out of the use of this OpenMMS, even
// if the University of California has been advised of the possibility of
// such damage.
//
// The OpenMMS provided herein is on an "as is" basis, and the
// University of California has no obligation to provide maintenance,
// support, updates, enhancements, or modifications.  The University of
// California makes no representations and extends no warranties of any
// kind, either implied or express, including, but not limited to, the
// implied warranties of merchantability or fitness for a particular
// purpose, or that the use of the OpenMMS will not infringe any patent,
// trademark or other rights.

package org.rcsb.openmms.util;

import java.util.*;
import java.sql.*;

// For definition of ORB functions
import org.omg.CORBA.*;

/**
 * Base Class containing utility functions for the Relational
 * Database Entry JDBC insertion code.
 *
 * @author Douglas S. Greer
 * @version 1.4
 */
abstract public class InsertEntryBase
  implements TypeNamesSql
{
  protected int debug;

  protected Connection Conn;
  protected MessageHandler messagePanel;
  protected Statement stmt;
  
  protected int entryKey = -1;

  public InsertEntryBase(MessageHandler ps, int dbug, Connection con)
    {
      messagePanel = ps;
      debug = dbug;
      Conn = con;
    }

  protected boolean isFlagSet(byte[] bits, int flag)
    {
      if ((bits[flag/8] & (1 << (flag%8))) != 0)
	return true;
      else
	return false;
    }

  private String lastCatName = "";
  private int lastCatKey;
  private int lastCatBase;

  private void readCategoryTable(String catTableName)
    throws MmsTranslationException, SQLException
    {
      lastCatKey = -1;
      String gkk = "SELECT "
	+ CATEGORY_TABLE_KEY_NAME + ", " + CATEGORY_TABLE_NEXT_RECORD_NAME
	+ " FROM " + SCHEMA_PREFIX + CATEGORY_TABLE_NAME
	+ " WHERE " + CATEGORY_TABLE_TABLE_NAME + " = '";

      lastCatName = catTableName;

      ResultSet rs = stmt.executeQuery(gkk + catTableName + "'");
      while (rs.next())
	{
	  lastCatKey = rs.getInt(1);
	  lastCatBase = rs.getInt(2);
	}
      if (lastCatKey < 0)
	{
	  throw new MmsTranslationException
	    ("readCategoryTable() Cannot find Table for " + catTableName);
	}
    }

  protected int getCategoryKey(String catTableName)
    throws MmsTranslationException, SQLException
    {
      // cache last retrieved key and base for efficiency
      if ( ! lastCatName.equalsIgnoreCase(catTableName))
	{
	  readCategoryTable(catTableName);
	}
      return lastCatKey;
    }

  protected int getCategoryBase(String catTableName)
    throws MmsTranslationException, SQLException
    {
      // cache last retrieved key and base for efficiency
      if ( ! lastCatName.equalsIgnoreCase(catTableName))
	{
	  readCategoryTable(catTableName);
	}
      return lastCatBase;
    }

  protected void updateCategoryEntryKey(int eKey, int catKey,
					int keyBase, int len)
    throws MmsTranslationException, SQLException
    {
      if (len > 0)
	{
	  // create new Entry-Category record
	  String cer = "INSERT INTO " + 
	    SCHEMA_PREFIX + ENTRY_CATS_TABLE_NAME + " ( "
	    + ENTRY_CATS_ENTRY_NAME + ", " +  ENTRY_CATS_CATEGORY_NAME + ", "
	    + ENTRY_CATS_FIRST_KEY_NAME + ", " + ENTRY_CATS_LEN_NAME
	    + " ) VALUES ( ?, ?, ?, ? )";
	  PreparedStatement epst = Conn.prepareStatement(cer);
	  epst.setInt(1, eKey);
	  epst.setInt(2, catKey);
	  epst.setInt(3, keyBase);
	  epst.setInt(4, len);
	  epst.executeUpdate();
	  epst.close();

	  int rval = -1;
	  String ucek = "UPDATE " + SCHEMA_PREFIX + CATEGORY_TABLE_NAME
	    + " SET "+ CATEGORY_TABLE_NEXT_RECORD_NAME + " = ? "
	    + " WHERE " + CATEGORY_TABLE_KEY_NAME + " = ?";
	  PreparedStatement ps = Conn.prepareStatement(ucek);
	  ps.setInt(2, catKey);
	  ps.setInt(1, keyBase + len);
	  if (ps.executeUpdate() != 1)
	    {
	      throw new MmsTranslationException
		("updateCategoryEntryKey():"
		 + "  Could not update next record in Category_Entry Table" 
		 + "  CategoryKey = " + catKey);
	    }
	  ps.close();
	}
    }
}

