//
// PrintMessageHandler.java,v 1.1 2002/10/11 22:41:21 dsg Exp
//
// Copyright 2001 The Regents of the University of California
// All Rights Reserved
//
// OpenMMS was developed by Dr. Douglas S. Greer at the San Diego
// Supercomputer Center, a research unit of the University of California,
// San Diego.  Support for this effort was provided by NSF through the
// Protein Data Bank (Grant DBI-9814284) and the National Partnership for
// Advanced Computational Infrastructure (Grant ACI-9619020)
//
// Permission to use, copy, modify and distribute any part of OpenMMS for
// educational, research and non-profit purposes, without fee, and
// without a written agreement is hereby granted, provided that the above
// copyright notice, this paragraph and the following paragraphs appear
// in all copies.
//
// Those desiring to incorporate this OpenMMS into commercial products or
// use for commercial purposes should contact the Technology Transfer
// Office, University of California, San Diego, 9500 Gilman Drive, La
// Jolla, CA 92093-0910, Ph: (619) 534-5815, FAX: (619) 534-7345.
//
// In no event shall the University of California be liable to any party
// for direct, indirect, special, incidental, or consequential damages,
// including lost profits, arising out of the use of this OpenMMS, even
// if the University of California has been advised of the possibility of
// such damage.
//
// The OpenMMS provided herein is on an "as is" basis, and the
// University of California has no obligation to provide maintenance,
// support, updates, enhancements, or modifications.  The University of
// California makes no representations and extends no warranties of any
// kind, either implied or express, including, but not limited to, the
// implied warranties of merchantability or fitness for a particular
// purpose, or that the use of the OpenMMS will not infringe any patent,
// trademark or other rights.

package org.rcsb.openmms.util;

import java.io.*;

/**
 * Simple Message Handler interface to print messages on StdErr
 *
 * @author Douglas S. Greer
 * @version 1.1
 */
public class PrintMessageHandler implements MessageHandler
{
  public void logMessage(String s)
    {
      
      logString(s + "\n");
    }

  public void logString(String s)
    {
      System.err.println(s);
    }

  public void logException(Throwable t, String title,
			   String exceptionType, String where,
			   String cause, String other, boolean doStackTrace)
    {
      StringBuffer m = new StringBuffer();
      m.append("\n********** " + title + " **********");
      m.append("\n  " + exceptionType + " in " + where);
      if (cause != null)
	{
	  m.append("\n  " + cause);
	}
      m.append("\n  Exception Description: " + t.toString());
      if (other != null)
	{
	  m.append("\n  " + other);
	}
      m.append("\n  Stack Trace\n");

      if (doStackTrace)
	{
	  StringWriter sw = new StringWriter();
	  t.printStackTrace(new PrintWriter(sw));
	  m.append(sw.toString());
	}
      m.append("\n********** end of exception report **********\n");
      logMessage(m.toString());
    }
}
