//
// SelectCategoryBase.java,v 1.2 2002/07/02 00:18:14 dsg Exp
//
// Copyright 2001 The Regents of the University of California
// All Rights Reserved
//
// OpenMMS was developed by Dr. Douglas S. Greer at the San Diego
// Supercomputer Center, a research unit of the University of California,
// San Diego.  Support for this effort was provided by NSF through the
// Protein Data Bank (Grant DBI-9814284) and the National Partnership for
// Advanced Computational Infrastructure (Grant ACI-9619020)
//
// Permission to use, copy, modify and distribute any part of OpenMMS for
// educational, research and non-profit purposes, without fee, and
// without a written agreement is hereby granted, provided that the above
// copyright notice, this paragraph and the following paragraphs appear
// in all copies.
//
// Those desiring to incorporate this OpenMMS into commercial products or
// use for commercial purposes should contact the Technology Transfer
// Office, University of California, San Diego, 9500 Gilman Drive, La
// Jolla, CA 92093-0910, Ph: (619) 534-5815, FAX: (619) 534-7345.
//
// In no event shall the University of California be liable to any party
// for direct, indirect, special, incidental, or consequential damages,
// including lost profits, arising out of the use of this OpenMMS, even
// if the University of California has been advised of the possibility of
// such damage.
//
// The OpenMMS provided herein is on an "as is" basis, and the
// University of California has no obligation to provide maintenance,
// support, updates, enhancements, or modifications.  The University of
// California makes no representations and extends no warranties of any
// kind, either implied or express, including, but not limited to, the
// implied warranties of merchantability or fitness for a particular
// purpose, or that the use of the OpenMMS will not infringe any patent,
// trademark or other rights.

package org.rcsb.openmms.util;

import java.util.*;
import java.sql.*;

// For definition of ORB functions
import org.omg.CORBA.*;

/**
 * Base Class containing utility functions for the Relational
 * Database Entry JDBC insertion code.
 *
 * @author Douglas S. Greer
 * @version 1.2
 */
abstract public class SelectCategoryBase
  implements TypeNamesSql
{
  protected Connection Conn;
  protected MessageHandler messagePanel;
  protected Statement stmt;
  
  protected int entryKey;
  protected int categoryKey;
  protected int categoryBase;
  protected int categoryLength;

  public SelectCategoryBase(MessageHandler ps, Connection con)
    throws SQLException
    {
      messagePanel = ps;
      Conn = con;
      stmt = Conn.createStatement();
    }

  public int readCategoryBase(int ekey, int ckey)
    throws MmsTranslationException, SQLException
    {
      int cBase = -2;
      String rcs = "SELECT "
	+ ENTRY_CATS_FIRST_KEY_NAME
	+ " FROM " + SCHEMA_PREFIX + ENTRY_CATS_TABLE_NAME
	+ " WHERE " + ENTRY_CATS_ENTRY_NAME + " = " + ekey
	+ " AND " + ENTRY_CATS_CATEGORY_NAME + " = " + ckey;
      ResultSet rs = stmt.executeQuery(rcs);
      while (rs.next())
	{
	  cBase = rs.getInt(1);
	}
      if (categoryBase < 0)
	{
	  throw new MmsTranslationException
	    ("readCategoryBase() Cannot find Table for Entry Key = "
	     + ekey + ", Category Key = " + ckey);
	}
      return cBase;
    }
      
  public void readCategoryStats(int ekey, int ckey)
    throws MmsTranslationException, SQLException
    {
      entryKey = ekey;
      categoryKey = ckey;

      categoryBase = -1;
      String rcs = "SELECT "
	+ ENTRY_CATS_FIRST_KEY_NAME + ", " + ENTRY_CATS_LEN_NAME
	+ " FROM " + SCHEMA_PREFIX + ENTRY_CATS_TABLE_NAME
	+ " WHERE " + ENTRY_CATS_ENTRY_NAME + " = " + entryKey + " AND "
	+ ENTRY_CATS_CATEGORY_NAME + " = " + categoryKey;
      ResultSet rs = stmt.executeQuery(rcs);
      while (rs.next())
	{
	  categoryBase = rs.getInt(1);
	  categoryLength = rs.getInt(2);
	}
      if (categoryBase < 0)
	{
	  throw new MmsTranslationException
	    ("readCategoryStats() Cannot find Table for Entry Key = "
	     + entryKey + ", Category Key = " + categoryKey);
	}
    }

  public Connection getConnection()
    {
      return Conn;
    }

  public int getEntryKey()
    {
      return entryKey;
    }

  public int getCategoryKey()
    {
      return categoryKey;
    }

  public int getCategoryBase()
    {
      return categoryBase;
    }

  public int getCategoryLength()
    {
      return categoryLength;
    }

  public static boolean isFlagSet(byte[] bits, int flag)
    {
      if ((bits[flag/8] & (1 << (flag%8))) != 0)
	return true;
      else
	return false;
    }

  public static void setFlag(byte[] bits, int flag)
    {
      bits[flag/8] |= 1 << (flag%8);
    }
}

