//
// TypeNamesSql.java,v 1.7 2003/05/09 00:44:12 dsg Exp
//
// Copyright 2001 The Regents of the University of California
// All Rights Reserved
//
// OpenMMS was developed by Dr. Douglas S. Greer at the San Diego
// Supercomputer Center, a research unit of the University of California,
// San Diego.  Support for this effort was provided by NSF through the
// Protein Data Bank (Grant DBI-9814284) and the National Partnership for
// Advanced Computational Infrastructure (Grant ACI-9619020)
//
// Permission to use, copy, modify and distribute any part of OpenMMS for
// educational, research and non-profit purposes, without fee, and
// without a written agreement is hereby granted, provided that the above
// copyright notice, this paragraph and the following paragraphs appear
// in all copies.
//
// Those desiring to incorporate this OpenMMS into commercial products or
// use for commercial purposes should contact the Technology Transfer
// Office, University of California, San Diego, 9500 Gilman Drive, La
// Jolla, CA 92093-0910, Ph: (619) 534-5815, FAX: (619) 534-7345.
//
// In no event shall the University of California be liable to any party
// for direct, indirect, special, incidental, or consequential damages,
// including lost profits, arising out of the use of this OpenMMS, even
// if the University of California has been advised of the possibility of
// such damage.
//
// The OpenMMS provided herein is on an "as is" basis, and the
// University of California has no obligation to provide maintenance,
// support, updates, enhancements, or modifications.  The University of
// California makes no representations and extends no warranties of any
// kind, either implied or express, including, but not limited to, the
// implied warranties of merchantability or fitness for a particular
// purpose, or that the use of the OpenMMS will not infringe any patent,
// trademark or other rights.

package org.rcsb.openmms.util;

/**
 * Contains String definitions for the JDBC "MMS System" tables and
 * the JDBC mappings of cif data types for various DB vendors.
 *
 * @author Douglas S. Greer
 * @version 1.7
 */
public interface TypeNamesSql
{
  final static String STD_KEY_TYPE = "INTEGER";
  final static String STD_NAME_TYPE = "VARCHAR(32)";
  final static String STD_LINE_TYPE = "VARCHAR(255)";
  final static String STD_DATE_TYPE = "DATE";

  // final static String SCHEMA_PREFIX = "PDB.";
  final static String SCHEMA_PREFIX = "";
  final static String KEY_ID_SUFFIX = "_key";

  final static String SYSTEM_TABLE_NAME = "MMS_SYSTEM";
  final static String SYSTEM_DATA_BANK_NAME = "data_bank";
  final static String SYSTEM_VERSION_NAME = "version";
  final static String SYSTEM_MODEL_ID_NAME = "model_id";
  final static String SYSTEM_REVISION_NUMBER_NAME = "revision_number";

  final static String ENTRY_TABLE_NAME = "MMS_ENTRY";
  final static String ENTRY_TABLE_KEY_NAME = "entry" + KEY_ID_SUFFIX;
  final static String ENTRY_TABLE_ID_NAME = "id";
  final static String ENTRY_TABLE_DEP_DATE_NAME = "deposition_date";
  final static String ENTRY_TABLE_LOAD_DATE_NAME = "db_load_date";
  final static String ENTRY_TABLE_LOAD_STATUS_NAME = "load_status";
  final static String ENTRY_TABLE_FLAG_BASE_NAME = "presence_flags_module_";

  final static String CATEGORY_TABLE_NAME = "MMS_CATEGORY";
  final static String CATEGORY_TABLE_KEY_NAME = "category" + KEY_ID_SUFFIX;
  final static String CATEGORY_TABLE_TABLE_NAME = "table_name";
  final static String CATEGORY_TABLE_CIF_ID_NAME = "id";
  final static String CATEGORY_TABLE_DESC_NAME = "description";
  final static String CATEGORY_TABLE_MAND_NAME = "mandatory";
  final static String CATEGORY_TABLE_NEXT_RECORD_NAME = "next_record";

  final static String ITEM_TABLE_NAME = "MMS_ITEM";
  final static String ITEM_TABLE_KEY_NAME = "item" + KEY_ID_SUFFIX;
  final static String ITEM_TABLE_COLUMN_NAME = "column_name";
  final static String ITEM_TABLE_CIF_ID_NAME = "id";
  final static String ITEM_TABLE_CAT_INDX_NAME = "category" + KEY_ID_SUFFIX;
  final static String ITEM_TABLE_DESC_NAME = "description";
  final static String ITEM_TABLE_MAND_NAME = "mandatory";

  final static String ENTRY_CATS_TABLE_NAME = "MMS_ENTRY_CATEGORIES";
  final static String ENTRY_CATS_ENTRY_NAME = ENTRY_TABLE_KEY_NAME;
  final static String ENTRY_CATS_CATEGORY_NAME = CATEGORY_TABLE_KEY_NAME;
  final static String ENTRY_CATS_FIRST_KEY_NAME = "first_record";
  final static String ENTRY_CATS_LEN_NAME = "len";

  // Different database flavors supported
  final static short NUMBER_OF_FLAVORS = 5;
  final static short ORACLE_FLAVOR = 0;
  final static short SYBASE_FLAVOR = 1;
  final static short MYSQL_FLAVOR = 2;
  final static short IBM_DB2_FLAVOR = 3;
  final static short MICROSOFT_ACCESS_FLAVOR = 4;


  // All of the following string arrays must match the order of the
  // dbTypeNames flavor declarations
  final static String[] dbTypeNames =
  {
    "Oracle",
    "Sybase",
    "MySQL",
    "IBM_DB2",
    "MS_Access"
  };

  final static int TYPE_FIELD_LEN = 14;

  final static String[] bigTextType =
  {
    "VARCHAR(4000)", // Oracle
    "TEXT",          // Sybase
    "TEXT",	     // MySQL
    "TEXT",          // IBM DB2
    "LONGCHAR"       // MS Access
  };

  final static String[] hugeTextType =
  {
    "LONG",          // Oracle
    "TEXT",          // Sybase
    "LONGTEXT",      // MySQL
    "TEXT",          // IBM DB2
    "LONGCHAR"       // MS Access
  };

  final String[] smallBinaryType =
  {
    "RAW(255)",         // Oracle 
    "VARBINARY(254)",   // Sybase ...
    "TINYBLOB",
    "CHAR(254) FOR BIT DATA",
    "VARBINARY(254)"
  };

  final String[] bigBinaryType =
  {
    "LONG RAW",         // Oracle
    "IMAGE",            // Sybase ...
    "LONGBLOB",
    "LONG VARCHAR FOR BIT DATA",
    "LONGBINARY"
  };

  // mySQL keyword to work-around 2G byte table size limit for ATOM_SITE
  final String[] largeTableQualifier =
  {
    "",               // Oracle
    "",               // Sybase ...
    " TYPE = INNODB", // MySQL
    "",               // IBM DB2
    ""                // MS Access
  };
}
