//
// CategoryNode.java,v 1.3 2001/10/27 02:02:54 dsg Exp
//
// Copyright 2001 The Regents of the University of California
// All Rights Reserved
//
// OpenMMS was developed by Dr. Douglas S. Greer at the San Diego
// Supercomputer Center, a research unit of the University of California,
// San Diego.  Support for this effort was provided by NSF through the
// Protein Data Bank (Grant DBI-9814284) and the National Partnership for
// Advanced Computational Infrastructure (Grant ACI-9619020)
//
// Permission to use, copy, modify and distribute any part of OpenMMS for
// educational, research and non-profit purposes, without fee, and
// without a written agreement is hereby granted, provided that the above
// copyright notice, this paragraph and the following paragraphs appear
// in all copies.
//
// Those desiring to incorporate this OpenMMS into commercial products or
// use for commercial purposes should contact the Technology Transfer
// Office, University of California, San Diego, 9500 Gilman Drive, La
// Jolla, CA 92093-0910, Ph: (619) 534-5815, FAX: (619) 534-7345.
//
// In no event shall the University of California be liable to any party
// for direct, indirect, special, incidental, or consequential damages,
// including lost profits, arising out of the use of this OpenMMS, even
// if the University of California has been advised of the possibility of
// such damage.
//
// The OpenMMS provided herein is on an "as is" basis, and the
// University of California has no obligation to provide maintenance,
// support, updates, enhancements, or modifications.  The University of
// California makes no representations and extends no warranties of any
// kind, either implied or express, including, but not limited to, the
// implied warranties of merchantability or fitness for a particular
// purpose, or that the use of the OpenMMS will not infringe any patent,
// trademark or other rights.

package org.rcsb.openmms.apps.xmc;

import java.io.IOException;
import org.rcsb.openmms.cifparse.*;

/**
 * Class to represent Category Elements
 *
 * @author Douglas S. Greer
 * @version 1.3
 */
public class CategoryNode extends Node
{
  protected boolean hasData;

  DictionaryCategory dictCategory;

  public CategoryNode(String n)
    {
      this(n, Node.TYPE_CATEGORY);
    }

  public CategoryNode(String n, int type)
    {
      super(n, type);
    }
  
  public void setHasData(boolean v)
    {
      hasData = v;
    }

  public boolean hasData()
    {
      return hasData;
    }

  public void setDictionaryCategory(DictionaryCategory di)
    {
      dictCategory = di;
    }

  public DictionaryCategory getDictionaryCategory()
    {
      return dictCategory;
    }

  public void accept(Visitor v)
    throws IOException, XmlGenException
    {
      // OPEN
      v.openCategory(this);
      // visit children
      Node t;
      for (int i = 0; i < numberOfChildren(); i++)
	{
	  t = getChild(i);
	  int type = t.getType();
	  switch (type)
	    {
	    case Node.TYPE_ITEM:
	      t.accept(v);
	      break;
	    default:
	      throw new XmlGenException
		("Invalid CategoryNode Child Type: " + type );
	    }
	}
      // CLOSE
      v.closeCategory(this);
    }
}
