//
// DtdWriter.java,v 1.3 2001/10/27 02:02:54 dsg Exp
//
// Copyright 2001 The Regents of the University of California
// All Rights Reserved
//
// OpenMMS was developed by Dr. Douglas S. Greer at the San Diego
// Supercomputer Center, a research unit of the University of California,
// San Diego.  Support for this effort was provided by NSF through the
// Protein Data Bank (Grant DBI-9814284) and the National Partnership for
// Advanced Computational Infrastructure (Grant ACI-9619020)
//
// Permission to use, copy, modify and distribute any part of OpenMMS for
// educational, research and non-profit purposes, without fee, and
// without a written agreement is hereby granted, provided that the above
// copyright notice, this paragraph and the following paragraphs appear
// in all copies.
//
// Those desiring to incorporate this OpenMMS into commercial products or
// use for commercial purposes should contact the Technology Transfer
// Office, University of California, San Diego, 9500 Gilman Drive, La
// Jolla, CA 92093-0910, Ph: (619) 534-5815, FAX: (619) 534-7345.
//
// In no event shall the University of California be liable to any party
// for direct, indirect, special, incidental, or consequential damages,
// including lost profits, arising out of the use of this OpenMMS, even
// if the University of California has been advised of the possibility of
// such damage.
//
// The OpenMMS provided herein is on an "as is" basis, and the
// University of California has no obligation to provide maintenance,
// support, updates, enhancements, or modifications.  The University of
// California makes no representations and extends no warranties of any
// kind, either implied or express, including, but not limited to, the
// implied warranties of merchantability or fitness for a particular
// purpose, or that the use of the OpenMMS will not infringe any patent,
// trademark or other rights.

package org.rcsb.openmms.apps.xmc;

import java.io.*;
import java.util.*;
import java.util.Date;

import org.rcsb.openmms.cifparse.*;

/**
 * Visitor subclass for writing XML DTD
 *
 * @author Douglas S. Greer
 * @version 1.3
 */
public class DtdWriter extends Visitor
{
  String xmlPath;
  String dtdName;

  public DtdWriter(String xp, String dtdn)
    {
      xmlPath = xp;
      dtdName= dtdn;
    }
  
  public void openO(ONode rt)
    throws IOException, XmlGenException
    {
      openDtd();
      String[] doc =
      {
	"<!ELEMENT DOCUMENT (ENTRY*) >",
	""
      };
      writeStr(doc);
    }

  public void closeO(ONode rt)
    throws IOException, XmlGenException
    {
      if (rt.getType() == Node.TYPE_O)
	{
	  closeDtd();
	}
    }

  public void openEntry(EntryNode rt)
    throws IOException, XmlGenException
    {
      writeStr("<!ELEMENT ENTRY");
      writeStr(indent + "(");
      // Categories in order
      Node t;
      ItemNode in;
      int type;
      // write items first (i.e. _entry.id )
      for (int i = 0; i < rt.numberOfChildren(); i++)
	{
	  t = rt.getChild(i);
	  type = t.getType();
	  if (type == Node.TYPE_ITEM)
	    {
	      in = (ItemNode) t;
	      writeStr(indent + in.getElementName() + ",");
	    }
	}
      for (int i = 0; i < rt.numberOfChildren(); i++)
	{
	  t = rt.getChild(i);
	  type = t.getType();
	  if (type == Node.TYPE_CATEGORY)
	    {
	      writeStr(indent + t.getName() + "?,");
	    }
	}
      writeStr(indent + ")");
      writeStr(">");
      writeStr("");
    }

  public void closeEntry(EntryNode rt)
    throws IOException, XmlGenException
    {
    }

  protected void openDtd()
    throws IOException, XmlGenException
    {
      if (dtdName == null)
	{
	  throw new XmlGenException("DTD name not specified");
	}
      if (outputFileWriter != null)
	{
	  close();
	}
      open(xmlPath + "/" + dtdName);

      String header =
	"\nXMC.dtd" +
	" - The Macromolecular Crystallographic Information XML DTD" +
	"\n" +
	"\nTranslated from the IUCr Macromolecular CIF Dictionary" +
	"\n    on " + (new Date()).toString() + 
	"\n    by Douglas S. Greer" +
	"\n" +
	"\nCopyright 2000" +
	"\n    Research Collaboratory for Structural Bioinfomatics," +
	"\n    International Union of Crystallography" +
	"\n    All rights reserved" +
	"\n";
      writeComStr(header);
      writeStr("");
    }

  protected void closeDtd()
    throws IOException
    {
      String[] closing =
      {
	"<--XMC_FIN-->",
	""
      };
      writeStr(closing);

      close();
    }

  public void openCategory(CategoryNode rt)
    throws IOException, XmlGenException
    {
      writeStr("<!ELEMENT " + rt.getName());
      writeStr(indent + "(");
      Node t;
      ItemNode it;
      int type;
      String optional;
      for (int i = 0; i < rt.numberOfChildren(); i++)
	{
	  t = rt.getChild(i);
	  type = t.getType();
	  if (type == Node.TYPE_ITEM)
	    {
	      it = (ItemNode) t;
	      if (it.getDictionaryItem().getItemMandatoryCode()
		  == DictionaryItem.ITEM_MANDATORY_CODE_NO)
		{
		  optional = "?";
		}
	      else
		{
		  optional = "";
		}
	      writeStr(indent + it.getElementName() + optional + ",");
	    }
	  else
	    {
	      throw new XmlGenException
		("Invalid Catagory Node Child Type: " + type );
	    }
	}
      writeStr(indent + ")");
      writeStr(">");
      // Category description
      writeStr("<!ATTLIST " + rt.getName() + " description CDATA #FIXED");
      writeDescription(rt.getDictionaryCategory().getCategoryDescription());
      writeStr("\">");
      writeStr("");
    }

  public void closeCategory(CategoryNode rt)
    throws IOException, XmlGenException
    {
    }

  public void openItem(ItemNode in)
    throws IOException, XmlGenException
    {
      String type;

      writeStr("<!ELEMENT " + in.getElementName() + " (#PCDATA)>");

      // Write type 
      type = in.getDictionaryItem().getItemType();
      writeStr("<!ATTLIST " + in.getElementName() 
	       + " length CDATA \"1\">");
      // if no is type specified in mmCIF dictionary,
      // then one is not written to DTD
      if (type != null)
	{
	  writeStr("<!ATTLIST " + in.getElementName() 
		   + " type CDATA #FIXED \"" + type + "\">");
	}
      // Write description
      writeStr("<!ATTLIST " + in.getElementName() 
	       + " description CDATA #FIXED");
      writeDescription(in.getDictionaryItem().getItemDescription());
      writeStr("\">");
      writeStr("");
    }

  public void closeItem(ItemNode rt)
    throws IOException, XmlGenException
    {
    }
}  

