//
// ItemNode.java,v 1.3 2001/10/27 02:02:55 dsg Exp
//
// Copyright 2001 The Regents of the University of California
// All Rights Reserved
//
// OpenMMS was developed by Dr. Douglas S. Greer at the San Diego
// Supercomputer Center, a research unit of the University of California,
// San Diego.  Support for this effort was provided by NSF through the
// Protein Data Bank (Grant DBI-9814284) and the National Partnership for
// Advanced Computational Infrastructure (Grant ACI-9619020)
//
// Permission to use, copy, modify and distribute any part of OpenMMS for
// educational, research and non-profit purposes, without fee, and
// without a written agreement is hereby granted, provided that the above
// copyright notice, this paragraph and the following paragraphs appear
// in all copies.
//
// Those desiring to incorporate this OpenMMS into commercial products or
// use for commercial purposes should contact the Technology Transfer
// Office, University of California, San Diego, 9500 Gilman Drive, La
// Jolla, CA 92093-0910, Ph: (619) 534-5815, FAX: (619) 534-7345.
//
// In no event shall the University of California be liable to any party
// for direct, indirect, special, incidental, or consequential damages,
// including lost profits, arising out of the use of this OpenMMS, even
// if the University of California has been advised of the possibility of
// such damage.
//
// The OpenMMS provided herein is on an "as is" basis, and the
// University of California has no obligation to provide maintenance,
// support, updates, enhancements, or modifications.  The University of
// California makes no representations and extends no warranties of any
// kind, either implied or express, including, but not limited to, the
// implied warranties of merchantability or fitness for a particular
// purpose, or that the use of the OpenMMS will not infringe any patent,
// trademark or other rights.

package org.rcsb.openmms.apps.xmc;

import java.util.*;
import java.io.IOException;
import org.rcsb.openmms.cifparse.*;

/**
 * Class to represent Item Elements
 *
 * @author Douglas S. Greer
 * @version 1.3
 */
public class ItemNode extends Node
{
  static final int MAX_PARAGRAPHS = 100;
  protected String elementName;
  protected CategoryNode containingCategory;
  // Dictionary Item corresponding to this node
  protected DictionaryItem dictItem;
  
  ArrayList vals = new ArrayList();

  public ItemNode(String cifname, CategoryNode cn, DictionaryItem di)
    {
      super(cifname, Node.TYPE_ITEM);
      containingCategory = cn;
      dictItem = di;
      // remove illegal characters for <!ENTITY name ... >
      elementName = cifNameToElementName(cifname);
    }

  public void setCategory(CategoryNode n)
    {
      containingCategory = n;
    }

  public CategoryNode getCategory()
    {
      return containingCategory;
    }

  public void setDictionaryItem(DictionaryItem di)
    {
      dictItem = di;
    }

  public DictionaryItem getDictionaryItem()
    {
      return dictItem;
    }

  public String getElementName()
    {
      return elementName;
    }

  public void addValue(String val)
    {
      vals.add(val);
    }

  public void clearValues()
    {
      vals.clear();
    }

  public ArrayList getValues()
    {
      return vals;
    }

  public void accept(Visitor v)
    throws IOException, XmlGenException
    {
      v.openItem(this);
      v.closeItem(this);
    }

  public String cifNameToElementName(String cname)
    {
      if (cname == null)
	{
	  return null;
	}

      StringBuffer sb = new StringBuffer();
      char c;

      // Convert the left brackets to underbars and delete
      // the right brackets
      for (int i = 0; i < cname.length(); i++)
	{
	  c = cname.charAt(i);
	  if (c == '[')
	    {
	      sb.append('_');
	    }
	  else if (c != ']')
	    {
	      sb.append(c);
	    }
	}
      String s = new String(sb);
      return s;
    }
}
