//
// NodeFactory.java,v 1.4 2003/07/29 23:56:22 dsg Exp
//
// Copyright 2001 The Regents of the University of California
// All Rights Reserved
//
// OpenMMS was developed by Dr. Douglas S. Greer at the San Diego
// Supercomputer Center, a research unit of the University of California,
// San Diego.  Support for this effort was provided by NSF through the
// Protein Data Bank (Grant DBI-9814284) and the National Partnership for
// Advanced Computational Infrastructure (Grant ACI-9619020)
//
// Permission to use, copy, modify and distribute any part of OpenMMS for
// educational, research and non-profit purposes, without fee, and
// without a written agreement is hereby granted, provided that the above
// copyright notice, this paragraph and the following paragraphs appear
// in all copies.
//
// Those desiring to incorporate this OpenMMS into commercial products or
// use for commercial purposes should contact the Technology Transfer
// Office, University of California, San Diego, 9500 Gilman Drive, La
// Jolla, CA 92093-0910, Ph: (619) 534-5815, FAX: (619) 534-7345.
//
// In no event shall the University of California be liable to any party
// for direct, indirect, special, incidental, or consequential damages,
// including lost profits, arising out of the use of this OpenMMS, even
// if the University of California has been advised of the possibility of
// such damage.
//
// The OpenMMS provided herein is on an "as is" basis, and the
// University of California has no obligation to provide maintenance,
// support, updates, enhancements, or modifications.  The University of
// California makes no representations and extends no warranties of any
// kind, either implied or express, including, but not limited to, the
// implied warranties of merchantability or fitness for a particular
// purpose, or that the use of the OpenMMS will not infringe any patent,
// trademark or other rights.

package org.rcsb.openmms.apps.xmc;

import org.rcsb.openmms.cifparse.*;

/**
 * Create XML model heirarchy
 *
 * @author Douglas S. Greer
 * @version 1.4
 */
public class NodeFactory
{
  CifDictionary cifDic;
  DictionaryCategoryList dictCatList;
  DictionaryItemList dictItemList;

  public NodeFactory(CifDictionary cdc)
    {
      cifDic = cdc;
      dictCatList = cifDic.getDictionaryCategoryList();
      dictItemList = cdc.getDictionaryItemList();
    }

  public ONode genTree()
    throws XmlGenException
    {
      ONode docNode = new ONode("DOCUMENT");
      EntryNode entryNode = createEntryNode();
      docNode.add(entryNode);

      genCats(cifDic, entryNode);
      genDictionaryLinks();

      return docNode;
    }

  protected EntryNode createEntryNode()
    throws XmlGenException
    {
      EntryNode e = new EntryNode("ENTRY");
      linkCategory(e);
      return e;
    }

  public void genCats(CifDictionary cdc, EntryNode entryNode)
    throws XmlGenException
    {
      CategoryNode cn;

      cn = createCategoryNode("ENTRY_LINK");
      entryNode.add(cn);
      cn = createCategoryNode("STRUCT");
      entryNode.add(cn);
      cn = createCategoryNode("AUDIT");
      entryNode.add(cn);
      cn = createCategoryNode("AUDIT_AUTHOR");
      entryNode.add(cn);
      cn = createCategoryNode("AUDIT_CONFORM");
      entryNode.add(cn);
      cn = createCategoryNode("AUDIT_CONTACT_AUTHOR");
      entryNode.add(cn);
      cn = createCategoryNode("CITATION");
      entryNode.add(cn);
      cn = createCategoryNode("CITATION_AUTHOR");
      entryNode.add(cn);
      cn = createCategoryNode("CITATION_EDITOR");
      entryNode.add(cn);
      cn = createCategoryNode("JOURNAL");
      entryNode.add(cn);
      cn = createCategoryNode("JOURNAL_INDEX");
      entryNode.add(cn);
      cn = createCategoryNode("COMPUTING");
      entryNode.add(cn);
      cn = createCategoryNode("SOFTWARE");
      entryNode.add(cn);
      cn = createCategoryNode("PUBL");
      entryNode.add(cn);
      cn = createCategoryNode("PUBL_AUTHOR");
      entryNode.add(cn);
      cn = createCategoryNode("PUBL_BODY");
      entryNode.add(cn);
      cn = createCategoryNode("PUBL_MANUSCRIPT_INCL");
      entryNode.add(cn);
      cn = createCategoryNode("DATABASE");
      entryNode.add(cn);
      cn = createCategoryNode("DATABASE_2");
      entryNode.add(cn);
      cn = createCategoryNode("DATABASE_PDB_CAVEAT");
      entryNode.add(cn);
      cn = createCategoryNode("DATABASE_PDB_MATRIX");
      entryNode.add(cn);
      cn = createCategoryNode("DATABASE_PDB_REMARK");
      entryNode.add(cn);
      cn = createCategoryNode("DATABASE_PDB_REV");
      entryNode.add(cn);
      cn = createCategoryNode("DATABASE_PDB_REV_RECORD");
      entryNode.add(cn);
      cn = createCategoryNode("DATABASE_PDB_TVECT");
      entryNode.add(cn);
      cn = createCategoryNode("CELL");
      entryNode.add(cn);
      cn = createCategoryNode("CELL_MEASUREMENT");
      entryNode.add(cn);
      cn = createCategoryNode("CELL_MEASUREMENT_REFLN");
      entryNode.add(cn);
      cn = createCategoryNode("REFLN");
      entryNode.add(cn);
      cn = createCategoryNode("REFLNS");
      entryNode.add(cn);
      cn = createCategoryNode("REFLNS_SCALE");
      entryNode.add(cn);
      cn = createCategoryNode("REFLNS_SHELL");
      entryNode.add(cn);
      cn = createCategoryNode("DIFFRN");
      entryNode.add(cn);
      cn = createCategoryNode("DIFFRN_ATTENUATOR");
      entryNode.add(cn);
      cn = createCategoryNode("DIFFRN_DETECTOR");
      entryNode.add(cn);
      cn = createCategoryNode("DIFFRN_MEASUREMENT");
      entryNode.add(cn);
      cn = createCategoryNode("DIFFRN_ORIENT_MATRIX");
      entryNode.add(cn);
      cn = createCategoryNode("DIFFRN_ORIENT_REFLN");
      entryNode.add(cn);
      cn = createCategoryNode("DIFFRN_RADIATION");
      entryNode.add(cn);
      cn = createCategoryNode("DIFFRN_RADIATION_WAVELENGTH");
      entryNode.add(cn);
      cn = createCategoryNode("DIFFRN_REFLN");
      entryNode.add(cn);
      cn = createCategoryNode("DIFFRN_REFLNS");
      entryNode.add(cn);
      cn = createCategoryNode("DIFFRN_SCALE_GROUP");
      entryNode.add(cn);
      cn = createCategoryNode("DIFFRN_SOURCE");
      entryNode.add(cn);
      cn = createCategoryNode("DIFFRN_STANDARDS");
      entryNode.add(cn);
      cn = createCategoryNode("DIFFRN_STANDARD_REFLN");
      entryNode.add(cn);
      cn = createCategoryNode("SYMMETRY");
      entryNode.add(cn);
      cn = createCategoryNode("SYMMETRY_EQUIV");
      entryNode.add(cn);
      cn = createCategoryNode("EXPTL");
      entryNode.add(cn);
      cn = createCategoryNode("EXPTL_CRYSTAL");
      entryNode.add(cn);
      cn = createCategoryNode("EXPTL_CRYSTAL_FACE");
      entryNode.add(cn);
      cn = createCategoryNode("EXPTL_CRYSTAL_GROW");
      entryNode.add(cn);
      cn = createCategoryNode("EXPTL_CRYSTAL_GROW_COMP");
      entryNode.add(cn);
      cn = createCategoryNode("PHASING");
      entryNode.add(cn);
      cn = createCategoryNode("PHASING_AVERAGING");
      entryNode.add(cn);
      cn = createCategoryNode("PHASING_ISOMORPHOUS");
      entryNode.add(cn);
      cn = createCategoryNode("PHASING_MAD");
      entryNode.add(cn);
      cn = createCategoryNode("PHASING_MAD_CLUST");
      entryNode.add(cn);
      cn = createCategoryNode("PHASING_MAD_EXPT");
      entryNode.add(cn);
      cn = createCategoryNode("PHASING_MAD_RATIO");
      entryNode.add(cn);
      cn = createCategoryNode("PHASING_MAD_SET");
      entryNode.add(cn);
      cn = createCategoryNode("PHASING_MIR");
      entryNode.add(cn);
      cn = createCategoryNode("PHASING_MIR_DER");
      entryNode.add(cn);
      cn = createCategoryNode("PHASING_MIR_DER_REFLN");
      entryNode.add(cn);
      cn = createCategoryNode("PHASING_MIR_DER_SHELL");
      entryNode.add(cn);
      cn = createCategoryNode("PHASING_MIR_DER_SITE");
      entryNode.add(cn);
      cn = createCategoryNode("PHASING_MIR_SHELL");
      entryNode.add(cn);
      cn = createCategoryNode("PHASING_SET");
      entryNode.add(cn);
      cn = createCategoryNode("PHASING_SET_REFLN");
      entryNode.add(cn);
      cn = createCategoryNode("REFINE");
      entryNode.add(cn);
      cn = createCategoryNode("REFINE_ANALYZE");
      entryNode.add(cn);
      cn = createCategoryNode("REFINE_B_ISO");
      entryNode.add(cn);
      cn = createCategoryNode("REFINE_HIST");
      entryNode.add(cn);
      cn = createCategoryNode("REFINE_LS_RESTR");
      entryNode.add(cn);
      cn = createCategoryNode("REFINE_LS_RESTR_NCS");
      entryNode.add(cn);
      cn = createCategoryNode("REFINE_LS_SHELL");
      entryNode.add(cn);
      cn = createCategoryNode("REFINE_OCCUPANCY");
      entryNode.add(cn);
      cn = createCategoryNode("CHEM_COMP");
      entryNode.add(cn);
      cn = createCategoryNode("CHEM_COMP_ANGLE");
      entryNode.add(cn);
      cn = createCategoryNode("CHEM_COMP_ATOM");
      entryNode.add(cn);
      cn = createCategoryNode("CHEM_COMP_BOND");
      entryNode.add(cn);
      cn = createCategoryNode("CHEM_COMP_CHIR");
      entryNode.add(cn);
      cn = createCategoryNode("CHEM_COMP_CHIR_ATOM");
      entryNode.add(cn);
      cn = createCategoryNode("CHEM_COMP_LINK");
      entryNode.add(cn);
      cn = createCategoryNode("CHEM_COMP_PLANE");
      entryNode.add(cn);
      cn = createCategoryNode("CHEM_COMP_PLANE_ATOM");
      entryNode.add(cn);
      cn = createCategoryNode("CHEM_COMP_TOR");
      entryNode.add(cn);
      cn = createCategoryNode("CHEM_COMP_TOR_VALUE");
      entryNode.add(cn);
      cn = createCategoryNode("CHEMICAL");
      entryNode.add(cn);
      cn = createCategoryNode("CHEMICAL_CONN_ATOM");
      entryNode.add(cn);
      cn = createCategoryNode("CHEMICAL_CONN_BOND");
      entryNode.add(cn);
      cn = createCategoryNode("CHEMICAL_FORMULA");
      entryNode.add(cn);
      cn = createCategoryNode("GEOM");
      entryNode.add(cn);
      cn = createCategoryNode("GEOM_ANGLE");
      entryNode.add(cn);
      cn = createCategoryNode("GEOM_BOND");
      entryNode.add(cn);
      cn = createCategoryNode("GEOM_CONTACT");
      entryNode.add(cn);
      cn = createCategoryNode("GEOM_HBOND");
      entryNode.add(cn);
      cn = createCategoryNode("GEOM_TORSION");
      entryNode.add(cn);
      cn = createCategoryNode("ENTITY");
      entryNode.add(cn);
      cn = createCategoryNode("ENTITY_KEYWORDS");
      entryNode.add(cn);
      cn = createCategoryNode("ENTITY_LINK");
      entryNode.add(cn);
      cn = createCategoryNode("ENTITY_NAME_COM");
      entryNode.add(cn);
      cn = createCategoryNode("ENTITY_NAME_SYS");
      entryNode.add(cn);
      cn = createCategoryNode("ENTITY_POLY");
      entryNode.add(cn);
      cn = createCategoryNode("ENTITY_POLY_SEQ");
      entryNode.add(cn);
      cn = createCategoryNode("ENTITY_SRC_GEN");
      entryNode.add(cn);
      cn = createCategoryNode("ENTITY_SRC_NAT");
      entryNode.add(cn);
      cn = createCategoryNode("ATOM_SITE");
      entryNode.add(cn);
      cn = createCategoryNode("ATOM_SITES");
      entryNode.add(cn);
      cn = createCategoryNode("ATOM_SITES_ALT");
      entryNode.add(cn);
      cn = createCategoryNode("ATOM_SITES_ALT_ENS");
      entryNode.add(cn);
      cn = createCategoryNode("ATOM_SITES_ALT_GEN");
      entryNode.add(cn);
      cn = createCategoryNode("ATOM_SITES_FOOTNOTE");
      entryNode.add(cn);
      cn = createCategoryNode("ATOM_SITE_ANISOTROP");
      entryNode.add(cn);
      cn = createCategoryNode("ATOM_TYPE");
      entryNode.add(cn);
      cn = createCategoryNode("CHEM_LINK");
      entryNode.add(cn);
      cn = createCategoryNode("CHEM_LINK_ANGLE");
      entryNode.add(cn);
      cn = createCategoryNode("CHEM_LINK_BOND");
      entryNode.add(cn);
      cn = createCategoryNode("CHEM_LINK_CHIR");
      entryNode.add(cn);
      cn = createCategoryNode("CHEM_LINK_CHIR_ATOM");
      entryNode.add(cn);
      cn = createCategoryNode("CHEM_LINK_PLANE");
      entryNode.add(cn);
      cn = createCategoryNode("CHEM_LINK_PLANE_ATOM");
      entryNode.add(cn);
      cn = createCategoryNode("CHEM_LINK_TOR");
      entryNode.add(cn);
      cn = createCategoryNode("CHEM_LINK_TOR_VALUE");
      entryNode.add(cn);
      cn = createCategoryNode("STRUCT_ASYM");
      entryNode.add(cn);
      cn = createCategoryNode("STRUCT_BIOL");
      entryNode.add(cn);
      cn = createCategoryNode("STRUCT_BIOL_GEN");
      entryNode.add(cn);
      cn = createCategoryNode("STRUCT_BIOL_KEYWORDS");
      entryNode.add(cn);
      cn = createCategoryNode("STRUCT_BIOL_VIEW");
      entryNode.add(cn);
      cn = createCategoryNode("STRUCT_CONF");
      entryNode.add(cn);
      cn = createCategoryNode("STRUCT_CONF_TYPE");
      entryNode.add(cn);
      cn = createCategoryNode("STRUCT_CONN");
      entryNode.add(cn);
      cn = createCategoryNode("STRUCT_CONN_TYPE");
      entryNode.add(cn);
      cn = createCategoryNode("STRUCT_KEYWORDS");
      entryNode.add(cn);
      cn = createCategoryNode("STRUCT_MON_DETAILS");
      entryNode.add(cn);
      cn = createCategoryNode("STRUCT_MON_NUCL");
      entryNode.add(cn);
      cn = createCategoryNode("STRUCT_MON_PROT");
      entryNode.add(cn);
      cn = createCategoryNode("STRUCT_MON_PROT_CIS");
      entryNode.add(cn);
      cn = createCategoryNode("STRUCT_NCS_DOM");
      entryNode.add(cn);
      cn = createCategoryNode("STRUCT_NCS_DOM_LIM");
      entryNode.add(cn);
      cn = createCategoryNode("STRUCT_NCS_ENS");
      entryNode.add(cn);
      cn = createCategoryNode("STRUCT_NCS_ENS_GEN");
      entryNode.add(cn);
      cn = createCategoryNode("STRUCT_NCS_OPER");
      entryNode.add(cn);
      cn = createCategoryNode("STRUCT_REF");
      entryNode.add(cn);
      cn = createCategoryNode("STRUCT_REF_SEQ");
      entryNode.add(cn);
      cn = createCategoryNode("STRUCT_REF_SEQ_DIF");
      entryNode.add(cn);
      cn = createCategoryNode("STRUCT_SHEET");
      entryNode.add(cn);
      cn = createCategoryNode("STRUCT_SHEET_HBOND");
      entryNode.add(cn);
      cn = createCategoryNode("STRUCT_SHEET_ORDER");
      entryNode.add(cn);
      cn = createCategoryNode("STRUCT_SHEET_RANGE");
      entryNode.add(cn);
      cn = createCategoryNode("STRUCT_SHEET_TOPOLOGY");
      entryNode.add(cn);
      cn = createCategoryNode("STRUCT_SITE");
      entryNode.add(cn);
      cn = createCategoryNode("STRUCT_SITE_GEN");
      entryNode.add(cn);
      cn = createCategoryNode("STRUCT_SITE_KEYWORDS");
      entryNode.add(cn);
      cn = createCategoryNode("STRUCT_SITE_VIEW");
      entryNode.add(cn);
    }

  protected CategoryNode createCategoryNode(String name)
    throws XmlGenException
    {
      CategoryNode cn = new CategoryNode(name);
      linkCategory(cn);
      return cn;
    }

  protected void linkCategory(CategoryNode cn)
    throws XmlGenException
    {
      String name = cn.getName();
      DictionaryCategory dc = dictCatList.findDictionaryCategory(name);
      if (dc == null)
	{
	  throw new XmlGenException
	    ("NodeFactory.createCategoryNode: cannot find category: " + name);
	}
      dc.setUObj(cn);
      cn.setDictionaryCategory(dc);
    }
  
  protected void genDictionaryLinks()
    throws XmlGenException
    {
      String nm;
      CategoryNode cn;
      DictionaryCategory dc;
      DictionaryItem di;
      ItemNode in;
      String catName;

      int len = dictItemList.size();

      for (int i = 0; i < len; i++)
	{
	  di = (DictionaryItem) dictItemList.elementAt(i);
	  nm  = di.getItemName();
	  int px;

	  // find Category
	  for (px = 0; px < nm.length(); px++)
	    {
	      if (nm.charAt(px) == '.')
		{
		  break;
		}
	    }
	  if (px >= nm.length())
	    {
	      throw new XmlGenException
		("NodeFactory.genDictionaryLinks: missing '.' in item: "
		 + nm);
	    }
	  catName = nm.substring(1, px);
	  dc = dictCatList.findDictionaryCategory(catName);
	  if (dc == null)
	    {
	      throw new XmlGenException
		("NodeFactory.genDictionaryLinks: cannot find category: "
		 + catName + "\n  For Item: " + nm);
	    }
	  cn = (CategoryNode) dc.getUObj();
 	  if (cn !=null)
 	    {
	      in = new ItemNode(nm, cn, di);
	      cn.add(in);
	      di.setUObj(in);
 	    }
	}
    }
}
