//
// Visitor.java,v 1.3 2001/10/27 02:02:55 dsg Exp
//
// Copyright 2001 The Regents of the University of California
// All Rights Reserved
//
// OpenMMS was developed by Dr. Douglas S. Greer at the San Diego
// Supercomputer Center, a research unit of the University of California,
// San Diego.  Support for this effort was provided by NSF through the
// Protein Data Bank (Grant DBI-9814284) and the National Partnership for
// Advanced Computational Infrastructure (Grant ACI-9619020)
//
// Permission to use, copy, modify and distribute any part of OpenMMS for
// educational, research and non-profit purposes, without fee, and
// without a written agreement is hereby granted, provided that the above
// copyright notice, this paragraph and the following paragraphs appear
// in all copies.
//
// Those desiring to incorporate this OpenMMS into commercial products or
// use for commercial purposes should contact the Technology Transfer
// Office, University of California, San Diego, 9500 Gilman Drive, La
// Jolla, CA 92093-0910, Ph: (619) 534-5815, FAX: (619) 534-7345.
//
// In no event shall the University of California be liable to any party
// for direct, indirect, special, incidental, or consequential damages,
// including lost profits, arising out of the use of this OpenMMS, even
// if the University of California has been advised of the possibility of
// such damage.
//
// The OpenMMS provided herein is on an "as is" basis, and the
// University of California has no obligation to provide maintenance,
// support, updates, enhancements, or modifications.  The University of
// California makes no representations and extends no warranties of any
// kind, either implied or express, including, but not limited to, the
// implied warranties of merchantability or fitness for a particular
// purpose, or that the use of the OpenMMS will not infringe any patent,
// trademark or other rights.

package org.rcsb.openmms.apps.xmc;

import java.io.*;

/**
 * Model vistor base class
 *
 * @author Douglas S. Greer
 * @version 1.3
 */
public class Visitor
{
  BufferedWriter outputFileWriter;
  int indentLevel = 0;
  static String indent = "    ";

  public Visitor()
    {
    }

  public void openO(ONode rt)
    throws IOException, XmlGenException
    {
    }

  public void closeO(ONode rt)
    throws IOException, XmlGenException
    {
    }

  public void openEntry(EntryNode rt)
    throws IOException, XmlGenException
    {
    }

  public void closeEntry(EntryNode rt)
    throws IOException, XmlGenException
    {
    }

  public void openCategory(CategoryNode rt)
    throws IOException, XmlGenException
    {
    }

  public void closeCategory(CategoryNode rt)
    throws IOException, XmlGenException
    {
    }

  public void openItem(ItemNode rt)
    throws IOException, XmlGenException
    {
    }

  public void closeItem(ItemNode rt)
    throws IOException, XmlGenException
    {
    }

  public void open(String fname) throws IOException
    {
      if (outputFileWriter != null)
	{
	  close();
	}
      outputFileWriter = new BufferedWriter(new FileWriter(fname));
    }
  
  public void close() throws IOException
    {
      outputFileWriter.close();
      outputFileWriter = null;
    }

  public void writeDescription(String s)
    throws IOException
    {
      StringBuffer sb = new StringBuffer();
      char c;

      sb.append('"');
      for (int i = 11; i < s.length(); i++)
	{
	  c = s.charAt(i);
	  switch (c)
	    {
	    case '<':
	      sb.append("&lt;");
	      break;
	    case '&':
	      sb.append("&amp;");
	      break;
	    case '"':
	      sb.append("&quot;");
	      break;
	    case '\n':
	      sb.append(c);
	      if (i+12 <= s.length() &&
		  s.substring(i+1, i+12).equals("           "))
		{
		  i += 11;
		}
	      break;
	    default:
	      sb.append(c);
	      break;
	    }
	}

      writeStr(sb.toString());
    }
  
  public void writeStr(String[] sl) throws IOException
    {
      for (int i = 0; i < sl.length; i++)
	{
	  writeStr(outputFileWriter, sl[i], 0);
	}
    }

  public void writeComStr(String s) throws IOException
    {
      writeStr("<!--" + s + "-->");
    }

  public void writeStr(String s) throws IOException
    {
      writeStr(outputFileWriter, s, 0);
    }

  public void writeBuffer(char[] ca) throws IOException
    {
      outputFileWriter.write(ca);
    }

  public void writeStr(BufferedWriter o, String s, int ilev)
    throws IOException
    {
      indentLevel += ilev;
      if (s != null && s.length() > 0)
	{
	  for (int i = 0; i < indentLevel; i++)
	    {
	      o.write(indent);
	    }
	  o.write(s);
	}
      o.newLine();
      indentLevel -= ilev;
    }

  static final int MAX_LINE = 68;
  int columnSz;
  int lineLen;
  String valTyp;

  public void  beginValues(String type, int sz)
    {
      lineLen = 0;
      columnSz = sz;
      valTyp = type;
    }

  public void writeValue(String s, int inum)
    throws IOException
    {
      String st = s.trim();

      if (valTyp == null)
	{
	  writeStdValue(s, inum);
	}
      else if (st.equals("?") || st.equals("."))
	{
	  writeStdValue(s, inum);
	}
      else if (valTyp.equalsIgnoreCase("text"))
	{
	  writeTextValue(s, inum);
	}
      else if (valTyp.equalsIgnoreCase("line"))
	{
	  writeLineValue(s, inum);
	}
      else
	{
	  writeStdValue(s, inum);
	}
    }
  
  public void writeTextValue(String s, int inum)
    throws IOException
    {
      writeStr("<![CDATA[\"");
      writeStr(convertToCDataStr(s));
      writeStr("\"]]>");
    }

  public void writeLineValue(String s, int inum)
    throws IOException
    {
      writeStr("'" + s + "'");
    }

  public void writeStdValue(String s, int inum)
    throws IOException
    {
      if (s != null)
	{
	  if (inum > 0 && lineLen > 0 && lineLen + s.length() > MAX_LINE)
	    {
	      outputFileWriter.newLine();
	      lineLen = 0;
	    }
	  else
	    {
	      if (inum != 0)
		{
		  outputFileWriter.write(' ');
		}
	    }
	  if (lineLen == 0)
	      writeIndent();
	  outputFileWriter.write(s);
	  lineLen += s.length() + 1;
	}
      if (inum == columnSz-1)
	{
	  outputFileWriter.newLine();
	}
    }

  public String convertToCDataStr(String s)
    {
      if (s == null)
	{
	  return null;
	}

      StringBuffer sb = new StringBuffer();
      char c;

      // Convert the left brackets to underbars and delete
      // the right brackets
      for (int i = 0; i < s.length(); i++)
	{
	  c = s.charAt(i);
	  switch (c)
	    {
	    case '\n':
	      sb.append(c);
	      for (int j = 0; j < indentLevel; j++)
		{
		  sb.append(indent);
		}
	      break;
	    case '"':
	      sb.append("\\\"");
	      break;
	    case '\\':
	      sb.append("\\\\");
	      break;
	    default:
	      sb.append(c);
	      break;
	    }
	}
      String rsv = new String(sb);
      return rsv;
    }

  public void writeIndent()
    throws IOException
    {
      for (int i = 0; i < indentLevel; i++)
	{
	  outputFileWriter.write(indent);
	}
    }
}  


