//
// XBuilder.java,v 1.3 2001/10/27 02:02:55 dsg Exp
//
// Copyright 2001 The Regents of the University of California
// All Rights Reserved
//
// OpenMMS was developed by Dr. Douglas S. Greer at the San Diego
// Supercomputer Center, a research unit of the University of California,
// San Diego.  Support for this effort was provided by NSF through the
// Protein Data Bank (Grant DBI-9814284) and the National Partnership for
// Advanced Computational Infrastructure (Grant ACI-9619020)
//
// Permission to use, copy, modify and distribute any part of OpenMMS for
// educational, research and non-profit purposes, without fee, and
// without a written agreement is hereby granted, provided that the above
// copyright notice, this paragraph and the following paragraphs appear
// in all copies.
//
// Those desiring to incorporate this OpenMMS into commercial products or
// use for commercial purposes should contact the Technology Transfer
// Office, University of California, San Diego, 9500 Gilman Drive, La
// Jolla, CA 92093-0910, Ph: (619) 534-5815, FAX: (619) 534-7345.
//
// In no event shall the University of California be liable to any party
// for direct, indirect, special, incidental, or consequential damages,
// including lost profits, arising out of the use of this OpenMMS, even
// if the University of California has been advised of the possibility of
// such damage.
//
// The OpenMMS provided herein is on an "as is" basis, and the
// University of California has no obligation to provide maintenance,
// support, updates, enhancements, or modifications.  The University of
// California makes no representations and extends no warranties of any
// kind, either implied or express, including, but not limited to, the
// implied warranties of merchantability or fitness for a particular
// purpose, or that the use of the OpenMMS will not infringe any patent,
// trademark or other rights.

package org.rcsb.openmms.apps.xmc;

import java.util.*;
import org.rcsb.openmms.cifparse.*;

/**
 * Builder subclass for reading the mmCIF datafiles and
 * translating it to XML format.
 *
 * @see org.rcsb.openmms.cifparse.Builder
 *
 * @author Douglas S. Greer
 * @version 1.3
 */
public class XBuilder implements Builder
{
  private static boolean trace;
  private static int debug = 0;

  ONode root; 

  DictionaryItem dictI;
  ItemNode in;

  public XBuilder(ONode r)
    {
      root = r;
    }

  public void setDebug(int d)
    {
      debug = d;
      if (debug >= 5)
	{
	  trace = true;
	}
    }

  //
  // Builder Methods called by CifParser
  //
  public void beginCompound()
    throws CifParseException
    {
      if (trace)
	{
	  System.out.println("XBuilder.beginCompound()");
	}
    }

  public void endCompound()
    throws CifParseException
    {
      CatLoader cl;

      if (trace)
	{
	  System.out.println("XBuilder.endCompound()");
	}
    }

  public void setSingleItem(DataItem di)
    throws CifParseException
    {
      CatLoader cl;

      if (trace)
	{
	  System.out.println
	    ("XBuilder.setSingleValue(): " + di.getItemName());
	}

      dictI = (DictionaryItem) di;
      if (dictI != null)
	{
	  in = (ItemNode) dictI.getUObj();
	  in.getCategory().setHasData(true);
	}
    }

  public void insertSingleValue(DataItem d, String val) 
    throws CifParseException
    {
      if (trace)
	{
	  System.out.println
	    ("XBuilder.insertSingleValue(): "
	     + d.getItemName() + ":" + val);
	}
      setValue(d, val);
    }

  public void beginLoop()
    throws CifParseException
    {
      if (trace)
	{
	  System.out.println("XBuilder.beginLoop()");
	}
    }

  public void endLoop()
    throws CifParseException
    {
      if (trace)
	{
	  System.out.println("XBuilder.endLoop()");
	}
    }

  public void beginRow()
    throws CifParseException
    {
      if (trace)
	{
	  System.out.println("XBuilder.beginRow()");
	}
    }

  public void endRow()
    throws CifParseException
    {
      if (trace)
	{
	  System.out.println("XBuilder.endRow()");
	}
    }

  public void setLoopItem(int column, DataItem di)
    throws CifParseException
    {
      if (trace)
	{
	  String iname = "(Null DataItem)";
	  if (di != null)
	    {
	      iname = di.getItemName();
	    }
	  System.out.println("XBuilder.setLoopItem(): " + iname);
	}

      dictI = (DictionaryItem) di;
      if (dictI != null)
	{
	  in = (ItemNode) dictI.getUObj();
	  in.getCategory().setHasData(true);
	}
    }

  public void insertLoopValue(int column, DataItem d, String val)
    throws CifParseException
    {
      if (trace)
	{
	  System.out.println
	    ("XBuilder.insertLoopValue(): " + d.getItemName() + ":" + val);
	}
      setValue(d, val);
    }

  protected void setValue(DataItem d, String val)
    throws CifParseException
    {
      dictI = (DictionaryItem) d;
      if (dictI != null)
	{
	  in = (ItemNode) dictI.getUObj();
	  if (in == null)
	    {
	      throw new CifParseException
		("XBuilder.setValue: null User Obj in item: "
		 + in.getName());
	    }
	  in.addValue(val);
	}
    }
}
