//
// XmcWriter.java,v 1.3 2001/10/27 02:02:55 dsg Exp
//
// Copyright 2001 The Regents of the University of California
// All Rights Reserved
//
// OpenMMS was developed by Dr. Douglas S. Greer at the San Diego
// Supercomputer Center, a research unit of the University of California,
// San Diego.  Support for this effort was provided by NSF through the
// Protein Data Bank (Grant DBI-9814284) and the National Partnership for
// Advanced Computational Infrastructure (Grant ACI-9619020)
//
// Permission to use, copy, modify and distribute any part of OpenMMS for
// educational, research and non-profit purposes, without fee, and
// without a written agreement is hereby granted, provided that the above
// copyright notice, this paragraph and the following paragraphs appear
// in all copies.
//
// Those desiring to incorporate this OpenMMS into commercial products or
// use for commercial purposes should contact the Technology Transfer
// Office, University of California, San Diego, 9500 Gilman Drive, La
// Jolla, CA 92093-0910, Ph: (619) 534-5815, FAX: (619) 534-7345.
//
// In no event shall the University of California be liable to any party
// for direct, indirect, special, incidental, or consequential damages,
// including lost profits, arising out of the use of this OpenMMS, even
// if the University of California has been advised of the possibility of
// such damage.
//
// The OpenMMS provided herein is on an "as is" basis, and the
// University of California has no obligation to provide maintenance,
// support, updates, enhancements, or modifications.  The University of
// California makes no representations and extends no warranties of any
// kind, either implied or express, including, but not limited to, the
// implied warranties of merchantability or fitness for a particular
// purpose, or that the use of the OpenMMS will not infringe any patent,
// trademark or other rights.

package org.rcsb.openmms.apps.xmc;

import java.io.*;
import java.util.*;
import java.util.Date;

import org.rcsb.openmms.cifparse.*;

/**
 * Visitor subclass from writing XML files
 *
 * @author Douglas S. Greer
 * @version 1.3
 */
public class XmcWriter extends Visitor
{
  String xmlPath;
  String eName;

  public XmcWriter(String xp)
    {
      xmlPath = xp;
    }

  public void setEntryName(String base)
    {
      eName = base;
    }
  
  public void openO(ONode rt)
    throws IOException, XmlGenException
    {
      openXmc();
      String[] doc =
      {
	"<DOCUMENT>",
      };
      writeStr(doc);
    }

  public void closeO(ONode rt)
    throws IOException, XmlGenException
    {
      String[] doc =
      {
	"</DOCUMENT>",
      };
      writeStr(doc);
      closeXmc();
    }

  protected void openXmc()
    throws IOException, XmlGenException
    {
      if (eName == null)
	{
	  throw new XmlGenException("DTD name not specified");
	}
      if (outputFileWriter != null)
	{
	  close();
	}
      open(xmlPath + "/" + eName + ".xml");

      String header =
	"\nFile:" + eName + ".xml" +
	"\n     uses XML Document Type Definition:  XMC.dtd" + 
	"\n" +
	"\nTranslated from " + eName + ".cif" +
	"\n     on " + (new Date()).toString() + " using Cif2Xmc.java" +
	"\n     written by Douglas S. Greer" +
	"\n";
      writeComStr(header);
      writeStr("");
    }

  protected void closeXmc()
    throws IOException
    {
      close();
    }

  public void openEntry(EntryNode rt)
    throws IOException, XmlGenException
    {
      writeStr("<ENTRY>");
    }

  public void closeEntry(EntryNode rt)
    throws IOException, XmlGenException
    {
      writeStr("</ENTRY>");
    }

  public void openCategory(CategoryNode cn)
    throws IOException, XmlGenException
    {
      if (cn.hasData())
	{
	  writeStr("<" + cn.getName() + ">");
	  indentLevel++;
	}
    }

  public void closeCategory(CategoryNode cn)
    throws IOException, XmlGenException
    {
      if (cn.hasData())
	{
	  indentLevel--;
	  writeStr("</" + cn.getName() + ">");
	}
    }

  ArrayList ial;
  public void openItem(ItemNode in)
    throws IOException, XmlGenException
    {
      int sz;
      String v, type;

      ial = in.getValues();

      if (ial.size() > 0)
	{
	  if (ial.size() > 1)
	    {
	      writeStr("<" + in.getElementName() 
		       + " length=\"" + ial.size() + "\">");
	    }
	  else
	    {
	      writeStr("<" + in.getElementName() + ">");
	    }
	  indentLevel++;

	  sz = ial.size();
	  type = in.getDictionaryItem().getItemType();
	  beginValues(type, sz);
	  for (int i = 0; i < sz; i++)
	    {
	      v = (String) ial.get(i);
	      writeValue(v, i);
	    }
	}
    }

  public void closeItem(ItemNode in)
    throws IOException, XmlGenException
    {
      ial = in.getValues();
      if (ial.size() > 0)
	{
	  indentLevel--;
	  writeStr("</" + in.getElementName() + ">");
	}
    }
}  

