//
// Record.java,v 1.1 2003/07/29 23:56:24 dsg Exp
//
// Copyright 2001 The Regents of the University of California
// All Rights Reserved
//
// OpenMMS was developed by Dr. Douglas S. Greer at the San Diego
// Supercomputer Center, a research unit of the University of California,
// San Diego.  Support for this effort was provided by NSF through the
// Protein Data Bank (Grant DBI-9814284) and the National Partnership for
// Advanced Computational Infrastructure (Grant ACI-9619020)
//
// Permission to use, copy, modify and distribute any part of OpenMMS for
// educational, research and non-profit purposes, without fee, and
// without a written agreement is hereby granted, provided that the above
// copyright notice, this paragraph and the following paragraphs appear
// in all copies.
//
// Those desiring to incorporate this OpenMMS into commercial products or
// use for commercial purposes should contact the Technology Transfer
// Office, University of California, San Diego, 9500 Gilman Drive, La
// Jolla, CA 92093-0910, Ph: (619) 534-5815, FAX: (619) 534-7345.
//
// In no event shall the University of California be liable to any party
// for direct, indirect, special, incidental, or consequential damages,
// including lost profits, arising out of the use of this OpenMMS, even
// if the University of California has been advised of the possibility of
// such damage.
//
// The OpenMMS provided herein is on an "as is" basis, and the
// University of California has no obligation to provide maintenance,
// support, updates, enhancements, or modifications.  The University of
// California makes no representations and extends no warranties of any
// kind, either implied or express, including, but not limited to, the
// implied warranties of merchantability or fitness for a particular
// purpose, or that the use of the OpenMMS will not infringe any patent,
// trademark or other rights.

package org.rcsb.openmms.apps.xconv;

import java.util.*;
import org.rcsb.openmms.cifparse.*;

/**
 * Create XML model heirarchy
 *
 * @author Douglas S. Greer
 * @version 1.1
 */
public class Record
{
  private CifDictionary cifDic;
  private Hashtable mandatoryItems = new Hashtable();
  private ArrayList list = new ArrayList();
  private HashSet hset = new HashSet();

  private boolean haveData = false;
  private boolean nullDataPresent = false;

  public Record(CifDictionary cdc)
    {
      cifDic = cdc;

      DictionaryItemList dil = cdc.getDictionaryItemList();
      // go through the list of dictionary items and add the mandatory
      // items to a ArrayList corresponding to its category.
      for (int i = 0; i < dil.size(); i++)
	{
	  DictionaryItem di = (DictionaryItem) dil.elementAt(i);
	  String iName = di.getItemName();
	  String catName = XmlWriter.parseCategoryName(iName);
	  // Check to see if we already have an array list for this
	  // category, if not create on and add it to the list
	  ArrayList mands = (ArrayList) mandatoryItems.get(catName);
	  if (mands == null)
	    {
	      mands = new ArrayList();
	      mandatoryItems.put(catName, mands);
	    }
	  if (di.getItemMandatoryCode() 
	      == DictionaryItem.ITEM_MANDATORY_CODE_YES)
	    {
	      mands.add(di);
	    }
	}
    }

  public ArrayList getArrayList()
    {
      return list;
    }

  public void clear()
    {
      list.clear();
      hset.clear();
      haveData = false;
      nullDataPresent = false;
    }

  public boolean haveData(String catName, DictionaryCategory dc)
    {
      boolean rval = haveData;

      if (rval)
	{
	  // check if we have all the mandatory items
	  ArrayList al = (ArrayList) mandatoryItems.get(catName);
	  if (al != null)
	    {
	      for (int i = 0; i < al.size(); i++)
		{
		  DictionaryItem di = (DictionaryItem) al.get(i);
		  if ( ! hset.contains(di))
		    {
		      // missing a mandatory item
		      rval = false;
		      break;
		    }
		}
	    }
	  // check to see if we deleted the only data inside the record
	  // record (non-attribute) data
	  if (rval & nullDataPresent)
	    {
	      boolean emptyInterior = false;
	      ArrayList a = getArrayList();
	      for (int i = 0; i < a.size(); i++)
		{
		  ItemElem ie = (ItemElem) a.get(i);
		  String fullName = ie.getDictionaryItem().getItemName();
		  boolean key = dc.isKey(fullName);
		  if ( ! key)
		    {
		      emptyInterior = true;
		      break;
		    }
		}
	      rval = emptyInterior;
	    }
	}
      return rval;
    }

  public void add(DictionaryItem d, String val)
    {
      String v = val.trim();
      if ( ! v.equals("?") && ! v.equals("."))
	{
	  haveData = true;
	  // must maintain order so keep DictionaryItems in a list
	  list.add(new ItemElem(d, val));
	  // for fast access of mandatory items check, also keep it in a HashSet
	  hset.add(d);
	}
      else
	{
	  nullDataPresent = true;
	}
    }
}
