--
-- PDB Macromolecular Structure
-- SQL Definitions for loading system tables
--     written: Tue Jul 29 17:48:52 PDT 2003
--
-- Copyright 2003
--     Douglas Greer, John Westbrook and Phil Bourne,
--     Research Collaboratory for Structural Bioinfomatics,
--     International Union of Crystallography
--


--
-- Setup commands specific for database type: MS_Access
--
-- <None>
--
-- End of database specific commands
--

INSERT into MMS_SYSTEM ( data_bank, model_id, revision_number, version )
    VALUES ( 'RCSB-PDB IUCr/Core', 'Std', '3.0', 'Std_3.0' ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 0, 'ATOM_SITE', 'atom_site', 'N', 0, 
        '              Data items in the ATOM_SITE category record details about\
               the atom sites in a macromolecular crystal structure, such as\
               the positional coordinates, atomic displacement parameters,\
               magnetic moments and directions, and so on.\
\
               The data items for describing anisotropic temperature or atomic\
               displacement factors are only used if the corresponding items\
               are not given in the ATOM_SITE_ANISOTROP category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 0, 'id', 'id', 0, 'Y', 
        '              The value of _atom_site.id must uniquely identify a record in the\
               ATOM_SITE list.\
\
               Note that this item need not be a number; it can be any unique\
               identifier.\
\
               This data item was introduced to facilitate compatibility between\
               small molecule and macromolecular files. In the small molecule\
               files, _atom_site_label is the identifier for the atom. In the\
               macromolecular files, the atom identifier is the aggregate of\
               _atom_site.label_alt_id, _atom_site.label_asym_id,\
               _atom_site.label_atom_id, _atom_site.label_comp_id and\
               _atom_site.label_seq_id. For the two types of files to be\
               compatible, a formal identifier for the category had to be\
               introduced that was independent of the different modes of\
               identifying atoms. For compatibility with older files,\
               _atom_site_label is aliased to _atom_site.id.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1, 'occupancy', 'occupancy', 0, 'N', 
        '              The fraction of the atom type present at this site.\
               The sum of the occupancies of all the atom types at this site\
               may not significantly exceed 1.0 unless it is a dummy site.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 2, 'b_iso_or_equiv', 'b_iso_or_equiv', 0, 'N', 
        '              Isotropic temperature factor parameter, or equivalent isotropic\
               temperature factor, B~equiv~, calculated from anisotropic\
               temperature factor parameters.\
\
               B~equiv~ = (1/3) sum~i~[sum~j~(B~ij~ A~i~ A~j~ a*~i~ a*~j~)] \
\
               A     = the real space cell lengths\
               a*    = the reciprocal space cell lengths\
               B~ij~ = 8 pi^2^ U~ij~\
\
               Ref: Fischer, R. X. \& Tillmanns, E. (1988). Acta Cryst. C44,\
                    775-776.\
\
               The IUCr Commission on Nomenclature recommends against the use\
               of B for reporting atomic displacement parameters. U, being\
               directly proportional to B, is preferred.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 3, 'model_num', 'model_num', 0, 'N', 
        '   PDB model number.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 4, 'attached_hydrogens', 'attached_hydrogens', 0, 'N', 
        '              The number of hydrogen atoms attached to the atom at this site\
               excluding any H atoms for which coordinates (measured or\
               calculated) are given.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 5, 'auth_asym_id', 'auth_asym_id', 0, 'N', 
        '              An alternative identifier for _atom_site.label_asym_id that\
               may be provided by an author in order to match the identification\
               used in the publication that describes the structure.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 6, 'auth_atom_id', 'auth_atom_id', 0, 'N', 
        '              An alternative identifier for _atom_site.label_atom_id that\
               may be provided by an author in order to match the identification\
               used in the publication that describes the structure.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 7, 'auth_comp_id', 'auth_comp_id', 0, 'N', 
        '              An alternative identifier for _atom_site.label_comp_id that\
               may be provided by an author in order to match the identification\
               used in the publication that describes the structure.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 8, 'auth_seq_id', 'auth_seq_id', 0, 'N', 
        '              An alternative identifier for _atom_site.label_seq_id that\
               may be provided by an author in order to match the identification\
               used in the publication that describes the structure.\
\
               Note that this is not necessarily a number, that the values do\
               not have to be positive, and that the value does not have to\
               correspond to the value of _atom_site.label_seq_id. The value\
               of _atom_site.label_seq_id is required to be a sequential list \
               of positive integers.\
\
               The author may assign values to _atom_site.auth_seq_id in any\
               desired way. For instance, the values may be used to relate\
               this structure to a numbering scheme in a homologous structure,\
               including sequence gaps or insertion codes. Alternatively, a\
               scheme may be used for a truncated polymer that maintains the\
               numbering scheme of the full length polymer. In all cases, the\
               scheme used here must match the scheme used in the publication\
               that describes the structure.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 9, 'calc_attached_atom', 'calc_attached_atom', 0, 'N', 
        '              The _atom_site.id of the atom site to which the ''geometry-\
               calculated'' atom site is attached.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 10, 'occupancy_esd', 'occupancy_esd', 0, 'N', 
        '              The estimated standard deviation of _atom_site.occupancy.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 11, 'pdbx_PDB_ins_code', 'pdbx_PDB_ins_code', 0, 'N', 
        '    PDB insertion code.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 1, 'ATOM_SITE_ANISOTROP', 'atom_site_anisotrop', 'N', 0, 
        '              Data items in the ATOM_SITE_ANISOTROP category record details\
               about temperature or thermal displacement factors, if those data\
               items are contained in a separate list from the ATOM_SITE list.\
               If the ATOM_SITE_ANISOTROP category is used for storing these\
               data, the corresponding ATOM_SITE data items are not used.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 12, 'b_0_0', 'B[1][1]', 1, 'N', 
        '              The [1][1] element of the anisotropic atomic displacement\
               matrix B, which appears in the structure factor term as:\
\
               T = exp{-1/4 sum~i~[sum~j~(B~ij~ h~i~ h~j~ a*~i~ a*~j~)]}\
\
               h  = the Miller indices\
               a* = the reciprocal space cell lengths\
\
               These matrix elements may appear with atomic coordinates\
               in the ATOM_SITE category, or they may appear in the separate\
               ATOM_SITE_ANISOTROP category, but they may not appear in both\
               places. Similarly, anisotropic displacements may appear as\
               either B''s or U''s, but not as both.\
\
               The unique elements of the real symmetric matrix are\
               entered by row.\
\
               The IUCr Commission on Nomenclature recommends against the use\
               of B for reporting atomic displacement parameters. U, being\
               directly proportional to B, is preferred.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 13, 'b_0_1', 'B[1][2]', 1, 'N', 
        '              The [1][2] element of the anisotropic atomic displacement\
               matrix B, which appears in the structure factor term as:\
\
               T = exp{-1/4 sum~i~[sum~j~(B~ij~ h~i~ h~j~ a*~i~ a*~j~)]}\
\
               h  = the Miller indices\
               a* = the reciprocal space cell lengths\
\
               These matrix elements may appear with atomic coordinates\
               in the ATOM_SITE category, or they may appear in the separate\
               ATOM_SITE_ANISOTROP category, but they may not appear in both\
               places. Similarly, anisotropic displacements may appear as\
               either B''s or U''s, but not as both.\
\
               The unique elements of the real symmetric matrix are\
               entered by row.\
\
               The IUCr Commission on Nomenclature recommends against the use\
               of B for reporting atomic displacement parameters. U, being\
               directly proportional to B, is preferred.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 14, 'b_0_2', 'B[1][3]', 1, 'N', 
        '              The [1][3] element of the anisotropic atomic displacement\
               matrix B, which appears in the structure factor term as:\
\
               T = exp{-1/4 sum~i~[sum~j~(B~ij~ h~i~ h~j~ a*~i~ a*~j~)]}\
\
               h  = the Miller indices\
               a* = the reciprocal space cell lengths\
\
               These matrix elements may appear with atomic coordinates\
               in the ATOM_SITE category, or they may appear in the separate\
               ATOM_SITE_ANISOTROP category, but they may not appear in both\
               places. Similarly, anisotropic displacements may appear as\
               either B''s or U''s, but not as both.\
\
               The unique elements of the real symmetric matrix are\
               entered by row.\
\
               The IUCr Commission on Nomenclature recommends against the use\
               of B for reporting atomic displacement parameters. U, being\
               directly proportional to B, is preferred.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 15, 'b_1_1', 'B[2][2]', 1, 'N', 
        '              The [2][2] element of the anisotropic atomic displacement\
               matrix B, which appears in the structure factor term as:\
\
               T = exp{-1/4 sum~i~[sum~j~(B~ij~ h~i~ h~j~ a*~i~ a*~j~)]}\
\
               h  = the Miller indices\
               a* = the reciprocal space cell lengths\
\
               These matrix elements may appear with atomic coordinates\
               in the ATOM_SITE category, or they may appear in the separate\
               ATOM_SITE_ANISOTROP category, but they may not appear in both\
               places. Similarly, anisotropic displacements may appear as\
               either B''s or U''s, but not as both.\
\
               The unique elements of the real symmetric matrix are\
               entered by row.\
\
               The IUCr Commission on Nomenclature recommends against the use\
               of B for reporting atomic displacement parameters. U, being\
               directly proportional to B, is preferred.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 16, 'b_1_2', 'B[2][3]', 1, 'N', 
        '              The [2][3] element of the anisotropic atomic displacement\
               matrix B, which appears in the structure factor term as:\
\
               T = exp{-1/4 sum~i~[sum~j~(B~ij~ h~i~ h~j~ a*~i~ a*~j~)]}\
\
               h  = the Miller indices\
               a* = the reciprocal space cell lengths\
\
               These matrix elements may appear with atomic coordinates\
               in the ATOM_SITE category, or they may appear in the separate\
               ATOM_SITE_ANISOTROP category, but they may not appear in both\
               places. Similarly, anisotropic displacements may appear as\
               either B''s or U''s, but not as both.\
\
               The unique elements of the real symmetric matrix are\
               entered by row.\
\
               The IUCr Commission on Nomenclature recommends against the use\
               of B for reporting atomic displacement parameters. U, being\
               directly proportional to B, is preferred.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 17, 'b_2_2', 'B[3][3]', 1, 'N', 
        '              The [3][3] element of the anisotropic atomic displacement\
               matrix B, which appears in the structure factor term as:\
\
               T = exp{-1/4 sum~i~[sum~j~(B~ij~ h~i~ h~j~ a*~i~ a*~j~)]}\
\
               h  = the Miller indices\
               a* = the reciprocal space cell lengths\
\
               These matrix elements may appear with atomic coordinates\
               in the ATOM_SITE category, or they may appear in the separate\
               ATOM_SITE_ANISOTROP category, but they may not appear in both\
               places. Similarly, anisotropic displacements may appear as\
               either B''s or U''s, but not as both.\
\
               The unique elements of the real symmetric matrix are\
               entered by row.\
\
               The IUCr Commission on Nomenclature recommends against the use\
               of B for reporting atomic displacement parameters. U, being\
               directly proportional to B, is preferred.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 18, 'b_esd_0_0', 'B[1][1]_esd', 1, 'N', 
        '              The estimated standard deviation of _atom_site_anisotrop.B[1][1].'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 19, 'b_esd_0_1', 'B[1][2]_esd', 1, 'N', 
        '              The estimated standard deviation of _atom_site_anisotrop.B[1][2].'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 20, 'b_esd_0_2', 'B[1][3]_esd', 1, 'N', 
        '              The estimated standard deviation of _atom_site_anisotrop.B[1][3].'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 21, 'b_esd_1_1', 'B[2][2]_esd', 1, 'N', 
        '              The estimated standard deviation of _atom_site_anisotrop.B[2][2].'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 22, 'b_esd_1_2', 'B[2][3]_esd', 1, 'N', 
        '              The estimated standard deviation of _atom_site_anisotrop.B[2][3].'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 23, 'b_esd_2_2', 'B[3][3]_esd', 1, 'N', 
        '              The estimated standard deviation of _atom_site_anisotrop.B[3][3].'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 24, 'ratio', 'ratio', 1, 'N', 
        '              Ratio of the maximum to minimum principal axes of\
               displacement (thermal) ellipsoids.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 25, 'u_0_0', 'U[1][1]', 1, 'N', 
        '              The [1][1] element of the standard anisotropic atomic\
               displacement matrix U, which appears in the structure factor\
               term as:\
\
               T = exp{-2 pi^2^ sum~i~[sum~j~(U~ij~ h~i~ h~j~ a*~i~ a*~j~)]}\
\
               h  = the Miller indices\
               a* = the reciprocal space cell lengths\
\
               These matrix elements may appear with atomic coordinates\
               in the ATOM_SITE category, or they may appear in the separate\
               ATOM_SITE_ANISOTROP category, but they may not appear in both\
               places. Similarly, anisotropic displacements may appear as\
               either B''s or U''s, but not as both.\
\
               The unique elements of the real symmetric matrix are\
               entered by row.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 26, 'u_0_1', 'U[1][2]', 1, 'N', 
        '              The [1][2] element of the standard anisotropic atomic\
               displacement matrix U, which appears in the structure factor\
               term as:\
\
               T = exp{-2 pi^2^ sum~i~[sum~j~(U~ij~ h~i~ h~j~ a*~i~ a*~j~)]}\
\
               h  = the Miller indices\
               a* = the reciprocal space cell lengths\
\
               These matrix elements may appear with atomic coordinates\
               in the ATOM_SITE category, or they may appear in the separate\
               ATOM_SITE_ANISOTROP category, but they may not appear in both\
               places. Similarly, anisotropic displacements may appear as\
               either B''s or U''s, but not as both.\
\
               The unique elements of the real symmetric matrix are\
               entered by row.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 27, 'u_0_2', 'U[1][3]', 1, 'N', 
        '              The [1][3] element of the standard anisotropic atomic\
               displacement matrix U, which appears in the structure factor\
               term as:\
\
               T = exp{-2 pi^2^ sum~i~[sum~j~(U~ij~ h~i~ h~j~ a*~i~ a*~j~)]}\
\
               h  = the Miller indices\
               a* = the reciprocal space cell lengths\
\
               These matrix elements may appear with atomic coordinates\
               in the ATOM_SITE category, or they may appear in the separate\
               ATOM_SITE_ANISOTROP category, but they may not appear in both\
               places. Similarly, anisotropic displacements may appear as\
               either B''s or U''s, but not as both.\
\
               The unique elements of the real symmetric matrix are\
               entered by row.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 28, 'u_1_1', 'U[2][2]', 1, 'N', 
        '              The [2][2] element of the standard anisotropic atomic\
               displacement matrix U, which appears in the structure factor\
               term as:\
\
               T = exp{-2 pi^2^ sum~i~[sum~j~(U~ij~ h~i~ h~j~ a*~i~ a*~j~)]}\
\
               h  = the Miller indices\
               a* = the reciprocal space cell lengths\
\
               These matrix elements may appear with atomic coordinates\
               in the ATOM_SITE category, or they may appear in the separate\
               ATOM_SITE_ANISOTROP category, but they may not appear in both\
               places. Similarly, anisotropic displacements may appear as\
               either B''s or U''s, but not as both.\
\
               The unique elements of the real symmetric matrix are\
               entered by row.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 29, 'u_1_2', 'U[2][3]', 1, 'N', 
        '              The [2][3] element of the standard anisotropic atomic\
               displacement matrix U, which appears in the structure factor\
               term as:\
\
               T = exp{-2 pi^2^ sum~i~[sum~j~(U~ij~ h~i~ h~j~ a*~i~ a*~j~)]}\
\
               h  = the Miller indices\
               a* = the reciprocal space cell lengths\
\
               These matrix elements may appear with atomic coordinates\
               in the ATOM_SITE category, or they may appear in the separate\
               ATOM_SITE_ANISOTROP category, but they may not appear in both\
               places. Similarly, anisotropic displacements may appear as\
               either B''s or U''s, but not as both.\
\
               The unique elements of the real symmetric matrix are\
               entered by row.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 30, 'u_2_2', 'U[3][3]', 1, 'N', 
        '              The [3][3] element of the standard anisotropic atomic\
               displacement matrix U, which appears in the structure factor\
               term as:\
\
               T = exp{-2 pi^2^ sum~i~[sum~j~(U~ij~ h~i~ h~j~ a*~i~ a*~j~)]}\
\
               h  = the Miller indices\
               a* = the reciprocal space cell lengths\
\
               These matrix elements may appear with atomic coordinates\
               in the ATOM_SITE category, or they may appear in the separate\
               ATOM_SITE_ANISOTROP category, but they may not appear in both\
               places. Similarly, anisotropic displacements may appear as\
               either B''s or U''s, but not as both.\
\
               The unique elements of the real symmetric matrix are\
               entered by row.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 31, 'u_esd_0_0', 'U[1][1]_esd', 1, 'N', 
        '              The estimated standard deviation of _atom_site_anisotrop.U[1][1].'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 32, 'u_esd_0_1', 'U[1][2]_esd', 1, 'N', 
        '              The estimated standard deviation of _atom_site_anisotrop.U[1][2].'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 33, 'u_esd_0_2', 'U[1][3]_esd', 1, 'N', 
        '              The estimated standard deviation of _atom_site_anisotrop.U[1][3].'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 34, 'u_esd_1_1', 'U[2][2]_esd', 1, 'N', 
        '              The estimated standard deviation of _atom_site_anisotrop.U[2][2].'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 35, 'u_esd_1_2', 'U[2][3]_esd', 1, 'N', 
        '              The estimated standard deviation of _atom_site_anisotrop.U[2][3].'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 36, 'u_esd_2_2', 'U[3][3]_esd', 1, 'N', 
        '              The estimated standard deviation of _atom_site_anisotrop.U[3][3].'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 37, 'pdbx_auth_seq_id', 'pdbx_auth_seq_id', 1, 'N', 
        '              Pointer to _atom_site.auth_seq_id'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 38, 'pdbx_auth_alt_id', 'pdbx_auth_alt_id', 1, 'N', 
        '      Pointer to _atom_site.pdbx_auth_alt_id.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 39, 'pdbx_auth_asym_id', 'pdbx_auth_asym_id', 1, 'N', 
        '      Pointer to _atom_site.auth_asym_id'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 40, 'pdbx_auth_atom_id', 'pdbx_auth_atom_id', 1, 'N', 
        '       Pointer to _atom_site.auth_atom_id'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 41, 'pdbx_auth_comp_id', 'pdbx_auth_comp_id', 1, 'N', 
        '     Pointer to _atom_site.auth_comp_id'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 42, 'pdbx_label_seq_id', 'pdbx_label_seq_id', 1, 'N', 
        '              Pointer to _atom_site.label_seq_id'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 43, 'pdbx_label_alt_id', 'pdbx_label_alt_id', 1, 'N', 
        '      Pointer to _atom_site.label_alt_id.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 44, 'pdbx_label_asym_id', 'pdbx_label_asym_id', 1, 'N', 
        '      Pointer to _atom_site.label_asym_id'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 45, 'pdbx_label_atom_id', 'pdbx_label_atom_id', 1, 'N', 
        '       Pointer to _atom_site.label_atom_id'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 46, 'pdbx_label_comp_id', 'pdbx_label_comp_id', 1, 'N', 
        '     Pointer to _atom_site.label_comp_id'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 47, 'pdbx_PDB_ins_code', 'pdbx_PDB_ins_code', 1, 'N', 
        '            Pointer to _atom_site.pdbx_PDB_ins_code         '
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 2, 'ATOM_TYPE', 'atom_type', 'N', 0, 
        '              Data items in the ATOM_TYPE category record details about\
               properties of the atoms that occupy the atom sites, such as the\
               atomic scattering factors.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 48, 'analytical_mass_percent', 'analytical_mass_percent', 2, 'N', 
        '              Mass percentage of this atom type derived from chemical analysis.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 49, 'description', 'description', 2, 'N', 
        '              A description of the atom(s) designated by this atom type. In\
               most cases this is the element name and oxidation state of\
               a single atom species. For disordered or nonstoichiometric\
               structures it will describe a combination of atom species.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 50, 'number_in_cell', 'number_in_cell', 2, 'N', 
        '              Total number of atoms of this atom type in the unit cell.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 51, 'oxidation_number', 'oxidation_number', 2, 'N', 
        '              Formal oxidation state of this atom type in the structure.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 52, 'radius_bond', 'radius_bond', 2, 'N', 
        '              The effective intramolecular bonding radius in angstroms\
               of this atom type.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 53, 'radius_contact', 'radius_contact', 2, 'N', 
        '              The effective intermolecular bonding radius in angstroms\
               of this atom type.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 54, 'scat_cromer_mann_a1', 'scat_cromer_mann_a1', 2, 'N', 
        '              The a1 Cromer-Mann scattering-factor coefficient used to\
               calculate the scattering factors for this atom type.\
\
               Ref: International Tables for X-ray Crystallography, Vol. IV,\
                    (1974). Table 2.2B.\
                or: International Tables for Crystallography, Vol. C,\
                    (1991). Tables 6.1.1.4 and 6.1.1.5.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 55, 'scat_cromer_mann_a2', 'scat_cromer_mann_a2', 2, 'N', 
        '              The a2 Cromer-Mann scattering-factor coefficient used to\
               calculate the scattering factors for this atom type.\
\
               Ref: International Tables for X-ray Crystallography, Vol. IV,\
                    (1974). Table 2.2B.\
                or: International Tables for Crystallography, Vol. C,\
                    (1991). Tables 6.1.1.4 and 6.1.1.5.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 56, 'scat_cromer_mann_a3', 'scat_cromer_mann_a3', 2, 'N', 
        '              The a3 Cromer-Mann scattering-factor coefficient used to\
               calculate the scattering factors for this atom type.\
\
               Ref: International Tables for X-ray Crystallography, Vol. IV,\
                    (1974). Table 2.2B.\
                or: International Tables for Crystallography, Vol. C,\
                    (1991). Tables 6.1.1.4 and 6.1.1.5.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 57, 'scat_cromer_mann_a4', 'scat_cromer_mann_a4', 2, 'N', 
        '              The a4 Cromer-Mann scattering-factor coefficient used to\
               calculate the scattering factors for this atom type.\
\
               Ref: International Tables for X-ray Crystallography, Vol. IV,\
                    (1974). Table 2.2B.\
                or: International Tables for Crystallography, Vol. C,\
                    (1991). Tables 6.1.1.4 and 6.1.1.5.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 58, 'scat_cromer_mann_b1', 'scat_cromer_mann_b1', 2, 'N', 
        '              The b1 Cromer-Mann scattering-factor coefficient used to\
               calculate the scattering factors for this atom type.\
\
               Ref: International Tables for X-ray Crystallography, Vol. IV,\
                    (1974). Table 2.2B.\
                or: International Tables for Crystallography, Vol. C,\
                    (1991). Tables 6.1.1.4 and 6.1.1.5.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 59, 'scat_cromer_mann_b2', 'scat_cromer_mann_b2', 2, 'N', 
        '              The b2 Cromer-Mann scattering-factor coefficient used to\
               calculate the scattering factors for this atom type.\
\
               Ref: International Tables for X-ray Crystallography, Vol. IV,\
                    (1974). Table 2.2B.\
                or: International Tables for Crystallography, Vol. C,\
                    (1991). Tables 6.1.1.4 and 6.1.1.5.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 60, 'scat_cromer_mann_b3', 'scat_cromer_mann_b3', 2, 'N', 
        '              The b3 Cromer-Mann scattering-factor coefficient used to\
               calculate the scattering factors for this atom type.\
\
               Ref: International Tables for X-ray Crystallography, Vol. IV,\
                    (1974). Table 2.2B.\
                or: International Tables for Crystallography, Vol. C,\
                    (1991). Tables 6.1.1.4 and 6.1.1.5.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 61, 'scat_cromer_mann_b4', 'scat_cromer_mann_b4', 2, 'N', 
        '              The b4 Cromer-Mann scattering-factor coefficient used to\
               calculate the scattering factors for this atom type.\
\
               Ref: International Tables for X-ray Crystallography, Vol. IV,\
                    (1974). Table 2.2B.\
                or: International Tables for Crystallography, Vol. C,\
                    (1991). Tables 6.1.1.4 and 6.1.1.5.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 62, 'scat_cromer_mann_c', 'scat_cromer_mann_c', 2, 'N', 
        '              The c Cromer-Mann scattering-factor coefficient used to\
               calculate the scattering factors for this atom type.\
\
               Ref: International Tables for X-ray Crystallography, Vol. IV,\
                    (1974). Table 2.2B.\
                or: International Tables for Crystallography, Vol. C,\
                    (1991). Tables 6.1.1.4 and 6.1.1.5.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 63, 'scat_dispersion_imag', 'scat_dispersion_imag', 2, 'N', 
        '              The imaginary component of the anomalous dispersion\
               scattering factors, f'''' (in electrons), for this atom type and\
               the radiation identified by _diffrn_radiation_wavelength.id.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 64, 'scat_dispersion_real', 'scat_dispersion_real', 2, 'N', 
        '              The real component of the anomalous dispersion\
               scattering factors, f'' (in electrons), for this atom type and\
               the radiation identified by _diffrn_radiation_wavelength.id.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 65, 'scat_length_neutron', 'scat_length_neutron', 2, 'N', 
        '              The bound coherent scattering length in femtometres for the\
               atom type at the isotopic composition used for the diffraction\
               experiment.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 66, 'scat_source', 'scat_source', 2, 'N', 
        '              Reference to source of scattering factors used for this atom\
               type.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 67, 'scat_versus_stol_list', 'scat_versus_stol_list', 2, 'N', 
        '              A table of scattering factors as a function of sin theta over\
               lambda. This table should be well commented to indicate the\
               items present. Regularly formatted lists are strongly\
               recommended.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 68, 'symbol', 'symbol', 2, 'Y', 
        '              The code used to identify the atom specie(s) representing this\
               atom type. Normally this code is the element symbol. The code\
               may be composed of any character except an underline with the\
               additional proviso that digits designate an oxidation state and\
               must be followed by a + or - character.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 3, 'CHEM_COMP', 'chem_comp', 'N', 0, 
        '              Data items in the CHEM_COMP category give details (such as\
               name, mass, charge, etc.) about each of the chemical components\
               from which the relevant chemical structures can be constructed.\
\
               The related categories CHEM_COMP_ATOM, CHEM_COMP_BOND, \
               CHEM_COMP_ANGLE, etc. describe the detailed geometry of these\
               chemical components.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 69, 'formula', 'formula', 3, 'N', 
        '              The formula for the chemical component. Formulae are written\
               according to the rules:\
\
               1. Only recognised element symbols may be used.\
\
               2. Each element symbol is followed by a ''count'' number. A count\
                  of ''1'' may be omitted.\
\
               3. A space or parenthesis must separate each element symbol and\
                  its count, but in general parentheses are not used.\
\
               4. The order of elements depends on whether or not carbon is\
                  present. If carbon is present, the order should be: C, then\
                  H, then the other elements in alphabetical order of their\
                  symbol. If carbon is not present, the elements are listed\
                  purely in alphabetic order of their symbol. This is the\
                  ''Hill'' system used by Chemical Abstracts.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 70, 'formula_weight', 'formula_weight', 3, 'N', 
        '              Formula mass in daltons of the chemical component.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 71, 'id', 'id', 3, 'Y', 
        '              The value of _chem_comp.id must uniquely identify each item in\
               the CHEM_COMP list.\
\
               For protein polymer entities, this is the three-letter code for\
               amino acids.\
\
               For nucleic acid polymer entities, this is the one-letter code\
               for the bases.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 72, 'model_details', 'model_details', 3, 'N', 
        '              A description of special aspects of the generation of the\
               coordinates for the model of the component.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 73, 'model_ext_reference_file', 'model_ext_reference_file', 3, 'N', 
        '              A pointer to an ''external reference file'', if the atomic\
               description of the component is taken from such a file.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 74, 'model_source', 'model_source', 3, 'N', 
        '              The source of the coordinates for the model of the component.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 75, 'mon_nstd_class', 'mon_nstd_class', 3, 'N', 
        '              A description of the class of a non-standard monomer, if the\
               group represents a modification of a standard monomer.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 76, 'mon_nstd_details', 'mon_nstd_details', 3, 'N', 
        '              A description of special details of a non-standard monomer.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 77, 'mon_nstd_flag', 'mon_nstd_flag', 3, 'N', 
        '              ''yes'' indicates that this is a "standard" monomer, ''no'' that it\
               is "non-standard."  Non-standard monomers should be further\
               described using the _chem_comp.mon_nstd_parent,\
               _chem_comp.mon_nstd_class, and _chem_comp.mon_nstd_details data\
               items.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 78, 'mon_nstd_parent', 'mon_nstd_parent', 3, 'N', 
        '              A name of the parent monomer of the non-standard monomer,\
               if this group represents a modification of a standard monomer.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 79, 'name', 'name', 3, 'N', 
        '              The full name of the component.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 80, 'number_atoms_all', 'number_atoms_all', 3, 'N', 
        '              The total number of atoms in the component.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 81, 'number_atoms_nh', 'number_atoms_nh', 3, 'N', 
        '              The number of non-hydrogen atoms in the component.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 82, 'one_letter_code', 'one_letter_code', 3, 'N', 
        '              For standard polymer components, the one-letter code for\
               the component. If there is not a standard one-letter code\
               for this component, or if this is a non-polymer\
               component, the one-letter code should be given as ''X''.\
               This code may be preceded by a ''+'' character to indicate\
               that the component is a modification of a standard \
               component.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 83, 'three_letter_code', 'three_letter_code', 3, 'N', 
        '              For standard polymer components, the three-letter code for\
               the component. If there is not a standard three-letter code\
               for this component, or if this is a non-polymer\
               component, the three-letter code should be given as ''UNK''.\
               This code may be preceded by a ''+'' character to indicate\
               that the component is a modification of a standard \
               component.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 84, 'type', 'type', 3, 'Y', 
        '              For standard polymer components, the type of the monomer.\
               Note that monomers that will form polymers are of three types:\
               linking monomers, monomers with some type of N-terminal (or 5'')\
               cap, and monomers with some type of C-terminal (or 3'') cap.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 85, 'pdbx_synonyms', 'pdbx_synonyms', 3, 'N', 
        '              Synonym list for the component.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 86, 'pdbx_modification_details', 'pdbx_modification_details', 3, 'N', 
        '             For nonstandard components a text description \
              of modification of the parent component.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 87, 'pdbx_component_no', 'pdbx_component_no', 3, 'N', 
        '              A serial number used by PDB in the FORMUL record.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 4, 'CHEM_COMP_ANGLE', 'chem_comp_angle', 'N', 0, 
        '              Data items in the CHEM_COMP_ANGLE category record details about\
               angles in a chemical component. Angles are designated by three\
               atoms, with the second atom forming the vertex of the angle.\
               Target values may be specified as angles in degrees, as a\
               distance between the first and third atoms, or both.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 88, 'value_angle', 'value_angle', 4, 'N', 
        '              The value that should be taken as the target value for the angle\
               associated with the specified atoms, expressed in degrees.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 89, 'value_angle_esd', 'value_angle_esd', 4, 'N', 
        '              The estimated standard deviation of\
               _chem_comp_angle.value_angle.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 90, 'value_dist', 'value_dist', 4, 'N', 
        '              The value that should be taken as the target value for the angle\
               associated with the specified atoms, expressed as the distance\
               between the atoms specified by _chem_comp_angle.atom_id_1 and\
               _chem_comp_angle.atom_id_3.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 91, 'value_dist_esd', 'value_dist_esd', 4, 'N', 
        '              The estimated standard deviation of\
               _chem_comp_angle.value_dist_esd.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 5, 'CHEM_COMP_ATOM', 'chem_comp_atom', 'N', 0, 
        '              Data items in the CHEM_COMP_ATOM category record details about\
               the atoms in a chemical component. Atomic coordinates can be\
               given for the components; specifying coordinates is an\
               alternative to specifying the structure of the component\
               via bonds, angles, planes, etc., in the appropriate\
               CHEM_COMP subcategories.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 92, 'alt_atom_id', 'alt_atom_id', 5, 'N', 
        '              An alternative identifier for the atom. This data item would be\
               used in cases where alternative nomenclatures exist for labeling\
               atoms in a group.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 93, 'atom_id', 'atom_id', 5, 'Y', 
        '              The value of _chem_comp_atom.atom_id must uniquely identify\
               each atom in each monomer in the CHEM_COMP_ATOM list.\
\
               The atom identifiers need not be unique over all atoms in the\
               data block; they need only be unique for each atom in a\
               component.\
\
               Note that this item need not be a number; it can be any unique\
               identifier.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 94, 'charge', 'charge', 5, 'N', 
        '              The net integer charge assigned to this atom. This is the\
               formal charge assignment normally found in chemical diagrams.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 95, 'partial_charge', 'partial_charge', 5, 'N', 
        '              The partial charge assigned to this atom.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 96, 'substruct_code', 'substruct_code', 5, 'N', 
        '              This data item assigns the atom to a substructure of the\
               component, if appropriate.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 6, 'CHEM_COMP_BOND', 'chem_comp_bond', 'N', 0, 
        '              Data items in the CHEM_COMP_BOND category record details about\
               the bonds between atoms in a chemical component. Target values\
               may be specified as bond orders, as a distance between the two\
               atoms, or both.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 97, 'value_order', 'value_order', 6, 'N', 
        '              The value that should be taken as the target for the chemical\
               bond associated with the specified atoms, expressed as a bond\
               order.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 98, 'value_dist', 'value_dist', 6, 'N', 
        '              The value that should be taken as the target for the chemical\
               bond associated with the specified atoms, expressed as a\
               distance.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 99, 'value_dist_esd', 'value_dist_esd', 6, 'N', 
        '              The estimated standard deviation of _chem_comp_bond.value_dist.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 7, 'CHEM_COMP_CHIR', 'chem_comp_chir', 'N', 0, 
        '              Data items in the CHEM_COMP_CHIR category provide detail about\
               the chiral centers in a chemical component. The atoms bonded\
               to the chiral atom are specified in the CHEM_COMP_CHIR_ATOM\
               category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 100, 'atom_config', 'atom_config', 7, 'N', 
        '              The chiral configuration of the atom that is a chiral center.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 101, 'id', 'id', 7, 'Y', 
        '              The value of _chem_comp_chir.id must uniquely identify a record\
               in the CHEM_COMP_CHIR list.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 102, 'number_atoms_all', 'number_atoms_all', 7, 'N', 
        '              The total number of atoms bonded to the atom specified by\
               _chem_comp_chir.atom_id.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 103, 'number_atoms_nh', 'number_atoms_nh', 7, 'N', 
        '              The number of non-hydrogen atoms bonded to the atom specified by\
               _chem_comp_chir.atom_id.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 104, 'volume_flag', 'volume_flag', 7, 'N', 
        '              A flag to indicate whether a chiral volume should match the\
               standard value in both magnitude and sign, or in magnitude only.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 105, 'volume_three', 'volume_three', 7, 'N', 
        '              The chiral volume, V(c), for chiral centers that involve a chiral\
               atom bonded to three non-hydrogen atoms and one hydrogen atom.\
\
               V~c~ = V1 * (V2 X V3)\
\
               V1 = the vector distance from the atom specified by\
                    _chem_comp_chir.atom_id to the first atom in the\
                    CHEM_COMP_CHIR_ATOM list\
               V2 = the vector distance from the atom specified by\
                    _chem_comp_chir.atom_id to the second atom in the\
                    CHEM_COMP_CHIR_ATOM list\
               V3 = the vector distance from the atom specified by\
                    _chem_comp_chir.atom_id to the third atom in the\
                    CHEM_COMP_CHIR_ATOM list\
               *  = the vector dot product\
               X  = the vector cross product'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 106, 'volume_three_esd', 'volume_three_esd', 7, 'N', 
        '              The estimated standard deviation of\
               _chem_comp_chir.volume_three.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 8, 'CHEM_COMP_CHIR_ATOM', 'chem_comp_chir_atom', 'N', 0, 
        '              Data items in the CHEM_COMP_CHIR_ATOM category enumerate the\
               atoms bonded to a chiral atom within a chemical component.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 107, 'dev', 'dev', 8, 'N', 
        '              The estimated standard deviation of the position of this atom\
               from the plane defined by all of the atoms in the plane.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 9, 'CHEM_COMP_LINK', 'chem_comp_link', 'N', 0, 
        '              Data items in the CHEM_COMP_LINK category give details about\
               the linkages between chemical components.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 108, 'details', 'details', 9, 'N', 
        '              A description of special aspects of a linkage between\
               chemical components in the structure.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 10, 'CHEM_COMP_PLANE', 'chem_comp_plane', 'N', 0, 
        '              Data items in the CHEM_COMP_PLANE category provide identifiers\
               for the planes in a chemical component.  The atoms in the plane\
               are specified in the CHEM_COMP_PLANE_ATOM category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 109, 'id', 'id', 10, 'Y', 
        '              The value of _chem_comp_plane.id must uniquely identify a record\
               in the CHEM_COMP_PLANE list.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 110, 'number_atoms_all', 'number_atoms_all', 10, 'N', 
        '              The total number of atoms in the plane.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 111, 'number_atoms_nh', 'number_atoms_nh', 10, 'N', 
        '              The number of non-hydrogen atoms in the plane.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 11, 'CHEM_COMP_PLANE_ATOM', 'chem_comp_plane_atom', 'N', 0, 
        '              Data items in the CHEM_COMP_PLANE_ATOM category enumerate the\
               atoms in a plane within a chemical component.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 112, 'dist_esd', 'dist_esd', 11, 'N', 
        '              This data item is the standard deviation of the\
               out-of-plane distance for this atom.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 12, 'CHEM_COMP_TOR', 'chem_comp_tor', 'N', 0, 
        '              Data items in the CHEM_COMP_TOR category record details about\
               the torsion angles in a chemical component. As torsion angles\
               can have more than one target value, the target values are\
               specified in the CHEM_COMP_TOR_VALUE category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 113, 'id', 'id', 12, 'Y', 
        '              The value of _chem_comp_tor.id must uniquely identify a\
               record in the CHEM_COMP_TOR list.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 13, 'CHEM_COMP_TOR_VALUE', 'chem_comp_tor_value', 'N', 0, 
        '              Data items in the CHEM_COMP_TOR_VALUE category record details\
               about the target values for the torsion angles enumerated in the\
               CHEM_COMP_TOR list. Target values may be specified as angles\
               in degrees, as a distance between the first and fourth atoms, or\
               both.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 114, 'angle', 'angle', 13, 'Y', 
        '              A value that should be taken as a potential target value for the\
               torsion angle associated with the specified atoms, expressed in\
               degrees.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 115, 'angle_esd', 'angle_esd', 13, 'Y', 
        '              The estimated standard deviation of _chem_comp_tor_value.angle.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 116, 'dist', 'dist', 13, 'N', 
        '              A value that should be taken as a potential target value for the\
               torsion angle associated with the specified atoms, expressed as\
               the distance between the atoms specified by\
               _chem_comp_tor.atom_id_1 and _chem_comp_tor.atom_id_4 in the\
               referenced record in the CHEM_COMP_TOR list. Note that the\
               torsion angle cannot be fully specified by a distance (for\
               instance, a torsion angle of -60 will yield the same distance as\
               a 60 degree angle). However the distance specification can be\
               useful for refinement in situations in which the angle is already\
               close to the desired value.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 117, 'dist_esd', 'dist_esd', 13, 'N', 
        '              The estimated standard deviation of\
               _chem_comp_tor_value.dist_esd.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 14, 'CHEM_LINK', 'chem_link', 'N', 0, 
        '              Data items in the CHEM_LINK category give details about\
               the linkages between chemical groups.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 118, 'id', 'id', 14, 'Y', 
        '              The value of _chem_link.id must uniquely identify each\
               item in the CHEM_LINK list.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 119, 'details', 'details', 14, 'N', 
        '              A description of special aspects of a linkage between\
               chemical components in the structure.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 15, 'CHEM_LINK_ANGLE', 'chem_link_angle', 'N', 0, 
        '              Data items in the CHEM_LINK_ANGLE category record details\
               about angles in a linkage between chemical groups.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 120, 'atom_1_comp_id', 'atom_1_comp_id', 15, 'N', 
        '              This data item indicates whether atom 1 is found in the first\
               or the second of the two components connected by the linkage.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 121, 'atom_2_comp_id', 'atom_2_comp_id', 15, 'N', 
        '              This data item indicates whether atom 2 is found in the first\
               or the second of the two components connected by the linkage.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 122, 'atom_3_comp_id', 'atom_3_comp_id', 15, 'N', 
        '              This data item indicates whether atom 3 is found in the first\
               or the second of the two components connected by the linkage.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 123, 'atom_id_1', 'atom_id_1', 15, 'Y', 
        '              The id of the first of the three atoms that define the angle.\
\
               An atom with this id must exist in the component of the type\
               specified by _chem_comp_link.type_1 (or _chem_comp_link.type_2,\
               where the appropriate data item is indated by the value of\
               _chem_comp_link.atom_1_comp_id).'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 124, 'atom_id_2', 'atom_id_2', 15, 'Y', 
        '              The id of the second of the three atoms that define the angle.\
               The second atom is taken to be the apex of the angle.\
\
               An atom with this id must exist in the component of the type\
               specified by _chem_comp_link.type_1 (or _chem_comp_link.type_2,\
               where the appropriate data item is indated by the value of\
               _chem_comp_link.atom_2_comp_id).'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 125, 'atom_id_3', 'atom_id_3', 15, 'Y', 
        '              The id of the third of the three atoms that define the angle.\
\
               An atom with this id must exist in the component of the type\
               specified by _chem_comp_link.type_1 (or _chem_comp_link.type_2,\
               where the appropriate data item is indated by the value of\
               _chem_comp_link.atom_3_comp_id).'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 126, 'value_angle', 'value_angle', 15, 'N', 
        '              The value that should be taken as the target value for the angle\
               associated with the specified atoms, expressed in degrees.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 127, 'value_angle_esd', 'value_angle_esd', 15, 'N', 
        '              The estimated standard deviation of\
               _chem_link_angle.value_angle.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 128, 'value_dist', 'value_dist', 15, 'N', 
        '              The value that should be taken as the target value for the angle\
               associated with the specified atoms, expressed as the distance\
               between the atoms specified by _chem_comp_angle.atom_id_1 and\
               _chem_comp_angle.atom_id_3.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 129, 'value_dist_esd', 'value_dist_esd', 15, 'N', 
        '              The estimated standard deviation of\
               _chem_comp_angle.value_dist_esd.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 16, 'CHEM_LINK_BOND', 'chem_link_bond', 'N', 0, 
        '              Data items in the CHEM_LINK_BOND category record details about\
               bonds in a linkage between components in the chemical structure.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 130, 'atom_1_comp_id', 'atom_1_comp_id', 16, 'N', 
        '              This data item indicates whether atom 1 is found in the first\
               or the second of the two components connected by the linkage.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 131, 'atom_2_comp_id', 'atom_2_comp_id', 16, 'N', 
        '              This data item indicates whether atom 2 is found in the first\
               or the second of the two chemical components connected by\
               the linkage.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 132, 'atom_id_1', 'atom_id_1', 16, 'Y', 
        '              The id of the first of the two atoms that define the bond.\
\
               As this data item does not point to a specific atom in a\
               specific chemical component, it is not a child in the\
               linkage sense.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 133, 'atom_id_2', 'atom_id_2', 16, 'Y', 
        '              The id of the second of the two atoms that define the bond.\
\
               As this data item does not point to a specific atom in a\
               specific component, it is not a child in the linkage sense.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 134, 'value_dist', 'value_dist', 16, 'N', 
        '              The value that should be taken as the target for the chemical\
               bond associated with the specified atoms, expressed as a\
               distance.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 135, 'value_dist_esd', 'value_dist_esd', 16, 'N', 
        '              The estimated standard deviation of\
               _chem_link_bond.value_dist_esd.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 136, 'value_order', 'value_order', 16, 'N', 
        '              The value that should be taken as the target for the chemical\
               bond associated with the specified atoms, expressed as a bond\
               order.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 17, 'CHEM_LINK_CHIR', 'chem_link_chir', 'N', 0, 
        '              Data items in the CHEM_LINK_CHIR category provide detail about\
               the chiral centers in a linkage between two chemical components.\
               The atoms bonded to the chiral atom are specified in the \
               CHEM_LINK_CHIR_ATOM category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 137, 'atom_comp_id', 'atom_comp_id', 17, 'N', 
        '              This data item indicates whether the chiral atom is found in the\
               first or the second of the two component connected by the\
               linkage.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 138, 'atom_id', 'atom_id', 17, 'Y', 
        '              The id of the atom that is a chiral center.\
\
               As this data item does not point to a specific atom in a\
               specific chemical component, it is not a child in the linkage\
               sense.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 139, 'atom_config', 'atom_config', 17, 'N', 
        '              The chiral configuration of the atom that is a chiral center.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 140, 'id', 'id', 17, 'Y', 
        '              The value of _chem_link_chir.id must uniquely identify a record\
               in the CHEM_LINK_CHIR list.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 141, 'number_atoms_all', 'number_atoms_all', 17, 'N', 
        '              The total number of atoms bonded to the atom specified by\
               _chem_link_chir.atom_id.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 142, 'number_atoms_nh', 'number_atoms_nh', 17, 'N', 
        '              The number of non-hydrogen atoms bonded to the atom specified by\
               _chem_link_chir.atom_id.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 143, 'volume_flag', 'volume_flag', 17, 'N', 
        '              A flag to indicate whether a chiral volume should match the\
               standard value in both magnitude and sign, or in magnitude only.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 144, 'volume_three', 'volume_three', 17, 'N', 
        '              The chiral volume, V(c), for chiral centers that involve a chiral\
               atom bonded to three non-hydrogen atoms and one hydrogen atom.\
\
               V~c~ = V1 * (V2 X V3)\
\
               V1 = the vector distance from the atom specified by\
                    _chem_link_chir.atom_id to the first atom in the\
                    CHEM_LINK_CHIR_ATOM list\
               V2 = the vector distance from the atom specified by\
                    _chem_link_chir.atom_id to the second atom in the\
                    CHEM_LINK_CHIR_ATOM list\
               V3 = the vector distance from the atom specified by\
                    _chem_link_chir.atom_id to the third atom in the\
                    CHEM_LINK_CHIR_ATOM list\
               *  = the vector dot product\
               X  = the vector cross product'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 145, 'volume_three_esd', 'volume_three_esd', 17, 'N', 
        '              The estimated standard deviation of\
               _chem_link_chir.volume_three.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 18, 'CHEM_LINK_CHIR_ATOM', 'chem_link_chir_atom', 'N', 0, 
        '              Data items in the CHEM_LINK_CHIR_ATOM category enumerate the\
               atoms bonded to a chiral atom in a linkage between two\
               chemical components.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 146, 'atom_comp_id', 'atom_comp_id', 18, 'N', 
        '              This data item indicates whether the atom bonded to a chiral\
               atom is found in the first or the second of the two components\
               connected by the linkage.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 147, 'atom_id', 'atom_id', 18, 'Y', 
        '              The id of an atom bonded to the chiral atom.\
\
               As this data item does not point to a specific atom in a\
               specific chemical component, it is not a child in the linkage\
               sense.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 148, 'dev', 'dev', 18, 'N', 
        '              The estimated standard deviation of the position of this atom\
               from the plane defined by all of the atoms in the plane.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 19, 'CHEM_LINK_PLANE', 'chem_link_plane', 'N', 0, 
        '              Data items in the CHEM_LINK_PLANE category provide identifiers\
               for the planes in a linkage between two chemical components.\
               The atoms in the plane are specified in the CHEM_LINK_PLANE_ATOM\
               category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 149, 'id', 'id', 19, 'Y', 
        '              The value of _chem_link_plane.id must uniquely identify a record\
               in the CHEM_LINK_PLANE list.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 150, 'number_atoms_all', 'number_atoms_all', 19, 'N', 
        '              The total number of atoms in the plane.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 151, 'number_atoms_nh', 'number_atoms_nh', 19, 'N', 
        '              The number of non-hydrogen atoms in the plane.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 20, 'CHEM_LINK_PLANE_ATOM', 'chem_link_plane_atom', 'N', 0, 
        '              Data items in the CHEM_LINK_PLANE_ATOM category enumerate the\
               atoms in a plane in a linkage between two chemical components.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 152, 'atom_comp_id', 'atom_comp_id', 20, 'N', 
        '              This data item indicates whether the atom in a plane is found in\
               the first or the second of the two components connected by the\
               linkage.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 153, 'atom_id', 'atom_id', 20, 'Y', 
        '              The id of an atom involved in the plane.\
\
               As this data item does not point to a specific atom in a\
               specific chemical component, it is not a child in the linkage\
               sense.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 21, 'CHEM_LINK_TOR', 'chem_link_tor', 'N', 0, 
        '              Data items in the CHEM_LINK_TOR category record details about\
               the torsion angles in a linkage between two chemical components.\
               As torsion angles can have more than one target value, the\
               target values are specified in the CHEM_LINK_TOR_VALUE category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 154, 'atom_1_comp_id', 'atom_1_comp_id', 21, 'N', 
        '              This data item indicates whether atom 1 is found in the first\
               or the second of the two components connected by the linkage.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 155, 'atom_2_comp_id', 'atom_2_comp_id', 21, 'N', 
        '              This data item indicates whether atom 2 is found in the first\
               or the second of the two components connected by the linkage.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 156, 'atom_3_comp_id', 'atom_3_comp_id', 21, 'N', 
        '              This data item indicates whether atom 3 is found in the first\
               or the second of the two components connected by the linkage.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 157, 'atom_4_comp_id', 'atom_4_comp_id', 21, 'N', 
        '              This data item indicates whether atom 4 is found in the first\
               or the second of the two components connected by the linkage.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 158, 'atom_id_1', 'atom_id_1', 21, 'Y', 
        '              The id of the first of the four atoms that define the torsion\
               angle.\
\
               As this data item does not point to a specific atom in a\
               specific chemical component, it is not a child in the linkage\
               sense.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 159, 'atom_id_2', 'atom_id_2', 21, 'Y', 
        '              The id of the second of the four atoms that define the torsion\
               angle.\
\
               As this data item does not point to a specific atom in a\
               specific chemical component, it is not a child in the linkage\
               sense.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 160, 'atom_id_3', 'atom_id_3', 21, 'Y', 
        '              The id of the third of the four atoms that define the torsion\
               angle.\
\
               As this data item does not point to a specific atom in a\
               specific chemical component, it is not a child in the linkage\
               sense.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 161, 'atom_id_4', 'atom_id_4', 21, 'Y', 
        '              The id of the fourth of the four atoms that define the torsion\
               angle.\
\
               As this data item does not point to a specific atom in a\
               specific chemical component, it is not a child in the linkage\
               sense.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 162, 'id', 'id', 21, 'Y', 
        '              The value of _chem_link_tor.id must uniquely identify a\
               record in the CHEM_LINK_TOR list.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 22, 'CHEM_LINK_TOR_VALUE', 'chem_link_tor_value', 'N', 0, 
        '              Data items in the CHEM_LINK_TOR_VALUE category record details\
               about the target values for the torsion angles enumerated in the\
               CHEM_LINK_TOR list. Target values may be specified as angles\
               in degrees, as a distance between the first and fourth atoms, or\
               both.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 163, 'angle', 'angle', 22, 'Y', 
        '              A value that should be taken as a potential target value for the\
               torsion angle associated with the specified atoms, expressed in\
               degrees.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 164, 'angle_esd', 'angle_esd', 22, 'Y', 
        '              The estimated standard deviation of _chem_link_tor_value.angle.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 165, 'dist', 'dist', 22, 'N', 
        '              A value that should be taken as a potential target value for the\
               torsion angle associated with the specified atoms, expressed as\
               the distance between the atoms specified by\
               _chem_link_tor.atom_id_1 and _chem_link_tor.atom_id_4 in the\
               referenced record in the CHEM_LINK_TOR list. Note that the\
               torsion angle cannot be fully specified by a distance (for\
               instance, a torsion angle of -60 will yield the same distance as\
               a 60 degree angle). However the distance specification can be\
               useful for refinement in situations in which the angle is already\
               close to the desired value.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 166, 'dist_esd', 'dist_esd', 22, 'N', 
        '              The estimated standard deviation of\
               _chem_link_tor_value.dist_esd.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 23, 'ENTITY', 'entity', 'N', 0, 
        '              Data items in the ENTITY category record details (such as\
               chemical composition, name, and source) about the molecular\
               entities that are present in the crystallographic structure.\
\
               Items in the various ENTITY sub-categories provide a full\
               chemical description of these molecular entities.\
\
               Entities are of three types:  polymer, non-polymer and water.\
               Note that the water category includes only water;  ordered\
               solvent such as sulfate ion or acetone would be described as\
               individual non-polymer entities.\
\
               The ENTITY category is specific to macromolecular CIF\
               applications, and replaces the function of the CHEMICAL category\
               in the CIF core.\
\
               It is important to remember that the ENTITY data are not the\
               result of the crystallographic experiment;  those results are\
               represented in the ATOM_SITE data items. ENTITY data items\
               describe the chemistry of the molecules under investigation,\
               and can most usefully be thought of as the ideal groups to which\
               the structure is restrained or constrained during refinement.\
\
               It is also important to remember that entities do not correspond\
               directly to the enumeration of the contents of the asymmetric\
               unit. Entities are described only once, even in those structures\
               that contain multiple observations of an entity. The\
               STRUCT_ASYM data items, which reference the entity list,\
               describe and label the contents of the asymmetric unit.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 167, 'details', 'details', 23, 'N', 
        '              A description of special aspects of the entity.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 168, 'formula_weight', 'formula_weight', 23, 'N', 
        '              Formula mass in daltons of the entity.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 169, 'id', 'id', 23, 'Y', 
        '              The value of _entity.id must uniquely identify a record in the\
               ENTITY list.\
\
               Note that this item need not be a number; it can be any unique\
               identifier.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 170, 'src_method', 'src_method', 23, 'N', 
        '              The method by which the sample for the entity was produced.\
               Entities isolated directly from natural sources (tissues, soil\
               samples, etc.) are expected to have further information in the\
               ENTITY_SRC_NAT category. Entities isolated from genetically\
               manipulated sources are expected to have further information in\
               the ENTITY_SRC_GEN category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 171, 'type', 'type', 23, 'N', 
        '              Defines the type of the entity.\
\
               Polymer entities are expected to have corresponding \
               ENTITY_POLY and associated entries.\
 \
               Non-polymer entities are expected to have corresponding \
               CHEM_COMP and associated entries.\
\
               Water entities are not expected to have corresponding\
               entries in the ENTITY category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 172, 'pdbx_description', 'pdbx_description', 23, 'N', 
        '              A description of the entity, with the name of the entity\
               in parenthesis.\
\
               Maps to PDB compound name.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 173, 'pdbx_number_of_molecules', 'pdbx_number_of_molecules', 23, 'N', 
        '              A place holder for the number of molecules of the entity in\
               the entry.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 174, 'pdbx_parent_entity_id', 'pdbx_parent_entity_id', 23, 'N', 
        '              An identifier for the parent entity if this entity\
               is part of a complex entity.  For instance a chimeric\
               entity may be decomposed into several independent \
               chemical entities where each component entity was\
               obtained from a different source.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 175, 'pdbx_mutation', 'pdbx_mutation', 23, 'N', 
        '              Details about any entity mutation(s).'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 176, 'pdbx_fragment', 'pdbx_fragment', 23, 'N', 
        '              Entity fragment description(s).'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 177, 'pdbx_ec', 'pdbx_ec', 23, 'N', 
        '             Enzyme Commission (EC) number(s)'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 178, 'pdbx_modification', 'pdbx_modification', 23, 'N', 
        '             Description(s) of any chemical or post-translational modifications'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 179, 'pdbx_formula_weight_exptl', 'pdbx_formula_weight_exptl', 23, 'N', 
        '              Experimentally determined formula mass in daltons of the entity '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 180, 'pdbx_formula_weight_exptl_meth', 'pdbx_formula_weight_exptl_meth', 23, 'N', 
        '              Method used to determine _entity.pdbx_formula_weight_exptl.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 24, 'ENTITY_KEYWORDS', 'entity_keywords', 'N', 0, 
        '              Data items in the ENTITY_KEYWORDS category specify keywords\
               relevant to the molecular entities. Note that this list of\
               keywords is separate from the list that is used for the\
               STRUCT_BIOL data items, and is intended to provide only the\
               information that one would know about the molecular entity *if\
               one did not know its structure*. Hence polypeptides are simply\
               polypeptides, and not cytokines or beta-alpha-barrels, and\
               polyribonucleic acids are simply poly-RNA, and not transfer-\
               RNA.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 181, 'text', 'text', 24, 'Y', 
        '              Keywords describing this entity.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 182, 'pdbx_mutation', 'pdbx_mutation', 24, 'N', 
        '              Entity mutation description(s).'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 183, 'pdbx_fragment', 'pdbx_fragment', 24, 'N', 
        '              Entity fragment description(s).'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 184, 'pdbx_ec', 'pdbx_ec', 24, 'N', 
        '             Enzyme Commission (EC) number(s)'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 25, 'ENTITY_LINK', 'entity_link', 'N', 0, 
        '              Data items in the ENTITY_LINK category give details about\
               the linkages between entities.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 185, 'details', 'details', 25, 'N', 
        '              A description of special aspects of a linkage between\
               chemical components in the structure.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 26, 'ENTITY_NAME_COM', 'entity_name_com', 'N', 0, 
        '              Data items in the ENTITY_NAME_COM category record the common name\
               or names associated with the entity. In some cases, the entity\
               name may not be the same as the name of the biological structure.\
               For instance, hemoglobin alpha chain would be the entity common\
               name, not hemoglobin.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 186, 'name', 'name', 26, 'Y', 
        '              A common name for the entity.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 27, 'ENTITY_NAME_SYS', 'entity_name_sys', 'N', 0, 
        '              Data items in the ENTITY_NAME_SYS category record the systematic\
               name or names associated with the entity, and tell which system\
               was is the source of the systematic name. In some cases, the\
               entity name may not be the same as the name of the biological\
               structure. For instance, hemoglobin alpha chain would be the\
               entity common name, not hemoglobin.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 187, 'name', 'name', 27, 'Y', 
        '              The systematic name for the entity.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 188, 'system', 'system', 27, 'N', 
        '              The system used to generate the systematic name of the entity.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 28, 'ENTITY_POLY', 'entity_poly', 'N', 0, 
        '              Data items in the ENTITY_POLY category record details about the\
               polymer, such as the type of the polymer, the number of \
               monomers, and whether it has non-standard features.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 189, 'nstd_chirality', 'nstd_chirality', 28, 'N', 
        '              A flag to indicate whether or not the polymer contains at least\
               one monomer unit with chirality different from that specified in\
               _entity_poly.type.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 190, 'nstd_linkage', 'nstd_linkage', 28, 'N', 
        '              A flag to indicate whether or not the polymer contains at least\
               one monomer-to-monomer linkage different from that implied by\
               _entity_poly.type.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 191, 'nstd_monomer', 'nstd_monomer', 28, 'N', 
        '              A flag to indicate whether or not the polymer contains at least\
               one monomer that is not considered standard.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 192, 'number_of_monomers', 'number_of_monomers', 28, 'N', 
        '              The number of monomers in the polymer.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 193, 'type', 'type', 28, 'N', 
        '              The type of the polymer.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 194, 'type_details', 'type_details', 28, 'N', 
        '              A description of special aspects of the polymer type.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 195, 'pdbx_strand_id', 'pdbx_strand_id', 28, 'N', 
        '              The PDB strand/chain id(s) corresponding to this polymer entity.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 196, 'pdbx_seq_one_letter_code', 'pdbx_seq_one_letter_code', 28, 'N', 
        '              Chemical sequence expressed as string of one-letter \
               amino acid codes. Modifications and non-standard \
               amino acids are coded as X.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 197, 'pdbx_seq_one_letter_code_can', 'pdbx_seq_one_letter_code_can', 28, 'N', 
        '              Cannonical chemical sequence expressed as string of \
               one-letter amino acid codes. Modifications are coded\
               as the parent amino acid where possible. \
\
A  for alanine or adenine\
B  for ambiguous asparagine/aspartic-acid\
R  for arginine\
N  for asparagine\
D  for aspartic-acid\
C  for cysteine or cystine or cytosine\
Q  for glutamine\
E  for glutamic-acid\
Z  for ambiguous glutamine/glutamic acid\
G  for glycine or guanine\
H  for histidine\
I  for isoleucine\
L  for leucine\
K  for lysine\
M  for methionine\
F  for phenylalanine\
P  for proline\
S  for serine\
T  for threonine or thymine\
W  for tryptophan\
Y  for tyrosine\
V  for valine\
U  for uracil'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 29, 'ENTITY_POLY_SEQ', 'entity_poly_seq', 'N', 0, 
        '              Data items in the ENTITY_POLY_SEQ category specify the sequence\
               of monomers in a polymer. Allowance is made for the possibility\
               of microheterogeneity in a sample by allowing a given sequence\
               number to be correlated with more than one monomer id - the\
               corresponding ATOM_SITE entries should reflect this\
               heterogeneity.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 198, 'hetero', 'hetero', 29, 'N', 
        '              A flag to indicate whether or not this monomer in the polymer is\
               heterogeneous in sequence. This would be a rare phenomenon.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 199, 'num', 'num', 29, 'Y', 
        '              The value of _entity_poly_seq.num must uniquely and sequentially\
               identify a record in the ENTITY_POLY_SEQ list.\
\
               Note that this item must be a number, and that the sequence\
               numbers must progress in increasing numerical order.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 30, 'ENTITY_SRC_GEN', 'entity_src_gen', 'N', 0, 
        '              Data items in the ENTITY_SRC_GEN category record details of\
               the source from which the entity was obtained, in those cases\
               where the source was a genetically manipulated one.  The\
               following are treated separately:  Items pertaining to the tissue\
               from which the gene was obtained, items pertaining to the host\
               organism for gene expression and items pertaining to the actual\
               producing organism (plasmid).'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 200, 'gene_src_common_name', 'gene_src_common_name', 30, 'N', 
        '              The common name of the natural organism from which the gene was\
               obtained.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 201, 'gene_src_details', 'gene_src_details', 30, 'N', 
        '              A description of special aspects of the natural organism from\
               which the gene was obtained.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 202, 'gene_src_genus', 'gene_src_genus', 30, 'N', 
        '              The genus of the natural organism from which the gene was\
               obtained.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 203, 'gene_src_species', 'gene_src_species', 30, 'N', 
        '              The species of the natural organism from which the gene was\
               obtained.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 204, 'gene_src_strain', 'gene_src_strain', 30, 'N', 
        '              The strain of the natural organism from which the gene was\
               obtained, if relevant.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 205, 'gene_src_tissue', 'gene_src_tissue', 30, 'N', 
        '              The tissue of the natural organism from which the gene was\
               obtained.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 206, 'gene_src_tissue_fraction', 'gene_src_tissue_fraction', 30, 'N', 
        '              The sub-cellular fraction of the tissue of the natural organism\
               from which the gene was obtained.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 207, 'host_org_common_name', 'host_org_common_name', 30, 'N', 
        '              The common name of the organism that served as host for the\
               production of the entity.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 208, 'host_org_details', 'host_org_details', 30, 'N', 
        '              A description of special aspects of the organism that served as\
               host for the production of the entity.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 209, 'host_org_genus', 'host_org_genus', 30, 'N', 
        '              The genus of the organism that served as host for the production\
               of the entity.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 210, 'host_org_species', 'host_org_species', 30, 'N', 
        '              The species of the organism that served as host for the\
               production of the entity.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 211, 'host_org_strain', 'host_org_strain', 30, 'N', 
        '              The strain of the organism that served as host for the\
               production of the entity.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 212, 'plasmid_details', 'plasmid_details', 30, 'N', 
        '              A description of special aspects of the plasmid that produced the\
               entity in the host organism.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 213, 'plasmid_name', 'plasmid_name', 30, 'N', 
        '              The name of the plasmid that produced the entity in the host\
               organism.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 214, 'pdbx_gene_src_fragment', 'pdbx_gene_src_fragment', 30, 'N', 
        '              A domain or fragment of the molecule.              '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 215, 'pdbx_gene_src_gene', 'pdbx_gene_src_gene', 30, 'N', 
        '              Identifies the gene.              '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 216, 'pdbx_gene_src_scientific_name', 'pdbx_gene_src_scientific_name', 30, 'N', 
        '              Scientific name of the organism.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 217, 'pdbx_gene_src_variant', 'pdbx_gene_src_variant', 30, 'N', 
        '              Identifies the variant.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 218, 'pdbx_gene_src_cell_line', 'pdbx_gene_src_cell_line', 30, 'N', 
        '              The specific line of cells.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 219, 'pdbx_gene_src_atcc', 'pdbx_gene_src_atcc', 30, 'N', 
        '              American Type Culture Collection tissue culture number.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 220, 'pdbx_gene_src_organ', 'pdbx_gene_src_organ', 30, 'N', 
        '           Organized group of tissues that carries on a specialized function.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 221, 'pdbx_gene_src_organelle', 'pdbx_gene_src_organelle', 30, 'N', 
        '              Organized structure within cell.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 222, 'pdbx_gene_src_plasmid', 'pdbx_gene_src_plasmid', 30, 'N', 
        '              The source plasmid.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 223, 'pdbx_gene_src_plasmid_name', 'pdbx_gene_src_plasmid_name', 30, 'N', 
        '              The source plasmid.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 224, 'pdbx_gene_src_cell', 'pdbx_gene_src_cell', 30, 'N', 
        '              Cell type.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 225, 'pdbx_gene_src_cellular_locatio', 'pdbx_gene_src_cellular_location', 30, 'N', 
        '              Identifies the location inside (or outside) the cell.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 226, 'pdbx_host_org_gene', 'pdbx_host_org_gene', 30, 'N', 
        '              Specific gene which expressed the molecule.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 227, 'pdbx_host_org_organ', 'pdbx_host_org_organ', 30, 'N', 
        '              Specific organ which expressed the molecule.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 228, 'pdbx_host_org_variant', 'pdbx_host_org_variant', 30, 'N', 
        '              Variant of the organism used as the expression system.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 229, 'pdbx_host_org_cell_line', 'pdbx_host_org_cell_line', 30, 'N', 
        '              A specific line of cells used as the expression system.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 230, 'pdbx_host_org_atcc', 'pdbx_host_org_atcc', 30, 'N', 
        '            Americal Tissue Culture Collection of the expression system.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 231, 'pdbx_host_org_culture_collecti', 'pdbx_host_org_culture_collection', 30, 'N', 
        '               Culture collection of the expression system.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 232, 'pdbx_host_org_cell', 'pdbx_host_org_cell', 30, 'N', 
        '               Specific cell type which expressed the molecule.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 233, 'pdbx_host_org_organelle', 'pdbx_host_org_organelle', 30, 'N', 
        '               Specific organelle which expressed the molecule.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 234, 'pdbx_host_org_cellular_locatio', 'pdbx_host_org_cellular_location', 30, 'N', 
        '              Identifies the location inside (or outside) the cell which \
               expressed the molecule.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 235, 'pdbx_host_org_scientific_name', 'pdbx_host_org_scientific_name', 30, 'N', 
        '\
     The scientific name of the organism that served as host for the\
     production of the entity. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 236, 'pdbx_host_org_strain', 'pdbx_host_org_strain', 30, 'N', 
        '\
               The strain of the organism in which the entity was\
               expressed.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 237, 'pdbx_host_org_tissue', 'pdbx_host_org_tissue', 30, 'N', 
        '\
              The specific tissue which expressed the molecule.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 238, 'pdbx_host_org_tissue_fraction', 'pdbx_host_org_tissue_fraction', 30, 'N', 
        '\
               The fraction of the tissue which expressed the\
               molecule.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 239, 'pdbx_host_org_vector', 'pdbx_host_org_vector', 30, 'N', 
        '              \
               Identifies the vector used.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 240, 'pdbx_host_org_vector_type', 'pdbx_host_org_vector_type', 30, 'N', 
        '\
              Identifies the type of vector used (plasmid, virus, or\
              cosmid).'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 241, 'pdbx_description', 'pdbx_description', 30, 'N', 
        '              Information on the source which is not given elsewhere.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 31, 'ENTITY_SRC_NAT', 'entity_src_nat', 'N', 0, 
        '              Data items in the ENTITY_SRC_NAT category record details of\
               the source from which the entity was obtained, in those cases\
               where the entity was isolated directly from a natural tissue.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 242, 'common_name', 'common_name', 31, 'Y', 
        '              The genus of the organism from which the entity was isolated.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 243, 'details', 'details', 31, 'N', 
        '              A description of special aspects of the organism from which the\
               entity was isolated.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 244, 'genus', 'genus', 31, 'Y', 
        '              The genus of the organism from which the entity was isolated.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 245, 'species', 'species', 31, 'Y', 
        '              The species of the organism from which the entity was isolated.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 246, 'strain', 'strain', 31, 'Y', 
        '              The strain of the organism from which the entity was isolated.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 247, 'tissue', 'tissue', 31, 'Y', 
        '              The tissue of the organism from which the entity was isolated.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 248, 'tissue_fraction', 'tissue_fraction', 31, 'Y', 
        '              The sub-cellular fraction of the tissue of the organism from\
               which the entity was isolated.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 249, 'pdbx_organism_scientific', 'pdbx_organism_scientific', 31, 'N', 
        '              Scientific name of the organism of the natural source.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 250, 'pdbx_secretion', 'pdbx_secretion', 31, 'N', 
        '              Identifies the secretion from which the molecule was isolated. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 251, 'pdbx_fragment', 'pdbx_fragment', 31, 'N', 
        '              A domain or fragment of the molecule.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 252, 'pdbx_variant', 'pdbx_variant', 31, 'N', 
        '              Identifies the variant.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 253, 'pdbx_cell_line', 'pdbx_cell_line', 31, 'N', 
        '              The specific line of cells.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 254, 'pdbx_atcc', 'pdbx_atcc', 31, 'N', 
        '              Americal Tissue Culture Collection number.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 255, 'pdbx_cellular_location', 'pdbx_cellular_location', 31, 'N', 
        '              Identifies the location inside (or outside) the cell.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 256, 'pdbx_organ', 'pdbx_organ', 31, 'N', 
        '          Organized group of tissues that carries on a specialized function.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 257, 'pdbx_organelle', 'pdbx_organelle', 31, 'N', 
        '              Organized structure within cell.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 258, 'pdbx_cell', 'pdbx_cell', 31, 'N', 
        '              A particular cell type.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 259, 'pdbx_plasmid_name', 'pdbx_plasmid_name', 31, 'N', 
        '              The plasmid containing the gene.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 260, 'pdbx_plasmid_details', 'pdbx_plasmid_details', 31, 'N', 
        '              Details about the plasmid.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 32, 'PDBX_ENTITY_NAME', 'pdbx_entity_name', 'N', 0, 
        '        The PDBX_ENTITY_NAME records additional name information for \
         each entity.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 261, 'entity_id ', 'entity_id ', 32, 'Y', 
        '    Pointer to _entity.id.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 262, 'name', 'name', 32, 'Y', 
        '    Entity name.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 263, 'name_type', 'name_type', 32, 'Y', 
        '    Entity name type.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 33, 'PDBX_PRERELEASE_SEQ', 'pdbx_prerelease_seq', 'N', 0, 
        '              This category provides a placeholder for pre-release \
               sequence information.  After release this category \
               should be discarded.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 264, 'entity_id', 'entity_id', 33, 'Y', 
        '              This data item is a pointer to _entity.id in the ENTITY category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 265, 'seq_one_letter_code', 'seq_one_letter_code', 33, 'N', 
        '              Chemical sequence expressed as string of one-letter \
               amino acid codes. \
\
A  for alanine or adenine\
B  for ambiguous asparagine/aspartic-acid\
R  for arginine\
N  for asparagine\
D  for aspartic-acid\
C  for cysteine or cystine or cytosine\
Q  for glutamine\
E  for glutamic-acid\
Z  for ambiguous glutamine/glutamic acid\
G  for glycine or guanine\
H  for histidine\
I  for isoleucine\
L  for leucine\
K  for lysine\
M  for methionine\
F  for phenylalanine\
P  for proline\
S  for serine\
T  for threonine or thymine\
W  for tryptophan\
Y  for tyrosine\
V  for valine\
U  for uracil'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 34, 'PDBX_POLY_SEQ_SCHEME', 'pdbx_poly_seq_scheme', 'N', 0, 
        '        The PDBX_POLY_SEQ_SCHEME category provides residue level nomenclature \
         mapping for polymer entities.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 266, 'asym_id', 'asym_id', 34, 'Y', 
        '    Pointer to _atom_site.label_asym_id.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 267, 'entity_id ', 'entity_id ', 34, 'N', 
        '    Pointer to _entity.id.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 268, 'seq_id', 'seq_id', 34, 'N', 
        '    Pointer to _atom_site.label_seq_id.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 269, 'mon_id', 'mon_id', 34, 'N', 
        '     Pointer to _entity_poly_seq.mon_id.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 270, 'pdb_strand_id', 'pdb_strand_id', 34, 'N', 
        '         PDB strand/chain id.  '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 271, 'ndb_seq_num', 'ndb_seq_num', 34, 'N', 
        '         NDB residue number.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 272, 'pdb_seq_num', 'pdb_seq_num', 34, 'N', 
        '         PDB residue number.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 273, 'auth_seq_num', 'auth_seq_num', 34, 'N', 
        '      _atom_site.auth_seq_id'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 274, 'pdb_mon_id', 'pdb_mon_id', 34, 'N', 
        '      PDB residue name.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 275, 'auth_mon_id', 'auth_mon_id', 34, 'N', 
        '           _atom_site.auth_comp_id'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 276, 'pdb_ins_code', 'pdb_ins_code', 34, 'N', 
        '      PDB insertion code.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 35, 'PDBX_NONPOLY_SCHEME', 'pdbx_nonpoly_scheme', 'N', 0, 
        '        The PDBX_NONPOLY_SCHEME category provides residue level nomenclature \
         mapping for non-polymer entities.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 277, 'id', 'id', 35, 'Y', 
        '    Ordinal for the list of mapping information.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 278, 'asym_id', 'asym_id', 35, 'Y', 
        '    Pointer to _atom_site.label_asym_id.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 279, 'entity_id ', 'entity_id ', 35, 'N', 
        '    Pointer to _atom_site.label_entity_id.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 280, 'mon_id', 'mon_id', 35, 'N', 
        '     Pointer to _atom_site.label_comp_id.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 281, 'pdb_strand_id', 'pdb_strand_id', 35, 'N', 
        '         PDB strand/chain id.  '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 282, 'ndb_seq_num', 'ndb_seq_num', 35, 'N', 
        '         NDB residue number.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 283, 'pdb_seq_num', 'pdb_seq_num', 35, 'N', 
        '         PDB residue number.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 284, 'auth_seq_num', 'auth_seq_num', 35, 'N', 
        '      _atom_site.auth_seq_id'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 285, 'pdb_mon_id', 'pdb_mon_id', 35, 'N', 
        '      PDB residue name.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 286, 'auth_mon_id', 'auth_mon_id', 35, 'N', 
        '           _atom_site.auth_comp_id'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 287, 'pdb_ins_code', 'pdb_ins_code', 35, 'N', 
        '      PDB insertion code.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 36, 'PDBX_ENTITY_ASSEMBLY', 'pdbx_entity_assembly', 'N', 0, 
        '              The PDBX_ENTITY_ASSEMBLY category provides a chemical description \
               of the biological assembly studied in terms of its constituent\
               entities.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 288, 'id', 'id', 36, 'Y', 
        '              An  identifier for the assembly.  '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 289, 'entity_id', 'entity_id', 36, 'Y', 
        '              An enity identifier.  A reference to _entity.id.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 290, 'biol_id', 'biol_id', 36, 'Y', 
        '              An  identifier for the assembly.  '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 291, 'num_copies', 'num_copies', 36, 'Y', 
        '              The number of copies of this entity in the assembly.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 37, 'PDBX_ENTITY_SRC_SYN', 'pdbx_entity_src_syn', 'N', 0, 
        '            PDBX_ENTITY_SRC_SYN records the details about each chemically\
             synthesized molecule (entity) in the asymmetric unit.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 292, 'details', 'details', 37, 'N', 
        '              A description of special aspects of the source for the \
               synthetic entity.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 293, 'entity_id', 'entity_id', 37, 'Y', 
        '              This data item is a pointer to _entity.id in the ENTITY category.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 38, 'ENTRY_LINK', 'entry_link', 'N', 0, 
        '              Data items in the ENTRY_LINK category record the \
               relationships between the current data block\
               identified by _entry.id and other data blocks\
               within the current file which may be referenced\
               in the current data block.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 294, 'entry_id', 'entry_id', 38, 'Y', 
        '              This data item is a pointer to _entry.id in the ENTRY category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 295, 'id', 'id', 38, 'Y', 
        '              The value of _entry_link.id identifies a data block\
               related to the data block identified by _entry_link.id.  '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 296, 'details', 'details', 38, 'N', 
        '              The description of the relationship between the data blocks\
               identified _entry_link.id and _entry_link.entry_id.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 39, 'GEOM', 'geom', 'N', 0, 
        '              Data items in the GEOM and related (GEOM_ANGLE,\
               GEOM_BOND, GEOM_CONTACT, GEOM_HBOND and GEOM_TORSION)\
               categories record details about the molecular and crystal\
               geometry, as calculated from the contents of the ATOM, CELL,\
               and SYMMETRY data.\
\
               Geometry data are therefore redundant, in that they can be\
               calculated from other more fundamental quantities in the data\
               block. They serve, however, the dual purpose of providing a\
               check on the correctness of both sets of data, and of enabling\
               the most important geometric data to be identified for\
               publication by setting the appropriate publication flag.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 297, 'entry_id', 'entry_id', 39, 'Y', 
        '              This data item is a pointer to _entry.id in the ENTRY category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 298, 'details', 'details', 39, 'N', 
        '              The description of geometrical information not covered by the\
               existing data names in the GEOM categories, such as\
               least-squares planes.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 40, 'GEOM_ANGLE', 'geom_angle', 'N', 0, 
        '              Data items in the GEOM_ANGLE category record details about the\
               molecular and crystal angles, as calculated from the contents\
               of the ATOM, CELL, and SYMMETRY data.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 299, 'publ_flag', 'publ_flag', 40, 'N', 
        '              This code signals if the angle is referred to in a publication or\
               should be placed in a table of significant angles.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 300, 'site_symmetry_1', 'site_symmetry_1', 40, 'Y', 
        '              The symmetry code of the first of the three atom sites that\
               define the angle specified by _geom_angle.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 301, 'site_symmetry_2', 'site_symmetry_2', 40, 'Y', 
        '              The symmetry code of the second of the three atom sites that\
               define the angle specified by _geom_angle.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 302, 'site_symmetry_3', 'site_symmetry_3', 40, 'Y', 
        '              The symmetry code of the third of the three atom sites that\
               define the angle specified by _geom_angle.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 303, 'value', 'value', 40, 'N', 
        '              Angle in degrees bounded by the three sites\
               _geom_angle.atom_site_id_1, _geom_angle.atom_site_id_2 and\
               _geom_angle.atom_site_id_3.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 304, 'value_esd', 'value_esd', 40, 'N', 
        '              The estimated standard deviation of _geom_angle.value.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 305, 'pdbx_atom_site_PDB_ins_code_1', 'pdbx_atom_site_PDB_ins_code_1', 40, 'N', 
        '   Pointer to _atom_site.pdbx_PDB_ins_code.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 306, 'pdbx_atom_site_PDB_ins_code_2', 'pdbx_atom_site_PDB_ins_code_2', 40, 'N', 
        '   Pointer to _atom_site.pdbx_PDB_ins_code.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 307, 'pdbx_atom_site_PDB_ins_code_3', 'pdbx_atom_site_PDB_ins_code_3', 40, 'N', 
        '   Pointer to _atom_site.pdbx_PDB_ins_code.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 308, 'pdbx_PDB_model_num', 'pdbx_PDB_model_num', 40, 'N', 
        '      Pointer to _atom_site.pdbx_PDB_model_num'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 41, 'GEOM_BOND', 'geom_bond', 'N', 0, 
        '              Data items in the GEOM_BOND category record details about\
               molecular and crystal bonds, as calculated from the contents\
               of the ATOM, CELL, and SYMMETRY data.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 309, 'dist', 'dist', 41, 'N', 
        '              The intramolecular bond distance in angstroms.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 310, 'dist_esd', 'dist_esd', 41, 'N', 
        '              The estimated standard deviation of _geom_bond.dist.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 311, 'publ_flag', 'publ_flag', 41, 'N', 
        '              This code signals if the bond distance is referred to in a\
               publication or should be placed in a list of significant bond\
               distances.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 312, 'site_symmetry_1', 'site_symmetry_1', 41, 'Y', 
        '              The symmetry code of the first of the two atom sites that\
               define the bond specified by _geom_bond.dist.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 313, 'site_symmetry_2', 'site_symmetry_2', 41, 'Y', 
        '              The symmetry code of the second of the two atom sites that\
               define the bond specified by _geom_bond.dist.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 314, 'pdbx_atom_site_PDB_ins_code_1', 'pdbx_atom_site_PDB_ins_code_1', 41, 'N', 
        '   Pointer to _atom_site.pdbx_PDB_ins_code.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 315, 'pdbx_atom_site_PDB_ins_code_2', 'pdbx_atom_site_PDB_ins_code_2', 41, 'N', 
        '   Pointer to _atom_site.pdbx_PDB_ins_code.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 316, 'pdbx_PDB_model_num', 'pdbx_PDB_model_num', 41, 'N', 
        '      Pointer to _atom_site.pdbx_PDB_model_num'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 42, 'GEOM_CONTACT', 'geom_contact', 'N', 0, 
        '              Data items in the GEOM_CONTACT category record details about\
               molecular and crystal contacts, as calculated from the contents\
               of the ATOM, CELL, and SYMMETRY data.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 317, 'dist', 'dist', 42, 'N', 
        '              The interatomic contact distance in angstroms.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 318, 'dist_esd', 'dist_esd', 42, 'N', 
        '              The estimated standard deviation of _geom_contact.dist.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 319, 'publ_flag', 'publ_flag', 42, 'N', 
        '              This code signals if the contact distance is referred to in a\
               publication or should be placed in a list of significant contact\
               distances.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 320, 'site_symmetry_1', 'site_symmetry_1', 42, 'Y', 
        '              The symmetry code of the first of the two atom sites that\
               define the contact specified by _geom_contact.dist.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 321, 'site_symmetry_2', 'site_symmetry_2', 42, 'Y', 
        '              The symmetry code of the second of the two atom sites that\
               define the contact specified by _geom_contact.dist.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 322, 'pdbx_atom_site_PDB_ins_code_1', 'pdbx_atom_site_PDB_ins_code_1', 42, 'N', 
        '   Pointer to _atom_site.pdbx_PDB_ins_code.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 323, 'pdbx_atom_site_PDB_ins_code_2', 'pdbx_atom_site_PDB_ins_code_2', 42, 'N', 
        '   Pointer to _atom_site.pdbx_PDB_ins_code.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 324, 'pdbx_PDB_model_num', 'pdbx_PDB_model_num', 42, 'N', 
        '      Pointer to _atom_site.pdbx_PDB_model_num'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 43, 'GEOM_HBOND', 'geom_hbond', 'N', 0, 
        '              Data items in the GEOM_HBOND category record details about\
               hydrogen bonds, as calculated from the contents of the ATOM,\
               CELL, and SYMMETRY data.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 325, 'angle_dha', 'angle_dha', 43, 'N', 
        '              The angle in degrees defined by the donor, hydrogen and acceptor\
               atom sites in a hydrogen bond.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 326, 'angle_dha_esd', 'angle_dha_esd', 43, 'N', 
        '              The standard uncertainty (e.s.d) of _geom_hbond.angle_DHA.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 327, 'atom_site_id_a', 'atom_site_id_a', 43, 'Y', 
        '              The identifier of the acceptor atom site that defines the\
               hydrogen bond.\
\
               This data item is a pointer to _atom_site.id in the ATOM_SITE\
               category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 328, 'atom_site_id_d', 'atom_site_id_d', 43, 'Y', 
        '              The identifier of the donor atom site that defines the hydrogen\
               bond.\
\
               This data item is a pointer to _atom_site.id in the ATOM_SITE\
               category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 329, 'atom_site_id_h', 'atom_site_id_h', 43, 'Y', 
        '              The identifier of the hydrogen atom site that defines the \
               hydrogen bond.\
\
               This data item is a pointer to _atom_site.id in the ATOM_SITE\
               category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 330, 'dist_da', 'dist_da', 43, 'N', 
        '              The distance in angstroms between the donor and acceptor atom\
               sites in a hydrogen bond.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 331, 'dist_da_esd', 'dist_da_esd', 43, 'N', 
        '              The standard undercertainty (e.s.d) in angstroms of\
               _geom_hbond.dist_DA.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 332, 'dist_dh', 'dist_dh', 43, 'N', 
        '              The distance in angstroms between the donor and hydrogen atom\
               sites in a hydrogen bond.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 333, 'dist_dh_esd', 'dist_dh_esd', 43, 'N', 
        '              The standard undercertainty (e.s.d) in angstroms of\
               _geom_hbond.dist_DH.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 334, 'dist_ha', 'dist_ha', 43, 'N', 
        '              The distance in angstroms between the hydrogen and acceptor\
               atom sites in a hydrogen bond.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 335, 'dist_ha_esd', 'dist_ha_esd', 43, 'N', 
        '              The standard undercertainty (e.s.d) in angstroms of\
               _geom_hbond.dist_HA.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 336, 'publ_flag', 'publ_flag', 43, 'N', 
        '              This code signals if the hydrogen bond information is referred\
               to in a publication or should be placed in a table of significant\
               hydrogen-bond geometry.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 337, 'site_symmetry_a', 'site_symmetry_a', 43, 'Y', 
        '              The symmetry code of the acceptor atom site that defines the\
               hydrogen bond.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 338, 'site_symmetry_d', 'site_symmetry_d', 43, 'Y', 
        '              The symmetry code of the donor atom site that defines the\
               hydrogen bond.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 339, 'site_symmetry_h', 'site_symmetry_h', 43, 'Y', 
        '              The symmetry code of the hydrogen atom site that defines the\
               hydrogen bond.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 44, 'GEOM_TORSION', 'geom_torsion', 'N', 0, 
        '              Data items in the GEOM_TORSION category record details about\
               molecular and crystal torsion angles, as calculated from the\
               contents of the ATOM, CELL, and SYMMETRY data.\
\
               The vector direction _geom_torsion.atom_site_id_2 to\
               _geom_torsion.atom_site_id_3 is the viewing direction, and the\
               torsion angle is the angle of twist required to superimpose the\
               projection of the vector site2-site1 onto the projection of the\
               vector site3-site4. Clockwise torsions are positive,\
               anticlockwise torsions are negative.\
\
               Ref: Klyne, W. \& Prelog, V. (1960). Experientia, 16, 521-523.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 340, 'publ_flag', 'publ_flag', 44, 'N', 
        '              This code signals if the torsion angle is referred to in a\
               publication or should be placed in a table of significant\
               torsion angles.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 341, 'site_symmetry_1', 'site_symmetry_1', 44, 'Y', 
        '              The symmetry code of the first of the four atom sites that\
               define the torsion angle specified by _geom_torsion.value.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 342, 'site_symmetry_2', 'site_symmetry_2', 44, 'Y', 
        '              The symmetry code of the second of the four atom sites that\
               define the torsion angle specified by _geom_torsion.value.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 343, 'site_symmetry_3', 'site_symmetry_3', 44, 'Y', 
        '              The symmetry code of the third of the four atom sites that\
               define the torsion angle specified by _geom_torsion.value.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 344, 'site_symmetry_4', 'site_symmetry_4', 44, 'Y', 
        '              The symmetry code of the fourth of the four atom sites that\
               define the torsion angle specified by _geom_torsion.value.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 345, 'value', 'value', 44, 'N', 
        '              The value of the torsion angle in degrees.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 346, 'value_esd', 'value_esd', 44, 'N', 
        '              The estimated standard deviation of _geom_torsion.value.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 347, 'pdbx_atom_site_PDB_ins_code_1', 'pdbx_atom_site_PDB_ins_code_1', 44, 'N', 
        '   Pointer to _atom_site.pdbx_PDB_ins_code.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 348, 'pdbx_atom_site_PDB_ins_code_2', 'pdbx_atom_site_PDB_ins_code_2', 44, 'N', 
        '   Pointer to _atom_site.pdbx_PDB_ins_code.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 349, 'pdbx_atom_site_PDB_ins_code_3', 'pdbx_atom_site_PDB_ins_code_3', 44, 'N', 
        '   Pointer to _atom_site.pdbx_PDB_ins_code.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 350, 'pdbx_atom_site_PDB_ins_code_4', 'pdbx_atom_site_PDB_ins_code_4', 44, 'N', 
        '   Pointer to _atom_site.pdbx_PDB_ins_code.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 351, 'pdbx_PDB_model_num', 'pdbx_PDB_model_num', 44, 'N', 
        '      Pointer to _atom_site.pdbx_PDB_model_num'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 45, 'STRUCT', 'struct', 'N', 0, 
        '              Data items in the STRUCT category record details about the\
               description of the crystallographic structure.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 352, 'entry_id', 'entry_id', 45, 'Y', 
        '              This data item is a pointer to _entry.id in the ENTRY category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 353, 'title', 'title', 45, 'N', 
        '              A title for the data block. The author should attempt to convey\
               the essence of the structure archived in the CIF in the title,\
               and to distinguish this structural result from others.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 354, 'pdbx_descriptor', 'pdbx_descriptor', 45, 'N', 
        '              An automatically generated descriptor for an NDB structure or\
               the unstructured content of the PDB COMPND record.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 355, 'pdbx_model_details', 'pdbx_model_details', 45, 'N', 
        '              Text description of the methodology which produced this\
               model structure.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 46, 'STRUCT_ASYM', 'struct_asym', 'N', 0, 
        '              Data items in the STRUCT_ASYM category record details about the\
               structural elements in the asymmetric unit.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 356, 'details', 'details', 46, 'N', 
        '              A description of special aspects of this portion of the contents\
               of the asymmetric unit.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 357, 'id', 'id', 46, 'Y', 
        '              The value of _struct_asym.id must uniquely identify a record in\
               the STRUCT_ASYM list.\
\
               Note that this item need not be a number; it can be any unique\
               identifier.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 358, 'pdbx_modified', 'pdbx_modified', 46, 'N', 
        '        This data item indicates whether the structural elements are modified.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 359, 'pdbx_blank_PDB_chainid_flag', 'pdbx_blank_PDB_chainid_flag', 46, 'N', 
        '              A flag indicating that this entity was originally labeled\
               with a blank PDB chain id.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 47, 'STRUCT_BIOL', 'struct_biol', 'N', 0, 
        '              Data items in the STRUCT_BIOL category record details about\
               the structural elements that form each structure of biological\
               significance.\
\
               A given crystal structure may contain many different biological\
               structures. A given structural component in the asymmetric\
               unit may be part of more than one biological unit. A given\
               biological structure may involve crystallographic symmetry.\
\
               For instance, in a structure of a lysozyme-FAB structure, the\
               light and heavy chain components of the FAB could be one\
               biological unit, while the two chains of the FAB and the lysozyme\
               could constitute a second biological unit.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 360, 'details', 'details', 47, 'N', 
        '              A description of special aspects of the biological unit.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 361, 'id', 'id', 47, 'Y', 
        '              The value of _struct_biol.id must uniquely identify a record in\
               the STRUCT_BIOL list.\
\
               Note that this item need not be a number; it can be any unique\
               identifier.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 362, 'pdbx_parent_biol_id', 'pdbx_parent_biol_id', 47, 'N', 
        '              An identifier for the parent biological assembly\
               if this biological unit is part of a complex assembly.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 48, 'STRUCT_BIOL_GEN', 'struct_biol_gen', 'N', 0, 
        '              Data items in the STRUCT_BIOL_GEN category record details about\
               the generation of each biological unit. The STRUCT_BIOL_GEN\
               data items provide the specifications of the components that\
               constitute that biological unit, which may include symmetry\
               elements.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 363, 'details', 'details', 48, 'N', 
        '              A description of special aspects of the symmetry generation of\
               this portion of the biological structure.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 364, 'symmetry', 'symmetry', 48, 'Y', 
        '              Describes the symmetry operation that should be applied to the\
               atom set specified by _struct_biol_gen.asym_id to generate a\
               portion of the biological structure.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 365, 'pdbx_full_symmetry_operation', 'pdbx_full_symmetry_operation', 48, 'N', 
        '\
               This item expresses category _struct_biol_gen.symmetry\
               on an X, Y and Z basis.         '
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 49, 'STRUCT_BIOL_KEYWORDS', 'struct_biol_keywords', 'N', 0, 
        '              Data items in the STRUCT_BIOL_KEYWORDS category record details\
               about keywords that describe each biological unit.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 366, 'text', 'text', 49, 'Y', 
        '              Keywords describing this biological entity.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 50, 'STRUCT_BIOL_VIEW', 'struct_biol_view', 'N', 0, 
        '              Data items in the STRUCT_BIOL_VIEW category record details\
               about how to draw and annotate a useful didactic view of the\
               biological structure.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 367, 'details', 'details', 50, 'N', 
        '              A description of special aspects of this view of the biological\
               structure.\
\
               This data item can be used as a figure legend, if desired.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 368, 'id', 'id', 50, 'Y', 
        '              The value of _struct_biol_view.id must uniquely identify a\
               record in the STRUCT_BIOL_VIEW list.\
\
               Note that this item need not be a number; it can be any unique\
               identifier.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 369, 'rot_matrix_0_0', 'rot_matrix[1][1]', 50, 'N', 
        '              The [1][1] element of the matrix used to rotate the subset of the\
               Cartesian coordinates in the ATOM_SITE category identified in the\
               STRUCT_BIOL_GEN category to a view useful for describing the\
               structure. The conventions used in the rotation are described in\
               _struct_biol_view.details.\
\
               |x''|                         |11 12 13| |x|\
               |y''|~reoriented Cartesian~ = |21 22 23| |y|~Cartesian~\
               |z''|                         |31 32 33| |z|'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 370, 'rot_matrix_0_1', 'rot_matrix[1][2]', 50, 'N', 
        '              The [1][2] element of the matrix used to rotate the subset of the\
               Cartesian coordinates in the ATOM_SITE category identified in the\
               STRUCT_BIOL_GEN category to a view useful for describing the\
               structure. The conventions used in the rotation are described in\
               _struct_biol_view.details.\
\
               |x''|                         |11 12 13| |x|\
               |y''|~reoriented Cartesian~ = |21 22 23| |y|~Cartesian~\
               |z''|                         |31 32 33| |z|'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 371, 'rot_matrix_0_2', 'rot_matrix[1][3]', 50, 'N', 
        '              The [1][3] element of the matrix used to rotate the subset of the\
               Cartesian coordinates in the ATOM_SITE category identified in the\
               STRUCT_BIOL_GEN category to a view useful for describing the\
               structure. The conventions used in the rotation are described in\
               _struct_biol_view.details.\
\
               |x''|                         |11 12 13| |x|\
               |y''|~reoriented Cartesian~ = |21 22 23| |y|~Cartesian~\
               |z''|                         |31 32 33| |z|'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 372, 'rot_matrix_1_0', 'rot_matrix[2][1]', 50, 'N', 
        '              The [2][1] element of the matrix used to rotate the subset of the\
               Cartesian coordinates in the ATOM_SITE category identified in the\
               STRUCT_BIOL_GEN category to a view useful for describing the\
               structure. The conventions used in the rotation are described in\
               _struct_biol_view.details.\
\
               |x''|                         |11 12 13| |x|\
               |y''|~reoriented Cartesian~ = |21 22 23| |y|~Cartesian~\
               |z''|                         |31 32 33| |z|'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 373, 'rot_matrix_1_1', 'rot_matrix[2][2]', 50, 'N', 
        '              The [2][2] element of the matrix used to rotate the subset of the\
               Cartesian coordinates in the ATOM_SITE category identified in the\
               STRUCT_BIOL_GEN category to a view useful for describing the\
               structure. The conventions used in the rotation are described in\
               _struct_biol_view.details.\
\
               |x''|                         |11 12 13| |x|\
               |y''|~reoriented Cartesian~ = |21 22 23| |y|~Cartesian~\
               |z''|                         |31 32 33| |z|'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 374, 'rot_matrix_1_2', 'rot_matrix[2][3]', 50, 'N', 
        '              The [2][3] element of the matrix used to rotate the subset of the\
               Cartesian coordinates in the ATOM_SITE category identified in the\
               STRUCT_BIOL_GEN category to a view useful for describing the\
               structure. The conventions used in the rotation are described in\
               _struct_biol_view.details.\
\
               |x''|                         |11 12 13| |x|\
               |y''|~reoriented Cartesian~ = |21 22 23| |y|~Cartesian~\
               |z''|                         |31 32 33| |z|'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 375, 'rot_matrix_2_0', 'rot_matrix[3][1]', 50, 'N', 
        '              The [3][1] element of the matrix used to rotate the subset of the\
               Cartesian coordinates in the ATOM_SITE category identified in the\
               STRUCT_BIOL_GEN category to a view useful for describing the\
               structure. The conventions used in the rotation are described in\
               _struct_biol_view.details.\
\
               |x''|                         |11 12 13| |x|\
               |y''|~reoriented Cartesian~ = |21 22 23| |y|~Cartesian~\
               |z''|                         |31 32 33| |z|'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 376, 'rot_matrix_2_1', 'rot_matrix[3][2]', 50, 'N', 
        '              The [3][2] element of the matrix used to rotate the subset of the\
               Cartesian coordinates in the ATOM_SITE category identified in the\
               STRUCT_BIOL_GEN category to a view useful for describing the\
               structure. The conventions used in the rotation are described in\
               _struct_biol_view.details.\
\
               |x''|                         |11 12 13| |x|\
               |y''|~reoriented Cartesian~ = |21 22 23| |y|~Cartesian~\
               |z''|                         |31 32 33| |z|'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 377, 'rot_matrix_2_2', 'rot_matrix[3][3]', 50, 'N', 
        '              The [3][3] element of the matrix used to rotate the subset of the\
               Cartesian coordinates in the ATOM_SITE category identified in the\
               STRUCT_BIOL_GEN category to a view useful for describing the\
               structure. The conventions used in the rotation are described in\
               _struct_biol_view.details.\
\
               |x''|                         |11 12 13| |x|\
               |y''|~reoriented Cartesian~ = |21 22 23| |y|~Cartesian~\
               |z''|                         |31 32 33| |z|'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 51, 'STRUCT_CONF', 'struct_conf', 'N', 0, 
        '              Data items in the STRUCT_CONF category record details about\
               the backbone conformation of a segment of polymer.\
\
               The STRUCT_CONF_TYPE records define the criteria used to\
               identify the backbone conformations.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 378, 'details', 'details', 51, 'N', 
        '              A description of special aspects of the conformation assignment.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 379, 'id', 'id', 51, 'Y', 
        '              The value of _struct_conf.id must uniquely identify a record in\
               the STRUCT_CONF list.\
\
               Note that this item need not be a number; it can be any unique\
               identifier.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 380, 'pdbx_beg_PDB_ins_code', 'pdbx_beg_PDB_ins_code', 51, 'N', 
        '              A component of the identifier for the residue at which the\
               conformation segment starts.\
'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 381, 'pdbx_end_PDB_ins_code', 'pdbx_end_PDB_ins_code', 51, 'N', 
        '              A component of the identifier for the residue at which the\
               conformation segment ends.\
'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 382, 'pdbx_PDB_helix_class', 'pdbx_PDB_helix_class', 51, 'N', 
        '              This item is a place holder for the helix class used in the PDB \
               HELIX record.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 383, 'pdbx_PDB_helix_length', 'pdbx_PDB_helix_length', 51, 'N', 
        '         \
               A placeholder for the lengths of the helix of the PDB\
               HELIX record.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 384, 'pdbx_PDB_helix_id', 'pdbx_PDB_helix_id', 51, 'N', 
        '         \
                A placeholder for the helix identifier of the PDB\
                HELIX record.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 52, 'STRUCT_CONF_TYPE', 'struct_conf_type', 'N', 0, 
        '              Data items in the STRUCT_CONF_TYPE category record details\
               about the criteria used to identify backbone conformations of a\
               segment of polymer.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 385, 'criteria', 'criteria', 52, 'N', 
        '              The criteria used to assign this conformation type.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 386, 'id', 'id', 52, 'Y', 
        '              The descriptor that categorizes type of the conformation of the\
               backbone of the polymer (whether protein or nucleic acid).\
               Explicit values for the torsions angles that define each\
               conformation are not given here, but it is expected that the\
               author would provide such information in either the\
               _struct_conf_type.criteria or _struct_conf_type.reference data\
               items, or both.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 387, 'reference', 'reference', 52, 'N', 
        '              A literature reference that defines the criteria used to assign\
               this conformation type and subtype.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 53, 'STRUCT_CONN', 'struct_conn', 'N', 0, 
        '              Data items in the STRUCT_CONN category record details about\
               the interactions between portions of structure. These can be\
               hydrogen bonds, salt bridges, disulfide bridges, and so on.\
\
               The STRUCT_CONN_TYPE records define the criteria used to\
               identify these contacts.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 388, 'details', 'details', 53, 'N', 
        '              A description of special aspects of the connected item.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 389, 'id', 'id', 53, 'Y', 
        '              The value of _struct_conn.id must uniquely identify a record in\
               the STRUCT_CONN list.\
\
               Note that this item need not be a number; it can be any unique\
               identifier.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 390, 'ptnr1_role', 'ptnr1_role', 53, 'N', 
        '              The chemical or structural role of the first partner in\
               the structure connection.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 391, 'ptnr1_symmetry', 'ptnr1_symmetry', 53, 'N', 
        '              Describes the symmetry operation that should be applied to the\
               atom set specified by _struct_conn.ptnr1_label* to generate the\
               first partner in the structure connection.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 392, 'ptnr2_role', 'ptnr2_role', 53, 'N', 
        '              The chemical or structural role of the second partner in\
               the structure connection.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 393, 'ptnr2_symmetry', 'ptnr2_symmetry', 53, 'N', 
        '              Describes the symmetry operation that should be applied to the\
               atom set specified by _struct_conn.ptnr2_label* to generate the\
               second partner in the structure connection.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 394, 'pdbx_ptnr1_PDB_ins_code', 'pdbx_ptnr1_PDB_ins_code', 53, 'N', 
        '              A component of the identifier for partner 1 of the structure\
               connection.\
\
               This data item is a pointer to _atom_site.ins_code in the\
               ATOM_SITE category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 395, 'pdbx_ptnr1_auth_alt_id', 'pdbx_ptnr1_auth_alt_id', 53, 'N', 
        '         \
               A component of the identifier for partner 1 of the\
               structure connection. This data item is a pointer to\
               _atom_site.pdbx_auth_alt_id in the ATOM_SITE category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 396, 'pdbx_ptnr1_label_alt_id', 'pdbx_ptnr1_label_alt_id', 53, 'N', 
        '         \
               A component of the identifier for partner 1 of the\
               structure connection. This data item is a pointer to\
               _atom_site.label_alt_id in the ATOM_SITE category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 397, 'pdbx_ptnr1_standard_comp_id', 'pdbx_ptnr1_standard_comp_id', 53, 'N', 
        '         \
               A placeholder for the standard residue name found in\
               the MODRES record of a PDB file.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 398, 'pdbx_ptnr2_PDB_ins_code', 'pdbx_ptnr2_PDB_ins_code', 53, 'N', 
        '           A component of the identifier for partner 1 of the structure\
            connection.\
\
            This data item is a pointer to _atom_site.pdbx_PDB_ins_code in the\
            ATOM_SITE category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 399, 'pdbx_ptnr2_auth_alt_id', 'pdbx_ptnr2_auth_alt_id', 53, 'N', 
        '         \
               A component of the identifier for partner 2 of the\
               structure connection. This data item is a pointer to\
               _atom_site.pdbx_auth_alt_id in the ATOM_SITE category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 400, 'pdbx_ptnr2_label_alt_id', 'pdbx_ptnr2_label_alt_id', 53, 'N', 
        '         \
               A component of the identifier for partner 2 of the\
               structure connection. This data item is a pointer to\
               _atom_site.label_alt_id in the ATOM_SITE category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 401, 'pdbx_ptnr3_auth_alt_id', 'pdbx_ptnr3_auth_alt_id', 53, 'N', 
        '         \
               A component of the identifier for partner 3 of the\
               structure connection. This data item is a pointer to\
               _atom_site.auth_alt_id in the ATOM_SITE category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 402, 'pdbx_ptnr3_auth_asym_id', 'pdbx_ptnr3_auth_asym_id', 53, 'N', 
        '         \
               A component of the identifier for partner 3 of the\
               structure connection. This data item is a pointer to\
               _atom_site.auth_asym_id in the ATOM_SITE category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 403, 'pdbx_ptnr3_auth_atom_id', 'pdbx_ptnr3_auth_atom_id', 53, 'N', 
        '         \
               A component of the identifier for partner 3 of the\
               structure connection. This data item is a pointer to\
               _atom_site.auth_atom_id in the ATOM_SITE category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 404, 'pdbx_ptnr3_auth_comp_id', 'pdbx_ptnr3_auth_comp_id', 53, 'N', 
        '\
               A component of the identifier for partner 3 of the\
               structure connection. This data item is a pointer to\
               _atom_site.auth_comp_id in the ATOM_SITE category.        '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 405, 'pdbx_ptnr3_PDB_ins_code', 'pdbx_ptnr3_PDB_ins_code', 53, 'N', 
        '\
               A component of the identifier for partner 3 of the\
               structure connection. This data item is a pointer to\
               _atom_site.pdbx_PDB_ins_code in the ATOM_SITE category.  '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 406, 'pdbx_ptnr3_auth_seq_id', 'pdbx_ptnr3_auth_seq_id', 53, 'N', 
        '         \
               A component of the identifier for partner 1 of the\
               structure connection. This data item is a pointer to\
               _atom_site.auth_seq_id in the ATOM_SITE category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 407, 'pdbx_ptnr3_label_alt_id', 'pdbx_ptnr3_label_alt_id', 53, 'N', 
        '         \
               A component of the identifier for partner 3 of the\
               structure connection. This data item is a pointer to\
               _atom_site.label_alt_id in the ATOM_SITE category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 408, 'pdbx_ptnr3_label_asym_id', 'pdbx_ptnr3_label_asym_id', 53, 'N', 
        '         \
               A component of the identifier for partner 3 of the\
               structure connection. This data item is a pointer to\
               _atom_site.label_asym_id in the ATOM_SITE category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 409, 'pdbx_ptnr3_label_atom_id', 'pdbx_ptnr3_label_atom_id', 53, 'N', 
        '         \
               A component of the identifier for partner 3 of the\
               structure connection. This data item is a pointer to\
               _atom_site.label_atom_id in the ATOM_SITE category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 410, 'pdbx_ptnr3_label_comp_id', 'pdbx_ptnr3_label_comp_id', 53, 'N', 
        '\
               A component of the identifier for partner 3 of the\
               structure connection. This data item is a pointer to\
               _atom_site.label_comp_id in the ATOM_SITE category.        '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 411, 'pdbx_ptnr3_label_seq_id', 'pdbx_ptnr3_label_seq_id', 53, 'N', 
        '         \
               A component of the identifier for partner 1 of the\
               structure connection. This data item is a pointer to\
               _atom_site.label_seq_id in the ATOM_SITE category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 412, 'pdbx_PDB_id', 'pdbx_PDB_id', 53, 'N', 
        '         \
               A placeholder for the PDB id in the case the category\
               is used to hold the information of the MODRES record of\
               a PDB file.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 54, 'STRUCT_CONN_TYPE', 'struct_conn_type', 'N', 0, 
        '              Data items in the STRUCT_CONN_TYPE category record details\
               about the criteria used to identify interactions between\
               portions of the structure.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 413, 'criteria', 'criteria', 54, 'N', 
        '              The criteria used to define the interaction.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 414, 'id', 'id', 54, 'Y', 
        '              The chemical or structural type of the interaction.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 415, 'reference', 'reference', 54, 'N', 
        '              A reference that specifies the criteria used to define the\
               interaction.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 55, 'STRUCT_KEYWORDS', 'struct_keywords', 'N', 0, 
        '              Data items in the STRUCT_KEYWORDS category specify keywords\
               that describe the chemical structure in this entry.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 416, 'entry_id', 'entry_id', 55, 'Y', 
        '              This data item is a pointer to _entry.id in the ENTRY category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 417, 'text', 'text', 55, 'Y', 
        '              Keywords describing this structure.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 418, 'pdbx_keywords', 'pdbx_keywords', 55, 'N', 
        '         '
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 56, 'STRUCT_MON_DETAILS', 'struct_mon_details', 'N', 0, 
        '              Data items in the STRUCT_MON_DETAILS category record details\
               about specifics of calculations summarized in data items in the\
               STRUCT_MON_PROT and STRUCT_MON_NUCL categories. These can\
               include the coefficients used in various map calculations,\
               the radii used for including points in a calculation, etc.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 419, 'entry_id', 'entry_id', 56, 'Y', 
        '              This data item is a pointer to _entry.id in the ENTRY category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 420, 'prot_cis', 'prot_cis', 56, 'N', 
        '              An ideal cis peptide bond would have an omega torsion angle of\
               zero. This data item gives the value in degrees by which the\
               observed torsion angle can differ from 0.0 and still be\
               considered cis.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 421, 'rscc', 'rscc', 56, 'N', 
        '              This data item describes the specifics of the calculations that\
               generated the values given in _struct_mon_prot.RSCC_all,\
               _struct_mon_prot.RSCC_main and _struct_mon_prot.RSCC_side. The\
               coefficients used to calculate the p(o) and p(c) maps should be\
               given as well as the criterion for inclusion of map grid points\
               in the calculation.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 422, 'rsr', 'rsr', 56, 'N', 
        '              This data item describes the specifics of the calculations that\
               generated the values given in _struct_mon_prot.RSR_all,\
               _struct_mon_prot.RSR_main and _struct_mon_prot.RSR_side. The\
               coefficients used to calculate the p(o) and p(c) maps should be\
               given as well as the criterion for inclusion of map grid points\
               in the calculation.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 57, 'STRUCT_MON_NUCL', 'struct_mon_nucl', 'N', 0, 
        '              Data items in the STRUCT_MON_NUCL category record details about\
               structural properties of a nucleic acid when analyzed at the\
               monomer level. Analogous data items for proteins are given in\
               the STRUCT_MON_PROT category. For items where the value of the\
               property depends on the method employed to calculate it, the\
               details of the method of calculation are described in data items\
               in the STRUCT_MON_DETAILS category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 423, 'alpha', 'alpha', 57, 'N', 
        '              The value in degrees of the backbone torsion angle alpha\
               O3''_P_O5''_C5''.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 424, 'beta', 'beta', 57, 'N', 
        '              The value in degrees of the backbone torsion angle beta\
               P_O5''_C5''_C4''.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 425, 'chi1', 'chi1', 57, 'N', 
        '              The value in degrees of the sugar-base torsion angle chi\
               O4''_C1''_N1_C2.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 426, 'chi2', 'chi2', 57, 'N', 
        '              The value in degrees of the sugar-base torsion angle chi\
               O4''_C1''_N9_C4.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 427, 'delta', 'delta', 57, 'N', 
        '              The value in degrees of the backbone torsion angle delta\
               C5''_C4''_C3''_O3''.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 428, 'details', 'details', 57, 'N', 
        '              A description of special aspects of the residue, its\
               conformation, behaviour in refinement, or any other aspect\
               that requires annotation.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 429, 'epsilon', 'epsilon', 57, 'N', 
        '              The value in degrees of the backbone torsion angle epsilon\
               C4''_C3''_O3''_P.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 430, 'gamma', 'gamma', 57, 'N', 
        '              The value in degrees of the backbone torsion angle gamma\
               O5''_C5''_C4''_C3''.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 431, 'mean_b_all', 'mean_b_all', 57, 'N', 
        '              The mean value of the isotropic temperature factor for all atoms\
               in the monomer.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 432, 'mean_b_base', 'mean_b_base', 57, 'N', 
        '              The mean value of the isotropic temperature factor for atoms\
               in the base moiety of the nucleic acid monomer.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 433, 'mean_b_phos', 'mean_b_phos', 57, 'N', 
        '              The mean value of the isotropic temperature factor for atoms\
               in the phosphate moiety of the nucleic acid monomer.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 434, 'mean_b_sugar', 'mean_b_sugar', 57, 'N', 
        '              The mean value of the isotropic temperature factor for atoms\
               in the sugar moiety of the nucleic acid monomer.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 435, 'nu0', 'nu0', 57, 'N', 
        '              The value in degrees of the sugar torsion angle nu0\
               C4''_O4''_C1''_C2''.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 436, 'nu1', 'nu1', 57, 'N', 
        '              The value in degrees of the sugar torsion angle nu1\
               O4''_C1''_C2''_C3''.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 437, 'nu2', 'nu2', 57, 'N', 
        '              The value in degrees of the sugar torsion angle nu2\
               C1''_C2''_C3''_C4''.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 438, 'nu3', 'nu3', 57, 'N', 
        '              The value in degrees of the sugar torsion angle nu3\
               C2''_C3''_C4''_O4''.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 439, 'nu4', 'nu4', 57, 'N', 
        '              The value in degrees of the sugar torsion angle nu4\
               C3''_C4''_O4''_C1''.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 440, 'p', 'p', 57, 'N', 
        '              P is the phase angle of pseudorotation for five membered rings. \
               This formulation is used for ribo and deoxyribo sugars in nucleic\
               acids.\
                          (tau4 +tau1)-(tau3+tau0)\
               P = ATAN (-------------------------)\
                           2tau2 (sin 36+sin 72)\
\
               If tau2 is <0, then P=P+180\
\
               This formulation is by Altona and Sundaralingam (1972), J.A.C.S.,\
               94, 8205-8212.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 441, 'rscc_all', 'rscc_all', 57, 'N', 
        '              The real-space (linear) correlation coefficient RSCC, as\
               described by Jones et al., evaluated over all atoms in the\
               nucleic acid monomer.\
\
                      sum|p~obs~ - <p~obs~>| * sum|p~calc~ - <p~calc~>|\
               RSCC = -------------------------------------------------\
                            [ sum|p~obs~  - <p~obs~> |^2^\
                            * sum|p~calc~ - <p~calc~>|^2^ ]^1/2^\
\
               p~obs~  = the density in an "experimental" map\
               p~calc~ = the density in a "calculated" map\
\
               sum is taken over the specified grid points\
\
               The details of how these maps were calculated should be described\
               in _struct_mon_details.RSCC. < > indicates an average and the\
               sums are taken over all map grid  points near the relevant atoms.\
               The radius for including grid points in the calculation should\
               also be given in _struct_mon_details.RSCC.\
\
               Ref: Jones, T. A., Zou, J. Y., Cowan, S. W. \& Kjeldgaard, M.\
                    (1991). Acta Cryst. A47, 110-119.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 442, 'rscc_base', 'rscc_base', 57, 'N', 
        '              The real-space (linear) correlation coefficient RSCC, as\
               described by Jones et al., evaluated over all atoms in the\
               base moiety of the nucleic acid monomer.\
\
                      sum|p~obs~ - <p~obs~>| * sum|p~calc~ - <p~calc~>|\
               RSCC = -------------------------------------------------\
                            [ sum|p~obs~  - <p~obs~> |^2^\
                            * sum|p~calc~ - <p~calc~>|^2^ ]^1/2^\
\
               p~obs~  = the density in an "experimental" map\
               p~calc~ = the density in a "calculated" map\
\
               sum is taken over the specified grid points\
\
               The details of how these maps were calculated should be described\
               in _struct_mon_details.RSCC. < > indicates an average and the\
               sums are taken over all map grid  points near the relevant atoms.\
               The radius for including grid points in the calculation should\
               also be given in _struct_mon_details.RSCC.\
\
               Ref: Jones, T. A., Zou, J. Y., Cowan, S. W. \& Kjeldgaard, M.\
                    (1991). Acta Cryst. A47, 110-119.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 443, 'rscc_phos', 'rscc_phos', 57, 'N', 
        '              The real-space (linear) correlation coefficient RSCC, as\
               described by Jones et al., evaluated over all atoms in the\
               phosphate moiety of the nucleic acid monomer.\
\
                      sum|p~obs~ - <p~obs~>| * sum|p~calc~ - <p~calc~>|\
               RSCC = -------------------------------------------------\
                            [ sum|p~obs~  - <p~obs~> |^2^\
                            * sum|p~calc~ - <p~calc~>|^2^ ]^1/2^\
\
               p~obs~  = the density in an "experimental" map\
               p~calc~ = the density in a "calculated" map\
\
               sum is taken over the specified grid points\
\
               The details of how these maps were calculated should be described\
               in _struct_mon_details.RSCC. < > indicates an average and the\
               sums are taken over all map grid  points near the relevant atoms.\
               The radius for including grid points in the calculation should\
               also be given in _struct_mon_details.RSCC.\
\
               Ref: Jones, T. A., Zou, J. Y., Cowan, S. W. \& Kjeldgaard, M.\
                    (1991). Acta Cryst. A47, 110-119.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 444, 'rscc_sugar', 'rscc_sugar', 57, 'N', 
        '              The real-space (linear) correlation coefficient RSCC, as\
               described by Jones et al., evaluated over all atoms in the\
               sugar moiety of the nucleic acid monomer.\
\
                      sum|p~obs~ - <p~obs~>| * sum|p~calc~ - <p~calc~>|\
               RSCC = -------------------------------------------------\
                            [ sum|p~obs~  - <p~obs~> |^2^\
                            * sum|p~calc~ - <p~calc~>|^2^ ]^1/2^\
\
               p~obs~  = the density in an "experimental" map\
               p~calc~ = the density in a "calculated" map\
\
               sum is taken over the specified grid points\
\
               The details of how these maps were calculated should be described\
               in _struct_mon_details.RSCC. < > indicates an average and the\
               sums are taken over all map grid  points near the relevant atoms.\
               The radius for including grid points in the calculation should\
               also be given in _struct_mon_details.RSCC.\
\
               Ref: Jones, T. A., Zou, J. Y., Cowan, S. W. \& Kjeldgaard, M.\
                    (1991). Acta Cryst. A47, 110-119.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 445, 'rsr_all', 'rsr_all', 57, 'N', 
        '              The real-space residual RSR, as described by Branden and Jones,\
               evaluated over all atoms in the nucleic acid monomer.\
\
                     sum|p~obs~ - p~calc~|\
               RSR = ---------------------\
                     sum|p~obs~ + p~calc~|\
\
               p~obs~  = the density in an "experimental" map\
               p~calc~ = the density in a "calculated" map\
\
               sum is taken over the specified grid points\
\
               The details of how these maps were calculated should be described\
               in _struct_mon_details.RSR. The sums are taken over all map grid\
               points near the relevant atoms. The radius for including grid\
               points in the calculation should also be given in\
               _struct_mon_details.RSR.\
\
               Ref: Branden, C.-I. \& Jones, T. A. (1990). Nature, 343,\
                    687-689.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 446, 'rsr_base', 'rsr_base', 57, 'N', 
        '              The real-space residual RSR, as described by Branden and Jones,\
               evaluated over all atoms in the base moiety of the nucleic acid\
               monomer.\
\
                     sum|p~obs~ - p~calc~|\
               RSR = ---------------------\
                     sum|p~obs~ + p~calc~|\
\
               p~obs~  = the density in an "experimental" map\
               p~calc~ = the density in a "calculated" map\
\
               sum is taken over the specified grid points\
\
               The details of how these maps were calculated should be described\
               in _struct_mon_details.RSR. The sums are taken over all map grid\
               points near the relevant atoms. The radius for including grid\
               points in the calculation should also be given in\
               _struct_mon_details.RSR.\
\
               Ref: Branden, C.-I. \& Jones, T. A. (1990). Nature, 343,\
                    687-689.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 447, 'rsr_phos', 'rsr_phos', 57, 'N', 
        '              The real-space residual RSR, as described by Branden and Jones,\
               evaluated over all atoms in the phosphate moiety of the nucleic\
               acid monomer.\
\
                     sum|p~obs~ - p~calc~|\
               RSR = ---------------------\
                     sum|p~obs~ + p~calc~|\
\
               p~obs~  = the density in an "experimental" map\
               p~calc~ = the density in a "calculated" map\
\
               sum is taken over the specified grid points\
\
               The details of how these maps were calculated should be described\
               in _struct_mon_details.RSR. The sums are taken over all map grid\
               points near the relevant atoms. The radius for including grid\
               points in the calculation should also be given in\
               _struct_mon_details.RSR.\
\
               Ref: Branden, C.-I. \& Jones, T. A. (1990). Nature, 343,\
                    687-689.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 448, 'rsr_sugar', 'rsr_sugar', 57, 'N', 
        '              The real-space residual RSR, as described by Branden and Jones,\
               evaluated over all atoms in the sugar moiety of the nucleic acid\
               monomer.\
\
                     sum|p~obs~ - p~calc~|\
               RSR = ---------------------\
                     sum|p~obs~ + p~calc~|\
\
               p~obs~  = the density in an "experimental" map\
               p~calc~ = the density in a "calculated" map\
\
               sum is taken over the specified grid points\
\
               The details of how these maps were calculated should be described\
               in _struct_mon_details.RSR. The sums are taken over all map grid\
               points near the relevant atoms. The radius for including grid\
               points in the calculation should also be given in\
               _struct_mon_details.RSR.\
\
               Ref: Branden, C.-I. \& Jones, T. A. (1990). Nature, 343,\
                    687-689.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 449, 'tau0', 'tau0', 57, 'N', 
        '              The value in degrees of the sugar torsion angle tau0\
               C4''_O4''_C1''_C2''.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 450, 'tau1', 'tau1', 57, 'N', 
        '              The value in degrees of the sugar torsion angle tau1\
               O4''_C1''_C2''_C3''.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 451, 'tau2', 'tau2', 57, 'N', 
        '              The value in degrees of the sugar torsion angle tau2\
               C1''_C2''_C3''_C4''.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 452, 'tau3', 'tau3', 57, 'N', 
        '              The value in degrees of the sugar torsion angle tau2\
               C2''_C3''_C4''_O4''.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 453, 'tau4', 'tau4', 57, 'N', 
        '              The value in degrees of the sugar torsion angle tau4\
               C3''_C4''_O4''_C1''.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 454, 'taum', 'taum', 57, 'N', 
        '              The maximum amplitide of puckering. It is derived from the\
               the pseudorotation value, P, and the torsion angles in the ribose\
               ring.\
\
               Tau2= Taum cosP\
               Tau3= Taum cos(P+144)\
               Tau4= Taum cos(P+288)\
               Tau0= Taum cos(P+ 72)\
               Tau1= Taum cos(P+216)'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 455, 'zeta', 'zeta', 57, 'N', 
        '              The value in degrees of the backbone torsion angle zeta\
               c3''_o3''_p_o5''.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 58, 'STRUCT_MON_PROT', 'struct_mon_prot', 'N', 0, 
        '              Data items in the STRUCT_MON_PROT category record details about\
               structural properties of a protein when analyzed at the monomer\
               level. Analogous data items for nucleic acids are given in the\
               STRUCT_MON_NUCL category. For items where the value of the\
               property depends on the method employed to calculate it, the\
               details of the method of calculation are described in data items\
               in the STRUCT_MON_DETAILS category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 456, 'chi1', 'chi1', 58, 'N', 
        '              The value in degrees of the side chain torsion angle chi1, for\
               those residues containing such an angle.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 457, 'chi2', 'chi2', 58, 'N', 
        '              The value in degrees of the side chain torsion angle chi2, for\
               those residues containing such an angle.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 458, 'chi3', 'chi3', 58, 'N', 
        '              The value in degrees of the side chain torsion angle chi3, for\
               those residues containing such an angle.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 459, 'chi4', 'chi4', 58, 'N', 
        '              The value in degrees of the side chain torsion angle chi4, for\
               those residues containing such an angle.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 460, 'chi5', 'chi5', 58, 'N', 
        '              The value in degrees of the side chain torsion angle chi5, for\
               those residues containing such an angle.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 461, 'details', 'details', 58, 'N', 
        '              A description of special aspects of the residue, its\
               conformation, behavior in refinement, or any other aspect that\
               requires annotation.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 462, 'rscc_all', 'rscc_all', 58, 'N', 
        '              The real-space (linear) correlation coefficient RSCC, as\
               described by Jones et al.,  evaluated over all atoms in the\
               monomer.\
\
                      sum|p~obs~ - <p~obs~>| * sum|p~calc~ - <p~calc~>|\
               RSCC = -------------------------------------------------\
                            [ sum|p~obs~  - <p~obs~> |^2^\
                            * sum|p~calc~ - <p~calc~>|^2^ ]^1/2^\
\
               p~obs~  = the density in an "experimental" map\
               p~calc~ = the density in a "calculated" map\
\
               sum is taken over the specified grid points\
\
               The details of how these maps were calculated should be described\
               in _struct_mon_details.RSCC. < > indicates an average and the\
               sums are taken over all map grid  points near the relevant atoms.\
               The radius for including grid points in the calculation should\
               also be given in _struct_mon_details.RSCC.\
\
               Ref: Jones, T. A., Zou, J. Y., Cowan, S. W. \& Kjeldgaard, M.\
                    (1991). Acta Cryst. A47, 110-119.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 463, 'rscc_main', 'rscc_main', 58, 'N', 
        '              The real-space (linear) correlation coefficient RSCC, as\
               described by Jones et al., evaluated over all atoms in the\
               main chain of the monomer.\
\
                      sum|p~obs~ - <p~obs~>| * sum|p~calc~ - <p~calc~>|\
               RSCC = -------------------------------------------------\
                            [ sum|p~obs~  - <p~obs~> |^2^\
                            * sum|p~calc~ - <p~calc~>|^2^ ]^1/2^\
\
               p~obs~  = the density in an "experimental" map\
               p~calc~ = the density in a "calculated" map\
\
               sum is taken over the specified grid points\
\
               The details of how these maps were calculated should be described\
               in _struct_mon_details.RSCC. < > indicates an average and the\
               sums are taken over all map grid  points near the relevant atoms.\
               The radius for including grid points in the calculation should\
               also be given in _struct_mon_details.RSCC.\
\
               Ref: Jones, T. A., Zou, J. Y., Cowan, S. W. \& Kjeldgaard, M.\
                    (1991). Acta Cryst. A47, 110-119.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 464, 'rscc_side', 'rscc_side', 58, 'N', 
        '              The real-space (linear) correlation coefficient RSCC, as\
               described by Jones et al., evaluated over all atoms in the\
               side chain of the monomer.\
\
                      sum|p~obs~ - <p~obs~>| * sum|p~calc~ - <p~calc~>|\
               RSCC = -------------------------------------------------\
                            [ sum|p~obs~  - <p~obs~> |^2^\
                            * sum|p~calc~ - <p~calc~>|^2^ ]^1/2^\
\
               p~obs~  = the density in an "experimental" map\
               p~calc~ = the density in a "calculated" map\
\
               sum is taken over the specified grid points\
\
               The details of how these maps were calculated should be described\
               in _struct_mon_details.RSCC. < > indicates an average and the\
               sums are taken over all map grid  points near the relevant atoms.\
               The radius for including grid points in the calculation should\
               also be given in _struct_mon_details.RSCC.\
\
               Ref: Jones, T. A., Zou, J. Y., Cowan, S. W. \& Kjeldgaard, M.\
                    (1991). Acta Cryst. A47, 110-119.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 465, 'rsr_all', 'rsr_all', 58, 'N', 
        '              The real-space residual RSR, as described by Branden and Jones,\
               evaluated over all atoms in the monomer.\
\
                     sum|p~obs~ - p~calc~|\
               RSR = ---------------------\
                     sum|p~obs~ + p~calc~|\
\
               p~obs~  = the density in an "experimental" map\
               p~calc~ = the density in a "calculated" map\
\
               sum is taken over the specified grid points\
\
               The details of how these maps were calculated should be described\
               in _struct_mon_details.RSR. The sums are taken over all map grid\
               points near the relevant atoms. The radius for including grid\
               points in the calculation should also be given in\
               _struct_mon_details.RSR.\
\
               Ref: Branden, C.-I. \& Jones, T. A. (1990). Nature, 343,\
                    687-689.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 466, 'rsr_main', 'rsr_main', 58, 'N', 
        '              The real-space residual RSR, as described by Branden and Jones,\
               (1990) evaluated over all atoms in the main chain of the monomer.\
\
                     sum|p~obs~ - p~calc~|\
               RSR = ---------------------\
                     sum|p~obs~ + p~calc~|\
\
               p~obs~  = the density in an "experimental" map\
               p~calc~ = the density in a "calculated" map\
\
               sum is taken over the specified grid points\
\
               The details of how these maps were calculated should be described\
               in _struct_mon_details.RSR. The sums are taken over all map grid\
               points near the relevant atoms. The radius for including grid\
               points in the calculation should also be given in\
               _struct_mon_details.RSR.\
\
               Ref: Branden, C.-I. \& Jones, T. A. (1990). Nature, 343,\
                    687-689.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 467, 'rsr_side', 'rsr_side', 58, 'N', 
        '              The real-space residual RSR, as described by Branden and Jones,\
               (1990) evaluated over all atoms in the side chain of the monomer.\
\
                     sum|p~obs~ - p~calc~|\
               RSR = ---------------------\
                     sum|p~obs~ + p~calc~|\
\
               p~obs~  = the density in an "experimental" map\
               p~calc~ = the density in a "calculated" map\
\
               sum is taken over the specified grid points\
\
               The details of how these maps were calculated should be described\
               in _struct_mon_details.RSR. The sums are taken over all map grid\
               points near the relevant atoms. The radius for including grid\
               points in the calculation should also be given in\
               _struct_mon_details.RSR.\
\
               Ref: Branden, C.-I. \& Jones, T. A. (1990). Nature, 343,\
                    687-689.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 468, 'mean_b_all', 'mean_b_all', 58, 'N', 
        '              The mean value of the isotropic temperature factor for all atoms\
               in the monomer.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 469, 'mean_b_main', 'mean_b_main', 58, 'N', 
        '              The mean value of the isotropic temperature factor for atoms\
               in the main chain of the monomer.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 470, 'mean_b_side', 'mean_b_side', 58, 'N', 
        '              The mean value of the isotropic temperature factor for atoms\
               in the side chain of the monomer.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 471, 'omega', 'omega', 58, 'N', 
        '              The value in degrees of the main chain torsion angle omega.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 472, 'phi', 'phi', 58, 'N', 
        '              The value in degrees of the main chain torsion angle phi.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 473, 'psi', 'psi', 58, 'N', 
        '              The value in degrees of the main chain torsion angle psi.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 59, 'STRUCT_MON_PROT_CIS', 'struct_mon_prot_cis', 'N', 0, 
        '              Data items in the STRUCT_MON_PROT_CIS category identify\
               monomers that have been found to have the peptide bond in the cis\
               conformation. The criterion used to select residues to be\
               designated as containing cis peptide bonds is given in\
               _struct_mon_details.prot_cis.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 474, 'pdbx_auth_asym_id_2', 'pdbx_auth_asym_id_2', 59, 'N', 
        '   Pointer to _atom_site.auth_asym_id.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 475, 'pdbx_auth_comp_id_2', 'pdbx_auth_comp_id_2', 59, 'N', 
        '   Pointer to _atom_site.auth_comp_id.         '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 476, 'pdbx_auth_seq_id_2', 'pdbx_auth_seq_id_2', 59, 'N', 
        '   Pointer to _atom_site.auth_seq_id         '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 477, 'pdbx_label_asym_id_2', 'pdbx_label_asym_id_2', 59, 'N', 
        '   Pointer to _atom_site.label_asym_id.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 478, 'pdbx_label_comp_id_2', 'pdbx_label_comp_id_2', 59, 'N', 
        '   Pointer to _atom_site.label_comp_id.         '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 479, 'pdbx_label_seq_id_2', 'pdbx_label_seq_id_2', 59, 'N', 
        '   Pointer to _atom_site.label_seq_id         '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 480, 'pdbx_PDB_ins_code', 'pdbx_PDB_ins_code', 59, 'N', 
        '   Pointer to _atom_site.pdbx_PDB_ins_code         '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 481, 'pdbx_PDB_ins_code_2', 'pdbx_PDB_ins_code_2', 59, 'N', 
        '   Pointer to _atom_site.pdbx_PDB_ins_code         '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 482, 'pdbx_PDB_model_num', 'pdbx_PDB_model_num', 59, 'N', 
        '      Pointer to _atom_site.pdbx_PDB_model_num'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 483, 'pdbx_omega_angle', 'pdbx_omega_angle', 59, 'N', 
        '         omega torsion angle '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 484, 'pdbx_id', 'pdbx_id', 59, 'N', 
        '    ordinal index         '
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 60, 'STRUCT_NCS_DOM', 'struct_ncs_dom', 'N', 0, 
        '              Data items in the STRUCT_NCS_DOM category record information\
               about the domains in an ensemble of domains related by one or\
               more non-crystallographic symmetry operators.\
\
               A domain need not correspond to a completely polypeptide chain;\
               it can be composed of one more more segments in a single chain,\
               or by segments from more than one chain.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 485, 'details', 'details', 60, 'N', 
        '              A description of special aspects of the structural elements that\
               comprise a domain in an ensemble of domains related by non-\
               crystallographic symmetry.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 486, 'id', 'id', 60, 'Y', 
        '              The value of _struct_ncs_dom.id must uniquely identify a\
               record in the STRUCT_NCS_DOM list.\
\
               Note that this item need not be a number; it can be any unique\
               identifier.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 61, 'STRUCT_NCS_DOM_LIM', 'struct_ncs_dom_lim', 'N', 0, 
        '              Data items in the STRUCT_NCS_DOM_LIM category identify the\
               beginning and ending points of polypeptide chain segments\
               that form all or part of a domain in an ensemble of domains\
               related by non-crystallographic symmetry.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 62, 'STRUCT_NCS_ENS', 'struct_ncs_ens', 'N', 0, 
        '              Data items in the STRUCT_NCS_ENS category record information\
               about ensembles of domains related by non-crystallographic\
               symmetry. The point group of the ensemble when taken as a\
               whole may be specified, as well as any special aspects of the\
               ensemble that require description.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 487, 'details', 'details', 62, 'N', 
        '              A description of special aspects of the ensemble.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 488, 'id', 'id', 62, 'Y', 
        '              The value of _struct_ncs_ens.id must uniquely identify a\
               record in the STRUCT_NCS_ENS list.\
\
               Note that this item need not be a number; it can be any unique\
               identifier.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 489, 'point_group', 'point_group', 62, 'N', 
        '              The point group of the ensemble of structural elements related by\
               one or more non-crystallographic symmetry operations. The\
               relationships need not be precise; this data item is intended\
               to give a rough description of the non-crystallographic symmetry\
               relationships.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 63, 'STRUCT_NCS_ENS_GEN', 'struct_ncs_ens_gen', 'N', 0, 
        '              Data items in the STRUCT_NCS_ENS_GEN category list domains\
               related by a non-crystallographic symmetry operation and\
               identify the operator.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 64, 'STRUCT_NCS_OPER', 'struct_ncs_oper', 'N', 0, 
        '              Data items in the STRUCT_NCS_OPER category describe the\
               non-crystallographic symmetry operations.\
\
               Each operator is specified as a matrix and a subsequent\
               translation vector. Operators need not represent proper\
               rotations.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 490, 'code', 'code', 64, 'N', 
        '              A code to indicate whether this operator describes a \
               relationship between coordinates all of which are given in the\
               data block (in which case the value of code is ''given''), or\
               whether the operator is used to generate new coordinates from\
               those that are given in the data block (in which case the value\
               of code is ''generate'').'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 491, 'details', 'details', 64, 'N', 
        '              A description of special aspects of the non-crystallographic\
               symmetry operator.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 492, 'id', 'id', 64, 'Y', 
        '              The value of _struct_ncs_oper.id must uniquely identify a\
               record in the STRUCT_NCS_OPER list.\
\
               Note that this item need not be a number; it can be any unique\
               identifier.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 493, 'matrix_0_0', 'matrix[1][1]', 64, 'N', 
        '              The [1][1] element of the 3x3 matrix component of a non-\
               crystallographic symmetry operation.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 494, 'matrix_0_1', 'matrix[1][2]', 64, 'N', 
        '              The [1][2] element of the 3x3 matrix component of a non-\
               crystallographic symmetry operation.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 495, 'matrix_0_2', 'matrix[1][3]', 64, 'N', 
        '              The [1][3] element of the 3x3 matrix component of a non-\
               crystallographic symmetry operation.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 496, 'matrix_1_0', 'matrix[2][1]', 64, 'N', 
        '              The [2][1] element of the 3x3 matrix component of a non-\
               crystallographic symmetry operation.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 497, 'matrix_1_1', 'matrix[2][2]', 64, 'N', 
        '              The [2][2] element of the 3x3 matrix component of a non-\
               crystallographic symmetry operation.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 498, 'matrix_1_2', 'matrix[2][3]', 64, 'N', 
        '              The [2][3] element of the 3x3 matrix component of a non-\
               crystallographic symmetry operation.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 499, 'matrix_2_0', 'matrix[3][1]', 64, 'N', 
        '              The [3][1] element of the 3x3 matrix component of a non-\
               crystallographic symmetry operation.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 500, 'matrix_2_1', 'matrix[3][2]', 64, 'N', 
        '              The [3][2] element of the 3x3 matrix component of a non-\
               crystallographic symmetry operation.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 501, 'matrix_2_2', 'matrix[3][3]', 64, 'N', 
        '              The [3][3] element of the 3x3 matrix component of a non-\
               crystallographic symmetry operation.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 502, 'vector_0', 'vector[1]', 64, 'N', 
        '              The [1] element of the 3 element vector component of a non-\
               crystallographic symmetry operation.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 503, 'vector_1', 'vector[2]', 64, 'N', 
        '              The [2] element of the 3 element vector component of a non-\
               crystallographic symmetry operation.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 504, 'vector_2', 'vector[3]', 64, 'N', 
        '              The [3] element of the 3 element vector component of a non-\
               crystallographic symmetry operation.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 65, 'STRUCT_REF', 'struct_ref', 'N', 0, 
        '              Data items in the STRUCT_REF category allow the author of a\
               data block to relate the entities or biological units\
               described in that data block to information archived in external\
               databases.\
\
               For references to the sequence of a polymer, the value of\
               the data item _struct_ref.seq_align is used to indicate\
               whether the correspondence between the sequence of the entity\
               or biological unit in the data block and the sequence in the\
               referenced database entry is ''complete'' or ''partial''. If\
               this value is ''partial'', the region (or regions) of the\
               alignment may be delimited using data items in the\
               STRUCT_REF_SEQ category.\
\
               Also for references to the sequence of a polymer, the value of\
               _struct_ref.seq_dif is used to indicate whether or not the\
               two sequences contain point differences. If the value is yes,\
               the differences may be identified and annotated using data\
               items in the STRUCT_REF_SEQ_DIF category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 505, 'db_code', 'db_code', 65, 'Y', 
        '              The code for this entity or biological unit or for a closely\
               related entity or biological unit in the named database.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 506, 'db_name', 'db_name', 65, 'Y', 
        '              The name of the database containing reference information about\
               this entity or biological unit.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 507, 'details', 'details', 65, 'N', 
        '              A description of special aspects of the relationship between\
               the entity or biological unit described in the data block and\
               the referenced database entry.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 508, 'id', 'id', 65, 'Y', 
        '              The value of _struct_ref.id must uniquely identify a record\
               in the STRUCT_REF list.\
\
               Note that this item need not be a number; it can be any unique\
               identifier.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 509, 'seq_align', 'seq_align', 65, 'N', 
        '              A flag to indicate the scope of the alignment between the\
               sequence of the entity or biological unit described in the data\
               block and the referenced database entry. ''entire'' indicates\
               that alignment spans the entire length of both sequences\
               (although point differences may occur, and can be annotated\
               using the data items in the STRUCT_REF_SEQ_DIF category).\
               ''partial'' indicates a partial alignment, and the region (or\
               regions) of the alignment may be delimited using data items\
               in the STRUCT_REF_SEQ category. This data item may also take\
               the value ''.'', indicating that the reference is not to a\
               sequence.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 510, 'seq_dif', 'seq_dif', 65, 'N', 
        '              A flag to indicate the presence (''yes'') or absence (''no'') of\
               point differences between the sequence of the entity or\
               biological unit described in the data block and the referenced\
               database entry. This data item may also take the value ''.'',\
               indicating that the reference is not to a sequence.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 511, 'pdbx_db_accession', 'pdbx_db_accession', 65, 'N', 
        '              Accession code of the reference database.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 512, 'pdbx_seq_one_letter_code', 'pdbx_seq_one_letter_code', 65, 'N', 
        '              Database chemical sequence expressed as string of one-letter \
               amino acid codes. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 513, 'pdbx_align_begin', 'pdbx_align_begin', 65, 'N', 
        '         \
               Beginning index in the chemical sequence from the \
               reference database.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 66, 'STRUCT_REF_SEQ', 'struct_ref_seq', 'N', 0, 
        '              Data items in the STRUCT_REF_SEQ category provide a mechanism\
               for indicating and annotating a region (or regions) of alignment \
               between the sequence of an entity or biological unit described\
               in the data block and the sequence in the referenced database\
               entry.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 514, 'align_id', 'align_id', 66, 'Y', 
        '              The value of _struct_ref_seq.align_id must uniquely identify a\
               record in the STRUCT_REF_SEQ list.\
\
               Note that this item need not be a number; it can be any unique\
               identifier.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 515, 'db_align_beg', 'db_align_beg', 66, 'Y', 
        '              The sequence position at which the alignment begins in the\
               referenced database entry.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 516, 'db_align_end', 'db_align_end', 66, 'Y', 
        '              The sequence position at which the alignment ends in the\
               referenced database entry.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 517, 'details', 'details', 66, 'N', 
        '              A description of special aspects of the sequence alignment.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 518, 'pdbx_strand_id', 'pdbx_strand_id', 66, 'N', 
        '         The PDB strand/chain ID .'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 519, 'pdbx_db_accession', 'pdbx_db_accession', 66, 'N', 
        '               Accession code of the reference database.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 520, 'pdbx_db_align_beg_ins_code', 'pdbx_db_align_beg_ins_code', 66, 'N', 
        '         \
               Initial insertion code of the sequence segment of the\
               reference database.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 521, 'pdbx_db_align_end_ins_code', 'pdbx_db_align_end_ins_code', 66, 'N', 
        '         \
               Ending insertion code of the sequence segment of the\
               reference database.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 522, 'pdbx_PDB_id_code', 'pdbx_PDB_id_code', 66, 'N', 
        '              The PDB code of the structure.\
  '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 523, 'pdbx_auth_seq_align_beg', 'pdbx_auth_seq_align_beg', 66, 'N', 
        '\
               Initial position in the PDB sequence segment.     '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 524, 'pdbx_auth_seq_align_end', 'pdbx_auth_seq_align_end', 66, 'N', 
        '\
               Ending position in the PDB sequence segment'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 525, 'pdbx_seq_align_beg_ins_code', 'pdbx_seq_align_beg_ins_code', 66, 'N', 
        '\
               Initial insertion code of the PDB sequence segment.     '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 526, 'pdbx_seq_align_end_ins_code', 'pdbx_seq_align_end_ins_code', 66, 'N', 
        '\
               Ending insertion code of the sequence segment'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 67, 'STRUCT_REF_SEQ_DIF', 'struct_ref_seq_dif', 'N', 0, 
        '              Data items in the STRUCT_REF_SEQ_DIF category provide a\
               mechanism for indicating and annotating point differences\
               between the sequence of the entity or biological unit described\
               in the data block and the sequence of the referenced database\
               entry.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 527, 'details', 'details', 67, 'N', 
        '              A description of special aspects of the point differences\
               between the sequence of the entity or biological unit described\
               in the data block and the referenced database entry.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 528, 'pdbx_pdb_id_code ', 'pdbx_pdb_id_code ', 67, 'N', 
        '\
               The PDB ID code.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 529, 'pdbx_pdb_strand_id ', 'pdbx_pdb_strand_id ', 67, 'N', 
        '              PDB strand/chain id.       '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 530, 'pdbx_pdb_ins_code ', 'pdbx_pdb_ins_code ', 67, 'N', 
        '              Insertion code in PDB sequence\
'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 531, 'pdbx_auth_seq_num', 'pdbx_auth_seq_num', 67, 'N', 
        '              Insertion code in PDB sequence\
'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 532, 'pdbx_seq_db_name', 'pdbx_seq_db_name', 67, 'N', 
        '              Sequence database name.\
'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 533, 'pdbx_seq_db_accession_code', 'pdbx_seq_db_accession_code', 67, 'N', 
        '              Sequence database accession number.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 534, 'pdbx_seq_db_seq_num', 'pdbx_seq_db_seq_num', 67, 'N', 
        '              Sequence database sequence number.\
'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 68, 'STRUCT_SHEET', 'struct_sheet', 'N', 0, 
        '              Data items in the STRUCT_SHEET category record details about\
               the beta sheets.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 535, 'details', 'details', 68, 'N', 
        '              A description of special aspects of the beta-sheet.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 536, 'id', 'id', 68, 'Y', 
        '              The value of _struct_sheet.id must uniquely identify a record in\
               the STRUCT_SHEET list.\
\
               Note that this item need not be a number; it can be any unique\
               identifier.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 537, 'number_strands', 'number_strands', 68, 'N', 
        '            The number of strands in the sheet. If a given range of residues\
             is bulged out from the strands, it is still counted as one strand.\
             If a strand is composed of two different regions of polypeptide,\
             it is still counted as one strand, so long as the proper hydrogen\
             bonding connections are made to adjacent strands.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 538, 'type', 'type', 68, 'N', 
        '              A simple descriptor for the type of the sheet.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 69, 'STRUCT_SHEET_HBOND', 'struct_sheet_hbond', 'N', 0, 
        '              Data items in the STRUCT_SHEET_HBOND category record details\
               about the hydrogen bonding between residue ranges in a beta\
               sheet. It is necessary to treat hydrogen bonding independently\
               of the designation of ranges, because the hydrogen bonding may\
               begin in different places for the interactions of a given strand\
               with the one preceding it and the one following it in the sheet.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 539, 'pdbx_range_1_beg_auth_comp_id', 'pdbx_range_1_beg_auth_comp_id', 69, 'N', 
        '              Pointer to _atom_site.auth_comp_id'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 540, 'pdbx_range_1_beg_auth_asym_id', 'pdbx_range_1_beg_auth_asym_id', 69, 'N', 
        '           Pointer to _atom_site.auth_asym_id.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 541, 'pdbx_range_1_end_auth_comp_id', 'pdbx_range_1_end_auth_comp_id', 69, 'N', 
        '           Pointer to _atom_site.auth_comp_id.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 542, 'pdbx_range_1_end_auth_asym_id', 'pdbx_range_1_end_auth_asym_id', 69, 'N', 
        '           Pointer to _atom_site.auth_comp_id.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 543, 'pdbx_range_1_beg_label_comp_id', 'pdbx_range_1_beg_label_comp_id', 69, 'N', 
        '              Pointer to _atom_site.label_comp_id'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 544, 'pdbx_range_1_beg_label_asym_id', 'pdbx_range_1_beg_label_asym_id', 69, 'N', 
        '              Pointer to _atom_site.label_asym_id.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 545, 'pdbx_range_1_beg_PDB_ins_code', 'pdbx_range_1_beg_PDB_ins_code', 69, 'N', 
        '  Pointer to _atom_site.pdbx_PDB_ins_code.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 546, 'pdbx_range_1_end_label_comp_id', 'pdbx_range_1_end_label_comp_id', 69, 'N', 
        ' Pointer to _atom_site.label_comp_id.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 547, 'pdbx_range_1_end_label_asym_id', 'pdbx_range_1_end_label_asym_id', 69, 'N', 
        ' Pointer to _atom_site.label_asym_id.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 548, 'pdbx_range_1_end_PDB_ins_code', 'pdbx_range_1_end_PDB_ins_code', 69, 'N', 
        '   Pointer to _atom_site.pdbx_PDB_ins_code.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 549, 'pdbx_range_2_beg_label_comp_id', 'pdbx_range_2_beg_label_comp_id', 69, 'N', 
        '   Pointer to _atom_site.label_comp_id.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 550, 'pdbx_range_2_beg_label_asym_id', 'pdbx_range_2_beg_label_asym_id', 69, 'N', 
        '   Pointer to _atom_site.label_asym_id.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 551, 'pdbx_range_2_beg_PDB_ins_code', 'pdbx_range_2_beg_PDB_ins_code', 69, 'N', 
        '   Pointer to _atom_site.pdbx_PDB_ins_code.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 552, 'pdbx_range_2_end_label_comp_id', 'pdbx_range_2_end_label_comp_id', 69, 'N', 
        '   Pointer to _atom_site.label_comp_id.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 553, 'pdbx_range_2_end_label_asym_id', 'pdbx_range_2_end_label_asym_id', 69, 'N', 
        '   Pointer to _atom_site.label_asym_id.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 554, 'pdbx_range_2_end_label_ins_cod', 'pdbx_range_2_end_label_ins_code', 69, 'N', 
        '              Place holder for PDB insertion code.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 70, 'PDBX_STRUCT_SHEET_HBOND', 'pdbx_struct_sheet_hbond', 'N', 0, 
        '          Data items in the PDBX_STRUCT_SHEET_HBOND category record details\
           about the hydrogen bonding between residue ranges in a beta sheet.\
           This category is provided for cases where only a single hydrogen\
           bond is used to register the two residue ranges.   Category\
           STRUCT_SHEET_HBOND should be used when the initial and terminal\
           hydrogen bonds for strand pair are known. \
'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 555, 'range_id_1', 'range_id_1', 70, 'Y', 
        '              This data item is a pointer to _struct_sheet_range.id in\
               the STRUCT_SHEET_RANGE category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 556, 'range_id_2', 'range_id_2', 70, 'Y', 
        '              This data item is a pointer to _struct_sheet_range.id in\
               the STRUCT_SHEET_RANGE category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 557, 'sheet_id', 'sheet_id', 70, 'Y', 
        '              This data item is a pointer to _struct_sheet.id in the\
               STRUCT_SHEET category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 558, 'range_1_label_atom_id', 'range_1_label_atom_id', 70, 'Y', 
        '           A component of the residue identifier for the first partner of the \
            registration hydrogen bond between two residue ranges in a sheet.\
\
               This data item is a pointer to _atom_site.label_atom_id in the\
               ATOM_SITE category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 559, 'range_1_label_seq_id', 'range_1_label_seq_id', 70, 'Y', 
        '          A component of the residue identifier for the first partner of the \
           registration hydrogen bond between two residue ranges in a sheet.\
\
           This data item is a pointer to _atom_site.label_seq_id in the\
           ATOM_SITE category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 560, 'range_1_label_comp_id', 'range_1_label_comp_id', 70, 'N', 
        '           A component of the residue identifier for the first partner of the \
            registration hydrogen bond between two residue ranges in a sheet.\
\
            This data item is a pointer to _atom_site.label_comp_id in the\
            ATOM_SITE category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 561, 'range_1_label_asym_id', 'range_1_label_asym_id', 70, 'N', 
        '           A component of the residue identifier for the first partner of the \
            registration hydrogen bond between two residue ranges in a sheet.\
\
            This data item is a pointer to _atom_site.label_asym_id in the\
            ATOM_SITE category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 562, 'range_1_auth_atom_id', 'range_1_auth_atom_id', 70, 'N', 
        '          A component of the residue identifier for the first partner of the \
           registration hydrogen bond between two residue ranges in a sheet.\
\
           This data item is a pointer to _atom_site.auth_atom_id in the\
           ATOM_SITE category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 563, 'range_1_auth_seq_id', 'range_1_auth_seq_id', 70, 'N', 
        '          A component of the residue identifier for the first partner of the \
           registration hydrogen bond between two residue ranges in a sheet.\
\
           This data item is a pointer to _atom_site.auth_seq_id in the\
           ATOM_SITE category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 564, 'range_1_auth_comp_id', 'range_1_auth_comp_id', 70, 'N', 
        '           A component of the residue identifier for the first partner of the \
            registration hydrogen bond between two residue ranges in a sheet.\
\
            This data item is a pointer to _atom_site.auth_comp_id in the\
            ATOM_SITE category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 565, 'range_1_auth_asym_id', 'range_1_auth_asym_id', 70, 'N', 
        '          A component of the residue identifier for the first partner of the \
           registration hydrogen bond between two residue ranges in a sheet.\
\
           This data item is a pointer to _atom_site.auth_asym_id in the\
           ATOM_SITE category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 566, 'range_1_PDB_ins_code', 'range_1_PDB_ins_code', 70, 'N', 
        '           A component of the residue identifier for the first partner of the \
            registration hydrogen bond between two residue ranges in a sheet.\
\
            This data item is a pointer to _atom_site.label_asym_id in the\
            ATOM_SITE category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 567, 'range_2_label_atom_id', 'range_2_label_atom_id', 70, 'Y', 
        '         A component of the residue identifier for the second partner of the \
          registration hydrogen bond between two residue ranges in a sheet.\
\
          This data item is a pointer to _atom_site.label_atom_id in the\
          ATOM_SITE category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 568, 'range_2_label_seq_id', 'range_2_label_seq_id', 70, 'Y', 
        '           A component of the residue identifier for the second partner of the \
            registration hydrogen bond between two residue ranges in a sheet.\
\
            This data item is a pointer to _atom_site.label_seq_id in the\
            ATOM_SITE category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 569, 'range_2_label_comp_id', 'range_2_label_comp_id', 70, 'N', 
        '           A component of the residue identifier for the second partner of the \
            registration hydrogen bond between two residue ranges in a sheet.\
\
            This data item is a pointer to _atom_site.label_comp_id in the\
            ATOM_SITE category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 570, 'range_2_label_asym_id', 'range_2_label_asym_id', 70, 'N', 
        '           A component of the residue identifier for the second partner of the \
            registration hydrogen bond between two residue ranges in a sheet.\
\
            This data item is a pointer to _atom_site.label_asym_id in the\
            ATOM_SITE category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 571, 'range_2_auth_atom_id', 'range_2_auth_atom_id', 70, 'N', 
        '           A component of the residue identifier for the second partner of the \
            registration hydrogen bond between two residue ranges in a sheet.\
\
            This data item is a pointer to _atom_site.auth_atom_id in the\
            ATOM_SITE category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 572, 'range_2_auth_seq_id', 'range_2_auth_seq_id', 70, 'N', 
        '          A component of the residue identifier for the second partner of the \
           registration hydrogen bond between two residue ranges in a sheet.\
\
           This data item is a pointer to _atom_site.auth_seq_id in the\
           ATOM_SITE category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 573, 'range_2_auth_comp_id', 'range_2_auth_comp_id', 70, 'N', 
        '          A component of the residue identifier for the second partner of the \
           registration hydrogen bond between two residue ranges in a sheet.\
\
           This data item is a pointer to _atom_site.auth_comp_id in the\
           ATOM_SITE category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 574, 'range_2_auth_asym_id', 'range_2_auth_asym_id', 70, 'N', 
        '          A component of the residue identifier for the second partner of the \
           registration hydrogen bond between two residue ranges in a sheet.\
\
           This data item is a pointer to _atom_site.auth_asym_id in the\
           ATOM_SITE category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 575, 'range_2_PDB_ins_code', 'range_2_PDB_ins_code', 70, 'N', 
        '           A component of the residue identifier for the second partner of the \
            registration hydrogen bond between two residue ranges in a sheet.\
\
            This data item is a pointer to _atom_site.label_asym_id in the\
            ATOM_SITE category.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 71, 'STRUCT_SHEET_ORDER', 'struct_sheet_order', 'N', 0, 
        '              Data items in the STRUCT_SHEET_ORDER category record details\
               about the order of the residue ranges that form a beta sheet.\
               All order linkages are pairwise, and the specified pairs are\
               assumed to be adjacent to one another in the sheet. These data\
               items are an alternative to the STRUCT_SHEET_TOPOLOGY data\
               items, and they allow for the formal description of all manner\
               of sheets.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 576, 'offset', 'offset', 71, 'N', 
        '              Designates the relative position in the sheet, plus or minus, of\
               the second residue range to the first.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 577, 'sense', 'sense', 71, 'N', 
        '              A flag to indicate whether the two designated residue ranges are\
               parallel or anti-parallel to one another.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 72, 'STRUCT_SHEET_RANGE', 'struct_sheet_range', 'N', 0, 
        '              Data items in the STRUCT_SHEET_RANGE category record details\
               about the residue ranges that form a beta sheet. Residues are\
               included in a range if they made beta-sheet type hydrogen bonding\
               interactions with at least one adjacent strand and if there are\
               at least two residues in the range.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 578, 'id', 'id', 72, 'Y', 
        '              The value of _struct_sheet_range.id must uniquely identify a\
               range in a given sheet in the STRUCT_SHEET_RANGE list.\
\
               Note that this item need not be a number; it can be any unique\
               identifier.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 579, 'symmetry', 'symmetry', 72, 'N', 
        '              Describes the symmetry operation that should be applied to the\
               residues delimited by the beginning and ending designators in\
               order to generate the appropriate strand in this sheet.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 580, 'pdbx_beg_PDB_ins_code', 'pdbx_beg_PDB_ins_code', 72, 'Y', 
        '              A component of the identifier for the residue at which the\
               beta sheet range begins.  Insertion code.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 581, 'pdbx_end_PDB_ins_code', 'pdbx_end_PDB_ins_code', 72, 'Y', 
        '              A component of the identifier for the residue at which the\
               beta sheet range ends. Insertion code.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 73, 'STRUCT_SHEET_TOPOLOGY', 'struct_sheet_topology', 'N', 0, 
        '              Data items in the STRUCT_SHEET_TOPOLOGY category record details\
               about the topology of the residue ranges that form a beta sheet.\
               All topology linkages are pairwise, and the specified pairs are\
               assumed to be successive in the amino acid sequence. These\
               data items are useful in describing various simple and complex\
               folds, but they become inadequate when the strands in the sheet\
               come from more than one chain. One can alternatively use the\
               STRUCT_SHEET_ORDER data items to describe both single and\
               multiple chain-containing sheets.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 582, 'offset', 'offset', 73, 'N', 
        '              Designates the relative position in the sheet, plus or minus, of\
               the second residue range to the first.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 583, 'sense', 'sense', 73, 'N', 
        '              A flag to indicate whether the two designated residue ranges are\
               parallel or anti-parallel to one another.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 74, 'STRUCT_SITE', 'struct_site', 'N', 0, 
        '              Data items in the STRUCT_SITE category record details about\
               portions of structure that contribute to certain structurally\
               relevant sites (e.g. active sites, substrate-binding subsites,\
               metal-coordination sites).'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 584, 'details', 'details', 74, 'N', 
        '              A description of special aspects of the structural site.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 585, 'id', 'id', 74, 'Y', 
        '              The value of _struct_site.id must uniquely identify a record in\
               the STRUCT_SITE list.\
\
               Note that this item need not be a number; it can be any unique\
               identifier.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 586, 'pdbx_num_residues', 'pdbx_num_residues', 74, 'N', 
        '         Number of residues in the site.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 75, 'STRUCT_SITE_GEN', 'struct_site_gen', 'N', 0, 
        '              Data items in the STRUCT_SITE_GEN category record details about\
               the generation of portions of structure that contribute to\
               structurally relevant sites.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 587, 'details', 'details', 75, 'N', 
        '              A description of special aspects of the symmetry generation of\
               this portion of the structural site.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 588, 'id', 'id', 75, 'Y', 
        '              The value of _struct_site_gen.id must uniquely identify a record\
               in the STRUCT_SITE_GEN list.\
\
               Note that this item need not be a number; it can be any unique\
               identifier.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 589, 'symmetry', 'symmetry', 75, 'N', 
        '              Describes the symmetry operation that should be applied to the\
               atom set specified by _struct_site_gen.label* to generate a\
               portion of the structure site.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 590, 'pdbx_auth_ins_code', 'pdbx_auth_ins_code', 75, 'N', 
        '         PDB insertion code.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 591, 'pdbx_num_res', 'pdbx_num_res', 75, 'N', 
        '         Number of residues in the site.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 76, 'STRUCT_SITE_KEYWORDS', 'struct_site_keywords', 'N', 0, 
        '              Data items in the STRUCT_SITE_KEYWORDS category record details\
               about this site.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 592, 'text', 'text', 76, 'Y', 
        '              Keywords describing this structural site.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 77, 'STRUCT_SITE_VIEW', 'struct_site_view', 'N', 0, 
        '              Data items in the STRUCT_SITE_VIEW category record details\
               about how to draw and annotate a useful didactic view of the\
               structural site.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 593, 'details', 'details', 77, 'N', 
        '              A description of special aspects of this view of the structural\
               site. This data item can be used as a figure legend, if desired.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 594, 'id', 'id', 77, 'Y', 
        '              The value of _struct_site_view.id must uniquely identify a\
               record in the STRUCT_SITE_VIEW list.\
\
               Note that this item need not be a number; it can be any unique\
               identifier.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 595, 'rot_matrix_0_0', 'rot_matrix[1][1]', 77, 'N', 
        '              The [1][1] element of the matrix used to rotate the subset of the\
               Cartesian coordinates in the ATOM_SITE category identified in the\
               STRUCT_SITE_GEN category to a view useful for describing the\
               structural site. The conventions used in the rotation are\
               described in _struct_site_view.details.\
\
               |x''|                         |11 12 13| |x|\
               |y''|~reoriented Cartesian~ = |21 22 23| |y|~Cartesian~\
               |z''|                         |31 32 33| |z|'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 596, 'rot_matrix_0_1', 'rot_matrix[1][2]', 77, 'N', 
        '              The [1][2] element of the matrix used to rotate the subset of the\
               Cartesian coordinates in the ATOM_SITE category identified in the\
               STRUCT_SITE_GEN category to a view useful for describing the\
               structural site. The conventions used in the rotation are\
               described in _struct_site_view.details.\
\
               |x''|                         |11 12 13| |x|\
               |y''|~reoriented Cartesian~ = |21 22 23| |y|~Cartesian~\
               |z''|                         |31 32 33| |z|'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 597, 'rot_matrix_0_2', 'rot_matrix[1][3]', 77, 'N', 
        '              The [1][3] element of the matrix used to rotate the subset of the\
               Cartesian coordinates in the ATOM_SITE category identified in the\
               STRUCT_SITE_GEN category to a view useful for describing the\
               structural site. The conventions used in the rotation are\
               described in _struct_site_view.details.\
\
               |x''|                         |11 12 13| |x|\
               |y''|~reoriented Cartesian~ = |21 22 23| |y|~Cartesian~\
               |z''|                         |31 32 33| |z|'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 598, 'rot_matrix_1_0', 'rot_matrix[2][1]', 77, 'N', 
        '              The [2][1] element of the matrix used to rotate the subset of the\
               Cartesian coordinates in the ATOM_SITE category identified in the\
               STRUCT_SITE_GEN category to a view useful for describing the\
               structural site. The conventions used in the rotation are\
               described in _struct_site_view.details.\
\
               |x''|                         |11 12 13| |x|\
               |y''|~reoriented Cartesian~ = |21 22 23| |y|~Cartesian~\
               |z''|                         |31 32 33| |z|'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 599, 'rot_matrix_1_1', 'rot_matrix[2][2]', 77, 'N', 
        '              The [2][2] element of the matrix used to rotate the subset of the\
               Cartesian coordinates in the ATOM_SITE category identified in the\
               STRUCT_SITE_GEN category to a view useful for describing the\
               structural site. The conventions used in the rotation are\
               described in _struct_site_view.details.\
\
               |x''|                         |11 12 13| |x|\
               |y''|~reoriented Cartesian~ = |21 22 23| |y|~Cartesian~\
               |z''|                         |31 32 33| |z|'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 600, 'rot_matrix_1_2', 'rot_matrix[2][3]', 77, 'N', 
        '              The [2][3] element of the matrix used to rotate the subset of the\
               Cartesian coordinates in the ATOM_SITE category identified in the\
               STRUCT_SITE_GEN category to a view useful for describing the\
               structural site. The conventions used in the rotation are\
               described in _struct_site_view.details.\
\
               |x''|                         |11 12 13| |x|\
               |y''|~reoriented Cartesian~ = |21 22 23| |y|~Cartesian~\
               |z''|                         |31 32 33| |z|'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 601, 'rot_matrix_2_0', 'rot_matrix[3][1]', 77, 'N', 
        '              The [3][1] element of the matrix used to rotate the subset of the\
               Cartesian coordinates in the ATOM_SITE category identified in the\
               STRUCT_SITE_GEN category to a view useful for describing the\
               structural site. The conventions used in the rotation are\
               described in _struct_site_view.details.\
\
               |x''|                         |11 12 13| |x|\
               |y''|~reoriented Cartesian~ = |21 22 23| |y|~Cartesian~\
               |z''|                         |31 32 33| |z|'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 602, 'rot_matrix_2_1', 'rot_matrix[3][2]', 77, 'N', 
        '              The [3][2] element of the matrix used to rotate the subset of the\
               Cartesian coordinates in the ATOM_SITE category identified in the\
               STRUCT_SITE_GEN category to a view useful for describing the\
               structural site. The conventions used in the rotation are\
               described in _struct_site_view.details.\
\
               |x''|                         |11 12 13| |x|\
               |y''|~reoriented Cartesian~ = |21 22 23| |y|~Cartesian~\
               |z''|                         |31 32 33| |z|'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 603, 'rot_matrix_2_2', 'rot_matrix[3][3]', 77, 'N', 
        '              The [3][3] element of the matrix used to rotate the subset of the\
               Cartesian coordinates in the ATOM_SITE category identified in the\
               STRUCT_SITE_GEN category to a view useful for describing the\
               structural site. The conventions used in the rotation are\
               described in _struct_site_view.details.\
\
               |x''|                         |11 12 13| |x|\
               |y''|~reoriented Cartesian~ = |21 22 23| |y|~Cartesian~\
               |z''|                         |31 32 33| |z|'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 78, 'ATOM_SITES', 'atom_sites', 'N', 0, 
        '              Data items in the ATOM_SITES category record details about\
               the crystallographic cell and cell transformations, which are\
               common to all atom sites.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 604, 'entry_id', 'entry_id', 78, 'Y', 
        '              This data item is a pointer to _entry.id in the ENTRY category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 605, 'cartn_transf_matrix_0_0', 'Cartn_transf_matrix[1][1]', 78, 'N', 
        '              The [1][1] element of the 3x3 matrix used to transform\
               fractional coordinates in the ATOM_SITE category to Cartesian\
               coordinates in the same category. The axial alignments of this\
               transformation are described in _atom_sites.Cartn_transform_axes.\
               The 3x1 translation is defined in\
               _atom_sites.Cartn_transf_vector[].\
\
               |x''|              |11 12 13| |x|               |1|\
               |y''|~Cartesian~ = |21 22 23| |y|~fractional~ + |2|\
               |z''|              |31 32 33| |z|               |3|'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 606, 'cartn_transf_matrix_0_1', 'Cartn_transf_matrix[1][2]', 78, 'N', 
        '              The [1][2] element of the 3x3 matrix used to transform\
               fractional coordinates in the ATOM_SITE category to Cartesian\
               coordinates in the same category. The axial alignments of this\
               transformation are described in _atom_sites.Cartn_transform_axes.\
               The 3x1 translation is defined in\
               _atom_sites.Cartn_transf_vector[].\
\
               |x''|              |11 12 13| |x|               |1|\
               |y''|~Cartesian~ = |21 22 23| |y|~fractional~ + |2|\
               |z''|              |31 32 33| |z|               |3|'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 607, 'cartn_transf_matrix_0_2', 'Cartn_transf_matrix[1][3]', 78, 'N', 
        '              The [1][3] element of the 3x3 matrix used to transform\
               fractional coordinates in the ATOM_SITE category to Cartesian\
               coordinates in the same category. The axial alignments of this\
               transformation are described in _atom_sites.Cartn_transform_axes.\
               The 3x1 translation is defined in\
               _atom_sites.Cartn_transf_vector[].\
\
               |x''|              |11 12 13| |x|               |1|\
               |y''|~Cartesian~ = |21 22 23| |y|~fractional~ + |2|\
               |z''|              |31 32 33| |z|               |3|'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 608, 'cartn_transf_matrix_1_0', 'Cartn_transf_matrix[2][1]', 78, 'N', 
        '              The [2][1] element of the 3x3 matrix used to transform\
               fractional coordinates in the ATOM_SITE category to Cartesian\
               coordinates in the same category. The axial alignments of this\
               transformation are described in _atom_sites.Cartn_transform_axes.\
               The 3x1 translation is defined in\
               _atom_sites.Cartn_transf_vector[].\
\
               |x''|              |11 12 13| |x|               |1|\
               |y''|~Cartesian~ = |21 22 23| |y|~fractional~ + |2|\
               |z''|              |31 32 33| |z|               |3|'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 609, 'cartn_transf_matrix_1_1', 'Cartn_transf_matrix[2][2]', 78, 'N', 
        '              The [2][2] element of the 3x3 matrix used to transform\
               fractional coordinates in the ATOM_SITE category to Cartesian\
               coordinates in the same category. The axial alignments of this\
               transformation are described in _atom_sites.Cartn_transform_axes.\
               The 3x1 translation is defined in\
               _atom_sites.Cartn_transf_vector[].\
\
               |x''|              |11 12 13| |x|               |1|\
               |y''|~Cartesian~ = |21 22 23| |y|~fractional~ + |2|\
               |z''|              |31 32 33| |z|               |3|'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 610, 'cartn_transf_matrix_1_2', 'Cartn_transf_matrix[2][3]', 78, 'N', 
        '              The [2][3] element of the 3x3 matrix used to transform\
               fractional coordinates in the ATOM_SITE category to Cartesian\
               coordinates in the same category. The axial alignments of this\
               transformation are described in _atom_sites.Cartn_transform_axes.\
               The 3x1 translation is defined in\
               _atom_sites.Cartn_transf_vector[].\
\
               |x''|              |11 12 13| |x|               |1|\
               |y''|~Cartesian~ = |21 22 23| |y|~fractional~ + |2|\
               |z''|              |31 32 33| |z|               |3|'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 611, 'cartn_transf_matrix_2_0', 'Cartn_transf_matrix[3][1]', 78, 'N', 
        '              The [3][1] element of the 3x3 matrix used to transform\
               fractional coordinates in the ATOM_SITE category to Cartesian\
               coordinates in the same category. The axial alignments of this\
               transformation are described in _atom_sites.Cartn_transform_axes.\
               The 3x1 translation is defined in\
               _atom_sites.Cartn_transf_vector[].\
\
               |x''|              |11 12 13| |x|               |1|\
               |y''|~Cartesian~ = |21 22 23| |y|~fractional~ + |2|\
               |z''|              |31 32 33| |z|               |3|'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 612, 'cartn_transf_matrix_2_1', 'Cartn_transf_matrix[3][2]', 78, 'N', 
        '              The [3][2] element of the 3x3 matrix used to transform\
               fractional coordinates in the ATOM_SITE category to Cartesian\
               coordinates in the same category. The axial alignments of this\
               transformation are described in _atom_sites.Cartn_transform_axes.\
               The 3x1 translation is defined in\
               _atom_sites.Cartn_transf_vector[].\
\
               |x''|              |11 12 13| |x|               |1|\
               |y''|~Cartesian~ = |21 22 23| |y|~fractional~ + |2|\
               |z''|              |31 32 33| |z|               |3|'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 613, 'cartn_transf_matrix_2_2', 'Cartn_transf_matrix[3][3]', 78, 'N', 
        '              The [3][3] element of the 3x3 matrix used to transform\
               fractional coordinates in the ATOM_SITE category to Cartesian\
               coordinates in the same category. The axial alignments of this\
               transformation are described in _atom_sites.Cartn_transform_axes.\
               The 3x1 translation is defined in\
               _atom_sites.Cartn_transf_vector[].\
\
               |x''|              |11 12 13| |x|               |1|\
               |y''|~Cartesian~ = |21 22 23| |y|~fractional~ + |2|\
               |z''|              |31 32 33| |z|               |3|'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 614, 'cartn_transf_vector_0', 'Cartn_transf_vector[1]', 78, 'N', 
        '              The [1] element of the 3 element vector used to transform\
               fractional coordinates in the ATOM_SITE category to Cartesian\
               coordinates in the same category. The axial alignments of this\
               transformation are described in _atom_sites.Cartn_transform_axes.\
               The rotation matrix is defined in\
               _atom_sites.Cartn_transf_matrix[][].\
\
               |x''|              |11 12 13| |x|               |1|\
               |y''|~Cartesian~ = |21 22 23| |y|~fractional~ + |2|\
               |z''|              |31 32 33| |z|               |3|'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 615, 'cartn_transf_vector_1', 'Cartn_transf_vector[2]', 78, 'N', 
        '              The [2] element of the 3 element vector used to transform\
               fractional coordinates in the ATOM_SITE category to Cartesian\
               coordinates in the same category. The axial alignments of this\
               transformation are described in _atom_sites.Cartn_transform_axes.\
               The rotation matrix is defined in\
               _atom_sites.Cartn_transf_matrix[][].\
\
               |x''|              |11 12 13| |x|               |1|\
               |y''|~Cartesian~ = |21 22 23| |y|~fractional~ + |2|\
               |z''|              |31 32 33| |z|               |3|'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 616, 'cartn_transf_vector_2', 'Cartn_transf_vector[3]', 78, 'N', 
        '              The [3] element of the 3 element vector used to transform\
               fractional coordinates in the ATOM_SITE category to Cartesian\
               coordinates in the same category. The axial alignments of this\
               transformation are described in _atom_sites.Cartn_transform_axes.\
               The rotation matrix is defined in\
               _atom_sites.Cartn_transf_matrix[][].\
\
               |x''|              |11 12 13| |x|               |1|\
               |y''|~Cartesian~ = |21 22 23| |y|~fractional~ + |2|\
               |z''|              |31 32 33| |z|               |3|'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 617, 'cartn_transform_axes', 'cartn_transform_axes', 78, 'N', 
        '              A description of the relative alignment of the crystal cell\
               axes to the Cartesian orthogonal axes as applied in the\
               transformation matrix _atom_sites.Cartn_transf_matrix.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 618, 'fract_transf_matrix_0_0', 'fract_transf_matrix[1][1]', 78, 'N', 
        '              The [1][1] element of the 3x3 matrix used to transform Cartesian\
               coordinates in the ATOM_SITE category to fractional coordinates\
               in the same category. The axial alignments of this\
               transformation are described in _atom_sites.Cartn_transform_axes.\
               The 3x1 translation is defined in\
               _atom_sites.fract_transf_vector[].\
\
               |x''|               |11 12 13| |x|              |1|\
               |y''|~fractional~ = |21 22 23| |y|~Cartesian~ + |2|\
               |z''|               |31 32 33| |z|              |3|'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 619, 'fract_transf_matrix_0_1', 'fract_transf_matrix[1][2]', 78, 'N', 
        '              The [1][2] element of the 3x3 matrix used to transform Cartesian\
               coordinates in the ATOM_SITE category to fractional coordinates\
               in the same category. The axial alignments of this\
               transformation are described in _atom_sites.Cartn_transform_axes.\
               The 3x1 translation is defined in\
               _atom_sites.fract_transf_vector[].\
\
               |x''|               |11 12 13| |x|              |1|\
               |y''|~fractional~ = |21 22 23| |y|~Cartesian~ + |2|\
               |z''|               |31 32 33| |z|              |3|'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 620, 'fract_transf_matrix_0_2', 'fract_transf_matrix[1][3]', 78, 'N', 
        '              The [1][3] element of the 3x3 matrix used to transform Cartesian\
               coordinates in the ATOM_SITE category to fractional coordinates\
               in the same category. The axial alignments of this\
               transformation are described in _atom_sites.Cartn_transform_axes.\
               The 3x1 translation is defined in\
               _atom_sites.fract_transf_vector[].\
\
               |x''|               |11 12 13| |x|              |1|\
               |y''|~fractional~ = |21 22 23| |y|~Cartesian~ + |2|\
               |z''|               |31 32 33| |z|              |3|'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 621, 'fract_transf_matrix_1_0', 'fract_transf_matrix[2][1]', 78, 'N', 
        '              The [2][1] element of the 3x3 matrix used to transform Cartesian\
               coordinates in the ATOM_SITE category to fractional coordinates\
               in the same category. The axial alignments of this\
               transformation are described in _atom_sites.Cartn_transform_axes.\
               The 3x1 translation is defined in\
               _atom_sites.fract_transf_vector[].\
\
               |x''|               |11 12 13| |x|              |1|\
               |y''|~fractional~ = |21 22 23| |y|~Cartesian~ + |2|\
               |z''|               |31 32 33| |z|              |3|'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 622, 'fract_transf_matrix_1_1', 'fract_transf_matrix[2][2]', 78, 'N', 
        '              The [2][3] element of the 3x3 matrix used to transform Cartesian\
               coordinates in the ATOM_SITE category to fractional coordinates\
               in the same category. The axial alignments of this\
               transformation are described in _atom_sites.Cartn_transform_axes.\
               The 3x1 translation is defined in\
               _atom_sites.fract_transf_vector[].\
\
               |x''|               |11 12 13| |x|              |1|\
               |y''|~fractional~ = |21 22 23| |y|~Cartesian~ + |2|\
               |z''|               |31 32 33| |z|              |3|'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 623, 'fract_transf_matrix_1_2', 'fract_transf_matrix[2][3]', 78, 'N', 
        '              The [2][3] element of the 3x3 matrix used to transform Cartesian\
               coordinates in the ATOM_SITE category to fractional coordinates\
               in the same category. The axial alignments of this\
               transformation are described in _atom_sites.Cartn_transform_axes.\
               The 3x1 translation is defined in\
               _atom_sites.fract_transf_vector[].\
\
               |x''|               |11 12 13| |x|              |1|\
               |y''|~fractional~ = |21 22 23| |y|~Cartesian~ + |2|\
               |z''|               |31 32 33| |z|              |3|'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 624, 'fract_transf_matrix_2_0', 'fract_transf_matrix[3][1]', 78, 'N', 
        '              The [3][1] element of the 3x3 matrix used to transform Cartesian\
               coordinates in the ATOM_SITE category to fractional coordinates\
               in the same category. The axial alignments of this\
               transformation are described in _atom_sites.Cartn_transform_axes.\
               The 3x1 translation is defined in\
               _atom_sites.fract_transf_vector[].\
\
               |x''|               |11 12 13| |x|              |1|\
               |y''|~fractional~ = |21 22 23| |y|~Cartesian~ + |2|\
               |z''|               |31 32 33| |z|              |3|'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 625, 'fract_transf_matrix_2_1', 'fract_transf_matrix[3][2]', 78, 'N', 
        '              The [3][2] element of the 3x3 matrix used to transform Cartesian\
               coordinates in the ATOM_SITE category to fractional coordinates\
               in the same category. The axial alignments of this\
               transformation are described in _atom_sites.Cartn_transform_axes.\
               The 3x1 translation is defined in\
               _atom_sites.fract_transf_vector[].\
\
               |x''|               |11 12 13| |x|              |1|\
               |y''|~fractional~ = |21 22 23| |y|~Cartesian~ + |2|\
               |z''|               |31 32 33| |z|              |3|'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 626, 'fract_transf_matrix_2_2', 'fract_transf_matrix[3][3]', 78, 'N', 
        '              The [3][3] element of the 3x3 matrix used to transform Cartesian\
               coordinates in the ATOM_SITE category to fractional coordinates\
               in the same category. The axial alignments of this\
               transformation are described in _atom_sites.Cartn_transform_axes.\
               The 3x1 translation is defined in\
               _atom_sites.fract_transf_vector[].\
\
               |x''|               |11 12 13| |x|              |1|\
               |y''|~fractional~ = |21 22 23| |y|~Cartesian~ + |2|\
               |z''|               |31 32 33| |z|              |3|'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 627, 'fract_transf_vector_0', 'fract_transf_vector[1]', 78, 'N', 
        '              The [1] element of the 3 element vector used to transform\
               Cartesian coordinates in the ATOM_SITE category to fractional\
               coordinates in the same category. The axial alignments of this\
               transformation are described in _atom_sites.Cartn_transform_axes.\
               The 3x3 rotation is defined in\
               _atom_sites.fract_transf_matrix[][].\
\
               |x''|               |11 12 13| |x|              |1|\
               |y''|~fractional~ = |21 22 23| |y|~Cartesian~ + |2|\
               |z''|               |31 32 33| |z|              |3|'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 628, 'fract_transf_vector_1', 'fract_transf_vector[2]', 78, 'N', 
        '              The [2] element of the 3 element vector used to transform\
               Cartesian coordinates in the ATOM_SITE category to fractional\
               coordinates in the same category. The axial alignments of this\
               transformation are described in _atom_sites.Cartn_transform_axes.\
               The 3x3 rotation is defined in\
               _atom_sites.fract_transf_matrix[][].\
\
               |x''|               |11 12 13| |x|              |1|\
               |y''|~fractional~ = |21 22 23| |y|~Cartesian~ + |2|\
               |z''|               |31 32 33| |z|              |3|'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 629, 'fract_transf_vector_2', 'fract_transf_vector[3]', 78, 'N', 
        '              The [3] element of the 3 element vector used to transform\
               Cartesian coordinates in the ATOM_SITE category to fractional\
               coordinates in the same category. The axial alignments of this\
               transformation are described in _atom_sites.Cartn_transform_axes.\
               The 3x3 rotation is defined in\
               _atom_sites.fract_transf_matrix[][].\
\
               |x''|               |11 12 13| |x|              |1|\
               |y''|~fractional~ = |21 22 23| |y|~Cartesian~ + |2|\
               |z''|               |31 32 33| |z|              |3|'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 630, 'solution_primary', 'solution_primary', 78, 'N', 
        '              A code which identifies the methods used to locate the initial\
               atomic sites. The solution_primary code identifies how the first\
               atom sites were determined.\
\
               *** This data item would not in general be used in a\
               macromolecular data block. ***'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 631, 'solution_secondary', 'solution_secondary', 78, 'N', 
        '              A code which identifies the methods used to locate the initial\
               atomic sites. The solution_secondary code identifies\
               how the non-hydrogen sites not include in solution_primary\
               were located.\
\
               *** This data item would not in general be used in a\
               macromolecular data block. ***'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 632, 'solution_hydrogens', 'solution_hydrogens', 78, 'N', 
        '              A code which identifies the methods used to locate the initial\
               atomic sites. The solution_hydrogens code identifies how the\
               hydrogens were located.\
\
               *** This data item would not in general be used in a\
               macromolecular data block. ***'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 79, 'ATOM_SITES_ALT', 'atom_sites_alt', 'N', 0, 
        '              Data items in the ATOM_SITES_ALT category record details\
               about the structural ensembles that should be generated from\
               atom sites or groups of atom sites that are modeled in\
               alternative conformations in this data block.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 633, 'details', 'details', 79, 'N', 
        '              A description of special aspects of the modeling of atoms in\
               alternative conformations.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 634, 'id', 'id', 79, 'Y', 
        '              The value of _atom_sites_alt.id must uniquely identify\
               a record in the ATOM_SITES_ALT list.\
\
               Note that this item need not be a number; it can be any unique\
               identifier.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 80, 'ATOM_SITES_ALT_ENS', 'atom_sites_alt_ens', 'N', 0, 
        '              Data items in the ATOM_SITES_ALT_ENS category record details\
               about the ensemble structure generated from atoms with various\
               alternative conformation ids.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 635, 'details', 'details', 80, 'N', 
        '              A description of special aspects of the ensemble structure\
               generated from atoms with various alternative ids.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 636, 'id', 'id', 80, 'Y', 
        '              The value of _atom_sites_alt_ens.id must uniquely identify a\
               record in the ATOM_SITES_ALT_ENS list.\
\
               Note that this item need not be a number; it can be any unique\
               identifier.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 81, 'ATOM_SITES_ALT_GEN', 'atom_sites_alt_gen', 'N', 0, 
        '              Data items in the ATOM_SITES_ALT_GEN category record details\
               about the interpretation of multiple conformations in the\
               structure.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 82, 'ATOM_SITES_FOOTNOTE', 'atom_sites_footnote', 'N', 0, 
        '              Data items in the ATOM_SITES_FOOTNOTE category record detailed\
               comments about an atom site or group of atom sites.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 637, 'id', 'id', 82, 'Y', 
        '              A code that identifies the footnote.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 638, 'text', 'text', 82, 'N', 
        '              The text of the footnote. Footnotes are used to describe\
               an atom site or group of atom sites in the ATOM_SITE list.\
\
               For example, footnotes may be used to indicate atoms for which\
               the electron density is very weak, or atoms for which static\
               disorder has been modeled, among many other possibilities.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 83, 'CELL', 'cell', 'N', 0, 
        '              Data items in the CELL category record details about the\
               crystallographic cell parameters.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 639, 'entry_id', 'entry_id', 83, 'Y', 
        '              This data item is a pointer to _entry.id in the ENTRY category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 640, 'details', 'details', 83, 'N', 
        '              A description of special aspects of the cell choice, noting\
               possible alternative settings.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 641, 'volume', 'volume', 83, 'N', 
        '              Cell volume V in angstroms cubed.\
\
               V = a b c (1 - cos^2^~alpha~ - cos^2^~beta~ - cos^2^~gamma~\
                          + 2 cos~alpha~ cos~beta~ cos~gamma~)^1/2^\
\
               a     = _cell.length_a\
               b     = _cell.length_b\
               c     = _cell.length_c\
               alpha = _cell.angle_alpha\
               beta  = _cell.angle_beta\
               gamma = _cell.angle_gamma'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 642, 'volume_esd', 'volume_esd', 83, 'N', 
        '              The estimated standard deviation of _cell.volume.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 643, 'z_pdb', 'z_pdb', 83, 'N', 
        '              The number of the polymeric chains in a unit cell. In the case\
               of heteropolymers, Z is the number of occurrences of the most\
               populous chain.\
\
               This data item is provided for compatibility with the original\
               Protein Data Bank format, and only for that purpose. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 644, 'pdbx_unique_axis', 'pdbx_unique_axis', 83, 'N', 
        '              To further identify unique axis if necessary.  E.g., P 21 with\
               an unique C axis will have ''C'' in this field.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 84, 'CELL_MEASUREMENT', 'cell_measurement', 'N', 0, 
        '              Data items in the CELL_MEASUREMENT category record details\
               about the measurement of the crystallographic cell parameters.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 645, 'entry_id', 'entry_id', 84, 'Y', 
        '              This data item is a pointer to _entry.id in the ENTRY category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 646, 'pressure', 'pressure', 84, 'N', 
        '              The pressure in kilopascals at which the unit-cell parameters\
               were measured (not the pressure used to synthesize the sample).'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 647, 'pressure_esd', 'pressure_esd', 84, 'N', 
        '              The estimated standard deviation of _cell_measurement.pressure.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 648, 'radiation', 'radiation', 84, 'N', 
        '              Description of the radiation used to measure the unit-cell data.\
               See also _cell_measurement.wavelength.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 649, 'reflns_used', 'reflns_used', 84, 'N', 
        '              The total number of reflections used to determine the unit cell.\
               These reflections may be specified as CELL_MEASUREMENT_REFLN\
               data items.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 650, 'temp', 'temp', 84, 'N', 
        '              The temperature in kelvins at which the unit-cell parameters\
               were measured (not the temperature of synthesis).'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 651, 'temp_esd', 'temp_esd', 84, 'N', 
        '              The estimated standard deviation of _cell_measurement.temp.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 652, 'theta_max', 'theta_max', 84, 'N', 
        '              The maximum theta angle in degrees of reflections used to measure\
               the unit cell.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 653, 'theta_min', 'theta_min', 84, 'N', 
        '              The minimum theta angle in degrees of reflections used to measure\
               the unit cell.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 654, 'wavelength', 'wavelength', 84, 'N', 
        '              The wavelength in angstroms of the radiation used to measure\
               the unit cell. If this is not specified, the wavelength is\
               assumed to be that specified in the category\
               DIFFRN_RADIATION_WAVELENGTH.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 85, 'CELL_MEASUREMENT_REFLN', 'cell_measurement_refln', 'N', 0, 
        '              Data items in the CELL_MEASUREMENT_REFLN category record\
               details about the reflections used in determination of the\
               crystallographic cell parameters.\
\
               The CELL_MEASUREMENT_REFLN data items would in general be used\
               only for diffractometer data.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 655, 'theta', 'theta', 85, 'N', 
        '              Theta angle in degrees of a reflection used for measurement of\
               the unit cell.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 86, 'DIFFRN', 'diffrn', 'N', 0, 
        '              Data items in the DIFFRN category record details about the\
               diffraction data and its measurement.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 656, 'ambient_environment', 'ambient_environment', 86, 'N', 
        '              The gas or liquid surrounding the sample, if not air.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 657, 'ambient_pressure', 'ambient_pressure', 86, 'N', 
        '              The mean pressure in kilopascals at which the intensities were\
               measured.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 658, 'ambient_pressure_esd', 'ambient_pressure_esd', 86, 'N', 
        '              The estimated standard deviation of _diffrn.ambient_pressure.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 659, 'ambient_temp', 'ambient_temp', 86, 'N', 
        '              The mean temperature in kelvins at which the intensities were\
               measured.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 660, 'ambient_temp_details', 'ambient_temp_details', 86, 'N', 
        '              A description of special aspects of temperature control during\
               data collection.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 661, 'ambient_temp_esd', 'ambient_temp_esd', 86, 'N', 
        '              The estimated standard deviation of _diffrn.ambient_temp.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 662, 'crystal_support', 'crystal_support', 86, 'N', 
        '              The physical device used to support the crystal during data\
               collection.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 663, 'crystal_treatment', 'crystal_treatment', 86, 'N', 
        '              Remarks about how the crystal was treated prior to intensity\
               measurement. Particularly relevant when intensities were\
               measured at low temperature.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 664, 'details', 'details', 86, 'N', 
        '              Special details of the diffraction measurement process. Should\
               include information about source instability, crystal motion,\
               degradation and so on.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 665, 'id', 'id', 86, 'Y', 
        '              This data item uniquely identifies a set of diffraction\
               data.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 87, 'DIFFRN_ATTENUATOR', 'diffrn_attenuator', 'N', 0, 
        '              Data items in the DIFFRN_ATTENUATOR category record details\
               about the diffraction attenuator scales employed.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 666, 'code', 'code', 87, 'Y', 
        '              A code associated with a particular attenuator setting. This \
               code is referenced by the _diffrn_refln.attenuator_code which is\
               stored with the diffraction data. See _diffrn_attenuator.scale.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 667, 'scale', 'scale', 87, 'N', 
        '              The scale factor applied when an intensity measurement is\
               reduced by an attenuator identified by _diffrn_attenuator_code.\
               This scale must be multiplied by the measured intensity to\
               convert it to the same scale as unattenuated intensities.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 88, 'DIFFRN_DETECTOR', 'diffrn_detector', 'N', 0, 
        '              Data items in the DIFFRN_DETECTOR category describe the \
               detector used to measure the scattered radiation, including\
               any analyser and post-sample collimation.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 668, 'details', 'details', 88, 'N', 
        '              A description of special aspects of the radiation detector.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 669, 'detector', 'detector', 88, 'N', 
        '              The general class of the radiation detector.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 670, 'dtime', 'dtime', 88, 'N', 
        '              The deadtime in microseconds of the detectors used to measure\
               the diffraction intensities.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 671, 'type', 'type', 88, 'N', 
        '              The make, model or name of the detector device used.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 672, 'pdbx_collection_date', 'pdbx_collection_date', 88, 'N', 
        '              The date of data collection.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 89, 'DIFFRN_MEASUREMENT', 'diffrn_measurement', 'N', 0, 
        '              Data items in the DIFFRN_MEASUREMENT category record details\
               about the device used to orient and/or position the crystal\
               during data measurement and the manner in which the diffraction\
               data were measured.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 673, 'details', 'details', 89, 'N', 
        '              A description of special aspects of the intensity measurement.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 674, 'device', 'device', 89, 'N', 
        '              The general class of  goniometer or device used to support and\
               orient the specimen.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 675, 'device_details', 'device_details', 89, 'N', 
        '              A description of special aspects of the device used to measure\
               the diffraction intensities.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 676, 'device_type', 'device_type', 89, 'N', 
        '              The make, model or name of the measurement device\
               (goniometer) used.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 677, 'method', 'method', 89, 'N', 
        '              Method used to measure intensities.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 678, 'specimen_support', 'specimen_support', 89, 'N', 
        '              The physical device used to support the crystal during data\
               collection.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 90, 'DIFFRN_ORIENT_MATRIX', 'diffrn_orient_matrix', 'N', 0, 
        '              Data items in the DIFFRN_ORIENT_MATRIX category record details\
               about the orientation matrix used in data measurement.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 679, 'type', 'type', 90, 'N', 
        '              A description of the orientation matrix type and how it should\
               be applied to define the orientation of the crystal precisely\
               with respect to the diffractometer axes.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 680, 'ub_0_0', 'UB[1][1]', 90, 'N', 
        '              The [1][1] element of the 3x3 matrix that defines the dimensions\
               of the reciprocal cell and its orientation to the local\
               diffractometer axes. See also _diffrn_orient_matrix.type.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 681, 'ub_0_1', 'UB[1][2]', 90, 'N', 
        '              The [1][2] element of the 3x3 matrix that defines the dimensions\
               of the reciprocal cell and its orientation to the local\
               diffractometer axes. See also _diffrn_orient_matrix.type.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 682, 'ub_0_2', 'UB[1][3]', 90, 'N', 
        '              The [1][3] element of the 3x3 matrix that defines the dimensions\
               of the reciprocal cell and its orientation to the local\
               diffractometer axes. See also _diffrn_orient_matrix.type.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 683, 'ub_1_0', 'UB[2][1]', 90, 'N', 
        '              The [2][1] element of the 3x3 matrix that defines the dimensions\
               of the reciprocal cell and its orientation to the local\
               diffractometer axes. See also _diffrn_orient_matrix.type.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 684, 'ub_1_1', 'UB[2][2]', 90, 'N', 
        '              The [2][2] element of the 3x3 matrix that defines the dimensions\
               of the reciprocal cell and its orientation to the local\
               diffractometer axes. See also _diffrn_orient_matrix.type.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 685, 'ub_1_2', 'UB[2][3]', 90, 'N', 
        '              The [2][3] element of the 3x3 matrix that defines the dimensions\
               of the reciprocal cell and its orientation to the local\
               diffractometer axes. See also _diffrn_orient_matrix.type.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 686, 'ub_2_0', 'UB[3][1]', 90, 'N', 
        '              The [3][1] element of the 3x3 matrix that defines the dimensions\
               of the reciprocal cell and its orientation to the local\
               diffractometer axes. See also _diffrn_orient_matrix.type.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 687, 'ub_2_1', 'UB[3][2]', 90, 'N', 
        '              The [3][2] element of the 3x3 matrix that defines the dimensions\
               of the reciprocal cell and its orientation to the local\
               diffractometer axes. See also _diffrn_orient_matrix.type.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 688, 'ub_2_2', 'UB[3][3]', 90, 'N', 
        '              The [3][3] element of the 3x3 matrix that defines the dimensions\
               of the reciprocal cell and its orientation to the local\
               diffractometer axes. See also _diffrn_orient_matrix.type.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 91, 'DIFFRN_ORIENT_REFLN', 'diffrn_orient_refln', 'N', 0, 
        '              Data items in the DIFFRN_ORIENT_REFLN category record details\
               about the reflections that define the orientation matrix used in\
               measurement of diffraction intensities.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 689, 'angle_chi', 'angle_chi', 91, 'N', 
        '              Diffractometer angle chi in degrees of a reflection used to\
               define the orientation matrix. See _diffrn_orient_matrix.UB and\
               the Miller indices in the DIFFRN_ORIENT_REFLN category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 690, 'angle_kappa', 'angle_kappa', 91, 'N', 
        '              Diffractometer angle kappa in degrees of a reflection used to\
               define the orientation matrix. See _diffrn_orient_matrix.UB and\
               the Miller indices in the DIFFRN_ORIENT_REFLN category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 691, 'angle_omega', 'angle_omega', 91, 'N', 
        '              Diffractometer angle omega in degrees of a reflection used to\
               define the orientation matrix. See _diffrn_orient_matrix.UB and\
               the Miller indices in the DIFFRN_ORIENT_REFLN category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 692, 'angle_phi', 'angle_phi', 91, 'N', 
        '              Diffractometer angle phi in degrees of a reflection used to\
               define the orientation matrix. See _diffrn_orient_matrix.UB and\
               the Miller indices in the DIFFRN_ORIENT_REFLN category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 693, 'angle_psi', 'angle_psi', 91, 'N', 
        '              Diffractometer angle psi in degrees of a reflection used to\
               define the orientation matrix. See _diffrn_orient_matrix.UB and\
               the Miller indices in the DIFFRN_ORIENT_REFLN category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 694, 'angle_theta', 'angle_theta', 91, 'N', 
        '              Diffractometer angle theta in degrees of a reflection used to\
               define the orientation matrix. See _diffrn_orient_matrix.UB and\
               the Miller indices in the DIFFRN_ORIENT_REFLN category.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 92, 'DIFFRN_RADIATION', 'diffrn_radiation', 'N', 0, 
        '              Data items in the DIFFRN_RADIATION category describe\
               the radiation used in measuring diffraction intensities,\
               its collimation and monochromatisation before the sample.\
\
               Post-sample treatment of the beam is described by data\
               items in the DIFFRN_DETECTOR category.\
'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 695, 'collimation', 'collimation', 92, 'N', 
        '              The collimation or focusing applied to the radiation.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 696, 'filter_edge', 'filter_edge', 92, 'N', 
        '              Absorption edge in angstroms of the radiation filter used.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 697, 'inhomogeneity', 'inhomogeneity', 92, 'N', 
        '              Half-width in millimetres of the incident beam in the\
               direction perpendicular to the diffraction plane.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 698, 'monochromator', 'monochromator', 92, 'N', 
        '              The method used to obtain monochromatic radiation. If a mono-\
               chromator crystal is used the material and the indices of the\
               Bragg reflection are specified.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 699, 'polarisn_norm', 'polarisn_norm', 92, 'N', 
        '              The angle in degrees, as viewed from the specimen, between the\
               perpendicular component of the polarisation and the diffraction\
               plane. See _diffrn_radiation_polarisn_ratio.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 700, 'polarisn_ratio', 'polarisn_ratio', 92, 'N', 
        '              Polarisation ratio of the diffraction beam incident on the\
               crystal. It is the ratio of the perpendicularly polarised to the\
               parallel polarised component of the radiation. The perpendicular\
               component forms an angle of _diffrn_radiation.polarisn_norm to\
               the normal to the diffraction plane of the sample (i.e. the plane\
               containing the incident and reflected beams).'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 701, 'probe', 'probe', 92, 'N', 
        '              Name of the type of radiation used. It is strongly encouraged\
               that this field be specified so that the probe radiation\
               can be simply determined.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 702, 'type', 'type', 92, 'N', 
        '              The nature of the radiation. This is typically a description\
               of the X-ray wavelength in Siegbahn notation.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 703, 'xray_symbol', 'xray_symbol', 92, 'N', 
        '              The IUPAC symbol for the X-ray wavelength for probe radiation.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 704, 'pdbx_monochromatic_or_laue_m_l', 'pdbx_monochromatic_or_laue_m_l', 92, 'N', 
        '           Monochromatic or Laue.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 705, 'pdbx_wavelength_list', 'pdbx_wavelength_list', 92, 'N', 
        '           Comma separated list of wavelengths or wavelength range.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 706, 'pdbx_wavelength', 'pdbx_wavelength', 92, 'N', 
        '           Wavelength of radiation.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 707, 'pdbx_diffrn_protocol', 'pdbx_diffrn_protocol', 92, 'N', 
        '           SINGLE WAVELENGTH, LAUE, or MAD.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 93, 'DIFFRN_RADIATION_WAVELENGTH', 'diffrn_radiation_wavelength', 'N', 0, 
        '              Data items in the DIFFRN_RADIATION_WAVELENGTH category \
               describe the wavelength of radiation used in measuring\
               diffraction intensities. Items may be looped to identify\
               and assign weights to distinct components of a \
               polychromatic beam.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 708, 'id', 'id', 93, 'Y', 
        '              The code identifying each value of _diffrn_radiation_wavelength.\
               Items in the DIFFRN_RADIATION_WAVELENGTH category are looped \
               when multiple wavelengths are used. \
\
               This code is used to link with the DIFFRN_REFLN category.\
               The _diffrn_refln.wavelength_id codes must match one of \
               the codes defined in this category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 709, 'wavelength', 'wavelength', 93, 'N', 
        '              The radiation wavelength in angstroms.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 710, 'wt', 'wt', 93, 'N', 
        '              The relative weight of a wavelength identified by the code\
               _diffrn_radiation_wavelength.id in the list of wavelengths.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 94, 'DIFFRN_REFLN', 'diffrn_refln', 'N', 0, 
        '              Data items in the DIFFRN_REFLN category record details about\
               the intensities measured in the diffraction data set \
               identified by _diffrn_refln.diffrn_id.\
\
               The DIFFRN_REFLN data items refer to individual intensity\
               measurements, and must be included in looped lists.\
\
               The DIFFRN_REFLNS data items specify the parameters that apply\
               to all intensity  measurements in the particular diffraction\
               data set identified by _diffrn_reflns.diffrn_id.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 711, 'angle_chi', 'angle_chi', 94, 'N', 
        '              The diffractometer angle chi in degrees of a reflection. This\
               angle corresponds to the specified orientation matrix\
               and the original measured cell before any subsequent cell\
               transformations.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 712, 'angle_kappa', 'angle_kappa', 94, 'N', 
        '              The diffractometer angle kappa in degrees of a reflection. This\
               angle corresponds to the specified orientation matrix\
               and the original measured cell before any subsequent cell\
               transformations.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 713, 'angle_omega', 'angle_omega', 94, 'N', 
        '              The diffractometer angle omega in degrees of a reflection. This\
               angle corresponds to the specified orientation matrix\
               and the original measured cell before any subsequent cell\
               transformations.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 714, 'angle_phi', 'angle_phi', 94, 'N', 
        '              The diffractometer angle phi in degrees of a reflection. This\
               angle corresponds to the specified orientation matrix\
               and the original measured cell before any subsequent cell\
               transformations.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 715, 'angle_psi', 'angle_psi', 94, 'N', 
        '              The diffractometer angle psi in degrees of a reflection. This\
               angle corresponds  to the specified orientation matrix\
               and the original measured cell before any subsequent cell\
               transformations.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 716, 'angle_theta', 'angle_theta', 94, 'N', 
        '              The diffractometer angle theta in degrees of a reflection. This\
               angle corresponds  to the specified orientation matrix\
               and the original measured cell before any subsequent cell\
               transformations.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 717, 'counts_bg_1', 'counts_bg_1', 94, 'N', 
        '              The diffractometer counts for the measurement of the background\
               before the peak.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 718, 'counts_bg_2', 'counts_bg_2', 94, 'N', 
        '              The diffractometer counts for the measurement of the background\
               after the peak.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 719, 'counts_net', 'counts_net', 94, 'N', 
        '              The diffractometer counts for the measurement of net counts after\
               background removal.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 720, 'counts_peak', 'counts_peak', 94, 'N', 
        '              The diffractometer counts for the measurement of counts for the\
               peak scan or position.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 721, 'counts_total', 'counts_total', 94, 'N', 
        '              The diffractometer counts for the measurement of total counts\
               (background plus peak).'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 722, 'detect_slit_horiz', 'detect_slit_horiz', 94, 'N', 
        '              Total slit aperture in degrees in the diffraction plane.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 723, 'detect_slit_vert', 'detect_slit_vert', 94, 'N', 
        '              Total slit aperture in degrees perpendicular to the\
               diffraction plane.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 724, 'elapsed_time', 'elapsed_time', 94, 'N', 
        '              Elapsed time in minutes from the start of diffraction measurement\
               to the measurement of this intensity.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 725, 'id', 'id', 94, 'Y', 
        '              The value of diffrn_refln.id must uniquely identify the \
               reflection in the data set identified by the item\
              _diffrn_refln.diffrn_id.\
\
               Note that this item need not be a number; it can be any unique\
               identifier.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 726, 'intensity_net', 'intensity_net', 94, 'N', 
        '              Net intensity calculated from the diffraction counts after the\
               attenuator and standard scales have been applied.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 727, 'intensity_sigma', 'intensity_sigma', 94, 'N', 
        '              Standard uncertainty (e.s.d.) of the intensity calculated from\
               the diffraction counts after the attenuator and standard scales\
               have been applied.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 728, 'scan_mode', 'scan_mode', 94, 'N', 
        '              The code identifying the mode of scanning with a diffractometer.\
               See _diffrn_refln.scan_width and _diffrn_refln.scan_mode_backgd.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 729, 'scan_mode_backgd', 'scan_mode_backgd', 94, 'N', 
        '              The code identifying the mode of scanning a reflection to \
               measure the background intensity.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 730, 'scan_rate', 'scan_rate', 94, 'N', 
        '              The rate of scanning a reflection to measure the intensity in \
               degrees per minute.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 731, 'scan_time_backgd', 'scan_time_backgd', 94, 'N', 
        '              The time spent measuring each background in seconds.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 732, 'scan_width', 'scan_width', 94, 'N', 
        '              The scan width in degrees of the scan mode defined by the code\
               _diffrn_refln.scan_mode.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 733, 'sint_over_lambda', 'sint_over_lambda', 94, 'N', 
        '              The (sin theta)/lambda value in reciprocal angstroms for this\
               reflection.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 734, 'wavelength', 'wavelength', 94, 'N', 
        '              The mean wavelength in angstroms of radiation used to measure\
               the intensity of this reflection. This is an important parameter\
               for data collected using energy dispersive detectors or the\
               Laue method.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 95, 'DIFFRN_REFLNS', 'diffrn_reflns', 'N', 0, 
        '              Data items in the DIFFRN_REFLNS category record details about\
               the set of intensities measured in the diffraction experiment.\
\
               The DIFFRN_REFLN data items refer to individual intensity\
               measurements, and must be included in looped lists.\
\
               The DIFFRN_REFLNS data items specify the parameters that apply\
               to all intensity measurements in a diffraction data set.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 735, 'av_r_equivalents', 'av_r_equivalents', 95, 'N', 
        '              The residual [sum|avdel(I)| / sum|av(I)|] for symmetry-equivalent\
               reflections used to calculate the average intensity av(I). The\
               avdel(I) term is the average difference between av(I) and the\
               individual symmetry-equivalent intensities.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 736, 'av_sigmaI_over_netI', 'av_sigmaI_over_netI', 95, 'N', 
        '              Measure [sum|sigma(I)|/sum|net(I)|] for all measured reflections.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 737, 'number2', 'number', 95, 'N', 
        '              The total number of measured intensities, excluding reflections\
               that are classified as systematically absent.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 738, 'reduction_process', 'reduction_process', 95, 'N', 
        '              A description of the process used to reduce the intensity data\
               into structure-factor magnitudes.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 739, 'theta_max', 'theta_max', 95, 'N', 
        '              Maximum theta angle in degrees for the measured diffraction\
               intensities.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 740, 'theta_min', 'theta_min', 95, 'N', 
        '              Minimum theta angle in degrees for the measured diffraction\
               intensities.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 741, 'transf_matrix_0_0', 'transf_matrix[1][1]', 95, 'N', 
        '              The [1][1] element of the 3x3 matrix used to transform Miller\
               indices in the DIFFRN_REFLN category into the Miller indices in\
               the REFLN category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 742, 'transf_matrix_0_1', 'transf_matrix[1][2]', 95, 'N', 
        '              The [1][2] element of the 3x3 matrix used to transform Miller\
               indices in the DIFFRN_REFLN category into the Miller indices in\
               the REFLN category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 743, 'transf_matrix_0_2', 'transf_matrix[1][3]', 95, 'N', 
        '              The [1][3] element of the 3x3 matrix used to transform Miller\
               indices in the DIFFRN_REFLN category into the Miller indices in\
               the REFLN category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 744, 'transf_matrix_1_0', 'transf_matrix[2][1]', 95, 'N', 
        '              The [2][1] element of the 3x3 matrix used to transform Miller\
               indices in the DIFFRN_REFLN category into the Miller indices in\
               the REFLN category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 745, 'transf_matrix_1_1', 'transf_matrix[2][2]', 95, 'N', 
        '              The [2][2] element of the 3x3 matrix used to transform Miller\
               indices in the DIFFRN_REFLN category into the Miller indices in\
               the REFLN category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 746, 'transf_matrix_1_2', 'transf_matrix[2][3]', 95, 'N', 
        '              The [2][3] element of the 3x3 matrix used to transform Miller\
               indices in the DIFFRN_REFLN category into the Miller indices in\
               the REFLN category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 747, 'transf_matrix_2_0', 'transf_matrix[3][1]', 95, 'N', 
        '              The [3][1] element of the 3x3 matrix used to transform Miller\
               indices in the DIFFRN_REFLN category into the Miller indices in\
               the REFLN category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 748, 'transf_matrix_2_1', 'transf_matrix[3][2]', 95, 'N', 
        '              The [3][2] element of the 3x3 matrix used to transform Miller\
               indices in the DIFFRN_REFLN category into the Miller indices in\
               the REFLN category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 749, 'transf_matrix_2_2', 'transf_matrix[3][3]', 95, 'N', 
        '              The [3][3] element of the 3x3 matrix used to transform Miller\
               indices in the DIFFRN_REFLN category into the Miller indices in\
               the REFLN category.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 96, 'DIFFRN_SCALE_GROUP', 'diffrn_scale_group', 'N', 0, 
        '              Data items in the DIFFRN_SCALE_GROUP category record details\
               about the reflections used to scale the diffraction intensities.\
               Scaling groups might, for instance, correspond to each film in a\
               multi-film data set, or each crystal in a multi-crystal data set.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 750, 'code', 'code', 96, 'Y', 
        '              The value of diffrn_scale_group.code must uniquely identify a\
               record in the DIFFRN_SCALE_GROUP list.\
\
               Note that this item need not be a number; it can be any unique\
               identifier.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 751, 'i_net', 'i_net', 96, 'N', 
        '              The scale for a specific measurement group which is to be\
               multiplied with the net intensity to place all intensities\
               in the DIFFRN_REFLN or REFLN list on a common scale.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 97, 'DIFFRN_SOURCE', 'diffrn_source', 'N', 0, 
        '              Data items in the DIFFRN_SOURCE category record details of\
               the source of radiation used in the diffraction experiment.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 752, 'current2', 'current', 97, 'N', 
        '              The current in milliamperes at which the radiation source\
               was operated. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 753, 'details', 'details', 97, 'N', 
        '              A description of special aspects of the radiation source used.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 754, 'power', 'power', 97, 'N', 
        '              The power in kilowatts at which the radiation source\
               was operated.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 755, 'size2', 'size', 97, 'N', 
        '              The dimensions of the source as viewed from the sample.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 756, 'source', 'source', 97, 'N', 
        '              The general class of the radiation source.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 757, 'target', 'target', 97, 'N', 
        '              The chemical element symbol for the X-ray target\
               (usually the anode) used for generation of X-rays.\
               This can be used also for spallation sources.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 758, 'type', 'type', 97, 'N', 
        '              The make, model or name of the source of radiation.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 759, 'voltage', 'voltage', 97, 'N', 
        '              The voltage in kilovolts at which the radiation source was\
               operated. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 760, 'pdbx_synchrotron_beamline', 'pdbx_synchrotron_beamline', 97, 'N', 
        '             Synchrotron beamline.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 761, 'pdbx_synchrotron_site', 'pdbx_synchrotron_site', 97, 'N', 
        '     Synchrotron site.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 98, 'DIFFRN_STANDARD_REFLN', 'diffrn_standard_refln', 'N', 0, 
        '              Data items in the DIFFRN_STANDARD_REFLN category record details\
               about the reflections treated as standards during the measurement\
               of a set of diffraction intensities.\
\
               Note that these are the individual standard reflections, not the\
               results of the analysis of the standard reflections.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 762, 'code', 'code', 98, 'Y', 
        '              The code identifying a reflection measured as a standard\
               reflection with the indices _diffrn_standard_refln.index_h,\
               _diffrn_standard_refln.index_k and\
               _diffrn_standard_refln.index_l. This is the same code as the\
               _diffrn_refln.standard_code in the DIFFRN_REFLN list. '
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 99, 'DIFFRN_STANDARDS', 'diffrn_standards', 'N', 0, 
        '              Data items in the DIFFRN_STANDARDS category record details\
               about the set of standard reflections used to monitor intensity\
               stability during measurement of diffraction intensities.\
\
               Note that these records describe properties common to the set of\
               standard reflections, not the standard reflections themselves.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 763, 'decay_percent', 'decay_percent', 99, 'N', 
        '              The percentage decrease in the mean of the intensities\
               for the set of standard reflections at the start of the\
               measurement process and at the finish. This value usually\
               affords a measure of the overall decay in crystal quality\
               during the diffraction measurement process. Negative values\
               are used in exceptional instances where the final intensities\
               are greater than the initial ones.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 764, 'interval_count', 'interval_count', 99, 'N', 
        '              The number of reflection intensities between the measurement of\
               standard reflection intensities.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 765, 'interval_time', 'interval_time', 99, 'N', 
        '              The time in minutes between the measurement of standard\
               reflection intensities.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 766, 'number2', 'number', 99, 'N', 
        '              The number of unique standard reflections used in the diffraction\
               measurements.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 767, 'scale_sigma', 'scale_sigma', 99, 'N', 
        '              The standard uncertainty (e.s.d.) of the individual mean\
               standard scales applied to the intensity data.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 100, 'EXPTL', 'exptl', 'N', 0, 
        '              Data items in the EXPTL category record details about the\
               growth of the crystal, and about experimental measurements on\
               the crystal, such as shape, size, density, and so on.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 768, 'absorpt_coefficient_mu', 'absorpt_coefficient_mu', 100, 'N', 
        '              The absorption coefficient mu in reciprocal millimetres\
               calculated from the atomic content of the cell, the density and\
               the radiation wavelength.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 769, 'absorpt_correction_t_max', 'absorpt_correction_t_max', 100, 'N', 
        '              The maximum transmission factors for the crystal and radiation.\
               These factors are also referred to as the absorption correction\
               A or 1/A*.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 770, 'absorpt_correction_t_min', 'absorpt_correction_t_min', 100, 'N', 
        '              The minimum transmission factors for the crystal and radiation.\
               These factors are also referred to as the absorption correction\
               A or 1/A*.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 771, 'absorpt_correction_type', 'absorpt_correction_type', 100, 'N', 
        '              The absorption correction type and method. The value\
               ''empirical'' should NOT be used unless no more detailed\
               information is available.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 772, 'absorpt_process_details', 'absorpt_process_details', 100, 'N', 
        '              Description of the absorption process applied to the\
               intensities. A literature reference should be supplied for\
               psi-scan techniques.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 773, 'entry_id', 'entry_id', 100, 'Y', 
        '              This data item is a pointer to _entry.id in the ENTRY category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 774, 'crystals_number', 'crystals_number', 100, 'N', 
        '              The total number of crystals used in the  measurement of\
               intensities.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 775, 'details', 'details', 100, 'N', 
        '              Any special information about the experimental work prior to the\
               intensity measurement. See also _exptl_crystal.preparation.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 776, 'method', 'method', 100, 'Y', 
        '              The method used in the experiment.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 777, 'method_details', 'method_details', 100, 'N', 
        '              A description of special aspects of the experimental method.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 101, 'EXPTL_CRYSTAL', 'exptl_crystal', 'N', 0, 
        '              Data items in the EXPTL_CRYSTAL category record details about\
               experimental measurements on the crystal or crystals used,\
               such as shape, size, density, and so on.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 778, 'colour', 'colour', 101, 'N', 
        '              The colour of the crystal.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 779, 'density_diffrn', 'density_diffrn', 101, 'N', 
        '              Density values calculated from crystal cell and contents. The\
               units are megagrams per cubic metre (grams per cubic centimetre).'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 780, 'density_matthews', 'density_matthews', 101, 'N', 
        '              The density of the crystal, expressed as the ratio of the\
               volume of the asymmetric unit to the molecular mass of a\
               monomer of the structure, in units of angstroms^3^ per dalton.\
\
               Ref: Matthews, B. W. (1960). J. Mol. Biol., 33, 491-497'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 781, 'density_meas', 'density_meas', 101, 'N', 
        '              Density values measured using standard chemical and physical\
               methods. The units are megagrams per cubic metre (grams per\
               cubic centimetre).'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 782, 'density_meas_temp', 'density_meas_temp', 101, 'N', 
        '              The temperature in kelvins at which _exptl_crystal.density_meas\
               was determined.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 783, 'density_method', 'density_method', 101, 'N', 
        '              The method used to measure _exptl_crystal.density_meas.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 784, 'density_percent_sol', 'density_percent_sol', 101, 'N', 
        '              Density value P calculated from crystal cell and contents,\
               expressed as percent solvent.\
\
               P = 1 - (1.23 N MMass) / V\
\
               N     = the number of molecules in the unit cell\
               MMass = the molecular mass of each molecule (gm/mole)\
               V     = the volume of the unit cell (A^3^)\
               1.23  = the evaluated conversion factor:\
\
                       (0.74 cm^3^/gm^3^) (10^24^ A^3^/cm^3^)\
                       --------------------------------------\
                            (6.02*10^23^) moles/molecule\
\
                       where 0.74 is an assumed value for the partial specific\
                       volume of the molecule'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 785, 'description', 'description', 101, 'N', 
        '              A description of the quality and habit of the crystal.\
               Dimensional data are better placed in the data items in the\
               EXPTL_CRYSTAL_FACE category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 786, 'f_000', 'f_000', 101, 'N', 
        '              The effective number of electrons in the crystal unit cell\
               contributing to F(000). It may contain dispersion contributions,\
               and is calculated as\
\
               F(000) = [ sum (f~r~^2^ + f~i~^2^) ]^1/2^\
\
               f~r~ = real part of the scattering factors at theta = 0\
               f~i~ = imaginary part of the scattering factors at theta = 0'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 787, 'id', 'id', 101, 'Y', 
        '              The value of _exptl_crystal.id must uniquely identify a record in\
               the EXPTL_CRYSTAL list.\
\
               Note that this item need not be a number; it can be any unique\
               identifier.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 788, 'preparation', 'preparation', 101, 'N', 
        '              Details of crystal growth and preparation of the crystal (e.g.\
               mounting) prior to the intensity measurements.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 789, 'size_max', 'size_max', 101, 'N', 
        '              The maximum dimension of the crystal. This item may appear in a\
               list with _exptl_crystal.id if multiple crystals are used in the\
               experiment.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 790, 'size_mid', 'size_mid', 101, 'N', 
        '              The medial dimension of the crystal. This item may appear in a\
               list with _exptl_crystal.id if multiple crystals are used in the\
               experiment.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 791, 'size_min', 'size_min', 101, 'N', 
        '              The minimum dimension of the crystal. This item may appear in a\
               list with _exptl_crystal.id if multiple crystals are used in the\
               experiment.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 792, 'size_rad', 'size_rad', 101, 'N', 
        '              The radius of the crystal, if the crystal is a sphere or a\
               cylinder. This item may appear in a list with _exptl_crystal.id\
               if multiple crystals are used in the experiment.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 793, 'pdbx_crystal_image_url', 'pdbx_crystal_image_url', 101, 'N', 
        ' The URL for an a file containing the image of crystal.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 794, 'pdbx_crystal_image_format', 'pdbx_crystal_image_format', 101, 'N', 
        ' The image format for the file containing the image of crystal specified\
  as an RFC2045/RFC2046 mime type.  '
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 102, 'EXPTL_CRYSTAL_FACE', 'exptl_crystal_face', 'N', 0, 
        '              Data items in the EXPTL_CRYSTAL_FACE category record details\
               of the crystal faces.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 795, 'diffr_chi', 'diffr_chi', 102, 'N', 
        '              The chi diffractometer setting angle in degrees for a specific\
               crystal face associated with _exptl_crystal_face.perp_dist.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 796, 'diffr_kappa', 'diffr_kappa', 102, 'N', 
        '              The kappa diffractometer setting angle in degrees for a specific\
               crystal face associated with _exptl_crystal_face.perp_dist.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 797, 'diffr_phi', 'diffr_phi', 102, 'N', 
        '              The phi diffractometer setting angle in degrees for a specific\
               crystal face associated with _exptl_crystal_face.perp_dist.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 798, 'diffr_psi', 'diffr_psi', 102, 'N', 
        '              The psi diffractometer setting angle in degrees for a specific\
               crystal face associated with _exptl_crystal_face.perp_dist.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 799, 'perp_dist', 'perp_dist', 102, 'N', 
        '              The perpendicular distance in millimetres of the face to the\
               centre of rotation of the crystal.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 103, 'EXPTL_CRYSTAL_GROW', 'exptl_crystal_grow', 'N', 0, 
        '              Data items in the EXPTL_CRYSTAL_GROW category record details\
               about the conditions and methods used to grow the crystal.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 800, 'apparatus', 'apparatus', 103, 'N', 
        '              The physical apparatus in which the crystal was grown.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 801, 'atmosphere', 'atmosphere', 103, 'N', 
        '              The nature of the gas or gas mixture in which the crystal was\
               grown.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 802, 'details', 'details', 103, 'N', 
        '              A description of special aspects of the crystal growth.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 803, 'method', 'method', 103, 'N', 
        '              The method used to grow the crystals.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 804, 'method_ref', 'method_ref', 103, 'N', 
        '              A literature reference that describes the method used to grow\
               the crystals.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 805, 'ph', 'ph', 103, 'N', 
        '              The pH at which the crystal was grown. If more than one pH was\
               employed during the crystallization process, the final pH should\
               be noted here and the protocol involving multiple pH values\
               should be described in _exptl_crystal_grow.details.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 806, 'pressure', 'pressure', 103, 'N', 
        '              The ambient pressure in kilopascals at which the crystal was\
               grown.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 807, 'pressure_esd', 'pressure_esd', 103, 'N', 
        '              The estimated standard deviation of _exptl_crystal_grow.pressure.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 808, 'seeding', 'seeding', 103, 'N', 
        '              A description of the protocol used for seeding the crystal\
               growth.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 809, 'seeding_ref', 'seeding_ref', 103, 'N', 
        '              A literature reference that describes the protocol used to seed\
               the crystal.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 810, 'temp', 'temp', 103, 'N', 
        '              The temperature in kelvins at which the crystal was grown.\
               If more than one temperature was employed during the\
               crystallization process, the final temperature should be noted\
               here and the protocol  involving multiple temperatures should be\
               described in _exptl_crystal_grow.details.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 811, 'temp_details', 'temp_details', 103, 'N', 
        '              A description of special aspects of temperature control during\
               crystal growth.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 812, 'temp_esd', 'temp_esd', 103, 'N', 
        '              The estimated standard deviation of _exptl_crystal_grow.temp.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 813, 'time', 'time', 103, 'N', 
        '              The approximate time that the crystal took to grow to the size\
               used for data collection.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 814, 'pdbx_details', 'pdbx_details', 103, 'N', 
        ' Text description of crystal grow procedure.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 815, 'pdbx_pH_range', 'pdbx_pH_range', 103, 'N', 
        ' The range of pH values at which the crystal was grown.   Used when \
  a point estimate of pH is not appropriate.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 104, 'EXPTL_CRYSTAL_GROW_COMP', 'exptl_crystal_grow_comp', 'N', 0, 
        '              Data items in the EXPTL_CRYSTAL_GROW_COMP category record\
               details about the components of the solutions that were ''mixed''\
               (by whatever means) to produce the crystal.\
\
               In general, solution 1 is the solution that contains the\
               molecule to be crystallized and solution 2 is the solution\
               that contains the precipitant. However, the number of solutions\
               required to describe the crystallization protocol is not limited\
               to 2.\
\
               Details of the crystallization protocol should be described in\
               EXPTL_CRYSTAL_GROW_DETAILS, using the solutions described in\
               EXPTL_CRYSTAL_GROW_COMP.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 816, 'conc', 'conc', 104, 'N', 
        '              The concentration of the solution component.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 817, 'details', 'details', 104, 'N', 
        '              A description of any special aspects of the solution component.\
               When the solution component is the one that contains the\
               macromolecule, this could be the specification of the buffer in\
               which the macromolecule was stored. When the solution component\
               is a buffer component, this could be the methods (or formula)\
               used to achieve a desired pH.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 818, 'id', 'id', 104, 'Y', 
        '              The value of _exptl_crystal_grow_comp.id must uniquely identify\
               each item in the EXPTL_CRYSTAL_GROW_COMP list.\
\
               Note that this item need not be a number; it can be any unique\
               identifier.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 819, 'name', 'name', 104, 'N', 
        '              A common name for the component of the solution.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 820, 'sol_id', 'sol_id', 104, 'N', 
        '              An identifier for the solution to which the given solution\
               component belongs.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 821, 'volume', 'volume', 104, 'N', 
        '              The volume of the solution component.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 105, 'PHASING', 'phasing', 'N', 0, 
        '              Data items in the PHASING category record details about the\
               phasing of the structure, listing the various methods used in\
               the phasing process. The details about the application of each\
               method are listed in the appropriate subcategories.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 822, 'method', 'method', 105, 'Y', 
        '              A listing of the method or methods applied to phase this\
               structure.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 106, 'PHASING_AVERAGING', 'phasing_averaging', 'N', 0, 
        '              Data items in the PHASING_AVERAGING category record details\
               about the phasing of the structure, when methods involving\
               averaging of multiple observations of the molecule in the\
               asymmetric unit are involved.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 823, 'details', 'details', 106, 'N', 
        '              A description of special aspects of the averaging process.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 824, 'entry_id', 'entry_id', 106, 'Y', 
        '              This data item is a pointer to _entry.id in the ENTRY category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 825, 'method', 'method', 106, 'N', 
        '              A description of the phase averaging phasing method applied to\
               phase this structure.\
\
               Note that this is not the computer program used, which is\
               described in the SOFTWARE category, but rather the method\
               itself.\
\
               This data item should be used to describe significant\
               methodological options used within the phase averaging program.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 107, 'PHASING_ISOMORPHOUS', 'phasing_isomorphous', 'N', 0, 
        '              Data items in the PHASING_ISOMORPHOUS category record details\
               about the phasing of the structure, when a model isomorphous\
               to the structure being phased was used to generate initial\
               phases.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 826, 'details', 'details', 107, 'N', 
        '              A description of special aspects of the isomorphous phasing.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 827, 'entry_id', 'entry_id', 107, 'Y', 
        '              This data item is a pointer to _entry.id in the ENTRY category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 828, 'method', 'method', 107, 'N', 
        '              A description of the isomorphous phasing method applied to\
               phase this structure.\
\
               Note that this is not the computer program used, which is\
               described in the SOFTWARE category, but rather the method\
               itself.\
\
               This data item should be used to describe significant\
               methodological options used within the isomorphous phasing\
               program.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 829, 'parent', 'parent', 107, 'N', 
        '              Reference to the structure used to generate starting phases\
               if the structure referenced in this data block was phased\
               by virtue of being isomorphous to a known structure (e.g.\
               a mutant that crystallizes in the same space group as the\
               wild type protein.)'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 108, 'PHASING_MAD', 'phasing_MAD', 'N', 0, 
        '              Data items in the PHASING_MAD category record details about\
               the phasing of the structure, when methods involving multiple\
               anomalous dispersion techniques are involved.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 830, 'details', 'details', 108, 'N', 
        '              A description of special aspects of the MAD phasing.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 831, 'entry_id', 'entry_id', 108, 'Y', 
        '              This data item is a pointer to _entry.id in the ENTRY category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 832, 'method', 'method', 108, 'N', 
        '              A description of the MAD phasing method applied to phase\
               this structure.\
\
               Note that this is not the computer program used, which is\
               described in the SOFTWARE category, but rather the method\
               itself.\
\
               This data item should be used to describe significant\
               methodological options used within the MAD phasing program.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 109, 'PHASING_MAD_CLUST', 'phasing_MAD_clust', 'N', 0, 
        '              Data items in the PHASING_MAD_CLUST category record details\
               about a cluster of experiments that contributed to the\
               generation of a set of phases.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 833, 'id', 'id', 109, 'Y', 
        '              The value of _phasing_MAD_clust.id must, together with\
               _phasing_MAD_clust.expt_id, uniquely identify a record in the\
               PHASING_MAD_CLUST list.\
\
               Note that this item need not be a number; it can be any unique\
               identifier.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 834, 'number_set', 'number_set', 109, 'N', 
        '              The number of data sets in this cluster of data sets.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 110, 'PHASING_MAD_EXPT', 'phasing_MAD_expt', 'N', 0, 
        '              Data items in the PHASING_MAD_EXPT category record details about\
               a MAD phasing experiment, such as the number of experiments that\
               were clustered together to produce a set of phases, the\
               statistics for those phases, and so on.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 835, 'delta_delta_phi', 'delta_delta_phi', 110, 'N', 
        '              The difference between two independent determinations of\
               _phasing_MAD_expt.delta_phi.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 836, 'delta_phi', 'delta_phi', 110, 'N', 
        '              The phase difference between F~t~(h), the structure factor due\
               to normal scattering from all atoms, and F~a~(h), the structure\
               factor due to normal scattering from only the anomalous\
               scatterers.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 837, 'delta_phi_sigma', 'delta_phi_sigma', 110, 'N', 
        '              The estimated standard deviation of _phasing_MAD_expt.delta_phi.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 838, 'id', 'id', 110, 'Y', 
        '              The value of _phasing_MAD_expt.id must uniquely identify each\
               record in the PHASING_MAD_EXPT list.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 839, 'mean_fom', 'mean_fom', 110, 'N', 
        '              The mean figure of merit.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 840, 'number_clust', 'number_clust', 110, 'N', 
        '              The number of clusters of data sets in this phasing experiment.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 841, 'r_normal_all', 'r_normal_all', 110, 'N', 
        '              Definition...'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 842, 'r_normal_anom_scat', 'r_normal_anom_scat', 110, 'N', 
        '              Definition...'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 111, 'PHASING_MAD_RATIO', 'phasing_MAD_ratio', 'N', 0, 
        '              Data items in the PHASING_MAD_RATIO category record\
               the ratios of phasing statistics between pairs of data sets\
               in a MAD phasing experiment, in given shells of resolution.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 843, 'd_res_high', 'd_res_high', 111, 'N', 
        '              The highest resolution for the interplanar spacing in the\
               reflection data used for this comparison of Bijvoet differences.\
               This is the smallest d value.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 844, 'd_res_low', 'd_res_low', 111, 'N', 
        '              The lowest resolution for the interplanar spacing in the\
               reflection data used for this comparison of Bijvoet differences.\
               This is the largest d value.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 845, 'ratio_one_wl', 'ratio_one_wl', 111, 'N', 
        '              The root mean square Bijvoet difference at one wavelength for\
               all reflections.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 846, 'ratio_one_wl_centric', 'ratio_one_wl_centric', 111, 'N', 
        '              The root mean square Bijvoet difference at one wavelength for\
               centric reflections. This would be equal to zero for perfect\
               data, and thus serves as an estimate of the noise in the\
               anomalous signals.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 847, 'ratio_two_wl', 'ratio_two_wl', 111, 'N', 
        '              The root mean square dispersive Bijvoet difference between\
               two wavelengths for all reflections.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 112, 'PHASING_MAD_SET', 'phasing_MAD_set', 'N', 0, 
        '              Data items in the PHASING_MAD_SET category record\
               details about the individual data sets used in a MAD phasing\
               experiment.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 848, 'd_res_high', 'd_res_high', 112, 'N', 
        '              The highest resolution for the interplanar spacing in the\
               reflection data used for this set of data. This is the smallest\
               d value.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 849, 'd_res_low', 'd_res_low', 112, 'N', 
        '              The lowest resolution for the interplanar spacing in the\
               reflection data used for this set of data. This is the largest\
               d value.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 850, 'f_double_prime', 'f_double_prime', 112, 'N', 
        '              The f'''' component of the anomalous scattering factor for this\
               wavelength.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 851, 'f_prime', 'f_prime', 112, 'N', 
        '              The f'' component of the anomalous scattering factor for this\
               wavelength.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 852, 'wavelength', 'wavelength', 112, 'Y', 
        '              The wavelength at which this data set was measured.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 853, 'wavelength_details', 'wavelength_details', 112, 'N', 
        '              A descriptor for this wavelength in this cluster of data sets.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 113, 'PHASING_MIR', 'phasing_mir', 'N', 0, 
        '              Data items in the PHASING_MIR category record details about\
               the phasing of the structure, when methods involving isomorphous\
               replacement are involved.\
\
               All isomorphous based techniques are subsumed in this category,\
               including single isomorphous replacement (SIR), multiple\
               isomorphous replacement (MIR), single or multiple isomorphous\
               replacement plus anomalous scattering (SIRAS, MIRAS).'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 854, 'details', 'details', 113, 'N', 
        '              A description of special aspects of the isomorphous phasing.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 855, 'entry_id', 'entry_id', 113, 'Y', 
        '              This data item is a pointer to _entry.id in the ENTRY category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 856, 'method', 'method', 113, 'N', 
        '              A description of the MIR phasing method applied to phase this\
               structure.\
\
               Note that this is not the computer program used, which is\
               described in the SOFTWARE category, but rather the method\
               itself.\
\
               This data item should be used to describe significant\
               methodological options used within the MIR phasing program.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 114, 'PHASING_MIR_DER', 'phasing_MIR_der', 'N', 0, 
        '              Data items in the PHASING_MIR_DER category record details\
               about individual derivatives used in the phasing of the\
               structure when methods involving isomorphous replacement are\
               involved.\
\
               A derivative in this context does not necessarily equate with\
               a data set; for instance, the same data set could be used to\
               one resolution limit as an isomorphous scatterer and to a\
               different resolution (and with a different sigma cutoff) as an\
               anomalous scatterer. These would be treated as two distinct\
               derivatives, although both derivatives would point to the same\
               data sets via _phasing_MIR_der.der_set_id and\
               _phasing_MIR_der.native_set_id.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 857, 'd_res_high', 'd_res_high', 114, 'Y', 
        '              The highest resolution for the interplanar spacing in the\
               reflection data used for this derivative. This is the smallest\
               d value.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 858, 'd_res_low', 'd_res_low', 114, 'Y', 
        '              The lowest resolution for the interplanar spacing in the\
               reflection data used for this derivative. This is the highest\
               d value.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 859, 'details', 'details', 114, 'N', 
        '              A description of special aspects of this derivative, its data,\
               its solution, or its use in phasing.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 860, 'id', 'id', 114, 'Y', 
        '              The value of _phasing_MIR_der.id must uniquely identify\
               a record in the PHASING_MIR_DER list.\
\
               Note that this item need not be a number; it can be any unique\
               identifier.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 861, 'number_of_sites', 'number_of_sites', 114, 'N', 
        '              The number of heavy atom sites in this derivative.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 862, 'reflns_criteria', 'reflns_criteria', 114, 'N', 
        '              Criteria used to limit the reflections used in the phasing\
               calculations.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 115, 'PHASING_MIR_DER_REFLN', 'phasing_MIR_der_refln', 'N', 0, 
        '              Data items in the PHASING_MIR_DER_REFLN category record details\
               about the calculated structure factors obtained in an MIR\
               phasing experiment.\
\
               This list may contain information from a number of different\
               derivatives; _phasing_MIR_der_refln.der_id indicates to which\
               derivative a given record corresponds. (A derivative in this\
               context does not necessarily equate with a data set; see the\
               definition of the PHASING_MIR_DER category for a more\
               thorough discussion of the meaning of derivative.)\
\
               It is not necessary for the data items describing the measured\
               value of F to appear in this list, as they will already have\
               been given in the PHASING_SET_REFLN category. However, these\
               items may also be listed here for completeness, if desired.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 863, 'f_calc', 'f_calc', 115, 'N', 
        '              The calculated value of the structure factor for this derivative,\
               in electrons.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 864, 'f_calc_au', 'f_calc_au', 115, 'N', 
        '              The calculated value of the structure factor for this derivative,\
               in arbitrary units.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 865, 'f_meas', 'f_meas', 115, 'N', 
        '              The measured value of the structure factor for this derivative,\
               in electrons.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 866, 'f_meas_au', 'f_meas_au', 115, 'N', 
        '              The measured value of the structure factor for this derivative,\
               in arbitrary units.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 867, 'f_meas_sigma', 'f_meas_sigma', 115, 'N', 
        '              The estimated standard deviation of\
               _phasing_MIR_der_refln.F_meas, in electrons.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 868, 'f_meas_sigma_au', 'f_meas_sigma_au', 115, 'N', 
        '              The estimated standard deviation of\
               _phasing_MIR_der_refln.F_meas_au, in arbitrary units.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 869, 'hl_a_iso', 'hl_a_iso', 115, 'N', 
        '              The isomorphous Hendrickson-Lattman coefficient A~iso~ for this\
               reflection for this derivative.\
\
                         -2.0 * (Fp~obs~^2^ + Fh~calc~^2^ - Fph~obs~^2^)\
                              *  Fp~obs~ * cos(alphah~calc~)\
               A~iso~ =  -----------------------------------------------\
                                              E^2^\
\
               E            = (Fph~obs~ - Fp~obs~ - Fh~calc~)^2^\
                              for centric reflections\
                            = [(Fph~obs~ - Fp~obs~) * 2^1/2^ - Fh~calc~]^2^\
                              for acentric reflections\
\
               Fp~obs~      = the observed structure factor amplitude of the\
                              native\
               Fph~obs~     = the observed structure factor amplitude of the\
                              derivative\
               Fh~calc~     = the calculated structure factor amplitude\
                              from the heavy atom model\
               alphah~calc~ = the calculated phase from the heavy atom model'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 870, 'hl_b_iso', 'hl_b_iso', 115, 'N', 
        '              The isomorphous Hendrickson-Lattman coefficient B~iso~ for this\
               reflection for this derivative.\
\
                         -2.0 * (Fp~obs~^2^ + Fh~calc~^2^ - Fph~obs~^2^)\
                              *  Fp~obs~ * sin(alphah~calc~)\
               B~iso~ =  -----------------------------------------------\
                                              E^2^\
\
               E            = (Fph~obs~ - Fp~obs~ - Fh~calc~)^2^\
                              for centric reflections\
                            = [(Fph~obs~ - Fp~obs~) * 2^1/2^ - Fh~calc~]^2^\
                              for acentric reflections\
\
               Fp~obs~      = the observed structure factor amplitude of the\
                              native\
               Fph~obs~     = the observed structure factor amplitude of the\
                              derivative\
               Fh~calc~     = the calculated structure factor amplitude\
                              from the heavy atom model\
               alphah~calc~ = the phase calculated from the heavy atom model'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 871, 'hl_c_iso', 'hl_c_iso', 115, 'N', 
        '              The isomorphous Hendrickson-Lattman coefficient C~iso~ for this\
               reflection for this derivative.\
\
                         -Fp~obs~^2^ * [sin(alphah~calc~)^2^\
                                     -  cos(alphah~calc~)^2^]\
               C~iso~ =  ------------------------------------\
                                        E^2^\
\
               E            = (Fph~obs~ - Fp~obs~ - Fh~calc~)^2^\
                              for centric reflections\
                            = [(Fph~obs~ - Fp~obs~) * 2^1/2^ - Fh~calc~]^2^\
                              for acentric reflections\
\
               Fp~obs~      = the observed structure factor amplitude of the\
                              native\
               Fph~obs~     = the observed structure factor amplitude of the\
                              derivative\
               Fh~calc~     = the calculated structure factor amplitude\
                              from the heavy atom model\
               alphah~calc~ = the phase calculated from the heavy atom model'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 872, 'hl_d_iso', 'hl_d_iso', 115, 'N', 
        '              The isomorphous Hendrickson-Lattman coefficient D~iso~ for this\
               reflection for this derivative.\
\
                         -2.0 * Fp~obs~^2^ * sin(alphah~calc~)^2^\
                                           * cos(alphah~calc~)^2^\
               D~iso~ =  ----------------------------------------\
                                          E^2^\
\
               E            = (Fph~obs~ - Fp~obs~ - Fh~calc~)^2^\
                              for centric reflections\
                            = [(Fph~obs~ - Fp~obs~) * 2^1/2^ - Fh~calc~]^2^\
                              for acentric reflections\
\
               Fp~obs~      = the observed structure factor amplitude of the\
                              native\
               Fph~obs~     = the observed structure factor amplitude of the\
                              derivative\
               Fh~calc~     = the calculated structure factor amplitude\
                              from the heavy atom model\
               alphah~calc~ = the phase calculated from the heavy atom model'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 873, 'phase_calc', 'phase_calc', 115, 'N', 
        '              The calculated value of the structure-factor phase, based on the\
               heavy atom model, for this derivative, in degrees.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 116, 'PHASING_MIR_DER_SHELL', 'phasing_MIR_der_shell', 'N', 0, 
        '              Data items in the PHASING_MIR_DER_SHELL category record\
               statistics, broken down into shells of resolution, for an MIR\
               phasing experiment.\
\
               This list may contain information from a number of different\
               derivatives; _phasing_MIR_der_shell.der_id indicates to which\
               derivative a given record corresponds. (A derivative in this\
               context does not necessarily equate with a data set; see the\
               definition of the PHASING_MIR_DER category for a more\
               thorough discussion of the meaning of derivative.)'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 874, 'd_res_high', 'd_res_high', 116, 'Y', 
        '              The highest resolution for the interplanar spacing in the\
               reflection data for this derivative in this shell. This is the\
               smallest d value.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 875, 'd_res_low', 'd_res_low', 116, 'Y', 
        '              The lowest resolution for the interplanar spacing in the\
               reflection data for this derivative in this shell. This is the\
               highest d value.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 876, 'fom', 'fom', 116, 'N', 
        '              The mean value of the figure of merit m for reflections for this\
               derivative in this shell.\
\
                   int P~alpha~ exp(i*alpha) dalpha\
               m = --------------------------------\
                         int P~alpha~ dalpha\
\
               P~alpha~ = the probability that phase angle alpha is correct\
\
               int is taken over the range alpha = 0 to 2 pi.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 877, 'ha_ampl', 'ha_ampl', 116, 'N', 
        '              The mean heavy-atom amplitude for reflections in this\
               derivative in this shell.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 878, 'loc', 'loc', 116, 'N', 
        '              The mean lack-of-closure error loc for reflections in this\
               derivative in this shell.\
\
               loc = sum|Fph~obs~ - Fph~calc~|\
\
               Fph~obs~  = the observed structure factor amplitude of the\
                           derivative\
               Fph~calc~ = the calculated structure factor amplitude of the\
                           derivative\
\
               sum is taken over the specified reflections'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 879, 'phase', 'phase', 116, 'N', 
        '              The mean of the phase values for reflections in this\
               derivative in this shell.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 880, 'power', 'power', 116, 'N', 
        '              The mean phasing power P for reflections in this derivative\
               in this shell.\
\
                          sum|Fh~calc~^2^|\
               P = (----------------------------)^1/2^\
                    sum|Fph~obs~ - Fph~calc~|^2^  \
\
               Fph~obs~  = the observed structure factor amplitude of the\
                           derivative\
               Fph~calc~ = the calculated structure factor amplitude of the\
                           derivative\
               Fh~calc~  = the calculated structure factor amplitude from the\
                           heavy atom model\
\
               sum is taken over the specified reflections'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 881, 'r_cullis', 'r_cullis', 116, 'N', 
        '              Residual factor R~cullis~ for centric reflections in this\
               derivative in this shell.\
\
                           sum| |Fph~obs~ +/- Fp~obs~| - Fh~calc~ |\
               R~cullis~ = ----------------------------------------\
                                   sum|Fph~obs~ - Fp~obs~|\
\
               Fp~obs~  = the observed structure factor amplitude of the native\
               Fph~obs~ = the observed structure factor amplitude of the\
                          derivative\
               Fh~calc~ = the calculated structure factor amplitude from the\
                          heavy atom model\
\
               sum is taken over the specified reflections\
\
               Ref: Cullis, A. F., Muirhead, H., Perutz, M. F., Rossmann, M. G.\
                    \& North, A. C. T. (1961). Proc. R. Soc. A265, 15-38.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 882, 'r_kraut', 'r_kraut', 116, 'N', 
        '              Residual factor R~kraut~ for general reflections in this\
               derivative in this shell.\
\
                          sum|Fph~obs~ - Fph~calc~|\
               R~kraut~ = -------------------------\
                                sum|Fph~obs~|\
\
               Fph~obs~  = the observed structure factor amplitude of the\
                           derivative\
               Fph~calc~ = the calculated structure factor amplitude of the\
                           derivative\
\
               sum is taken over the specified reflections\
\
               Ref: Kraut, J., Sieker, L. C., High, D. F. \& Freer, S. T.\
                    (1962). Proc. Natl. Acad. Sci. USA, 48, 1417-14??.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 883, 'reflns', 'reflns', 116, 'N', 
        '              The number of reflections in this shell.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 117, 'PHASING_MIR_DER_SITE', 'phasing_MIR_der_site', 'N', 0, 
        '              Data items in the PHASING_MIR_DER_SITE category record details\
               about the heavy-atom sites in an MIR phasing experiment.\
\
               This list may contain information from a number of different\
               derivatives; _phasing_MIR_der_site.der_id indicates to which\
               derivative a given record corresponds. (A derivative in this\
               context does not necessarily equate with a data set; see the\
               definition of the PHASING_MIR_DER category for a more\
               thorough discussion of the meaning of derivative.)'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 884, 'b_iso', 'b_iso', 117, 'N', 
        '              Isotropic temperature factor for this heavy-atom site in this\
               derivative.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 885, 'b_iso_esd', 'b_iso_esd', 117, 'N', 
        '              The estimated standard deviation of _phasing_MIR_der_site.B_iso.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 886, 'details', 'details', 117, 'N', 
        '              A description of special aspects of the derivative site.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 887, 'id', 'id', 117, 'Y', 
        '              The value of _phasing_MIR_der_site.id must uniquely identify each\
               site in each derivative in the PHASING_MIR_DER_SITE list.\
\
               The atom identifiers need not be unique over all sites in all\
               derivatives; they need only be unique for each site in each\
               derivative.\
\
               Note that this item need not be a number; it can be any unique\
               identifier.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 888, 'occupancy', 'occupancy', 117, 'N', 
        '              The fraction of the atom type present at this heavy-atom site\
               in a given derivative. The sum of the occupancies of all the\
               atom types at this site may not significantly exceed 1.0 unless\
               it is a dummy site.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 118, 'PHASING_MIR_SHELL', 'phasing_MIR_shell', 'N', 0, 
        '              Data items in the PHASING_MIR_SHELL category record details\
               broken down into shells of resolution, when the phasing method\
               involves isomorphous replacement.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 889, 'd_res_high', 'd_res_high', 118, 'Y', 
        '              The highest resolution for the interplanar spacing in the\
               reflection data in this shell. This is the smallest d value.\
               Note that the resolution limits of shells in the items\
               _phasing_MIR_shell.d_res_high and _phasing_MIR_shell.d_res_low\
               are independent of the resolution limits of shells in the items\
               _reflns_shell.d_res_high and _reflns_shell.d_res_low.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 890, 'd_res_low', 'd_res_low', 118, 'Y', 
        '              The lowest resolution for the interplanar spacing in the\
               reflection data in this shell. This is the largest d value.\
               Note that the resolution limits of shells in the items\
               _phasing_MIR_shell.d_res_high and _phasing_MIR_shell.d_res_low\
               are independent of the resolution limits of shells in the items\
               _reflns_shell.d_res_high and _reflns_shell.d_res_low.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 891, 'fom', 'fom', 118, 'N', 
        '              The mean value of the figure of merit m for reflections in this\
               shell.\
\
                   int P~alpha~ exp(i*alpha) dalpha\
               m = --------------------------------\
                         int P~alpha~ dalpha\
\
               P~alpha~ = the probability that phase angle alpha is correct\
\
               int is taken over the range alpha = 0 to 2 pi.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 892, 'loc', 'loc', 118, 'N', 
        '              The mean lack-of-closure error loc for reflections in this shell.\
\
               loc = sum|Fph~obs~ - Fph~calc~|\
\
               Fph~obs~  = the observed structure factor amplitude of the\
                           derivative\
               Fph~calc~ = the calculated structure factor amplitude of the\
                           derivative\
\
               sum is taken over the specified reflections'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 893, 'mean_phase', 'mean_phase', 118, 'N', 
        '              The mean of the phase values for all reflections in this shell.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 894, 'power', 'power', 118, 'N', 
        '              The mean phasing power P for reflections in this shell.\
\
                          sum|Fh~calc~^2^|\
               P = (----------------------------)^1/2^\
                    sum|Fph~obs~ - Fph~calc~|^2^\
\
               Fph~obs~  = the observed structure factor amplitude of the\
                           derivative\
               Fph~calc~ = the calculated structure factor amplitude of the\
                           derivative\
               Fh~calc~  = the calculated structure factor amplitude from the\
                           heavy atom model\
\
               sum is taken over the specified reflections'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 895, 'r_cullis', 'r_cullis', 118, 'N', 
        '              Residual factor R~cullis~ for centric reflections in this shell.\
\
                           sum| |Fph~obs~ +/- Fp~obs~| - Fh~calc~ |\
               R~cullis~ = ----------------------------------------\
                                   sum|Fph~obs~ - Fp~obs~|\
\
               Fp~obs~  = the observed structure factor amplitude of the native\
               Fph~obs~ = the observed structure factor amplitude of the\
                          derivative\
               Fh~calc~ = the calculated structure factor amplitude from the\
                          heavy atom model\
\
               sum is taken over the specified reflections\
\
               Ref: Cullis, A. F., Muirhead, H., Perutz, M. F., Rossmann, M. G.\
                    \& North, A. C. T. (1961). Proc. R. Soc. A265, 15-38.\
'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 896, 'r_kraut', 'r_kraut', 118, 'N', 
        '              Residual factor R~kraut~ for general reflections in this shell.\
\
                          sum|Fph~obs~ - Fph~calc~|\
               R~kraut~ = -------------------------\
                                sum|Fph~obs~|     \
\
               Fph~obs~  = the observed structure factor amplitude of the\
                           derivative\
               Fph~calc~ = the calculated structure factor amplitude of the\
                           derivative\
\
               sum is taken over the specified reflections\
\
               Ref: Kraut, J., Sieker, L. C., High, D. F. \& Freer, S. T.\
                    (1962). Proc. Natl. Acad. Sci. USA, 48, 1417-14??.\
'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 897, 'reflns', 'reflns', 118, 'N', 
        '              The number of reflections in this shell.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 119, 'PHASING_SET', 'phasing_set', 'N', 0, 
        '              Data items in the PHASING_SET category record details about\
               the data sets used in a phasing experiment. A given data set\
               may be used in a number of different ways; for instance, a\
               single data set could be used both as an isomorphous derivative\
               and as a component of a multi-wavelength calculation. This\
               category establishes identifiers for each data set, and permits\
               the archiving of a subset of experimental information for each\
               data set (cell constants, wavelength, temperature, etc.)\
\
               This and related categories of data items are provided so that\
               derivative intensity and phase information can be stored in\
               the same data block as the information for the refined\
               structure.\
\
               If it is deemed desirable to archive all possible experimental\
               information for each data set (raw data sets, crystal growth\
               conditions, etc.) those data items should be recorded in a\
               separate data block.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 898, 'detector_specific', 'detector_specific', 119, 'N', 
        '              The particular radiation detector. In general this will be a\
               manufacturer, description, model number or some combination of\
               these.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 899, 'detector_type', 'detector_type', 119, 'N', 
        '              The general class of the radiation detector.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 900, 'id', 'id', 119, 'Y', 
        '              The value of _phasing_set.id must uniquely identify\
               a record in the PHASING_SET list.\
\
               Note that this item need not be a number; it can be any unique\
               identifier.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 901, 'radiation_source_specific', 'radiation_source_specific', 119, 'N', 
        '              The particular source of radiation. In general this will be a\
               manufacturer, description, or model number (or some combination\
               of these) for laboratory sources and an institution name and\
               beamline name for synchrotron sources.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 902, 'radiation_wavelength', 'radiation_wavelength', 119, 'N', 
        '              The mean wavelength of radiation at which this data set was\
               measured.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 903, 'temp', 'temp', 119, 'N', 
        '              The temperature in kelvins at which the data set was\
               measured.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 120, 'PHASING_SET_REFLN', 'phasing_set_refln', 'N', 0, 
        '              Data items in the PHASING_SET_REFLN category record the values\
               of the measured structure factors used in a phasing experiment.\
               This list may contain information from a number of different\
               data sets; _phasing_set_refln.set_id indicates the data set\
               to which a given record corresponds.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 904, 'f_meas', 'f_meas', 120, 'N', 
        '              The measured value of the structure factor for this reflection\
               in this data set, in electrons.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 905, 'f_meas_au', 'f_meas_au', 120, 'N', 
        '              The measured value of the structure factor for this reflection\
               in this data set, in arbitrary units.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 906, 'f_meas_sigma', 'f_meas_sigma', 120, 'N', 
        '              The estimated standard deviation of _phasing_set_refln.F_meas, in\
               electrons.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 907, 'f_meas_sigma_au', 'f_meas_sigma_au', 120, 'N', 
        '              The estimated standard deviation of _phasing_set_refln.F_meas_au,\
               in arbitrary units.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 121, 'REFINE', 'refine', 'N', 0, 
        '              Data items in the REFINE category record details about the\
               structure refinement parameters.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 908, 'aniso_b_0_0', 'aniso_B[1][1]', 121, 'N', 
        '              The [1][1] element of the matrix that defines the overall\
               anisotropic thermal model, if one was refined for this\
               structure.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 909, 'aniso_b_0_1', 'aniso_B[1][2]', 121, 'N', 
        '              The [1][2] element of the matrix that defines the overall\
               anisotropic thermal model, if one was refined for this\
               structure.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 910, 'aniso_b_0_2', 'aniso_B[1][3]', 121, 'N', 
        '              The [1][3] element of the matrix that defines the overall\
               anisotropic thermal model, if one was refined for this\
               structure.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 911, 'aniso_b_1_1', 'aniso_B[2][2]', 121, 'N', 
        '              The [2][2] element of the matrix that defines the overall\
               anisotropic thermal model, if one was refined for this\
               structure.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 912, 'aniso_b_1_2', 'aniso_B[2][3]', 121, 'N', 
        '              The [2][3] element of the matrix that defines the overall\
               anisotropic thermal model, if one was refined for this\
               structure.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 913, 'aniso_b_2_2', 'aniso_B[3][3]', 121, 'N', 
        '              The [3][3] element of the matrix that defines the overall\
               anisotropic thermal model, if one was refined for this\
               structure.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 914, 'b_iso_max', 'b_iso_max', 121, 'N', 
        '              The maximum value for isotropic B value (temperature factors)\
               found in the coordinate set.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 915, 'b_iso_mean', 'b_iso_mean', 121, 'N', 
        '              The mean value for isotropic B value (temperature factors)\
               found in the coordinate set.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 916, 'b_iso_min', 'b_iso_min', 121, 'N', 
        '              The minimum value for isotropic B value (temperature factors)\
               found in the coordinate set.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 917, 'entry_id', 'entry_id', 121, 'Y', 
        '              This data item is a pointer to _entry.id in the ENTRY category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 918, 'details', 'details', 121, 'N', 
        '              Description of special aspects of the refinement process.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 919, 'diff_density_max', 'diff_density_max', 121, 'N', 
        '              The maximum value of the electron density in the final difference\
               Fourier map.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 920, 'diff_density_max_esd', 'diff_density_max_esd', 121, 'N', 
        '              The estimated standard deviation of _refine.diff_density_max.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 921, 'diff_density_min', 'diff_density_min', 121, 'N', 
        '              The minimum value of the electron density in the final difference\
               Fourier map.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 922, 'diff_density_min_esd', 'diff_density_min_esd', 121, 'N', 
        '              The estimated standard deviation of _refine.diff_density_min.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 923, 'diff_density_rms', 'diff_density_rms', 121, 'N', 
        '              The root-mean-square-deviation of the electron density in the\
               final difference Fourier map. This value is measured with respect\
               to the arithmetic mean density, and is derived from summations\
               over each grid point in the asymmetric unit of the cell. This\
               quantity is useful for assessing the significance of the values\
               of _refine.diff_density_min and _refine.diff_density_max, and\
               also for defining suitable contour levels.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 924, 'diff_density_rms_esd', 'diff_density_rms_esd', 121, 'N', 
        '              The estimated standard deviation of _refine.diff_density_rms.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 925, 'ls_abs_structure_details', 'ls_abs_structure_details', 121, 'N', 
        '              The nature of the absolute structure and how it was determined.\
               For example, it may describe the Friedel pairs used.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 926, 'ls_abs_structure_flack', 'ls_abs_structure_flack', 121, 'N', 
        '              The measure of absolute structure (enantiomorph or polarity) as\
               defined by Flack. The value must be between 0. and 1. with a\
               standard uncertainty (e.s.d.).\
\
               Ref: Flack, H. D. (1983). Acta Cryst. A39, 876-881.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 927, 'ls_abs_structure_flack_esd', 'ls_abs_structure_flack_esd', 121, 'N', 
        '              The estimated standard deviation of\
               _refine.ls_abs_structure_Flack.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 928, 'ls_abs_structure_rogers', 'ls_abs_structure_rogers', 121, 'N', 
        '              The measure of absolute structure (enantiomorph or polarity) as\
               defined by Rogers.\
\
               Ref: Rogers, D. (1981). Acta Cryst. A37, 734-741.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 929, 'ls_abs_structure_rogers_esd', 'ls_abs_structure_rogers_esd', 121, 'N', 
        '              The estimated standard deviation of\
               _refine.ls_abs_structure_Rogers.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 930, 'ls_d_res_high', 'ls_d_res_high', 121, 'Y', 
        '              The highest resolution in angstroms for the interplanar spacing\
               in the reflection data used in refinement. This is the smallest\
               d value.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 931, 'ls_d_res_low', 'ls_d_res_low', 121, 'Y', 
        '              The lowest resolution in ansgtroms for the interplanar spacing in\
               the reflection data used in refinement. This is the largest d\
               value.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 932, 'ls_extinction_coef', 'ls_extinction_coef', 121, 'N', 
        '              The extinction coefficient used to calculate the correction\
               factor applied to the structure-factor data. The nature of the\
               extinction coefficient is given in the definitions of\
               _refine_ls_extinction_expression and\
               _refine_ls_extinction_method.\
\
               For the ''Zachariasen'' method it is the r* value; for the\
               ''Becker-Coppens type 1 isotropic'' method it is the ''g'' value,\
               and for ''Becker-Coppens type 2 isotropic'' corrections it is\
               the ''rho'' value. Note that the magnitude of these values is\
               usually of the order of 10000.\
\
               Ref:  Becker, P. J. \& Coppens, P. (1974). Acta Cryst. A30,\
                     129-153.\
                     Zachariasen, W. H. (1967). Acta Cryst. 23, 558-564.\
                     Larson, A. C. (1967). Acta Cryst. 23, 664-665.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 933, 'ls_extinction_coef_esd', 'ls_extinction_coef_esd', 121, 'N', 
        '              The estimated standard deviation of _refine.ls_extinction_coef.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 934, 'ls_extinction_expression', 'ls_extinction_expression', 121, 'N', 
        '              A description or reference of the extinction correction equation\
               used to apply the data item _refine.ls_extinction_coef. This\
               information must be sufficient to reproduce the extinction\
               correction factors applied to the structure factors.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 935, 'ls_extinction_method', 'ls_extinction_method', 121, 'N', 
        '              A description of the extinction correction method applied with\
               the data item _refine.ls_extinction_coef. This description should\
               include information about the correction method, either\
               ''Becker-Coppens'' or ''Zachariasen''  The latter is sometimes\
               referred to as the ''Larson'' method even though it employs\
               Zachariasen''s formula.\
\
               The Becker-Coppens procedure is referred to as ''type 1'' when\
               correcting secondary extinction dominated by the mosaic spread;\
               as ''type 2'' when secondary extinction is dominated by particle\
               size and includes a primary extinction component; and as ''mixed''\
               when there is a mixture of types 1 and 2.\
\
               For the Becker-Coppens method it is also necessary to set the\
               mosaic distribution as either ''Gaussian'' or ''Lorentzian''; and the\
               nature of the extinction as ''isotropic'' or ''anisotropic''. Note\
               that if either the ''mixed'' or ''anisotropic'' corrections are\
               applied the multiple coefficients cannot be contained in\
               *_extinction_coef and must be listed in _refine.details.\
\
               Ref: Becker, P. J. \& Coppens, P. (1974). Acta Cryst. A30,\
                    129-153.\
                    Zachariasen, W. H. (1967). Acta Cryst. 23, 558- 564.\
                    Larson, A. C. (1967). Acta Cryst. 23, 664-665.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 936, 'ls_goodness_of_fit_all', 'ls_goodness_of_fit_all', 121, 'N', 
        '              The least-squares goodness-of-fit parameter S for all data,\
               after the final cycle of refinement. Ideally, account should be\
               taken of parameters restrained in the least squares. See also\
               the definition of _refine.ls_restrained_S_all.\
\
                   ( sum|w |Y~obs~ - Y~calc~|^2^| )^1/2^\
               S = ( ---------------------------- )\
                   (       N~ref~ - N~param~      )\
\
               Y~obs~   = the observed coefficients\
                          (see _refine.ls_structure_factor_coef)\
               Y~calc~  = the calculated coefficients\
                          (see _refine.ls_structure_factor_coef)\
               w        = the least-squares reflection weight\
                          [1/(e.s.d. squared)]\
\
               N~ref~   = the number of reflections used in the refinement\
               N~param~ = the number of refined parameters\
\
               sum is taken over the specified reflections'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 937, 'ls_goodness_of_fit_all_esd', 'ls_goodness_of_fit_all_esd', 121, 'N', 
        '              The estimated standard deviation of\
               _refine.ls_goodness_of_fit_all.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 938, 'ls_goodness_of_fit_obs', 'ls_goodness_of_fit_obs', 121, 'N', 
        '              The least-squares goodness-of-fit parameter S for reflection data\
               classified as ''observed'' (see _reflns.observed_criterion), after\
               the final cycle of refinement. Ideally, account should be taken\
               of parameters restrained in the least squares. See also the\
               definition of _refine.ls_restrained_S_obs.\
\
                   ( sum|w |Y~obs~ - Y~calc~|^2^| )^1/2^\
               S = ( ---------------------------- )\
                   (       N~ref~ - N~param~      )\
\
               Y~obs~   = the observed coefficients\
                          (see _refine.ls_structure_factor_coef)\
               Y~calc~  = the calculated coefficients\
                          (see _refine.ls_structure_factor_coef)\
               w        = the least-squares reflection weight\
                          [1/(e.s.d. squared)]\
\
               N~ref~   = the number of reflections used in the refinement\
               N~param~ = the number of refined parameters\
\
               sum is taken over the specified reflections'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 939, 'ls_goodness_of_fit_obs_esd', 'ls_goodness_of_fit_obs_esd', 121, 'N', 
        '              The estimated standard deviation of\
               _refine.ls_goodness_of_fit_obs.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 940, 'ls_hydrogen_treatment', 'ls_hydrogen_treatment', 121, 'N', 
        '              Treatment of hydrogen atoms in the least-squares refinement.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 941, 'ls_matrix_type', 'ls_matrix_type', 121, 'N', 
        '              Type of matrix used to accumulate the least-squares derivatives.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 942, 'ls_number_constraints', 'ls_number_constraints', 121, 'N', 
        '              The number of constrained (non-refined or dependent) parameters\
               in the least-squares process. These may be due to symmetry or any\
               other constraint process (e.g. rigid-body refinement). See also\
               _atom_site.constraints and _atom_site_refinement_flags. A general\
               description of constraints may appear in _refine.details.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 943, 'ls_number_parameters', 'ls_number_parameters', 121, 'N', 
        '              The number of parameters refined in the least-squares process.\
               If possible this number should include some contribution from\
               the restrained parameters. The restrained parameters are\
               distinct from the constrained parameters (where one or more\
               parameters are linearly dependent on the refined value of\
               another). Least-squares restraints often depend on geometry or\
               energy considerations and this makes their direct contribution\
               to this number, and to the goodness-of-fit calculation,\
               difficult to assess.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 944, 'ls_number_reflns_all', 'ls_number_reflns_all', 121, 'N', 
        '              The number of reflections that satisfy the resolution limits\
               established by _refine.ls_d_res_high and _refine.ls_d_res_low.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 945, 'ls_number_reflns_obs', 'ls_number_reflns_obs', 121, 'N', 
        '              The number of reflections that satisfy the resolution limits\
               established by _refine.ls_d_res_high and _refine.ls_d_res_low\
               and the observation limit established by\
               _reflns.observed_criterion.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 946, 'ls_number_reflns_r_free', 'ls_number_reflns_r_free', 121, 'N', 
        '              The number of reflections that satisfy the resolution limits\
               established by _refine.ls_d_res_high and _refine.ls_d_res_low\
               and the observation limit established by\
               _reflns.observed_criterion, and that were used as the test\
               (i.e. excluded from refinement) reflections when refinement\
               included calculation of a "free" R factor. Details of how\
               reflections were assigned to the working and test sets are\
               given in _reflns.R_free_details.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 947, 'ls_number_reflns_r_work', 'ls_number_reflns_r_work', 121, 'N', 
        '              The number of reflections that satisfy the resolution limits\
               established by _refine.ls_d_res_high and _refine.ls_d_res_low\
               and the observation limit established by\
               _reflns.observed_criterion, and that were used as the working\
               (i.e. included in refinement) reflections when refinement\
               included calculation of a "free" R factor. Details of how\
               reflections were assigned to the working and test sets are\
               given in _reflns.R_free_details.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 948, 'ls_number_restraints', 'ls_number_restraints', 121, 'N', 
        '              The number of restrained parameters. These are parameters which\
               are not directly dependent on another refined parameter. Often\
               restrained parameters involve geometry or energy dependencies.\
               See also _atom_site.constraints and _atom_site_refinement_flags.\
               A general description of refinement constraints may appear in\
               _refine.details.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 949, 'ls_percent_reflns_obs', 'ls_percent_reflns_obs', 121, 'N', 
        '              The number of reflections that satisfy the resolution limits\
               established by _refine.ls_d_res_high and _refine.ls_d_res_low\
               and the observation limit established by\
               _reflns.observed_criterion, expressed as a percentage of the\
               number of geometrically observable reflections that satisfy\
               the resolution limits.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 950, 'ls_percent_reflns_r_free', 'ls_percent_reflns_r_free', 121, 'N', 
        '              The number of reflections that satisfy the resolution limits\
               established by _refine.ls_d_res_high and _refine.ls_d_res_low\
               and the observation limit established by\
               _reflns.observed_criterion, and that were used as the test\
               (i.e. excluded from refinement) reflections when refinement\
               included calculation of a "free" R factor, espressed as a\
               percentage of the number of geometrically observable\
               reflections that satisfy the resolution limits.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 951, 'ls_r_factor_all', 'ls_r_factor_all', 121, 'N', 
        '              Residual factor R for all reflections that satisfy the resolution\
               limits established by _refine.ls_d_res_high and\
               _refine.ls_d_res_low.\
\
                   sum|F~obs~ - F~calc~|\
               R = ---------------------\
                        sum|F~obs~|\
\
               F~obs~  = the observed structure factor amplitudes\
               F~calc~ = the calculated structure factor amplitudes\
\
               sum is taken over the specified reflections'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 952, 'ls_r_factor_obs', 'ls_r_factor_obs', 121, 'N', 
        '              Residual factor R for reflections that satisfy the resolution\
               limits established by _refine.ls_d_res_high and \
               _refine.ls_d_res_low and the observation limit established by\
               _reflns.observed_criterion.\
\
               _refine.ls_R_factor_obs should not be confused with\
               _refine.ls_R_factor_R_work; the former reports the results of a\
               refinement in which all observed reflections were used, the\
               latter a refinement in which a subset of the observed\
               reflections were excluded from refinement for the calculation\
               of a "free" R factor. However, it would be meaningful to quote\
               both values if a "free" R factor were calculated for most of\
               the refinement, but all of the observed reflections were used\
               in the final rounds of refinement; such a protocol should be\
               explained in _refine.details.\
\
                   sum|F~obs~ - F~calc~|\
               R = ---------------------\
                        sum|F~obs~|\
\
               F~obs~  = the observed structure factor amplitudes\
               F~calc~ = the calculated structure factor amplitudes\
\
               sum is taken over the specified reflections'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 953, 'ls_r_factor_r_free', 'ls_r_factor_r_free', 121, 'N', 
        '              Residual factor R for reflections that satisfy the resolution\
               limits established by _refine.ls_d_res_high and\
               _refine.ls_d_res_low and the observation limit established by\
               _reflns.observed_criterion, and that were used as the test\
               (i.e., excluded from refinement) reflections when refinement\
               included calculation of a "free" R factor. Details of how\
               reflections were assigned to the working and test sets are\
               given in _reflns.R_free_details.\
\
                   sum|F~obs~ - F~calc~|\
               R = ---------------------\
                        sum|F~obs~|\
\
               F~obs~  = the observed structure factor amplitudes\
               F~calc~ = the calculated structure factor amplitudes\
\
               sum is taken over the specified reflections'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 954, 'ls_r_factor_r_free_error', 'ls_r_factor_r_free_error', 121, 'N', 
        '              The estimated error in _refine.ls_R_factor_R_free.\
               The method used to estimate the error is described in the\
               item _refine.ls_R_factor_R_free_error_details.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 955, 'ls_r_factor_r_free_error_detai', 'ls_r_factor_r_free_error_details', 121, 'N', 
        '              Special aspects of the method used to estimated the error in\
               _refine.ls_R_factor_R_free.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 956, 'ls_r_factor_r_work', 'ls_r_factor_r_work', 121, 'N', 
        '              Residual factor R for reflections that satisfy the resolution\
               limits established by _refine.ls_d_res_high and\
               _refine.ls_d_res_low and the observation limit established by\
               _reflns.observed_criterion, and that were used as the working\
               (i.e., included in refinement) reflections when refinement\
               included calculation of a "free" R factor. Details of how\
               reflections were assigned to the working and test sets are\
               given in _reflns.R_free_details.\
\
               _refine.ls_R_factor_obs should not be confused with\
               _refine.ls_R_factor_R_work; the former reports the results of a\
               refinement in which all observed reflections were used, the\
               latter a refinement in which a subset of the observed\
               reflections were excluded from refinement for the calculation\
               of a "free" R factor. However, it would be meaningful to quote\
               both values if a "free" R factor were calculated for most of\
               the refinement, but all of the observed reflections were used\
               in the final rounds of refinement; such a protocol should be\
               explained in _refine.details.\
\
                   sum|F~obs~ - F~calc~|\
               R = ---------------------\
                        sum|F~obs~|\
\
               F~obs~  = the observed structure factor amplitudes\
               F~calc~ = the calculated structure factor amplitudes\
\
               sum is taken over the specified reflections'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 957, 'ls_r_fsqd_factor_obs', 'ls_r_fsqd_factor_obs', 121, 'N', 
        '              Residual factor R(Fsqd) for reflections that satisfy the\
               resolution limits established by _refine.ls_d_res_high and\
               _refine.ls_d_res_low and the observation limit established by\
               _reflns.observed_criterion, calculated on the squares of the\
               observed and calculated structure factor amplitudes.\
\
                         sum|F~obs~^2^ - F~calc~^2^|\
               R(Fsqd) = ---------------------------\
                                sum|F~obs~^2^|\
\
               F~obs~^2^  = squares of the observed structure factor amplitudes\
               F~calc~^2^ = squares of the calculated structure factor\
                            amplitudes\
\
               sum is taken over the specified reflections'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 958, 'ls_r_i_factor_obs', 'ls_r_i_factor_obs', 121, 'N', 
        '              Residual factor R(I) for reflections that satisfy the\
               resolution limits established by _refine.ls_d_res_high and\
               _refine.ls_d_res_low and the observation limit established by\
               _reflns.observed_criterion, calculated on the estimated\
               reflection intensities.\
\
               This is most often calculated in Rietveld refinements of powder\
               data, where it is referred to as R~B~ or R~Bragg~.\
\
                      sum|I~obs~ - I~calc~|\
               R(I) = ---------------------\
                           sum|I~obs~|\
\
               I~obs~  = the net observed intensities \
               I~calc~ = the net calculated intensities\
\
               sum is taken over the specified reflections'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 959, 'ls_redundancy_reflns_all', 'ls_redundancy_reflns_all', 121, 'N', 
        '              The ratio of the total number of observations of the \
               reflections that satisfy the resolution limits established by\
               _refine.ls_d_res_high and _refine.ls_d_res_low to the number\
               of crystallographically unique reflections that satisfy those\
               same limits.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 960, 'ls_redundancy_reflns_obs', 'ls_redundancy_reflns_obs', 121, 'N', 
        '              The ratio of the total number of observations of the \
               reflections that satisfy the resolution limits established by\
               _refine.ls_d_res_high and _refine.ls_d_res_low and the\
               observation limit established by _reflns.observed_criterion to\
               the number of crystallographically unique reflections that\
               satisfy those same limits.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 961, 'ls_restrained_s_all', 'ls_restrained_s_all', 121, 'N', 
        '              The least-squares goodness-of-fit parameter S'' for all reflection\
               data, after the final cycle of least squares. This parameter\
               explicitly includes the restraints applied in the least-squares\
               process. See also the definition of\
               _refine.ls_goodness_of_fit_all.\
\
                    (   sum   |w    |Y~obs~  - Y~calc~|^2^| )^1/2^\
                    ( + sum~r~|w~r~ |P~calc~ - P~targ~|^2^| )\
               S'' = ( ------------------------------------- )\
                    (      N~ref~ + N~restr~ - N~param~     )\
\
               Y~obs~   = the observed coefficients\
                          (see _refine.ls_structure_factor_coef)\
               Y~calc~  = the observed coefficients\
                          (see _refine.ls_structure_factor_coef)\
               w        = the least-squares reflection weight\
                          [1/(e.s.d. squared)]\
\
               P~calc~  = the calculated restraint values\
               P~targ~  = the target restraint values\
               w~r~     = the restraint weight\
\
               N~refr~  = the number of reflections used in the refinement\
                          (see _refine.ls_number_reflns_obs)\
               N~restr~ = the number of restraints\
                          (see _refine.ls_number_restraints)\
               N~param~ = the number of refined parameters\
                          (see _refine.ls_number_parameters)\
\
               sum  is taken over the specified reflection data\
               sumr is taken over the restraint data'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 962, 'ls_restrained_s_obs', 'ls_restrained_s_obs', 121, 'N', 
        '              The least-squares goodness-of-fit parameter S'' for reflection\
               data classified as observed (see _reflns.observed_criterion)\
               after the final cycle of least squares. This parameter explicitly\
               includes the restraints applied in the least-squares process. See\
               also the definition of _refine.ls_goodness_of_fit_obs.\
\
                    (   sum   |w    |Y~obs~  - Y~calc~|^2^| )^1/2^\
                    ( + sum~r~|w~r~ |P~calc~ - P~targ~|^2^| )\
               S'' = ( ------------------------------------- )\
                    (      N~ref~ + N~restr~ - N~param~     )\
\
               Y~obs~   = the observed coefficients\
                          (see _refine.ls_structure_factor_coef)\
               Y~calc~  = the observed coefficients\
                          (see _refine.ls_structure_factor_coef)\
               w        = the least-squares reflection weight\
                          [1/(e.s.d. squared)]\
\
               P~calc~  = the calculated restraint values\
               P~targ~  = the target restraint values\
               w~r~     = the restraint weight\
\
               N~refr~  = the number of reflections used in the refinement\
                          (see _refine.ls_number_reflns_obs)\
               N~restr~ = the number of restraints\
                          (see _refine.ls_number_restraints)\
               N~param~ = the number of refined parameters\
                          (see _refine.ls_number_parameters)\
\
               sum  is taken over the specified reflection data\
               sumr is taken over the restraint data'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 963, 'ls_shift_over_esd_max', 'ls_shift_over_esd_max', 121, 'N', 
        '              The largest ratio of the final least-squares parameter shift\
               divided by the final standard uncertainty (e.s.d.).'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 964, 'ls_shift_over_esd_mean', 'ls_shift_over_esd_mean', 121, 'N', 
        '              The average ratio of the final least-squares parameter shift\
               divided by the final standard uncertainty (e.s.d.).'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 965, 'ls_structure_factor_coef', 'ls_structure_factor_coef', 121, 'N', 
        '              Structure-factor coefficient |F|, F^2^ or I, used in the least-\
               squares refinement process.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 966, 'ls_weighting_details', 'ls_weighting_details', 121, 'N', 
        '              A description of special aspects of the weighting scheme used\
               in least-squares refinement. Used to describe the weighting\
               when the value of _refine.ls_weighting_scheme is specified\
               as ''calc''.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 967, 'ls_weighting_scheme', 'ls_weighting_scheme', 121, 'N', 
        '              The weighting scheme applied in the least-squares process. The\
               standard code may be followed by a description of the weight\
               (but see _refine_ls_weighting_details for a preferred approach).'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 968, 'ls_wr_factor_all', 'ls_wr_factor_all', 121, 'N', 
        '              Weighted residual factor wR for all reflections that satisfy the\
               resolution limits established by _refine.ls_d_res_high and\
               _refine.ls_d_res_low.\
\
                    ( sum|w |Y~obs~ - Y~calc~|^2^| )^1/2^\
               wR = ( ---------------------------- )\
                    (        sum|w Y~obs~^2^|      )\
\
               Y~obs~  = the observed amplitude specified by\
                         _refine.ls_structure_factor_coef\
               Y~calc~ = the calculated amplitude specified by\
                         _refine.ls_structure_factor_coef\
               w       = the least squares weight\
\
               sum is taken over the specified reflections'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 969, 'ls_wr_factor_obs', 'ls_wr_factor_obs', 121, 'N', 
        '              Weighted residual factor wR for reflections that satisfy the\
               resolution limits established by _refine.ls_d_res_high and\
               _refine.ls_d_res_low and the obervation limit established by\
               _reflns.observed_criterion.\
\
                    ( sum|w |Y~obs~ - Y~calc~|^2^| )^1/2^\
               wR = ( ---------------------------- )\
                    (        sum|w Y~obs~^2^|      )\
\
               Y~obs~  = the observed amplitude specified by\
                         _refine.ls_structure_factor_coef\
               Y~calc~ = the calculated amplitude specified by\
                         _refine.ls_structure_factor_coef\
               w       = the least squares weight\
\
               sum is taken over the specified reflections'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 970, 'ls_wr_factor_r_free', 'ls_wr_factor_r_free', 121, 'N', 
        '              Weighted residual factor wR for reflections that satisfy the\
               resolution limits established by _refine.ls_d_res_high and\
               _refine.ls_d_res_low and the observation limit established by\
               _reflns.observed_criterion, and that were used as the test\
               (i.e., excluded from refinement) reflections when refinement\
               included calculation of a "free" R factor. Details of how\
               reflections were assigned to the working and test sets are\
               given in _reflns.R_free_details.\
\
                    ( sum|w |Y~obs~ - Y~calc~|^2^| )^1/2^\
               wR = ( ---------------------------- )\
                    (        sum|w Y~obs~^2^|      )\
\
               Y~obs~  = the observed amplitude specified by\
                         _refine.ls_structure_factor_coef\
               Y~calc~ = the calculated amplitude specified by\
                         _refine.ls_structure_factor_coef\
               w       = the least squares weight\
\
               sum is taken over the specified reflections'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 971, 'ls_wr_factor_r_work', 'ls_wr_factor_r_work', 121, 'N', 
        '              Weighted residual factor wR for reflections that satisfy the\
               resolution limits established by _refine.ls_d_res_high and\
               _refine.ls_d_res_low and the observation limit established by\
               _reflns.observed_criterion, and that were used as the working\
               (i.e., included in refinement) reflections when refinement\
               included calculation of a "free" R factor. Details of how\
               reflections were assigned to the working and test sets are\
               given in _reflns.R_free_details.\
\
                    ( sum|w |Y~obs~ - Y~calc~|^2^| )^1/2^\
               wR = ( ---------------------------- )\
                    (        sum|w Y~obs~^2^|      )\
\
               Y~obs~  = the observed amplitude specified by\
                         _refine.ls_structure_factor_coef\
               Y~calc~ = the calculated amplitude specified by\
                         _refine.ls_structure_factor_coef\
               w       = the least squares weight\
\
               sum is taken over the specified reflections'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 972, 'occupancy_max', 'occupancy_max', 121, 'N', 
        '              The maximum value for occupancy found in the coordinate set.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 973, 'occupancy_min', 'occupancy_min', 121, 'N', 
        '              The minimum value for occupancy found in the coordinate set.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 974, 'solvent_model_details', 'solvent_model_details', 121, 'N', 
        '              Special aspects of the solvent model used in refinement.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 975, 'solvent_model_param_bsol', 'solvent_model_param_bsol', 121, 'N', 
        '              The value of the BSOL solvent model parameter describing \
               the average isotropic temperature factor of disordered\
               solvent atoms.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 976, 'solvent_model_param_ksol', 'solvent_model_param_ksol', 121, 'N', 
        '              The value of the KSOL solvent model parameter describing \
               the ratio of electron density in the bulk solvent to the \
               electron density in the molecular solute.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 977, 'pdbx_ls_sigma_I', 'pdbx_ls_sigma_I', 121, 'N', 
        '              Data cutoff (SIGMA(I))'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 978, 'pdbx_ls_sigma_F', 'pdbx_ls_sigma_F', 121, 'N', 
        '              Data cutoff (SIGMA(F))'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 979, 'pdbx_data_cutoff_high_absF', 'pdbx_data_cutoff_high_absF', 121, 'N', 
        '              Value of F at "high end" of data cutoff.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 980, 'pdbx_data_cutoff_high_rms_absF', 'pdbx_data_cutoff_high_rms_absF', 121, 'N', 
        '              Value of RMS |F| used as high data cutoff.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 981, 'pdbx_data_cutoff_low_absF', 'pdbx_data_cutoff_low_absF', 121, 'N', 
        '              Value of F at "low end" of data cutoff.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 982, 'pdbx_isotropic_thermal_model', 'pdbx_isotropic_thermal_model', 121, 'N', 
        '\
               Whether the structure was refined with indvidual\
               isotropic, anisotropic or overall temperature factor.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 983, 'pdbx_ls_cross_valid_method', 'pdbx_ls_cross_valid_method', 121, 'N', 
        '\
               Whether the cross validataion method was used through\
               out or only at the end.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 984, 'pdbx_method_to_determine_struc', 'pdbx_method_to_determine_struct', 121, 'N', 
        '                 Method(s) used to determine the structure.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 985, 'pdbx_starting_model', 'pdbx_starting_model', 121, 'N', 
        '                 Starting model for refinement.  Starting model for \
                  molecular replacement should refer to a previous\
                  structure or experiment.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 986, 'pdbx_stereochemistry_target_va', 'pdbx_stereochemistry_target_values', 121, 'N', 
        '                  Stereochemistry target values used in refinement. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 987, 'pdbx_R_Free_selection_details', 'pdbx_R_Free_selection_details', 121, 'N', 
        '            Details of the manner in which the cross validation \
             reflections were selected.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 988, 'pdbx_stereochem_target_val_spe', 'pdbx_stereochem_target_val_spec_case', 121, 'N', 
        '\
                  Special case of stereochemistry target values used\
                  in SHELXL refinement.  \
'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 989, 'pdbx_overall_ESU_R', 'pdbx_overall_ESU_R', 121, 'N', 
        '              Overall estimated standard uncertainties of positional\
               parameters based on R value.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 990, 'pdbx_overall_ESU_R_Free', 'pdbx_overall_ESU_R_Free', 121, 'N', 
        '              Overall estimated standard uncertainties of positional\
               parameters based on R value.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 991, 'pdbx_solvent_vdw_probe_radii', 'pdbx_solvent_vdw_probe_radii', 121, 'N', 
        '              CCP4 solvent proble van der Waals radii '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 992, 'pdbx_solvent_ion_probe_radii', 'pdbx_solvent_ion_probe_radii', 121, 'N', 
        '              CCP4 solvent ion proble radii '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 993, 'pdbx_solvent_shrinkage_radii', 'pdbx_solvent_shrinkage_radii', 121, 'N', 
        '              CCP4 solvent shrinkage radii '
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 122, 'REFINE_ANALYZE', 'refine_analyze', 'N', 0, 
        '              Data items in the REFINE_ANALYZE category record details\
               about the refined structure that are often used to analyze the\
               refinement and asses its quality. A given computer program\
               may or may not produce values corresponding to these data\
               names.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 994, 'entry_id', 'entry_id', 122, 'Y', 
        '              This data item is a pointer to _entry.id in the ENTRY category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 995, 'luzzati_coordinate_error_obs', 'luzzati_coordinate_error_obs', 122, 'N', 
        '              The estimated coordinate error obtained from the plot of \
               the R value versus sin(theta)/lambda for reflections classified\
               as observed.\
\
               Ref:  Luzzati, V. (1952). Acta Cryst. 5, 134-136.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 996, 'luzzati_d_res_low_obs', 'luzzati_d_res_low_obs', 122, 'N', 
        '              The value of the low resolution cutoff used in \
               constructing the Luzzati plot for reflections classified as\
               observed.\
\
               Ref:  Luzzati, V. (1952). Acta Cryst. 5, 134-136.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 997, 'luzzati_sigma_a_obs', 'luzzati_sigma_a_obs', 122, 'N', 
        '              The value of sigma~a~ used in constructing the Luzzati plot for\
               reflections classified as observed. The details of the\
               estimation of sigma~a~ can be specified in\
               _refine_analyze.Luzzati_sigma_a_obs_details.\
\
               Ref:  Luzzati, V. (1952). Acta Cryst. 5, 134-136.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 998, 'luzzati_sigma_a_obs_details', 'luzzati_sigma_a_obs_details', 122, 'N', 
        '              Special aspects of the estimation of sigma~a~ for the \
               reflections classified as observed.\
\
               Ref:  Luzzati, V. (1952). Acta Cryst. 5, 134-136.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 999, 'luzzati_coordinate_error_free', 'luzzati_coordinate_error_free', 122, 'N', 
        '              The estimated coordinate error obtain from the plot of \
               the R value versus sin(theta)/lambda for the reflections\
               treated as a test set in refinement. \
\
               Ref:  Luzzati, V. (1952). Acta Cryst. 5, 134-136.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1000, 'luzzati_d_res_low_free', 'luzzati_d_res_low_free', 122, 'N', 
        '              The value of the low resolution cutoff used in constructing the\
               Luzzati plot for reflections treated as a test set in \
               refinement.\
\
               Ref:  Luzzati, V. (1952). Acta Cryst. 5, 134-136.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1001, 'luzzati_sigma_a_free', 'luzzati_sigma_a_free', 122, 'N', 
        '              The value of sigma~a~ used in constructing the Luzzati plot for\
               the reflections treated as a test set in refinement. The\
               details of the estimation of sigma~a~ can be specified\
               in _refine_analyze.Luzzati_sigma_a_free_details.\
\
               Ref:  Luzzati, V. (1952). Acta Cryst. 5, 134-136.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1002, 'luzzati_sigma_a_free_details', 'luzzati_sigma_a_free_details', 122, 'N', 
        '              The details of the estimation of sigma~a~ for the reflections\
               treated as a test set in refinement.\
\
               Ref:  Luzzati, V. (1952). Acta Cryst. 5, 134-136.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1003, 'number_disordered_residues', 'number_disordered_residues', 122, 'N', 
        '              The number of discretely disorded residues in the refined model.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1004, 'occupancy_sum_hydrogen', 'occupancy_sum_hydrogen', 122, 'N', 
        '              The sum of the occupancies of the hydrogen atoms in the refined\
               model.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1005, 'occupancy_sum_non_hydrogen', 'occupancy_sum_non_hydrogen', 122, 'N', 
        '              The sum of the occupancies of the non-hydrogen atoms in the\
                refined model.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 123, 'REFINE_B_ISO', 'refine_b_iso', 'N', 0, 
        '              Data items in the REFINE_B_ISO category record details about\
               the treatment of isotropic B (temperature) factors during\
               refinement.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1006, 'class_atoms', 'class_atoms', 123, 'Y', 
        '              A class of atoms treated similarly for isotropic B (temperature)\
               factor refinement.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1007, 'details', 'details', 123, 'N', 
        '              A description of special aspects of the isotropic B (temperature)\
               factor refinement for the class of atoms described in\
               _refine_B_iso.class.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1008, 'treatment', 'treatment', 123, 'N', 
        '              The treatment of isotropic B (temperature) factor refinement for\
               a class of atoms defined in _refine_B_iso.class.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1009, 'value', 'value', 123, 'N', 
        '              The value of the isotropic B (temperature) factor assigned to a\
               class of atoms defined in _refine_B_iso.class. Meaningful only\
               for atoms with fixed isotropic B (temperature) factors.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 124, 'REFINE_HIST', 'refine_hist', 'N', 0, 
        '              Data items in the REFINE_HIST category record details about the\
               various steps along the way in the refinement of the structure.\
               These data items are not meant to be as thorough a description\
               of the refinement as is provided for the final model in other\
               categories; rather, these data items provide a mechanism for\
               sketching out the progress of the refinement, supported by a\
               small set of representative statistics.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1010, 'cycle_id', 'cycle_id', 124, 'Y', 
        '              The value of refine_hist.cycle_id must uniquely identify a record\
               in the REFINE_HIST list.\
\
               Note that this item need not be a number; it can be any unique\
               identifier.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1011, 'details', 'details', 124, 'N', 
        '              Description of special aspects of this cycle of the refinement\
               process.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1012, 'd_res_high', 'd_res_high', 124, 'Y', 
        '              The highest resolution for the interplanar spacing in the\
               reflection data for this cycle of refinement.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1013, 'd_res_low', 'd_res_low', 124, 'Y', 
        '              The lowest resolution for the interplanar spacing in the\
               reflection data for this cycle of refinement.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1014, 'number_atoms_solvent', 'number_atoms_solvent', 124, 'N', 
        '              The number of solvent atoms that were included in the model at\
               this cycle of the refinement.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1015, 'number_atoms_total', 'number_atoms_total', 124, 'N', 
        '              The total number of atoms that were included in the model at\
               this cycle of the refinement.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1016, 'number_reflns_all', 'number_reflns_all', 124, 'N', 
        '              The number of reflections that satisfy the resolution limits\
               established by _refine_hist.d_res_high and\
               _refine_hist.d_res_low.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1017, 'number_reflns_obs', 'number_reflns_obs', 124, 'N', 
        '              The number of reflections that satisfy the resolution limits\
               established by _refine_hist.d_res_high and\
               _refine_hist.d_res_low and the observation criterion\
               established by _reflns.observed_criterion.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1018, 'number_reflns_R_free', 'number_reflns_R_free', 124, 'N', 
        '              The number of reflections that satisfy the resolution limits\
               established by _refine_hist.d_res_high and\
               _refine_hist.d_res_low and the observation limit\
               established by _reflns.observed_criterion, and that were used\
               as the test (i.e., excluded from refinement) reflections when\
               refinement included calculation of a "free" R factor. Details\
               of how reflections were assigned to the working and test sets\
               are given in _reflns.R_free_details.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1019, 'number_reflns_R_work', 'number_reflns_R_work', 124, 'N', 
        '              The number of reflections that satisfy the resolution limits\
               established by _refine_hist.d_res_high and\
               _refine_hist.d_res_low and the observation limit\
               established by _reflns.observed_criterion, and that were used\
               as the working (i.e., included in refinement) reflections when\
               refinement included calculation of a "free" R factor. Details\
               of how reflections were assigned to the working and test sets\
               are given in _reflns.R_free_details.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1020, 'r_factor_all', 'r_factor_all', 124, 'N', 
        '              Residual factor R for reflections that satisfy the resolution\
               limits established by _refine_hist.d_res_high and\
               _refine_hist.d_res_low.\
\
                   sum|F~obs~ - F~calc~|\
               R = ---------------------\
                        sum|F~obs~|\
\
               F~obs~  = the observed structure factor amplitudes\
               F~calc~ = the calculated structure factor amplitudes\
\
               sum is taken over the specified reflections'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1021, 'r_factor_obs', 'r_factor_obs', 124, 'N', 
        '              Residual factor R for reflections that satisfy the resolution\
               limits established by _refine_hist.d_res_high and\
               _refine_hist.d_res_low and the observation criterion\
               established by _reflns.observed_criterion.\
\
                   sum|F~obs~ - F~calc~|\
               R = ---------------------\
                        sum|F~obs~|\
\
               F~obs~  = the observed structure factor amplitudes\
               F~calc~ = the calculated structure factor amplitudes\
\
               sum is taken over the specified reflections'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1022, 'r_factor_r_free', 'r_factor_r_free', 124, 'N', 
        '              Residual factor R for reflections that satisfy the resolution\
               limits established by _refine_hist.d_res_high and\
               _refine_hist.d_res_low and the observation limit\
               established by _reflns.observed_criterion, and that were used\
               as the test (i.e., excluded from refinement) reflections when\
               refinement included calculation of a "free" R factor. Details\
               of how reflections were assigned to the working and test sets\
               are given in _reflns.R_free_details.\
\
                   sum|F~obs~ - F~calc~|\
               R = ---------------------\
                        sum|F~obs~|\
\
               F~obs~  = the observed structure factor amplitudes\
               F~calc~ = the calculated structure factor amplitudes\
\
               sum is taken over the specified reflections'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1023, 'r_factor_r_work', 'r_factor_r_work', 124, 'N', 
        '              Residual factor R for reflections that satisfy the resolution\
               limits established by _refine_hist.d_res_high and\
               _refine_hist.d_res_low and the observation limit\
               established by _reflns.observed_criterion, and that were used\
               as the working (i.e., included in refinement) reflections when\
               refinement included calculation of a "free" R factor. Details\
               of how reflections were assigned to the working and test sets\
               are given in _reflns.R_free_details.\
\
                   sum|F~obs~ - F~calc~|\
               R = ---------------------\
                        sum|F~obs~|\
\
               F~obs~  = the observed structure factor amplitudes\
               F~calc~ = the calculated structure factor amplitudes\
\
               sum is taken over the specified reflections'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1024, 'pdbx_number_atoms_protein', 'pdbx_number_atoms_protein', 124, 'N', 
        '              Number of protein atoms included in refinement'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1025, 'pdbx_number_atoms_nucleic_acid', 'pdbx_number_atoms_nucleic_acid', 124, 'N', 
        '              Number of nucleic atoms included in refinement'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1026, 'pdbx_number_atoms_ligand', 'pdbx_number_atoms_ligand', 124, 'N', 
        '              Number of ligand atoms included in refinement'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1027, 'pdbx_number_atoms_lipid', 'pdbx_number_atoms_lipid', 124, 'N', 
        '              Number of lipid atoms included in refinement'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1028, 'pdbx_number_atoms_carb', 'pdbx_number_atoms_carb', 124, 'N', 
        '              Number of carbohydrate atoms included in refinement'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1029, 'pdbx_pseudo_atom_details', 'pdbx_pseudo_atom_details', 124, 'N', 
        '              Details of pseduo atoms used to model unexplained density'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 125, 'REFINE_LS_RESTR', 'refine_ls_restr', 'N', 0, 
        '              Data items in the REFINE_LS_RESTR category record details about\
               the restraints applied to various classes of parameters during\
               least-squares refinement.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1030, 'criterion', 'criterion', 125, 'N', 
        '              A criterion used to define a parameter value that deviates\
               significantly from its ideal value in the model obtained by\
               restrained least-squares refinement.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1031, 'dev_ideal', 'dev_ideal', 125, 'N', 
        '              For the given parameter type, the root-mean-square deviation\
               between the ideal values used as restraints in the least-squares\
               refinement and the values obtained by refinement. For instance,\
               bond distances may deviate by 0.018 \\%A (r.m.s.) from ideal\
               values in current model.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1032, 'number2', 'number', 125, 'N', 
        '              The number of parameters of this type subjected to restraint in\
               least-squares refinement.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1033, 'rejects', 'rejects', 125, 'N', 
        '              The number of parameters of this type that deviate from ideal\
               values by more than the amount defined in\
               _refine_ls_restr.criterion in the model obtained by restrained\
               least-squares refinement.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1034, 'dev_ideal_target', 'dev_ideal_target', 125, 'N', 
        '              For the given parameter type, the target root-mean-square\
               deviation between the ideal values used as restraints in the\
               least-squares refinement and the values obtained by refinement.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1035, 'type', 'type', 125, 'Y', 
        '              The type of the parameter being restrained.\
\
               Explicit sets of data values are provided for the programs\
               PROTIN/PROLSQ (beginning with p_) and RESTRAIN (beginning with\
               RESTRAIN_). As computer programs will evolve, these data values\
               are given as examples, and not as an enumeration list. Computer\
               programs converting a data block to a refinement table will\
               expect the exact form of the data values given here to be used.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1036, 'weight', 'weight', 125, 'N', 
        '              The weighting value applied to this type of restraint in\
               least-squares refinement.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 126, 'REFINE_LS_RESTR_NCS', 'refine_ls_restr_ncs', 'N', 0, 
        '              Data items in the REFINE_LS_RESTR_NCS category record details \
               about the restraints applied to atomic positions in domains\
               related by non-crystallographic symmetry during least-squares\
               refinement, and also about the deviation of the restrained\
               atomic parameters at the conclusion of refinement.  It is\
               expected that these values will only be reported once for each\
               set of restrained domains.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1037, 'dom_id', 'dom_id', 126, 'Y', 
        '              This data item is a pointer to _struct_ncs_dom.id in the \
               STRUCT_NCS_DOM category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1038, 'ncs_model_details', 'ncs_model_details', 126, 'N', 
        '              Special aspects of the manner in which non-crystallographic\
               restraints were applied to atomic parameters in the domain\
               specified by _refine_ls_restr_ncs.dom_id and equivalent\
               atomic parameters in the domains against which it was restrained.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1039, 'weight_position', 'weight_position', 126, 'N', 
        '              The value of the weighting coefficient used in\
               non-crystallographic restraint of atomic positions in the\
               domain specified by _refine_ls_restr_ncs.dom_id to equivalent\
               atomic positions in the domains against which it was restrained.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1040, 'weight_b_iso', 'weight_b_iso', 126, 'N', 
        '              The value of the weighting coefficient used in \
               non-crystallographic restraint of isotropic thermal factors in \
               the domain specified by _refine_ls_restr_ncs.dom_id to \
               equivalent isotropic thermal factors in the domains against \
               which it was restrained.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1041, 'rms_dev_position', 'rms_dev_position', 126, 'N', 
        '              The root-mean-square deviation in equivalent atomic positions in\
               the domain specified by _refine_ls_restr_ncs.dom_id and in the\
               domains against which it was restrained.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1042, 'rms_dev_b_iso', 'rms_dev_b_iso', 126, 'N', 
        '              The root-mean-square deviation in equivalent isotropic thermal\
               factors in the domain specified by _refine_ls_restr_ncs.dom_id\
               and in the domains against which it was restrained.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 127, 'REFINE_LS_SHELL', 'refine_ls_shell', 'N', 0, 
        '              Data items in the REFINE_LS_SHELL category record details about\
               the results of least-squares refinement, broken out by shells of\
               resolution.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1043, 'd_res_high', 'd_res_high', 127, 'Y', 
        '              The highest resolution for the interplanar spacing in the\
               reflection data in this shell. This is the largest d value.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1044, 'd_res_low', 'd_res_low', 127, 'Y', 
        '              The lowest resolution for the interplanar spacing in the\
               reflection data in this shell. This is the smallest d value.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1045, 'number_reflns_all', 'number_reflns_all', 127, 'N', 
        '              The number of reflections that satisfy the resolution limits\
               established by _refine_ls_shell.d_res_high and\
               _refine_ls_shell.d_res_low.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1046, 'number_reflns_obs', 'number_reflns_obs', 127, 'N', 
        '              The number of reflections that satisfy the resolution limits\
               established by _refine_ls_shell.d_res_high and\
               _refine_ls_shell.d_res_low and the observation criterion\
               established by _reflns.observed_criterion.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1047, 'number_reflns_r_free', 'number_reflns_r_free', 127, 'N', 
        '              The number of reflections that satisfy the resolution limits\
               established by _refine_ls_shell.d_res_high and\
               _refine_ls_shell.d_res_low and the observation limit\
               established by _reflns.observed_criterion, and that were used\
               as the test (i.e., excluded from refinement) reflections when\
               refinement included calculation of a "free" R factor. Details\
               of how reflections were assigned to the working and test sets\
               are given in _reflns.R_free_details.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1048, 'number_reflns_r_work', 'number_reflns_r_work', 127, 'N', 
        '              The number of reflections that satisfy the resolution limits\
               established by _refine_ls_shell.d_res_high and\
               _refine_ls_shell.d_res_low and the observation limit\
               established by _reflns.observed_criterion, and that were used\
               as the working (i.e., included in refinement) reflections when\
               refinement included calculation of a "free" R factor. Details\
               of how reflections were assigned to the working and test sets\
               are given in _reflns.R_free_details.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1049, 'percent_reflns_obs', 'percent_reflns_obs', 127, 'N', 
        '              The number of reflections that satisfy the resolution limits\
               established by _refine_ls_shell.d_res_high and\
               _refine_ls_shell.d_res_low and the observation criterion\
               established by _reflns.observed_criterion, expressed as a\
               percentage of the number of geometrically observable\
               reflections that satisfy the resolution limits.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1050, 'percent_reflns_r_free', 'percent_reflns_r_free', 127, 'N', 
        '              The number of reflections that satisfy the resolution limits\
               established by _refine_ls_shell.d_res_high and\
               _refine_ls_shell.d_res_low and the observation limit\
               established by _reflns.observed_criterion, and that were used\
               as the test (i.e., excluded from refinement) reflections when\
               refinement included calculation of a "free" R factor,\
               expressed as a percentage of the number of geometrically\
               observable reflection that satisfy the reflection limits.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1051, 'r_factor_all', 'r_factor_all', 127, 'N', 
        '              Residual factor R for reflections that satisfy the resolution\
               limits established by _refine_ls_shell.d_res_high and\
               _refine_ls_shell.d_res_low.\
\
                   sum|F~obs~ - F~calc~|\
               R = ---------------------\
                        sum|F~obs~|\
\
               F~obs~  = the observed structure factor amplitudes\
               F~calc~ = the calculated structure factor amplitudes\
\
               sum is taken over the specified reflections'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1052, 'r_factor_obs', 'r_factor_obs', 127, 'N', 
        '              Residual factor R for reflections that satisfy the resolution\
               limits established by _refine_ls_shell.d_res_high and\
               _refine_ls_shell.d_res_low and the observation criterion\
               established by _reflns.observed_criterion.\
\
                   sum|F~obs~ - F~calc~|\
               R = ---------------------\
                        sum|F~obs~|\
\
               F~obs~  = the observed structure factor amplitudes\
               F~calc~ = the calculated structure factor amplitudes\
\
               sum is taken over the specified reflections'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1053, 'r_factor_r_free', 'r_factor_r_free', 127, 'N', 
        '              Residual factor R for reflections that satisfy the resolution\
               limits established by _refine_ls_shell.d_res_high and\
               _refine_ls_shell.d_res_low and the observation limit\
               established by _reflns.observed_criterion, and that were used\
               as the test (i.e., excluded from refinement) reflections when\
               refinement included calculation of a "free" R factor. Details\
               of how reflections were assigned to the working and test sets\
               are given in _reflns.R_free_details.\
\
                   sum|F~obs~ - F~calc~|\
               R = ---------------------\
                        sum|F~obs~|\
\
               F~obs~  = the observed structure factor amplitudes\
               F~calc~ = the calculated structure factor amplitudes\
\
               sum is taken over the specified reflections'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1054, 'r_factor_r_free_error', 'r_factor_r_free_error', 127, 'N', 
        '              The estimated error in _refine_ls_shell.R_factor_R_free.\
               The method used to estimate the error is described in the\
               item _refine.ls_R_factor_R_free_error_details.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1055, 'r_factor_r_work', 'r_factor_r_work', 127, 'N', 
        '              Residual factor R for reflections that satisfy the resolution\
               limits established by _refine_ls_shell.d_res_high and\
               _refine_ls_shell.d_res_low and the observation limit\
               established by _reflns.observed_criterion, and that were used\
               as the working (i.e., included in refinement) reflections when\
               refinement included calculation of a "free" R factor. Details\
               of how reflections were assigned to the working and test sets\
               are given in _reflns.R_free_details.\
\
                   sum|F~obs~ - F~calc~|\
               R = ---------------------\
                        sum|F~obs~|\
\
               F~obs~  = the observed structure factor amplitudes\
               F~calc~ = the calculated structure factor amplitudes\
\
               sum is taken over the specified reflections'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1056, 'redundancy_reflns_all', 'redundancy_reflns_all', 127, 'N', 
        '              The ratio of the total number of observations of the reflections\
               that satisfy the resolution limits established by\
               _refine_ls_shell.d_res_high and _refine_ls_shell.d_res_low\
               to the number of crystallographically unique reflections that\
               satisfy those same limits.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1057, 'redundancy_reflns_obs', 'redundancy_reflns_obs', 127, 'N', 
        '              The ratio of the total number of observations of the\
               reflections that satisfy the resolution limits established by\
               _refine_ls_shell.d_res_high and _refine_ls_shell.d_res_low and\
               the observation criterion established by\
               _reflns.observed_criterion to the number of crystallographically\
               unique reflections that satisfy those same limits.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1058, 'wr_factor_all', 'wr_factor_all', 127, 'N', 
        '              Weighted residual factor wR for reflections that satisfy the\
               resolution limits established by _refine_ls_shell.d_res_high\
               and _refine_ls_shell.d_res_low.\
\
                    ( sum|w |Y~obs~ - Y~calc~|^2^| )^1/2^\
               wR = ( ---------------------------- )\
                    (        sum|w Y~obs~^2^|      )\
\
               Y~obs~  = the observed amplitude specified by\
                         _refine.ls_structure_factor_coef\
               Y~calc~ = the calculated amplitude specified by\
                         _refine.ls_structure_factor_coef\
               w       = the least squares weight\
\
               sum is taken over the specified reflections'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1059, 'wr_factor_obs', 'wr_factor_obs', 127, 'N', 
        '              Weighted residual factor wR for reflections that satisfy the\
               resolution limits established by _refine_ls_shell.d_res_high\
               and _refine_ls_shell.d_res_low and the observation criterion\
               established by _reflns.observed_criterion.\
\
                    ( sum|w |Y~obs~ - Y~calc~|^2^| )^1/2^\
               wR = ( ---------------------------- )\
                    (        sum|w Y~obs~^2^|      )\
\
               Y~obs~  = the observed amplitude specified by\
                         _refine.ls_structure_factor_coef\
               Y~calc~ = the calculated amplitude specified by\
                         _refine.ls_structure_factor_coef\
               w       = the least squares weight\
\
               sum is taken over the specified reflections'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1060, 'wr_factor_r_free', 'wr_factor_r_free', 127, 'N', 
        '              Weighted residual factor wR for reflections that satisfy the\
               resolution limits established by _refine_ls_shell.d_res_high\
               and _refine_ls_shell.d_res_low and the observation limit\
               established by _reflns.observed_criterion, and that were used\
               as the test (i.e., excluded from refinement) reflections when\
               refinement included calculation of a "free" R factor. Details\
               of how reflections were assigned to the working and test sets\
               are given in _reflns.R_free_details.\
\
                    ( sum|w |Y~obs~ - Y~calc~|^2^| )^1/2^\
               wR = ( ---------------------------- )\
                    (        sum|w Y~obs~^2^|      )\
\
               Y~obs~  = the observed amplitude specified by\
                         _refine.ls_structure_factor_coef\
               Y~calc~ = the calculated amplitude specified by\
                         _refine.ls_structure_factor_coef\
               w       = the least squares weight\
\
               sum is taken over the specified reflections'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1061, 'wr_factor_r_work', 'wr_factor_r_work', 127, 'N', 
        '              Weighted residual factor wR for reflections that satisfy the\
               resolution limits established by _refine_ls_shell.d_res_high\
               and _refine_ls_shell.d_res_low and the observation limit\
               established by _reflns.observed_criterion, and that were used\
               as the working (i.e., included in refinement) reflections when\
               refinement included calculation of a "free" R factor. Details\
               of how reflections were assigned to the working and test sets\
               are given in _reflns.R_free_details.\
\
                    ( sum|w |Y~obs~ - Y~calc~|^2^| )^1/2^\
               wR = ( ---------------------------- )\
                    (        sum|w Y~obs~^2^|      )\
\
               Y~obs~  = the observed amplitude specified by\
                         _refine.ls_structure_factor_coef\
               Y~calc~ = the calculated amplitude specified by\
                         _refine.ls_structure_factor_coef\
               w       = the least squares weight\
\
               sum is taken over the specified reflections'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1062, 'pdbx_total_number_of_bins_used', 'pdbx_total_number_of_bins_used', 127, 'N', 
        '              Total number of bins used.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 128, 'REFINE_OCCUPANCY', 'refine_occupancy', 'N', 0, 
        '              Data items in the REFINE_OCCUPANCY category record details\
               about the treatment of atomic occupancies during refinement.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1063, 'class_atoms', 'class_atoms', 128, 'Y', 
        '              The class of atoms treated similarly for occupancy refinement.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1064, 'details', 'details', 128, 'N', 
        '              A description of special aspects of the occupancy refinement for\
               a class of atoms described in _refine_occupancy.class.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1065, 'treatment', 'treatment', 128, 'N', 
        '              The treatment of occupancy refinement for a class of atoms\
               described in _refine_occupancy.class.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1066, 'value', 'value', 128, 'N', 
        '              The value of occupancy assigned to a class of atoms defined in\
               _refine_occupancy.class. Meaningful only for atoms with fixed\
               occupancy.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 129, 'PDBX_REFINE', 'pdbx_refine', 'N', 0, 
        '              Data items in the PDBX_REFINE category record details about \
               additional structure refinement parameters which are needed \
               to complete legacy REMARK 3 refinement templates in PDB \
               format files.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1067, 'entry_id', 'entry_id', 129, 'Y', 
        '              This data item is a pointer to _entry.id in the ENTRY category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1068, 'R_factor_all_no_cutoff', 'R_factor_all_no_cutoff', 129, 'N', 
        '              R-value (all reflections, no cutoff)  \
       Placeholder for PDB mapping of SHELXL refinement data.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1069, 'R_factor_obs_no_cutoff', 'R_factor_obs_no_cutoff', 129, 'N', 
        '              R-value (working set reflections, no cutoff)\
       Placeholder for PDB mapping of SHELXL refinement data.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1070, 'free_R_factor_4sig_cutoff', 'free_R_factor_4sig_cutoff', 129, 'N', 
        '               R free value (4 sigma cutoff). \
       Placeholder for PDB mapping of SHELXL refinement data.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1071, 'free_R_factor_no_cutoff', 'free_R_factor_no_cutoff', 129, 'N', 
        '                  Free R-value (no cutoff)\
       Placeholder for PDB mapping of SHELXL refinement data.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1072, 'free_R_val_test_set_size_perc_', 'free_R_val_test_set_size_perc_no_cutoff', 129, 'N', 
        '              Free R-value test set size (in percent, no cutoff)\
       Placeholder for PDB mapping of SHELXL refinement data.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1073, 'free_R_val_test_set_ct_no_cuto', 'free_R_val_test_set_ct_no_cutoff', 129, 'N', 
        '              Free R-value test set count (no cutoff)\
       Placeholder for PDB mapping of SHELXL refinement data.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1074, 'number_reflns_obs_no_cutoff', 'number_reflns_obs_no_cutoff', 129, 'N', 
        '              Total number of reflections (no cutoff).\
       Placeholder for PDB mapping of SHELXL refinement data.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1075, 'R_factor_all_4sig_cutoff', 'R_factor_all_4sig_cutoff', 129, 'N', 
        '              R-value (all reflections, 4 sigma cutoff)\
       Placeholder for PDB mapping of SHELXL refinement data.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1076, 'R_factor_obs_4sig_cutoff', 'R_factor_obs_4sig_cutoff', 129, 'N', 
        '              R-value (working set, 4 sigma cutoff)\
       Placeholder for PDB mapping of SHELXL refinement data.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1077, 'free_R_val_4sig_cutoff', 'free_R_val_4sig_cutoff', 129, 'N', 
        '              Free R-value (4 sigma cutoff)\
       Placeholder for PDB mapping of SHELXL refinement data.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1078, 'free2_R_val_test_set_size_perc', 'free2_R_val_test_set_size_perc_4sig_cutoff', 129, 'N', 
        '       Free R-value test set size (in percent, 4 sigma cutoff)\
       Placeholder for PDB mapping of SHELXL refinement data.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1079, 'free_R_val_test_set_ct_4sig_cu', 'free_R_val_test_set_ct_4sig_cutoff', 129, 'N', 
        '       Free R-value test set count (4 sigma cutoff)\
    Placeholder for PDB mapping of SHELXL refinement data.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1080, 'number_reflns_obs_4sig_cutoff', 'number_reflns_obs_4sig_cutoff', 129, 'N', 
        '          Total number of reflections (4 sigma cutoff).\
    Placeholder for PDB mapping of SHELXL refinement data.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 130, 'PDBX_XPLOR_FILE', 'pdbx_xplor_file', 'N', 0, 
        '         \
           Parameter and topology files used in X-PLOR/CNS refinement.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1081, 'serial_no', 'serial_no', 130, 'Y', 
        '                 Serial number.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1082, 'param_file', 'param_file', 130, 'N', 
        '                 Parameter file name in X-PLOR/CNS refinement.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1083, 'topol_file', 'topol_file', 130, 'N', 
        '                 Topology file name in X-PLOR/CNS refinement.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 131, 'PDBX_REFINE_AUX_FILE', 'pdbx_refine_aux_file', 'N', 0, 
        '         \
        Auxilary parameter and topology files used in refinement.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1084, 'serial_no', 'serial_no', 131, 'Y', 
        '                 Serial number.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1085, 'file_name', 'file_name', 131, 'N', 
        '                 Auxilary file name.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1086, 'file_type', 'file_type', 131, 'N', 
        '                 Auxilary file type.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 132, 'PDBX_REFINE_TLS', 'pdbx_refine_tls', 'N', 0, 
        '              Data items in the REFINE_TLS category record details about \
               TLS parameters used in structure refinement. Note that the\
               intention is primarily to describe directly refined TLS\
               parameters, although other methods of obtaining TLS parameters\
               may be covered, see item _pdbx_refine_tls.method'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1087, 't_0_0', 'T[1][1]', 132, 'N', 
        '             The [1][1] element of the translation tensor T. This should\
              be given in the same coordinate frame and units as the\
              corresponding anisotropic displacement parameters.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1088, 't_0_1', 'T[1][2]', 132, 'N', 
        '             The [1][2] element of the translation tensor T. This should\
              be given in the same coordinate frame and units as the\
              corresponding anisotropic displacement parameters.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1089, 't_0_2', 'T[1][3]', 132, 'N', 
        '             The [1][3] element of the translation tensor T. This should\
              be given in the same coordinate frame and units as the\
              corresponding anisotropic displacement parameters.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1090, 't_1_1', 'T[2][2]', 132, 'N', 
        '             The [2][2] element of the translation tensor T. This should\
              be given in the same coordinate frame and units as the\
              corresponding anisotropic displacement parameters.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1091, 't_1_2', 'T[2][3]', 132, 'N', 
        '             The [2][3] element of the translation tensor T. This should\
              be given in the same coordinate frame and units as the\
              corresponding anisotropic displacement parameters.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1092, 't_2_2', 'T[3][3]', 132, 'N', 
        '             The [3][3] element of the translation tensor T. This should\
              be given in the same coordinate frame and units as the\
              corresponding anisotropic displacement parameters.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1093, 't_esd_0_0', 'T[1][1]_esd', 132, 'N', 
        '              The estimated standard deviation of _pdbx_refine_tls.T[1][1].'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1094, 't_esd_0_1', 'T[1][2]_esd', 132, 'N', 
        '              The estimated standard deviation of _pdbx_refine_tls.T[1][2].'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1095, 't_esd_0_2', 'T[1][3]_esd', 132, 'N', 
        '              The estimated standard deviation of _pdbx_refine_tls.T[1][3].'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1096, 't_esd_1_1', 'T[2][2]_esd', 132, 'N', 
        '              The estimated standard deviation of _pdbx_refine_tls.T[2][2].'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1097, 't_esd_1_2', 'T[2][3]_esd', 132, 'N', 
        '              The estimated standard deviation of _pdbx_refine_tls.T[2][3].'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1098, 't_esd_2_2', 'T[3][3]_esd', 132, 'N', 
        '              The estimated standard deviation of _pdbx_refine_tls.T[3][3].'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1099, 'l_0_0', 'L[1][1]', 132, 'N', 
        '             The [1][1] element of the libration tensor L. This should\
              be given in the same coordinate frame as the\
              corresponding anisotropic displacement parameters.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1100, 'l_0_1', 'L[1][2]', 132, 'N', 
        '             The [1][2] element of the libration tensor L. This should\
              be given in the same coordinate frame as the\
              corresponding anisotropic displacement parameters.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1101, 'l_0_2', 'L[1][3]', 132, 'N', 
        '             The [1][3] element of the libration tensor L. This should\
              be given in the same coordinate frame as the\
              corresponding anisotropic displacement parameters.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1102, 'l_1_1', 'L[2][2]', 132, 'N', 
        '             The [2][2] element of the libration tensor L. This should\
              be given in the same coordinate frame as the\
              corresponding anisotropic displacement parameters.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1103, 'l_1_2', 'L[2][3]', 132, 'N', 
        '             The [2][3] element of the libration tensor L. This should\
              be given in the same coordinate frame as the\
              corresponding anisotropic displacement parameters.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1104, 'l_2_2', 'L[3][3]', 132, 'N', 
        '             The [3][3] element of the libration tensor L. This should\
              be given in the same coordinate frame as the\
              corresponding anisotropic displacement parameters.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1105, 'l_esd_0_0', 'L[1][1]_esd', 132, 'N', 
        '              The estimated standard deviation of _pdbx_refine_tls.L[1][1].'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1106, 'l_esd_0_1', 'L[1][2]_esd', 132, 'N', 
        '              The estimated standard deviation of _pdbx_refine_tls.L[1][2].'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1107, 'l_esd_0_2', 'L[1][3]_esd', 132, 'N', 
        '              The estimated standard deviation of _pdbx_refine_tls.L[1][3].'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1108, 'l_esd_1_1', 'L[2][2]_esd', 132, 'N', 
        '              The estimated standard deviation of _pdbx_refine_tls.L[2][2].'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1109, 'l_esd_1_2', 'L[2][3]_esd', 132, 'N', 
        '              The estimated standard deviation of _pdbx_refine_tls.L[2][3].'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1110, 'l_esd_2_2', 'L[3][3]_esd', 132, 'N', 
        '              The estimated standard deviation of _pdbx_refine_tls.L[3][3].'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1111, 's_0_0', 'S[1][1]', 132, 'N', 
        '             The [1][1] element of the screw-rotation tensor S. This should\
              be given in the same coordinate frame as the\
              corresponding anisotropic displacement parameters.\
\
              The trace of S is indeterminate by crystallography, and should\
              be set to zero.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1112, 's_0_1', 'S[1][2]', 132, 'N', 
        '             The [1][2] element of the screw-rotation tensor S. This should\
              be given in the same coordinate frame as the\
              corresponding anisotropic displacement parameters.\
\
               If the origin is omitted, it is assumed to be the centre of\
               reaction of the group, in which case S must be symmetric'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1113, 's_0_2', 'S[1][3]', 132, 'N', 
        '             The [1][3] element of the screw-rotation tensor S. This should\
              be given in the same coordinate frame as the\
              corresponding anisotropic displacement parameters.\
\
               If the origin is omitted, it is assumed to be the centre of\
               reaction of the group, in which case S must be symmetric'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1114, 's_1_1', 'S[2][2]', 132, 'N', 
        '             The [2][2] element of the screw-rotation tensor S. This should\
              be given in the same coordinate frame as the\
              corresponding anisotropic displacement parameters.\
\
              The trace of S is indeterminate by crystallography, and should\
              be set to zero.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1115, 's_1_2', 'S[2][3]', 132, 'N', 
        '             The [2][3] element of the screw-rotation tensor S. This should\
              be given in the same coordinate frame as the\
              corresponding anisotropic displacement parameters.\
\
               If the origin is omitted, it is assumed to be the centre of\
               reaction of the group, in which case S must be symmetric'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1116, 's_2_2', 'S[3][3]', 132, 'N', 
        '             The [3][3] element of the screw-rotation tensor S. This should\
              be given in the same coordinate frame as the\
              corresponding anisotropic displacement parameters.\
\
              The trace of S is indeterminate by crystallography, and should\
              be set to zero.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1117, 's_esd_0_0', 'S[1][1]_esd', 132, 'N', 
        '              The estimated standard deviation of _pdbx_refine_tls.S[1][1].'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1118, 's_esd_0_1', 'S[1][2]_esd', 132, 'N', 
        '              The estimated standard deviation of _pdbx_refine_tls.S[1][2].'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1119, 's_esd_0_2', 'S[1][3]_esd', 132, 'N', 
        '              The estimated standard deviation of _pdbx_refine_tls.S[1][3].'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1120, 's_esd_1_1', 'S[2][2]_esd', 132, 'N', 
        '              The estimated standard deviation of _pdbx_refine_tls.S[2][2].'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1121, 's_esd_1_2', 'S[2][3]_esd', 132, 'N', 
        '              The estimated standard deviation of _pdbx_refine_tls.S[2][3].'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1122, 's_esd_2_2', 'S[3][3]_esd', 132, 'N', 
        '              The estimated standard deviation of _pdbx_refine_tls.S[3][3].'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 133, 'PDBX_REFINE_TLS_GROUP', 'pdbx_refine_tls_group', 'N', 0, 
        '              Data items in the PDBX_REFINE_TLS_GROUP category record details about\
               a fragment of a TLS group.\
\
               Properties of the TLS group are recorded in PDBX_REFINE_TLS'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1123, 'id', 'id', 133, 'Y', 
        '              The value of _pdbx_refine_tls_group.id must uniquely identify \
               a record in the REFINE_TLS_GROUP list.\
               Note that this item need not be a number; it can be any unique\
               identifier.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1124, 'refine_tls_id', 'refine_tls_id', 133, 'Y', 
        '              This data item is a pointer to _pdbx_refine_tls.id in the\
               REFINE_TLS category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1125, 'selection  ', 'selection  ', 133, 'N', 
        '              A description of the subset of atoms in the specified\
               range included in the TLS fragment.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 134, 'REFLN', 'refln', 'N', 0, 
        '              Data items in the REFLN category record details about the\
               reflection data used to determine the ATOM_SITE data items.\
\
               The REFLN data items refer to individual reflections and must\
               be included in looped lists.\
\
               The REFLNS data items specify the parameters that apply to all\
               reflections. The REFLNS data items are not looped.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1126, 'a_calc', 'a_calc', 134, 'N', 
        '              The calculated value of structure-factor component A, in\
               electrons.\
\
               A = |F|cos(phase)'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1127, 'a_calc_au', 'a_calc_au', 134, 'N', 
        '              The calculated value of structure-factor component A, in\
               arbitrary units.\
\
               A = |F|cos(phase)'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1128, 'a_meas', 'a_meas', 134, 'N', 
        '              The measured value of structure-factor component A, in electrons.\
\
               A = |F|cos(phase)'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1129, 'a_meas_au', 'a_meas_au', 134, 'N', 
        '              The measured value of structure-factor component A, in\
               arbitrary units.\
\
               A = |F|cos(phase)'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1130, 'b_calc', 'b_calc', 134, 'N', 
        '              The calculated value of structure-factor component B, in\
               electrons.\
\
               B = |F|sin(phase)'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1131, 'b_calc_au', 'b_calc_au', 134, 'N', 
        '              The calculated value of structure-factor component B, in\
               arbitrary units.\
\
               B = |F|sin(phase)'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1132, 'b_meas', 'b_meas', 134, 'N', 
        '              The measured value of structure-factor component B, in electrons.\
\
               B = |F|sin(phase)'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1133, 'b_meas_au', 'b_meas_au', 134, 'N', 
        '              The measured value of structure-factor component B, in\
               arbitrary units.\
\
               B = |F|sin(phase)'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1134, 'f_calc', 'f_calc', 134, 'N', 
        '              The calculated value of the structure factor in electrons.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1135, 'f_calc_au', 'f_calc_au', 134, 'N', 
        '              The calculated value of the structure factor in arbitrary\
               units.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1136, 'f_meas', 'f_meas', 134, 'N', 
        '              The measured value of the structure factor in electrons.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1137, 'f_meas_au', 'f_meas_au', 134, 'N', 
        '              The measured value of the structure factor in arbitrary units.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1138, 'f_meas_sigma', 'f_meas_sigma', 134, 'N', 
        '              The standard uncertainty (e.s.d.) of _refln.F_meas, in\
               electrons.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1139, 'f_meas_sigma_au', 'f_meas_sigma_au', 134, 'N', 
        '              The standard uncertainty (e.s.d.) of _refln.F_meas_au, in\
               arbitrary units.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1140, 'f_squared_calc', 'f_squared_calc', 134, 'N', 
        '              The calculated value of the squared structure factor, in\
               electrons squared.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1141, 'f_squared_meas', 'f_squared_meas', 134, 'N', 
        '              The measured value of the squared structure factor, in electrons\
               squared.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1142, 'f_squared_sigma', 'f_squared_sigma', 134, 'N', 
        '              The standard uncertainty (derived from measurement) of the\
               squared structure factor, in electrons squared.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1143, 'fom', 'fom', 134, 'N', 
        '              The figure of merit m for this reflection.\
\
                   int P~alpha~ exp(i*alpha) dalpha\
               m = --------------------------------\
                         int P~alpha~ dalpha\
\
               P~a~ = the probability that phase angle a is correct\
\
               int is taken over the range alpha = 0 to 2 pi.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1144, 'intensity_calc', 'intensity_calc', 134, 'N', 
        '              The calculated value of the intensity, in the measured units.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1145, 'intensity_meas', 'intensity_meas', 134, 'N', 
        '              The measured value of the intensity, in the measured units.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1146, 'intensity_sigma', 'intensity_sigma', 134, 'N', 
        '              The standard uncertainty (derived from measurement) of the\
               intensity, in the measured units.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1147, 'mean_path_length_tbar', 'mean_path_length_tbar', 134, 'N', 
        '              Mean path length in millimetres through the crystal for this\
               reflection.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1148, 'status', 'status', 134, 'N', 
        '              Classification of a reflection so as to indicate its status with\
               respect to inclusion in refinement and calculation of R factors.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1149, 'phase_calc', 'phase_calc', 134, 'N', 
        '              The calculated structure-factor phase in degrees.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1150, 'phase_meas', 'phase_meas', 134, 'N', 
        '              The measured structure-factor phase in degrees.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1151, 'refinement_status', 'refinement_status', 134, 'N', 
        '              Status of reflection in the structure refinement process.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1152, 'sint_over_lambda', 'sint_over_lambda', 134, 'N', 
        '              The (sin theta)/lambda value in reciprocal angstroms for this\
               reflection.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1153, 'symmetry_epsilon', 'symmetry_epsilon', 134, 'N', 
        '              The symmetry reinforcement factor corresponding to the number of\
               times the reflection indices are generated identically from the\
               space-group symmetry operations.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1154, 'symmetry_multiplicity', 'symmetry_multiplicity', 134, 'N', 
        '              The number of symmetry-equivalent reflections. The equivalent\
               reflections have the same structure-factor magnitudes because\
               of the space-group symmetry and the Friedel relationship.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1155, 'wavelength', 'wavelength', 134, 'N', 
        '              The mean wavelength in angstroms of radiation used to measure\
               this reflection. This is an important parameter for data\
               collected using energy-dispersive detectors or the Laue\
               method.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1156, 'pdbx_F_calc_part_solvent', 'pdbx_F_calc_part_solvent', 134, 'N', 
        '              The calculated value of the structure factor in arbitrary\
               units reflecting only the contribution of the solvent model.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1157, 'pdbx_phase_calc_part_solvent', 'pdbx_phase_calc_part_solvent', 134, 'N', 
        '              The calculated structure-factor phase in degrees reflecting\
               only the contribution of the solvent model.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1158, 'pdbx_F_calc_with_solvent', 'pdbx_F_calc_with_solvent', 134, 'N', 
        '              The calculated value of the structure factor in arbitrary\
               units including the contribution of the solvent model.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1159, 'pdbx_phase_calc_with_solvent', 'pdbx_phase_calc_with_solvent', 134, 'N', 
        '              The calculated structure-factor phase in degrees including\
               the contribution of the solvent model.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 135, 'REFLNS', 'reflns', 'N', 0, 
        '              Data items in the REFLNS category record details about the\
               reflection data used to determine the ATOM_SITE data items.\
\
               The REFLN data items refer to individual reflections and must\
               be included in looped lists.\
\
               The REFLNS data items specify the parameters that apply to all\
               reflections. The REFLNS data items are not looped.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1160, 'b_iso_wilson_estimate', 'b_iso_wilson_estimate', 135, 'N', 
        '              The value of the overall isotropic temperature factor estimated\
               from the slope of the Wilson plot.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1161, 'entry_id', 'entry_id', 135, 'Y', 
        '              This data item is a pointer to _entry.id in the ENTRY category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1162, 'data_reduction_details', 'data_reduction_details', 135, 'N', 
        '              A description of special aspects of the data reduction\
               procedures.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1163, 'data_reduction_method', 'data_reduction_method', 135, 'N', 
        '              The method used in reducing the data.\
\
               Note that this is not the computer program used, which is\
               described in the SOFTWARE category, but that the method\
               itself.\
\
               This data item should be used to describe significant\
               methodological options used within the data reduction programs.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1164, 'd_resolution_high', 'd_resolution_high', 135, 'N', 
        '              The highest resolution for the interplanar spacings in\
               the reflection data. This is the smallest d value.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1165, 'd_resolution_low', 'd_resolution_low', 135, 'N', 
        '              The lowest resolution for the interplanar spacings in the\
               reflection data. This is the largest d value.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1166, 'details', 'details', 135, 'N', 
        '              A description of reflection data not covered by the other data\
               names. It should include details of the Friedel pairs.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1167, 'number_all', 'number_all', 135, 'N', 
        '              The total number of reflections in the REFLN list (not the\
               DIFFRN_REFLN list). This number may contain Friedel equivalent\
               reflections according to the nature of the structure and the\
               procedures used. The item _reflns.details describes the\
               reflection data.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1168, 'number_obs', 'number_obs', 135, 'N', 
        '              The number of reflections in the REFLN list (not the DIFFRN_REFLN\
               list) classified as observed (see _reflns.observed_criterion).\
               This number may contain Friedel equivalent reflections according\
               to the nature of the structure and the procedures used.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1169, 'observed_criterion', 'observed_criterion', 135, 'N', 
        '              The criterion used to classify a reflection as ''observed''. This\
               criterion is usually expressed in terms of a sigma(I) or\
               sigma(F) threshold.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1170, 'observed_criterion_F_max', 'observed_criterion_F_max', 135, 'N', 
        '              The criterion used to classify a reflection as ''observed'',\
               expressed as a upper limit in the value of F.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1171, 'observed_criterion_F_min', 'observed_criterion_F_min', 135, 'N', 
        '              The criterion used to classify a reflection as ''observed'',\
               expressed as a lower limit in the value of F.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1172, 'observed_criterion_I_max', 'observed_criterion_I_max', 135, 'N', 
        '              The criterion used to classify a reflection as ''observed'',\
               expressed as a upper limit in the value of I.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1173, 'observed_criterion_I_min', 'observed_criterion_I_min', 135, 'N', 
        '              The criterion used to classify a reflection as ''observed'',\
               expressed as a lower limit in the value of I.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1174, 'observed_criterion_sigma_F', 'observed_criterion_sigma_F', 135, 'N', 
        '              The criterion used to classify a reflection as ''observed'',\
               expressed as a multiple of the value of sigma(F).'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1175, 'observed_criterion_sigma_I', 'observed_criterion_sigma_I', 135, 'N', 
        '              The criterion used to classify a reflection as ''observed'',\
               expressed as a multiple of the value of sigma(I).  '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1176, 'percent_possible_obs', 'percent_possible_obs', 135, 'N', 
        '              The percentage of geometrically possible reflections represented\
               by reflections that satisfy the resolution limits established\
               by _reflns.d_resolution_high and _reflns.d_resolution_low and\
               the observation limit established by \
               _reflns.observed_criterion.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1177, 'r_free_details', 'r_free_details', 135, 'N', 
        '              A description of the method by which a subset of reflections was\
               selected for exclusion from refinement so as to be used in the\
               calculation of a "free" R factor.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1178, 'rmerge_f_all', 'rmerge_f_all', 135, 'N', 
        '              Residual factor Rmerge for all reflections that satisfy the\
               resolution limits established by _reflns.d_resolution_high \
               and _reflns.d_resolution_low.\
\
                           sum~i~(sum~j~|F~j~ - <F>|)\
               Rmerge(F) = --------------------------\
                                sum~i~(sum~j~<F>)\
\
               F~j~ = the amplitude of the jth observation of reflection i\
               <F>  = the mean of the amplitudes of all observations of\
                      reflection i\
\
               sum~i~ is taken over all reflections\
               sum~j~ is taken over all observations of each reflection'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1179, 'rmerge_f_obs', 'rmerge_f_obs', 135, 'N', 
        '              Residual factor Rmerge for reflections that satisfy the\
               resolution limits established by _reflns.d_resolution_high\
               and _reflns.d_resolution_low and the observation limit\
               established by _reflns.observed_criterion.\
\
                           sum~i~(sum~j~|F~j~ - <F>|)\
               Rmerge(F) = --------------------------\
                                sum~i~(sum~j~<F>)\
\
               F~j~ = the amplitude of the jth observation of reflection i\
               <F>  = the mean of the amplitudes of all observations of\
                      reflection i\
\
               sum~i~ is taken over all reflections\
               sum~j~ is taken over all observations of each reflection'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1180, 'pdbx_redundancy', 'pdbx_redundancy', 135, 'N', 
        '            Overall redundancy.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1181, 'pdbx_Rmerge_I_obs', 'pdbx_Rmerge_I_obs', 135, 'N', 
        ''
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1182, 'pdbx_Rsym_value', 'pdbx_Rsym_value', 135, 'N', 
        '              R Sym value in percent.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1183, 'pdbx_netI_over_av_sigmaI', 'pdbx_netI_over_av_sigmaI', 135, 'N', 
        '           Overall  <I/sigma(I)>'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1184, 'pdbx_chi_squared', 'pdbx_chi_squared', 135, 'N', 
        '           Overall  Chi-squared statistic.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1185, 'pdbx_scaling_rejects', 'pdbx_scaling_rejects', 135, 'N', 
        '              Number of reflections rejected in scaling operations.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1186, 'pdbx_d_res_high_opt', 'pdbx_d_res_high_opt', 135, 'N', 
        '              The highest optical resolution for this reflection data set\
               as determined by computational method _reflns.pdbx_d_res_opt_method.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1187, 'pdbx_d_res_low_opt', 'pdbx_d_res_low_opt', 135, 'N', 
        '              The lowest optical resolution for this reflection data set \
               as determined by computational method _reflns.pdbx_d_res_opt_method.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1188, 'pdbx_d_res_opt_method', 'pdbx_d_res_opt_method', 135, 'N', 
        '              The computational method used to determine the optical \
               resolution limits _reflns.pdbx_d_res_high_opt and \
               _reflns.pdbx_d_res_low_opt.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 136, 'REFLNS_SCALE', 'reflns_scale', 'N', 0, 
        '              Data items in the REFLNS_SCALE category record details about\
               the structure factor scales. They are referenced from within\
               the REFLN list through _refln.scale_group_code.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1189, 'group_code', 'group_code', 136, 'Y', 
        '              The code identifying a scale _reflns_scale.meas_F, \
               _reflns_scale.meas_F_squared or _reflns_scale.meas_intensity.\
               These are linked to the REFLN list by the\
               _refln.scale_group_code.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1190, 'meas_f', 'meas_f', 136, 'N', 
        '              A scale associated with _reflns_scale.group_code. These codes\
               may not correspond to those in the DIFFRN_SCALE list.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1191, 'meas_f_squared', 'meas_f_squared', 136, 'N', 
        '              A scale associated with _reflns_scale.group_code. These codes\
               may not correspond to those in the DIFFRN_SCALE list.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1192, 'meas_intensity', 'meas_intensity', 136, 'N', 
        '              A scale associated with _reflns_scale.group_code. These codes\
               may not correspond to those in the DIFFRN_SCALE list.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 137, 'REFLNS_SHELL', 'reflns_shell', 'N', 0, 
        '              Data items in the REFLNS_SHELL category record details about\
               the reflection data used to determine the ATOM_SITE data items,\
               as broken down by shells of resolution.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1193, 'd_res_high', 'd_res_high', 137, 'Y', 
        '              The highest resolution in angstroms for the interplanar spacing\
               in the reflections in this shell. This is the smallest d value.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1194, 'd_res_low', 'd_res_low', 137, 'Y', 
        '              The lowest resolution in angstroms for the interplanar spacing\
               in the reflections in this shell. This is the largest d value.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1195, 'mean_i_over_sig_i_all', 'mean_i_over_sig_i_all', 137, 'N', 
        '              The ratio of the mean of the intensities of all reflections\
               in this shell to the mean of the standard uncertainties of the\
               intensities of all reflections in the resolution shell.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1196, 'mean_i_over_sig_i_obs', 'mean_i_over_sig_i_obs', 137, 'N', 
        '              The ratio of the mean of the intensities of the reflections\
               classified as ''observed'' (see _reflns.observed_criterion) in\
               this shell to the mean of the standard uncertainties of the\
               intensities of the ''observed'' reflections in the resolution\
               shell.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1197, 'number_measured_all', 'number_measured_all', 137, 'N', 
        '              The total number of reflections measured for this resolution\
               shell.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1198, 'number_measured_obs', 'number_measured_obs', 137, 'N', 
        '              The number of reflections classified as ''observed''\
               (see _reflns.observed_criterion) measured for this\
               resolution shell.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1199, 'number_possible', 'number_possible', 137, 'N', 
        '              The number of unique reflections it is possible to measure in\
               this reflection shell.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1200, 'number_unique_all', 'number_unique_all', 137, 'N', 
        '              The total number of measured reflections which are symmetrically\
               unique after merging for this resolution shell.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1201, 'number_unique_obs', 'number_unique_obs', 137, 'N', 
        '              The total number of measured reflections classified as ''observed''\
               (see _reflns.observed_criterion) which are symmetrically unique\
               after merging for this resolution shell.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1202, 'percent_possible_all', 'percent_possible_all', 137, 'N', 
        '              The percentage of geometrically possible reflections represented\
               by all reflections measured for this resolution shell.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1203, 'percent_possible_obs', 'percent_possible_obs', 137, 'N', 
        '              The percentage of geometrically possible reflections represented\
               by reflections classified as ''observed'' (see\
               _reflns.observed_criterion) measured for this resolution shell.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1204, 'rmerge_f_all', 'rmerge_f_all', 137, 'N', 
        '              Residual factor Rmerge for all reflections that satisfy the\
               resolution limits established by _reflns_shell.d_res_high and\
               _reflns_shell.d_res_low.\
\
                           sum~i~(sum~j~|F~j~ - <F>|)\
               Rmerge(F) = --------------------------\
                                sum~i~(sum~j~<F>)\
\
               F~j~ = the amplitude of the jth observation of reflection i\
               <F>  = the mean of the amplitudes of all observations of\
                      reflection i\
\
               sum~i~ is taken over all reflections\
               sum~j~ is taken over all observations of each reflection'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1205, 'rmerge_f_obs', 'rmerge_f_obs', 137, 'N', 
        '              Residual factor Rmerge for reflections that satisfy the\
               resolution limits established by _reflns_shell.d_res_high and\
               _reflns_shell.d_res_low and the observation criterion\
               established by _reflns.observed_criterion.\
\
                           sum~i~(sum~j~|F~j~ - <F>|)\
               Rmerge(F) = --------------------------\
                                sum~i~(sum~j~<F>)\
\
               F~j~ = the amplitude of the jth observation of reflection i\
               <F>  = the mean of the amplitudes of all observations of\
                      reflection i\
\
               sum~i~ is taken over all reflections\
               sum~j~ is taken over all observations of each reflection'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1206, 'rmerge_i_all', 'rmerge_i_all', 137, 'N', 
        '              The value of Rmerge(I) for all reflections in a given shell.\
\
                           sum~i~(sum~j~|I~j~ - <I>|)\
               Rmerge(I) = --------------------------\
                               sum~i~(sum~j~<I>)\
\
               I~j~ = the intensity of the jth observation of reflection i\
               <I>  = the mean of the intensities of all observations of\
                      reflection i\
\
               sum~i~ is taken over all reflections\
               sum~j~ is taken over all observations of each reflection\
'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1207, 'rmerge_i_obs', 'rmerge_i_obs', 137, 'N', 
        '              The value of Rmerge(I) for reflections classified as ''observed''\
               (see _reflns.observed_criterion) in a given shell.\
\
                           sum~i~(sum~j~|I~j~ - <I>|)\
               Rmerge(I) = --------------------------\
                               sum~i~(sum~j~<I>)\
\
               I~j~ = the intensity of the jth observation of reflection i\
               <I>  = the mean of the intensities of all observations of\
                      reflection i\
\
               sum~i~ is taken over all reflections\
               sum~j~ is taken over all observations of each reflection'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1208, 'pdbx_redundancy', 'pdbx_redundancy', 137, 'N', 
        '        Redundancy for the current shell.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1209, 'pdbx_Rsym_value', 'pdbx_Rsym_value', 137, 'N', 
        '              R sym value in percent.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1210, 'pdbx_chi_squared', 'pdbx_chi_squared', 137, 'N', 
        '          Chi-squared statistic for this resolution shell.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 138, 'SYMMETRY', 'symmetry', 'N', 0, 
        '              Data items in the SYMMETRY category record details about the\
               space-group symmetry.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1211, 'entry_id', 'entry_id', 138, 'Y', 
        '              This data item is a pointer to _entry.id in the ENTRY category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1212, 'cell_setting', 'cell_setting', 138, 'N', 
        '              The cell settings for this space-group symmetry.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1213, 'int_tables_number', 'int_tables_number', 138, 'N', 
        '              Space-group number from International Tables for Crystallography,\
               Vol. A (1987).'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1214, 'space_group_name_hall', 'space_group_name_hall', 138, 'N', 
        '              Space-group symbol as described by Hall. This symbol gives the\
               space-group setting explicitly. Leave spaces between the separate\
               components of the symbol.\
\
               Ref: Hall, S. R. (1981). Acta Cryst. A37, 517-525.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1215, 'space_group_name_h_m', 'space_group_name_h_m', 138, 'N', 
        '              Hermann-Mauguin space-group symbol. Note that the H-M symbol does\
               not necessarily contain complete information about the symmetry\
               and the space-group origin. If used always supply the FULL symbol\
               from International Tables for Crystallography, Vol. A (1987) and\
               indicate the origin and the setting if it is not implicit. If\
               there is any doubt that the equivalent positions can be uniquely\
               deduced from this symbol specify the _symmetry_equiv.pos_as_xyz\
               or _symmetry.space_group_name_Hall data items as well. Leave\
               spaces between symbols referring to different axes.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1216, 'pdbx_full_space_group_name_h_m', 'pdbx_full_space_group_name_h_m', 138, 'N', 
        '              Used for PDB space group:\
\
               Example: ''C 1 2 1''  (instead of C 2)\
                        ''P 1 2 1''  (instead of P 2)\
                        ''P 1 21 1'' (instead of P 21) \
                        ''P 1 1 21'' (instead of P 21 -unique C axis)\
                        ''H 3''      (instead of R 3   -hexagonal)\
                        ''H 3 2''    (instead of R 3 2 -hexagonal)\
 '
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 139, 'SYMMETRY_EQUIV', 'symmetry_equiv', 'N', 0, 
        '              Data items in the SYMMETRY_EQUIV category list the\
               symmetry equivalent positions for the space group.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1217, 'id', 'id', 139, 'Y', 
        '              The value of _symmetry_equiv.id must uniquely identify\
               a record in the SYMMETRY_EQUIV category.\
\
               Note that this item need not be a number; it can be any unique\
               identifier.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1218, 'pos_as_xyz', 'pos_as_xyz', 139, 'N', 
        '              Symmetry equivalent position in the ''xyz'' representation. Except\
               for the space group P1, these data are repeated in a loop.\
               The format of the data item is as per International Tables for\
               Crystallography, Vol. A. (1987). All equivalent positions should\
               be entered, including those for lattice centring and a centre of\
               symmetry, if present.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 140, 'PDBX_NMR_DETAILS', 'pdbx_nmr_details', 'N', 0, 
        '\
Experimental details of the NMR study that have not been \
described elsewhere in this deposition.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1219, 'entry_id', 'entry_id', 140, 'Y', 
        '  The entry ID for the structure determination.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1220, 'text', 'text', 140, 'N', 
        '   Additional details describing the NMR experiment.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 141, 'PDBX_NMR_SAMPLE_DETAILS', 'pdbx_nmr_sample_details', 'N', 0, 
        '   \
Complete description of each NMR sample, including the solvent\
system used.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1221, 'solution_id', 'solution_id', 141, 'Y', 
        '   \
The name (number) of the sample.     '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1222, 'contents', 'contents', 141, 'N', 
        '   \
A complete description of each NMR sample. Include the concentration \
and concentration units for each component (include buffers, etc.). For each\
component describe the isotopic composition, including the % labeling level,\
if known. \
\
For example:\
1. Uniform (random) labeling with 15N: U-15N\
2. Uniform (random) labeling with 13C, 15N at known labeling\
   levels: U-95% 13C;U-98% 15N\
3. Residue selective labeling: U-95% 15N-Thymine\
4. Site specific labeling: 95% 13C-Ala18,\
5. Natural abundance labeling in an otherwise uniformly labeled\
   biomolecule is designated by NA: U-13C; NA-K,H\
  '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1223, 'solvent_system', 'solvent_system', 141, 'N', 
        '   \
The solvent system used for this sample.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 142, 'PDBX_NMR_EXPTL_SAMPLE', 'pdbx_nmr_exptl_sample', 'N', 0, 
        '   The chemical constituents of\
    each NMR sample. Each sample is identified by a number and \
    each component in the sample is identified by name.   '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1224, 'solution_id', 'solution_id', 142, 'N', 
        '   The name (number) of the sample.     '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1225, 'component_name', 'component_name', 142, 'N', 
        '   The name of each component in the sample   '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1226, 'concentration', 'concentration', 142, 'N', 
        '   The concentration value of the component.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1227, 'concentration_units', 'concentration_units', 142, 'N', 
        '   The concentration units of the component.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1228, 'isotopic_labeling', 'isotopic_labeling', 142, 'N', 
        '   The isotopic composition of each component, including\
    the % labeling level, if known. For example:\
    1. Uniform (random) labeling with 15N: U-15N\
    2. Uniform (random) labeling with 13C, 15N at known labeling\
     levels: U-95% 13C;U-98% 15N\
    3. Residue selective labeling: U-95% 15N-Thymine\
    4. Site specific labeling: 95% 13C-Ala18,\
    5. Natural abundance labeling in an otherwise uniformly labled\
      biomolecule is designated by NA: U-13C; NA-K,H '
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 143, 'PDBX_NMR_EXPTL_SAMPLE_CONDITIONS', 'pdbx_nmr_exptl_sample_conditions', 'N', 0, 
        '   \
The experimental conditions used to for each sample.  Each set of conditions\
is identified by a numerical code.  '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1229, 'conditions_id', 'conditions_id', 143, 'N', 
        '   The condition number as defined above.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1230, 'temperature', 'temperature', 143, 'N', 
        '   The temperature (in Kelvin) at which NMR data were\
    collected.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1231, 'pressure_units', 'pressure_units', 143, 'N', 
        '   The units of pressure at which NMR data were collected.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1232, 'pressure', 'pressure', 143, 'N', 
        '   The pressure at which NMR data were collected.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1233, 'pH', 'pH', 143, 'N', 
        '   The pH at which the NMR data were collected.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1234, 'ionic_strength', 'ionic_strength', 143, 'N', 
        '   The ionic strength at which the NMR data were collected -in lieu of\
    this enter the concentration and identity of the salt in the sample.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 144, 'PDBX_NMR_SPECTROMETER', 'pdbx_nmr_spectrometer', 'N', 0, 
        '   \
The details about each spectrometer used to collect data for this \
deposition.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1235, 'spectrometer_id', 'spectrometer_id', 144, 'N', 
        '   \
Assign a numerical ID to each instrument.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1236, 'model', 'model', 144, 'N', 
        '   \
The model of the NMR spectrometer.    '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1237, 'type', 'type', 144, 'N', 
        '   \
Select the instrument manufacturer(s) and the model(s) of the NMR(s)\
used for this work.    '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1238, 'manufacturer', 'manufacturer', 144, 'N', 
        '\
The name of the manufacturer of the spectrometer. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1239, 'field_strength', 'field_strength', 144, 'N', 
        '            \
Select the field strength for protons in MHz.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 145, 'PDBX_NMR_EXPTL', 'pdbx_nmr_exptl', 'N', 0, 
        '\
In this section, enter information on those experiments that were \
used to generate constraint data. For each NMR experiment indicate \
which sample and which sample conditions were used for the experiment.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1240, 'experiment_id', 'experiment_id', 145, 'N', 
        '   A numerical ID for each experiment.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1241, 'conditions_id', 'conditions_id', 145, 'N', 
        ' The number to identify the set of sample conditions.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1242, 'solution_id', 'solution_id', 145, 'N', 
        '   The solution_id from the Experimental Sample to identify the sample\
    that these conditions refer to. \
\
    [Remember to save the entries here before returning to the \
     Experimental Sample form]'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1243, 'type', 'type', 145, 'N', 
        '   The type of NMR experiment.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 146, 'PDBX_NMR_SOFTWARE', 'pdbx_nmr_software', 'N', 0, 
        ' \
Description of the software that was used for data collection, data processing, \
data analysis, structure calculations and refinement. The description should \
include the name of the software, the author of the software and the version used.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1244, 'classification', 'classification', 146, 'Y', 
        '  The purpose of the software.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1245, 'name', 'name', 146, 'N', 
        '   The name of the software used for the task.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1246, 'version', 'version', 146, 'N', 
        '   The version of the software.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1247, 'authors', 'authors', 146, 'N', 
        '   The name of the authors of the software used in this\
    procedure.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 147, 'PDBX_NMR_CONSTRAINTS', 'pdbx_nmr_constraints', 'N', 0, 
        '   This section provides a tabulation of constraint data. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1248, 'entry_id', 'entry_id', 147, 'N', 
        '   You can leave this blank as an ID will be assigned by the MSD \
    to the constraint file.     '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1249, 'NOE_constraints_total', 'NOE_constraints_total', 147, 'N', 
        '   The total number of all NOE constraints used in the final\
    structure calculation.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1250, 'NOE_intraresidue_total_count', 'NOE_intraresidue_total_count', 147, 'N', 
        '   The total number of all intraresidue, [i-j]=0, NOE constraints \
    used in the final structure calculation.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1251, 'NOE_interentity_total_count', 'NOE_interentity_total_count', 147, 'N', 
        '   The total number of interentity, NOE constraints \
    used in the final structure calculation. This field should only be\
    if system is complex -i.e more than one entity e.g. a dimer or ligand-protein \
    complex'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1252, 'NOE_sequential_total_count', 'NOE_sequential_total_count', 147, 'N', 
        '   The total number of sequential, [i-j]=1, NOE constraints used \
    in the final structure calculation.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1253, 'NOE_medium_range_total_count', 'NOE_medium_range_total_count', 147, 'N', 
        '   The total number of medium range 1<[i-j]<=5 NOE constraints used \
    in the final structure calculation.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1254, 'NOE_long_range_total_count', 'NOE_long_range_total_count', 147, 'N', 
        '   The total number of long range [i-j]>5 NOE constraints used \
    in the final structure calculation.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1255, 'protein_phi_angle_constraints_', 'protein_phi_angle_constraints_total_count', 147, 'N', 
        '   The total number of phi angle constraints used in the final structure\
    calculation'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1256, 'protein_psi_angle_constraints_', 'protein_psi_angle_constraints_total_count', 147, 'N', 
        '   The total number of psi angle constraints used in the final structure\
    calculation.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1257, 'protein_chi_angle_constraints_', 'protein_chi_angle_constraints_total_count', 147, 'N', 
        '   The total number of chi angle constraints used in the final structure\
    calculation.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1258, 'protein_other_angle_constraint', 'protein_other_angle_constraints_total_count', 147, 'N', 
        '   The total number of other angle constraints used in the final structure\
  calculation.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1259, 'NOE_interproton_distance_evalu', 'NOE_interproton_distance_evaluation', 147, 'N', 
        '   Describe the method used to quantify the NOE and ROE values.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1260, 'NOE_pseudoatom_corrections', 'NOE_pseudoatom_corrections', 147, 'N', 
        '   Describe any corrections made for pseudoatoms'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1261, 'NOE_motional_averaging_correct', 'NOE_motional_averaging_correction', 147, 'N', 
        'Describe any corrections that were made to the NOE data for motional averaging.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1262, 'hydrogen_bond_constraints_tota', 'hydrogen_bond_constraints_total_count', 147, 'N', 
        '  The total number of hydrogen bond constraints used in the final\
   structure calculation. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1263, 'disulfide_bond_constraints_tot', 'disulfide_bond_constraints_total_count', 147, 'N', 
        '  The total number of disulfide bond constraints used in the final\
   structure calculation. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1264, 'NA_alpha_angle_constraints_tot', 'NA_alpha_angle_constraints_total_count ', 147, 'N', 
        '  The total number of nucleic acid alpha-angle constraints used in\
   the final structure calculation.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1265, 'NA_beta_angle_constraints_tota', 'NA_beta_angle_constraints_total_count', 147, 'N', 
        '  The total number of nucleic acid beta-angle constraints used in\
   the final structure calculation.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1266, 'NA_gamma_angle_constraints_tot', 'NA_gamma_angle_constraints_total_count', 147, 'N', 
        '  The total number of nucleic acid gamma-angle constraints used in\
   the final structure calculation. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1267, 'NA_delta_angle_constraints_tot', 'NA_delta_angle_constraints_total_count', 147, 'N', 
        '  The total number of nucleic acid delta-angle constraints used in\
   the final structure calculation. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1268, 'NA_epsilon_angle_constraints_t', 'NA_epsilon_angle_constraints_total_count', 147, 'N', 
        '  The total number of nucleic acid epsilon-angle constraints used\
   in the final structure calculation. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1269, 'NA_chi_angle_constraints_total', 'NA_chi_angle_constraints_total_count', 147, 'N', 
        '  The total number of nucleic acid chi-angle constraints used\
   in the final structure calculation. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1270, 'NA_other_angle_constraints_tot', 'NA_other_angle_constraints_total_count', 147, 'N', 
        '  The total number of nucleic acid other-angle constraints used\
   in the final structure calculation. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1271, 'NA_sugar_pucker_constraints_to', 'NA_sugar_pucker_constraints_total_count', 147, 'N', 
        '  The total number of nucleic acid sugar pucker constraints used\
   in the final structure calculation. '
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 148, 'PDBX_NMR_ENSEMBLE', 'pdbx_nmr_ensemble', 'N', 0, 
        '   This category contains the information that describes the \
    ensemble of deposited structures. If only an average structure \
    has been deposited skip this section. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1272, 'entry_id', 'entry_id', 148, 'N', 
        '   Leave this blank as the ID is provided by the MSD'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1273, 'conformers_calculated_total_nu', 'conformers_calculated_total_number', 148, 'N', 
        '   The total number of conformer (models) that were calculated in the final round.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1274, 'conformers_submitted_total_num', 'conformers_submitted_total_number', 148, 'N', 
        '   The number of conformer (models) that are submitted for the ensemble.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1275, 'conformer_selection_criteria', 'conformer_selection_criteria', 148, 'N', 
        '   \
By highlighting the appropriate choice(s), describe how the submitted \
conformer (models) were selected.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1276, 'representative_conformer', 'representative_conformer', 148, 'N', 
        '   The number of the conformer identified as most representative.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1277, 'average_constraints_per_residu', 'average_constraints_per_residue', 148, 'N', 
        '   The average number of constraints per residue for the ensemble'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1278, 'average_constraint_violations_', 'average_constraint_violations_per_residue', 148, 'N', 
        '   The average number of constraint violations on a per residue basis for\
    the ensemble. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1279, 'maximum_distance_constraint_vi', 'maximum_distance_constraint_violation', 148, 'N', 
        '   The maximum distance constraint violation for the ensemble.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1280, 'average_distance_constraint_vi', 'average_distance_constraint_violation', 148, 'N', 
        '   The average distance restraint violation for the ensemble.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1281, 'maximum_upper_distance_constra', 'maximum_upper_distance_constraint_violation', 148, 'N', 
        '   The maximum upper distance constraint violation for the ensemble.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1282, 'maximum_lower_distance_constra', 'maximum_lower_distance_constraint_violation', 148, 'N', 
        '   The maximum lower distance constraint violation for the ensemble.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1283, 'distance_constraint_violation_', 'distance_constraint_violation_method', 148, 'N', 
        '   Describe the method used to calculate the distance constraint violation statistics,\
    i.e. are they calculated over all the distance constraints or calculated for\
    violations only?'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1284, 'maximum_torsion_angle_constrai', 'maximum_torsion_angle_constraint_violation', 148, 'N', 
        '   The maximum torsion angle constraint violation for the ensemble.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1285, 'average_torsion_angle_constrai', 'average_torsion_angle_constraint_violation', 148, 'N', 
        '   The average torsion angle constraint violation for the ensemble.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1286, 'torsion_angle_constraint_viola', 'torsion_angle_constraint_violation_method', 148, 'N', 
        '   This item describes the method used to calculate the torsion angle constraint violation statistics.\
  i.e. are the entered values based on all torsion angle or calculated for violations only? '
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 149, 'PDBX_NMR_ENSEMBLE_RMS', 'pdbx_nmr_ensemble_rms', 'N', 0, 
        ' Structural statistics are derived from molecular dynamics and simulated annealing \
  programs. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1287, 'entry_id', 'entry_id', 149, 'N', 
        '               ''?'''
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1288, 'residue_range_begin', 'residue_range_begin', 149, 'N', 
        ' Structure statistics are often calculated only over the well-ordered region(s) \
  of the biopolymer. Portions of the macromolecule are often mobile and    \
  disordered,  hence they are excluded in calculating the statistics. To define\
  the range(s) over which the statistics are calculated, enter the beginning   \
  residue number(s): e.g. if the regions used were 5-32 and 41-69, enter 5,41      '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1289, 'chain_range_begin', 'chain_range_begin', 149, 'N', 
        '   The beginning chain id. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1290, 'residue_range_end', 'residue_range_end', 149, 'N', 
        '   The ending residue number: e.g. 32,69.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1291, 'chain_range_end', 'chain_range_end', 149, 'N', 
        '   The ending chain id:'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1292, 'atom_type', 'atom_type', 149, 'N', 
        ' Statistics are often calculated over only some of the atoms, \
  e.g. backbone, or heavy atoms. Describe which type of atoms are used for \
  the statistical analysis.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1293, 'distance_rms_dev', 'distance_rms_dev', 149, 'N', 
        '  The distance rmsd to the mean structure for the ensemble of structures.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1294, 'distance_rms_dev_error', 'distance_rms_dev_error', 149, 'N', 
        ' The error in the distance rmsd.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1295, 'covalent_bond_rms_dev', 'covalent_bond_rms_dev', 149, 'N', 
        '   The covalent bond rmsd to the target value for the ensemble.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1296, 'covalent_bond_rms_dev_error', 'covalent_bond_rms_dev_error', 149, 'N', 
        '   The error in the covalent bond rmsd.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1297, 'bond_angle_rms_dev', 'bond_angle_rms_dev', 149, 'N', 
        '   The bond angle rmsd to the target values for the ensemble.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1298, 'bond_angle_rms_dev_error', 'bond_angle_rms_dev_error', 149, 'N', 
        '   The error in the bond angle rmsd.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1299, 'improper_torsion_angle_rms_dev', 'improper_torsion_angle_rms_dev', 149, 'N', 
        '   The improper torsion angle rmsd to the target values for the ensemble.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1300, 'improper2_torsion_angle_rms_de', 'improper2_torsion_angle_rms_dev_error', 149, 'N', 
        '   The error in the improper torsion angle rmsd.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1301, 'peptide_planarity_rms_dev', 'peptide_planarity_rms_dev', 149, 'N', 
        '   The peptide planarity rmsd.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1302, 'peptide_planarity_rms_dev_erro', 'peptide_planarity_rms_dev_error', 149, 'N', 
        '   The error in the peptide planarity rmsd.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1303, 'dihedral_angles_rms_dev', 'dihedral_angles_rms_dev', 149, 'N', 
        '   The dihedral angle rmsd to the target values for the ensemble.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1304, 'dihedral_angles_rms_dev_error', 'dihedral_angles_rms_dev_error', 149, 'N', 
        '   The error of the rmsd dihedral angles.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1305, 'coord_average_rmsd_method', 'coord_average_rmsd_method', 149, 'N', 
        '   Describe the method for calculating the coordinate average rmsd.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 150, 'PDBX_NMR_REPRESENTATIVE', 'pdbx_nmr_representative', 'N', 0, 
        ' An average structure is often calculated in addition to the ensemble, or one\
  of the ensemble is selected as a representative structure. This section\
  describes selection of the representative structure.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1306, 'entry_id', 'entry_id', 150, 'N', 
        '    msd will assign the ID.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1307, 'conformer_id', 'conformer_id', 150, 'N', 
        '   If a member of the ensemble has been selected as a representative\
    structure, identify it by its model number.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1308, 'selection_criteria', 'selection_criteria', 150, 'N', 
        '   \
By highlighting the appropriate choice(s), describe the criteria used to \
select this structure as a representative structure, or if an average \
structure has been calculated describe how this was done.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 151, 'PDBX_NMR_REFINE', 'pdbx_nmr_refine', 'N', 0, 
        '   \
Describe the method and details of the refinement of the deposited structure.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1309, 'entry_id', 'entry_id', 151, 'Y', 
        '   You can leave this blank as an ID will be assigned by the RCSB\
    to the constraint file.     '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1310, 'method', 'method', 151, 'Y', 
        '   The method used to determine the structure.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1311, 'details', 'details', 151, 'N', 
        '   Additional details about the NMR refinement.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 152, 'PDBX_NMR_FORCE_CONSTANTS', 'pdbx_nmr_force_constants', 'N', 0, 
        '\
The final force constants, including units, employed for the various \
experimental constraints, covalent geometry constraints, and the non-bonded \
interaction terms in the target function used for simulated annealing.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1312, 'entry_id    ', 'entry_id    ', 152, 'Y', 
        '   You can leave this blank as an ID will be assigned by the RCSB.          '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1313, 'exptl_distance_term', 'exptl_distance_term', 152, 'N', 
        '  The final force constant for distance (NOEs) constraints \
   term employed in the target function used for simulated annealing. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1314, 'exptl_distance_term_units', 'exptl_distance_term_units', 152, 'N', 
        '   The units for the force constant for the distance \
    constraints term.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1315, 'exptl_torsion_angles_term', 'exptl_torsion_angles_term', 152, 'N', 
        '  The final force constant for the torsion angle term employed in \
   the target function used for simulated annealing. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1316, 'exptl_torsion_angles_term_unit', 'exptl_torsion_angles_term_units', 152, 'N', 
        '   The units for the force constant for the torsion angle \
    constraints term.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1317, 'exptl_J_coupling_term', 'exptl_J_coupling_term', 152, 'N', 
        '  The final force constant for J coupling term employed in the \
   target function used for simulated annealing. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1318, 'exptl_J_coupling_term_units', 'exptl_J_coupling_term_units', 152, 'N', 
        '   The units for the force constant for the J coupling term.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1319, 'exptl_13C_shift_term', 'exptl_13C_shift_term', 152, 'N', 
        '  The final force constant for 13C shift constraints term employed \
   in the target function used for simulated annealing. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1320, 'exptl_13C_shift_term_units', 'exptl_13C_shift_term_units', 152, 'N', 
        '  The units for the force constant for the 13C shift constraints\
   term.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1321, 'exptl_1H_shift_term', 'exptl_1H_shift_term', 152, 'N', 
        '  The final force constant for 1H shift constraints term employed \
   in the target function used for simulated annealing.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1322, 'exptl_1H_shift_term_units', 'exptl_1H_shift_term_units', 152, 'N', 
        '   The units for the force constant for the 1H shift constraints term.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1323, 'exptl_dipolar_coupling_term', 'exptl_dipolar_coupling_term', 152, 'N', 
        '  The final force constant for dipolar coupling constraint term \
   employed in the target function used for simulated annealing. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1324, 'exptl_dipolar_coupling_term_un', 'exptl_dipolar_coupling_term_units', 152, 'N', 
        '   The units for the force constant for the dipolar coupling \
    constraints term.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1325, 'exptl_D_isotope_shift_term', 'exptl_D_isotope_shift_term', 152, 'N', 
        '  The final force constant for Deuterium isotope shift constraints \
   term employed in the target function used for simulated annealing. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1326, 'exptl_D_isotope_shift_term_uni', 'exptl_D_isotope_shift_term_units', 152, 'N', 
        '   The units for the force constant for the Deuterium isotope \
    shift constraints term.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1327, 'covalent_geom_bond_term', 'covalent_geom_bond_term', 152, 'N', 
        '  The final force constant for the covalent geometry bond length \
   constraints term employed in the target function used for simulated \
   annealing. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1328, 'covalent_geom_bond_term_units', 'covalent_geom_bond_term_units', 152, 'N', 
        '   The units for the force constant for the covalent geometry bond \
    length constraints term.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1329, 'covalent_geom_angles_term', 'covalent_geom_angles_term', 152, 'N', 
        '  The final force constant for covalent geometry angle constraints \
   term employed in the target function used for simulated annealing. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1330, 'covalent_geom_angles_term_unit', 'covalent_geom_angles_term_units', 152, 'N', 
        '   The units for the force constant for the covalent geometry angle \
    constraints term.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1331, 'covalent_geom_impropers_term', 'covalent_geom_impropers_term', 152, 'N', 
        '  The final force constant for covalent geometry impropers \
   contstraints term employed in the target function used for simulated \
   annealing. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1332, 'covalent_geom_impropers_term_u', 'covalent_geom_impropers_term_units', 152, 'N', 
        '   The units for the force constant for the covalent geometry \
    impropers constraints term.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1333, 'non_bonded_inter_van_der_Waals', 'non_bonded_inter_van_der_Waals_term_type', 152, 'N', 
        '  The type of van der Waals term employed in the target function \
   used for simulated annealing. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1334, 'non_bonded2_inter_van_der_Waal', 'non_bonded2_inter_van_der_Waals_term', 152, 'N', 
        '  The force constant used for the non-bonded interaction van der Waals \
   term employed in the target function used for simulated annealing. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1335, 'non_bonded3_inter_van_der_Waal', 'non_bonded3_inter_van_der_Waals_term_units', 152, 'N', 
        '   The units for the force constant for the van der Waals term.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1336, 'non_bonded_inter_conf_db_poten', 'non_bonded_inter_conf_db_potential_term', 152, 'N', 
        '  The force constant used for the non-bonded interaction conformational \
   database potential term employed in the target function used for simulated \
   annealing. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1337, 'non_bonded_inter_radius_of_gyr', 'non_bonded_inter_radius_of_gyration_term', 152, 'N', 
        '  The force constant used for the non-bonded interaction radius of \
   gyration term employed in the target function used for simulated annealing. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1338, 'non_bonded2_inter_radius_of_gy', 'non_bonded2_inter_radius_of_gyration_term_units ', 152, 'N', 
        '   The units for the force constant for the radius of gyration term.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 153, 'CITATION', 'citation', 'N', 0, 
        '              Data items in the CITATION category record details about the\
               literature cited relevant to the contents of the data block.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1339, 'abstract_text', 'abstract_text', 153, 'N', 
        '              Abstract for the citation. This is used most when the\
               citation is extracted from a bibliographic database that\
               contains full text or abstract information.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1340, 'abstract_id_CAS', 'abstract_id_CAS', 153, 'N', 
        '              The Chemical Abstracts Service (CAS) abstract identifier;\
               relevant for journal articles.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1341, 'book_id_isbn', 'book_id_isbn', 153, 'N', 
        '              The International Standard Book Number (ISBN) code assigned to\
               the book cited; relevant for book chapters.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1342, 'book_publisher', 'book_publisher', 153, 'N', 
        '              The name of the publisher of the citation; relevant\
               for book chapters.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1343, 'book_publisher_city', 'book_publisher_city', 153, 'N', 
        '              The location of the publisher of the citation; relevant\
               for book chapters.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1344, 'book_title', 'book_title', 153, 'N', 
        '              The title of the book in which the citation appeared; relevant\
               for book chapters.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1345, 'coordinate_linkage', 'coordinate_linkage', 153, 'N', 
        '              _citation.coordinate_linkage states whether or not this citation\
               is concerned with precisely the set of coordinates given in the\
               data block. If, for instance, the publication described the same\
               structure, but the coordinates had undergone further refinement\
               prior to creation of the data block, the value of this data item\
               would be ''no''.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1346, 'country', 'country', 153, 'N', 
        '              The country of publication; relevant for both journal articles\
               and book chapters.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1347, 'database_id_medline', 'database_id_medline', 153, 'N', 
        '              Ascession number used by Medline to categorize a specific\
               bibliographic entry.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1348, 'details', 'details', 153, 'N', 
        '              A description of special aspects that describe the relationship\
               of the contents of the data block to the literature item cited.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1349, 'id', 'id', 153, 'Y', 
        '              The value of _citation.id must uniquely identify a record in the\
               CITATION list.\
\
               The _citation.id ''primary'' should be used to indicate the\
               citation that the author(s) consider to be the most pertinent to\
               the contents of the data block.\
\
               Note that this item need not be a number; it can be any unique\
               identifier.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1350, 'journal_abbrev', 'journal_abbrev', 153, 'N', 
        '              Abbreviated name of the journal cited as given in the Chemical\
               Abstracts Service Source Index.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1351, 'journal_id_astm', 'journal_id_astm', 153, 'N', 
        '              The American Society for the Testing of Materials (ASTM) code\
               assigned to the journal cited (also referred to as the CODEN\
               designator of the Chemical Abstracts Service); relevant for\
               journal articles.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1352, 'journal_id_csd', 'journal_id_csd', 153, 'N', 
        '              The Cambridge Structural Database (CSD) code assigned to the \
               journal cited; relevant for journal articles. This is also the \
               system used at the Brookhaven Protein Data Bank (PDB).'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1353, 'journal_id_issn', 'journal_id_issn', 153, 'N', 
        '              The International Standard Serial Number (ISSN) code assigned to\
               the journal cited; relevant for journal articles.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1354, 'journal_full', 'journal_full', 153, 'N', 
        '              Full name of the journal cited; relevant for journal articles.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1355, 'journal_issue', 'journal_issue', 153, 'N', 
        '              Issue number of the journal cited; relevant for journal\
               articles.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1356, 'journal_volume', 'journal_volume', 153, 'N', 
        '              Volume number of the journal cited; relevant for journal\
               articles.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1357, 'language', 'language', 153, 'N', 
        '              Language in which the citation appears.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1358, 'page_first', 'page_first', 153, 'N', 
        '              The first page of the citation; relevant for journal\
               articles and book chapters.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1359, 'page_last', 'page_last', 153, 'N', 
        '              The last page of the citation; relevant for journal\
               articles and book chapters.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1360, 'title', 'title', 153, 'N', 
        '              The title of the citation; relevant for both journal articles\
               and book chapters.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1361, 'year', 'year', 153, 'N', 
        '              The year of the citation; relevant for both journal articles\
               and book chapters.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 154, 'CITATION_AUTHOR', 'citation_author', 'N', 0, 
        '              Data items in the CITATION_AUTHOR category record details\
               about the authors associated with the citations in the\
               CITATION list.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1362, 'name', 'name', 154, 'Y', 
        '              Name of an author of the citation; relevant for both journal\
               articles and book chapters.\
\
               The family name(s), followed by a comma and including any\
               dynastic components, precedes the first name(s) or initial(s).'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1363, 'ordinal', 'ordinal', 154, 'N', 
        '              This data item defines the order of the author''s name in the\
               list of authors of a citation.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 155, 'CITATION_EDITOR', 'citation_editor', 'N', 0, 
        '              Data items in the CITATION_EDITOR category record details\
               about the editor associated with book chapter citations in\
               the CITATION list.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1364, 'name', 'name', 155, 'N', 
        '              Names of an editor of the citation; relevant for book chapters.\
\
               The family name(s), followed by a comma and including any\
               dynastic components, precedes the first name(s) or initial(s).'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1365, 'ordinal', 'ordinal', 155, 'N', 
        '              This data item defines the order of the editor''s name in the\
               list of editors of a citation.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 156, 'DATABASE_2', 'database_2', 'N', 0, 
        '              Data items in the DATABASE_2 category record details about the\
               database identifiers of the data block.\
\
               These data items are assigned by database managers and should\
               only appear in a data block if they originate from that source.\
\
               The somewhat awkward name of this category (DATABASE_2) is a\
               consequence of the name DATABASE having been already used in\
               the CIF core, but used in a manner different from the usage\
               in mmCIF. Since CIF data names, once adopted, cannot be\
               changed, a new category was created.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1366, 'database_id', 'database_id', 156, 'Y', 
        '              An abbreviation that identifies the database.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1367, 'database_code', 'database_code', 156, 'Y', 
        '              The code assigned by the database identified in\
               _database_2.database_id.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 157, 'DATABASE_PDB_CAVEAT', 'database_PDB_caveat', 'N', 0, 
        '              Data items in the DATABASE_PDB_CAVEAT category record details\
               about features of the data block flagged as ''caveats'' by the\
               Protein Data Bank (PDB).\
\
               These data items are included only for consistency with PDB\
               format files. They should appear in a data block only if that\
               data block was created by reformatting a PDB format file.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1368, 'id', 'id', 157, 'Y', 
        '              A unique identifier for the PDB caveat record.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1369, 'text', 'text', 157, 'N', 
        '              The full text of the PDB caveat record.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 158, 'DATABASE_PDB_MATRIX', 'database_PDB_matrix', 'N', 0, 
        '              The DATABASE_PDB_MATRIX category provides placeholders for\
               transformation matrices and vectors used by the Protein Data\
               Bank (PDB).\
\
               These data items are included only for consistency with older\
               PDB format files. They should appear in a data block only if\
               that data block was created by reformatting a PDB format file.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1370, 'entry_id', 'entry_id', 158, 'Y', 
        '              This data item is a pointer to _entry.id in the ENTRY category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1371, 'origx_0_0', 'origx[1][1]', 158, 'N', 
        '              The [1][1] element of the PDB ORIGX matrix. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1372, 'origx_0_1', 'origx[1][2]', 158, 'N', 
        '              The [1][2] element of the PDB ORIGX matrix. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1373, 'origx_0_2', 'origx[1][3]', 158, 'N', 
        '              The [1][3] element of the PDB ORIGX matrix. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1374, 'origx_1_0', 'origx[2][1]', 158, 'N', 
        '              The [2][1] element of the PDB ORIGX matrix. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1375, 'origx_1_1', 'origx[2][2]', 158, 'N', 
        '              The [2][2] element of the PDB ORIGX matrix. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1376, 'origx_1_2', 'origx[2][3]', 158, 'N', 
        '              The [2][3] element of the PDB ORIGX matrix. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1377, 'origx_2_0', 'origx[3][1]', 158, 'N', 
        '              The [3][1] element of the PDB ORIGX matrix. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1378, 'origx_2_1', 'origx[3][2]', 158, 'N', 
        '              The [3][2] element of the PDB ORIGX matrix. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1379, 'origx_2_2', 'origx[3][3]', 158, 'N', 
        '              The [3][3] element of the PDB ORIGX matrix. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1380, 'origx_vector_0', 'origx_vector[1]', 158, 'N', 
        '              The [1] element of the PDB ORIGX vector. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1381, 'origx_vector_1', 'origx_vector[2]', 158, 'N', 
        '              The [2] element of the PDB ORIGX vector. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1382, 'origx_vector_2', 'origx_vector[3]', 158, 'N', 
        '              The [3] element of the PDB ORIGX vector. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1383, 'scale_0_0', 'scale[1][1]', 158, 'N', 
        '              The [1][1] element of the PDB SCALE matrix. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1384, 'scale_0_1', 'scale[1][2]', 158, 'N', 
        '              The [1][2] element of the PDB SCALE matrix. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1385, 'scale_0_2', 'scale[1][3]', 158, 'N', 
        '              The [1][3] element of the PDB SCALE matrix. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1386, 'scale_1_0', 'scale[2][1]', 158, 'N', 
        '              The [2][1] element of the PDB SCALE matrix. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1387, 'scale_1_1', 'scale[2][2]', 158, 'N', 
        '              The [2][2] element of the PDB SCALE matrix. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1388, 'scale_1_2', 'scale[2][3]', 158, 'N', 
        '              The [2][3] element of the PDB SCALE matrix. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1389, 'scale_2_0', 'scale[3][1]', 158, 'N', 
        '              The [3][1] element of the PDB SCALE matrix. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1390, 'scale_2_1', 'scale[3][2]', 158, 'N', 
        '              The [3][2] element of the PDB SCALE matrix. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1391, 'scale_2_2', 'scale[3][3]', 158, 'N', 
        '              The [1][1] element of the PDB SCALE matrix. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1392, 'scale_vector_0', 'scale_vector[1]', 158, 'N', 
        '              The [1] element of the PDB SCALE vector. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1393, 'scale_vector_1', 'scale_vector[2]', 158, 'N', 
        '              The [2] element of the PDB SCALE vector. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1394, 'scale_vector_2', 'scale_vector[3]', 158, 'N', 
        '              The [3] element of the PDB SCALE vector. '
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 159, 'DATABASE_PDB_REMARK', 'database_PDB_remark', 'N', 0, 
        '              Data items in the DATABASE_PDB_REMARK category record details\
               about the data block as archived by the Protein Data Bank (PDB).\
\
               Some data appearing in PDB REMARK records can be\
               algorithmically extracted into the appropriate data items\
               in the data block.\
\
               These data items are included only for consistency with older\
               PDB format files. They should appear in a data block only if\
               that data block was created by reformatting a PDB format file.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1395, 'id', 'id', 159, 'Y', 
        '              A unique identifier for the PDB remark record.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1396, 'text', 'text', 159, 'N', 
        '              The full text of the PDB remark record.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 160, 'DATABASE_PDB_REV', 'database_PDB_rev', 'N', 0, 
        '              Data items in the DATABASE_PDB_REV category record details\
               about the history of the data block as archived by the Protein\
               Data Bank (PDB).\
\
               These data items are assigned by the PDB database managers and\
               should only appear in a data block if they originate from that\
               source.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1397, 'author_name', 'author_name', 160, 'N', 
        '              The name of the person responsible for submitting this revision\
               to the PDB.\
\
               The family name(s) followed by a comma, precedes the first\
               name(s) or initial(s).'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1398, 'date2', 'date', 160, 'N', 
        '              Date the PDB revision took place. Taken from the REVDAT record.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1399, 'date_original', 'date_original', 160, 'N', 
        '              Date the entry first entered the PDB database in the form:\
               yyyy-mm-dd. Taken from the PDB HEADER record.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1400, 'mod_type', 'mod_type', 160, 'N', 
        '              Taken from the REVDAT record. Refer to the Protein Data Bank\
               format description for details.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1401, 'num', 'num', 160, 'Y', 
        '              The value of _database_PDB_rev.num must uniquely and\
               sequentially identify a record in the DATABASE_PDB_REV list.\
\
               Note that this item must be a number, and that modification\
               numbers are assigned in increasing numerical order.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1402, 'replaced_by', 'replaced_by', 160, 'N', 
        '              The PDB code for a subsequent PDB entry that replaced the\
               PDB file corresponding to this data block.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1403, 'replaces', 'replaces', 160, 'N', 
        '              The PDB code for a previous PDB entry that was replaced by\
               the PDB file corresponding to this data block.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1404, 'status', 'status', 160, 'N', 
        '              The status of this revision.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 161, 'DATABASE_PDB_REV_RECORD', 'database_PDB_rev_record', 'N', 0, 
        '              Data items in the DATABASE_PDB_REV_RECORD category record\
               details about specific record types that were changed in a\
               given revision of a PDB entry.\
\
               These data items are assigned by the PDB database managers and\
               should only appear in a data block if they originate from that\
               source.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1405, 'details', 'details', 161, 'N', 
        '              A description of special aspects of the revision of records in\
               this PDB entry.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1406, 'type', 'type', 161, 'Y', 
        '              The types of records that were changed in this revision to a\
               PDB entry.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 162, 'DATABASE_PDB_TVECT', 'database_PDB_tvect', 'N', 0, 
        '              The DATABASE_PDB_TVECT category provides placeholders for\
               the TVECT matrices and vectors used by the Protein Data\
               Bank (PDB).\
\
               These data items are included only for consistency with older\
               PDB format files. They should appear in a data block only if\
               that data block was created by reformatting a PDB format file.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1407, 'details', 'details', 162, 'N', 
        '              A description of special aspects of this TVECT.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1408, 'id', 'id', 162, 'Y', 
        '              The value of _database_PDB_tvect.id must uniquely identify a\
               record in the DATABASE_PDB_TVECT list.\
\
               Note that this item need not be a number; it can be any unique\
               identifier.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1409, 'vector_0', 'vector[1]', 162, 'N', 
        '              The [1] element of the PDB TVECT vector. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1410, 'vector_1', 'vector[2]', 162, 'N', 
        '              The [2] element of the PDB TVECT vector. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1411, 'vector_2', 'vector[3]', 162, 'N', 
        '              The [3] element of the PDB TVECT vector. '
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 163, 'PDBX_DATABASE_MESSAGE', 'pdbx_database_message', 'N', 0, 
        '              The PDBX_DATABASE_MESSAGE category provides information about\
               correspondance related to a structure deposition.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1412, 'entry_id', 'entry_id', 163, 'Y', 
        '      The value of _pdbx_database_message.entry_id identifies the data block.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1413, 'message_id', 'message_id', 163, 'Y', 
        '              This is an unique and sequential identifier for a message.\
'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1414, 'content_type', 'content_type', 163, 'Y', 
        '              This code defines the content of the message.\
'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1415, 'message_type', 'message_type', 163, 'Y', 
        '              Defines how the message was sent or received.\
'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1416, 'sender', 'sender', 163, 'N', 
        '              The name of the sender.\
'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1417, 'sender_address_fax', 'sender_address_fax', 163, 'N', 
        '              The FAX phone number of the sender.\
'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1418, 'sender_address_phone', 'sender_address_phone', 163, 'N', 
        '              The phone number of the sender.\
'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1419, 'sender_address_email', 'sender_address_email', 163, 'N', 
        '              The email address of the sender.\
'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1420, 'sender_address_mail', 'sender_address_mail', 163, 'N', 
        '              The postal address of the sender.\
'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1421, 'receiver', 'receiver', 163, 'N', 
        '              The name of the receiver.\
'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1422, 'receiver_address_fax', 'receiver_address_fax', 163, 'N', 
        '              The FAX phone number of the receiver.\
'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1423, 'receiver_address_phone', 'receiver_address_phone', 163, 'N', 
        '              The phone number of the receiver.\
'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1424, 'receiver_address_email', 'receiver_address_email', 163, 'N', 
        '              The email address of the receiver.\
'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1425, 'receiver_address_mail', 'receiver_address_mail', 163, 'N', 
        '              The postal address of the receiver.\
'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1426, 'message', 'message', 163, 'N', 
        '              The text of the message.\
'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 164, 'PDBX_DATABASE_PDB_OBS_SPR', 'pdbx_database_PDB_obs_spr', 'N', 0, 
        '              The PDBX_DATABASE_PDB_OBS_SPR category provides placeholders\
               for information on obsolete/superseded PDB entries'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1427, 'id ', 'id ', 164, 'Y', 
        '     Identifier for the type of obsolete entry to be added to this entry.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1428, 'date2', 'date', 164, 'Y', 
        '              The date of replacement.\
'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1429, 'pdb_id ', 'pdb_id ', 164, 'Y', 
        '              The new PDB identifier for the replaced entry.\
'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1430, 'replace_pdb_id ', 'replace_pdb_id ', 164, 'Y', 
        '              The PDB identifier for the replaced (OLD) entry.\
'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 165, 'PDBX_DATABASE_PROC', 'pdbx_database_proc', 'N', 0, 
        '              Internal records to track the data processing cycle.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1431, 'entry_id', 'entry_id', 165, 'Y', 
        '     The value of _pdbx_database_proc.entry_id identifies the data block.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1432, 'cycle_id', 'cycle_id', 165, 'Y', 
        '              This is a number of the processing cycle.\
'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1433, 'date_begin_cycle', 'date_begin_cycle', 165, 'Y', 
        '              This is the date of the start of the processing cycle.\
'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1434, 'date_end_cycle', 'date_end_cycle', 165, 'Y', 
        '              This is the date of the end of the processing cycle.\
'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1435, 'details', 'details', 165, 'N', 
        '              Special details about the current processing cycle.\
'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 166, 'PDBX_DATABASE_REMARK', 'pdbx_database_remark', 'N', 0, 
        '\
       Data items in the PDBX_DATABASE_REMARK category record keep additional \
       information about the entry.  They are mostly used to create \
       ''non-standard'' PDB REMARK annotations (6-99).'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1436, 'id', 'id', 166, 'Y', 
        '              A unique identifier for the PDB remark record.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1437, 'text', 'text', 166, 'N', 
        '              The full text of the PDB remark record.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 167, 'PDBX_DATABASE_STATUS', 'pdbx_database_status', 'N', 0, 
        '              These are internal RCSB records to keep track of data processing\
               and status of the entry.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1438, 'status_code', 'status_code', 167, 'Y', 
        '              Code for status of file.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1439, 'author_release_status_code', 'author_release_status_code', 167, 'Y', 
        '              The release status authorized by the depositor.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1440, 'dep_release_code_coordinates', 'dep_release_code_coordinates', 167, 'Y', 
        '\
The deposited coordinates for this deposition will be released according\
the value of this item.  '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1441, 'dep_release_code_sequence', 'dep_release_code_sequence', 167, 'Y', 
        '\
The sequence information for this deposition will be released according\
the value of this item.  Setting this status code to "RELEASE NOW" indicates \
that the macromolecular sequence(s) for this entry may be displayed in PDB\
status reports prior to the release of the entry.   Setting this status\
code to "HOLD FOR RELEASE" conceals the sequence information in PDB status\
reports until the coordinate data for this entry are released.  '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1442, 'dep_release_code_struct_fact', 'dep_release_code_struct_fact', 167, 'Y', 
        '\
The deposited structure factors for this deposition will be released according\
the value of this item.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1443, 'dep_release_code_nmr_constrain', 'dep_release_code_nmr_constraints', 167, 'Y', 
        '\
The deposited NMR constrait data for this deposition will be released according\
the value of this item.  '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1444, 'entry_id', 'entry_id', 167, 'Y', 
        '       The value of _pdbx_database_status.entry_id identifies the data block.\
'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1445, 'recvd_deposit_form', 'recvd_deposit_form', 167, 'Y', 
        '              This code indicates whether the deposition form for an entry\
               has been received.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1446, 'date_deposition_form', 'date_deposition_form', 167, 'N', 
        '              The date the deposition form is received.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1447, 'recvd_coordinates', 'recvd_coordinates', 167, 'Y', 
        '              This code indicates whether the coordinates for an entry\
               have been received.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1448, 'date_coordinates', 'date_coordinates', 167, 'N', 
        '              The date the coordinates are received.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1449, 'recvd_struct_fact', 'recvd_struct_fact', 167, 'Y', 
        '              This code indicates whether the structure factors for an entry\
               have been received.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1450, 'date_struct_fact', 'date_struct_fact', 167, 'N', 
        '              The date the structure factors are received.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1451, 'recvd_nmr_constraints', 'recvd_nmr_constraints', 167, 'Y', 
        '              This code indicates whether the NMR contraint data for an entry\
               have been received.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1452, 'date_nmr_constraints', 'date_nmr_constraints', 167, 'N', 
        '              The date the structure factors are received.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1453, 'recvd_internal_approval', 'recvd_internal_approval', 167, 'Y', 
        '              This code indicates whether the internal approval for an entry  \
               have been received.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1454, 'recvd_manuscript', 'recvd_manuscript', 167, 'Y', 
        '              This code indicates whether the manuscript for an entry\
               has been received.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1455, 'date_manuscript', 'date_manuscript', 167, 'Y', 
        '              The date the manuscript is received.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1456, 'name_depositor', 'name_depositor', 167, 'Y', 
        '              The last name of the depositor to be used in correspondance.\
'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1457, 'recvd_author_approval', 'recvd_author_approval', 167, 'Y', 
        '              This code indicates whether the author''s approval for \
               an entry has been received.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1458, 'author_approval_type', 'author_approval_type', 167, 'Y', 
        '              This code indicates whether the author''s approval for \
               an entry was received explicitly or implicitly.  The\
               latter is automatically implied by failure to respond\
               to the validation summary within the prescribed period.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1459, 'date_author_approval', 'date_author_approval', 167, 'N', 
        '              The date the author''s approval is received.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1460, 'recvd_initial_deposition_date', 'recvd_initial_deposition_date', 167, 'Y', 
        '              The date of initial deposition.  (The first message for\
               deposition has been received.)'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1461, 'date_submitted', 'date_submitted', 167, 'N', 
        '              The date of complete deposition.  This corresponds to the date\
               at which the PDB identifier is assigned.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1462, 'rcsb_annotator', 'rcsb_annotator', 167, 'N', 
        '              The initials of the annotator processing this entry.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1463, 'date_of_PDB_release', 'date_of_PDB_release', 167, 'N', 
        '              PDB release date.  This is the date that appears in the PDB\
               REVDAT record.\
'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1464, 'date_hold_coordinates', 'date_hold_coordinates', 167, 'Y', 
        '              At an author''s request, a coordinate entry may be held after\
               processing for some period of time.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1465, 'date_hold_struct_fact', 'date_hold_struct_fact', 167, 'Y', 
        '              At an author''s request, the structure factors may be held after\
               processing for some period of time.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1466, 'date_hold_nmr_constraints', 'date_hold_nmr_constraints', 167, 'Y', 
        '              At an author''s request, the NMR constraint data may be held after\
               processing for some period of time.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1467, 'hold_for_publication', 'hold_for_publication', 167, 'Y', 
        '              At an author''s request, an entry is to be held until\
               publication.  '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1468, 'pdb_date_of_author_approval', 'pdb_date_of_author_approval', 167, 'N', 
        '              This is the date when PDB received the author''s approval for an\
               entry which has been processed by NDB.  (This is a place holder \
               for entries processed before Jan. 1, 1996.)\
'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1469, 'deposit_site', 'deposit_site', 167, 'N', 
        '              The site where the file was deposited.\
'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1470, 'process_site', 'process_site', 167, 'N', 
        '              The site where the file was deposited.\
'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 168, 'PDBX_DATABASE_RELATED', 'pdbx_database_related', 'N', 0, 
        '    Data items in PDBX_DATABASE_RELATED contain references to entries\
     that are related to the this entry.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1471, 'db_name', 'db_name', 168, 'N', 
        '    The name of the database containing the related entry.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1472, 'details', 'details', 168, 'N', 
        '              A description of the related entry.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1473, 'db_id', 'db_id', 168, 'N', 
        '              The identifying code in the related database.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1474, 'content_type', 'content_type', 168, 'N', 
        '              The identifying content type of the related entry.'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 169, 'COMPUTING', 'computing', 'N', 0, 
        '              Data items in the COMPUTING category record details about the\
               computer programs used in the crystal structure analysis.\
 \
               Data items in this category would not, in general, be used in\
               a macromolecular CIF.  The category SOFTWARE, which allows \
               for a more detailed description of computer programs and \
               their attribues, would be used instead.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1475, 'entry_id', 'entry_id', 169, 'Y', 
        '              This data item is a pointer to _entry.id in the ENTRY category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1476, 'cell_refinement', 'cell_refinement', 169, 'N', 
        '              Software used in refining the cell.\
\
               Give the program or package name and a brief reference.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1477, 'data_collection', 'data_collection', 169, 'N', 
        '              Software used for data collection.\
\
               Give the program or package name and a brief reference.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1478, 'data_reduction', 'data_reduction', 169, 'N', 
        '              Software used for data reduction.\
\
               Give the program or package name and a brief reference.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1479, 'molecular_graphics', 'molecular_graphics', 169, 'N', 
        '              Software used for molecular graphics.\
\
               Give the program or package name and a brief reference.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1480, 'publication_material', 'publication_material', 169, 'N', 
        '              Software used for generating material for publication.\
\
               Give the program or package name and a brief reference.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1481, 'structure_refinement', 'structure_refinement', 169, 'N', 
        '              Software used for refinement of the structure.\
\
               Give the program or package name and a brief reference.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1482, 'structure_solution', 'structure_solution', 169, 'N', 
        '              Software used for solution of the structure.\
\
               Give the program or package name and a brief reference.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1483, 'pdbx_structure_refinement_meth', 'pdbx_structure_refinement_method', 169, 'N', 
        '              Program/package name for structure refinement method.\
'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1484, 'pdbx_data_reduction_ii', 'pdbx_data_reduction_ii', 169, 'N', 
        '       Program/package name for data reduction/intensity integration software'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1485, 'pdbx_data_reduction_ds', 'pdbx_data_reduction_ds', 169, 'N', 
        '              Program/package name for data reduction/data scaling'
     ) ;
INSERT into MMS_CATEGORY ( category_key, table_name, id, mandatory, next_record, description )
    VALUES ( 170, 'SOFTWARE', 'software', 'N', 0, 
        '              Data items in the SOFTWARE category record details about \
               the software used in the structure analysis, which implied\
               any software used in the generation of any data items\
               associated with the structure determination and\
               structure representation. \
\
               These data items provide an alternative, and more thorough, \
               method for referencing computer programs than do data items \
               in the COMPUTING category.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1486, 'classification', 'classification', 170, 'N', 
        '              The classification of the program according to its\
               major function.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1487, 'compiler_name', 'compiler_name', 170, 'N', 
        '              The compiler used to compile the software.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1488, 'compiler_version', 'compiler_version', 170, 'N', 
        '              The version of the compiler used to compile the software.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1489, 'contact_author', 'contact_author', 170, 'N', 
        '              The recognized contact author of the software. This could be \
               the original author, modifier of the code, or maintainer, but\
               should be the individual most commonly associated with the\
               code.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1490, 'contact_author_email', 'contact_author_email', 170, 'N', 
        '              The email address of the _software.contact_author.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1491, 'date2', 'date', 170, 'N', 
        '              The date the software was released. '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1492, 'description', 'description', 170, 'N', 
        '              Description of the software.              '
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1493, 'dependencies', 'dependencies', 170, 'N', 
        '              Any prerequisite software required to run _software.name.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1494, 'hardware', 'hardware', 170, 'N', 
        '              The hardware upon which the software was run.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1495, 'language', 'language', 170, 'N', 
        '              The major computing language in which the software is \
               coded.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1496, 'location', 'location', 170, 'N', 
        '              An Internet address in the form of a URL describing\
               where details of the software can be found.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1497, 'mods', 'mods', 170, 'N', 
        '              Any noteworthy modifications to the base software, if applicable.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1498, 'name', 'name', 170, 'Y', 
        '              The name of the software.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1499, 'os', 'os', 170, 'N', 
        '              The name of the operating system under which the software\
               runs.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1500, 'os_version', 'os_version', 170, 'N', 
        '              The version of the operating system under which the software\
               runs.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1501, 'type', 'type', 170, 'N', 
        '              The classification of the software according to the most\
               common types.'
     ) ;
INSERT into MMS_ITEM ( item_key, column_name, id, category_key, mandatory, description )
     VALUES ( 1502, 'version', 'version', 170, 'Y', 
        '              The version of the software.'
     ) ;