//
// CompactRootTrans.java,v 1.3 2003/05/28 01:09:04 dsg Exp
//
// Copyright 2001 The Regents of the University of California
// All Rights Reserved
//
// OpenMMS was developed by Dr. Douglas S. Greer at the San Diego
// Supercomputer Center, a research unit of the University of California,
// San Diego.  Support for this effort was provided by NSF through the
// Protein Data Bank (Grant DBI-9814284) and the National Partnership for
// Advanced Computational Infrastructure (Grant ACI-9619020)
//
// Permission to use, copy, modify and distribute any part of OpenMMS for
// educational, research and non-profit purposes, without fee, and
// without a written agreement is hereby granted, provided that the above
// copyright notice, this paragraph and the following paragraphs appear
// in all copies.
//
// Those desiring to incorporate this OpenMMS into commercial products or
// use for commercial purposes should contact the Technology Transfer
// Office, University of California, San Diego, 9500 Gilman Drive, La
// Jolla, CA 92093-0910, Ph: (619) 534-5815, FAX: (619) 534-7345.
//
// In no event shall the University of California be liable to any party
// for direct, indirect, special, incidental, or consequential damages,
// including lost profits, arising out of the use of this OpenMMS, even
// if the University of California has been advised of the possibility of
// such damage.
//
// The OpenMMS provided herein is on an "as is" basis, and the
// University of California has no obligation to provide maintenance,
// support, updates, enhancements, or modifications.  The University of
// California makes no representations and extends no warranties of any
// kind, either implied or express, including, but not limited to, the
// implied warranties of merchantability or fitness for a particular
// purpose, or that the use of the OpenMMS will not infringe any patent,
// trademark or other rights.

package org.rcsb.openmms.meta;

import java.io.IOException;

import org.rcsb.openmms.cifparse.*;

/** 
 * Generate a DB developement Cif to Idl Translation Hierarchary
 *
 * @author Douglas S. Greer
 * @version 1.3
 */
public class CompactRootTrans extends RootTrans
{
  public CompactRootTrans(String modName)
    {
      super(modName);
    }

  public String getModelIdentifier()
    {
      return "Compact";
    }

  // Must be a value of the form "x.y" that can be converted to a float
  // for comparison purposes.
  // Additions to the model/schema can be done with a minor release
  // i.e incrementing "x.y" to "x.y+1".  Subtractions or substitutions
  // require a major release i.e changing "x.y" to "x+1.y".
  public String getRevisionNumber()
    {
      return "2.0";
    }

  // Use a much smaller version of the IDL definition
  // and implementation for code development
  public void doCoreModDefs(ModuleTrans cmod)
    {
      doAtomSite(cmod);
      doAtomType(cmod);
      doChemComp(cmod);
      doChemLink(cmod);

      // "Chemical" categories are depricated and have been omitted
      // doChemical(cmod);

      doEntity(cmod);
      doEntryLink(cmod);
      doGeom(cmod);
      doStruct(cmod);
    }

  public void doReferModDefs(ModuleTrans mod)
    {
      //___________________________________________________________
      // MMS Reference
      //
      ModuleTrans[] modQual = {mod};
      
      // Audit, Journal, and Publ removed in revised submission
      // doAudit(mod, modQual);

      doCitation(mod, modQual);
      doDatabase(mod, modQual);

      // doJournal(mod, modQual);
      // doPubl(mod, modQual);

      doComputing(mod, modQual);
      doSoftware(mod, modQual);
    }

  public void doDepoModDefs(ModuleTrans mod)
    {
      //___________________________________________________________
      // MMS Deposition
      //
      ModuleTrans[] modQual = {mod};
      doDeposition(mod, modQual);
    }

  public void doDeposition(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // Deposition Interface
      Trans iface, t;

      TypeDefTrans eld = new TypeDefTrans("ErrorList",
					  "sequence<string>");
      String[] eldCom = {
	"Error List returned by deposition checking software"
      };
      eld.setComment(eldCom);
      cmod.add(eld);

      iface = new InterfaceTrans("Deposition");
      String[] dCom = {
	"Interface for the deposition of new entries."
      };
      iface.setComment(dCom);
      cmod.add(iface);

      t = new MethodTrans(coreModuleName + "::FormatTypeList",
			  "deposition_formats_supported",
			  null, null, basicExcepts);
      String[] nfsCom = {
	"Retrieve a list of deposition formats supported."
      };
      t.setComment(nfsCom);
      iface.add(t);
      
      String[] dprTypes= {"in string", "in string", "in string",
			  "in " + coreModuleName + "::EntryRepresentation"};
      String[] dprNames= {"user", "password", "format", "entry"};
      t = new MethodTrans("ErrorList",
			  "deposit_entry",
			  dprTypes, dprNames, basicExcepts);
      String[] dprCom = {
	"Deposit a new entry for error checking and databank inclusion."
      };
      t.setComment(dprCom);
      t.setBlankLines(1);
      iface.add(t);
    }

  public void doXRayModDefs(ModuleTrans mod)
    {
      //___________________________________________________________
      // X-Ray Crystllograpy Module
      //
      // Begin XRayCrystallograpy module
      ModuleTrans[] modQual = {mod};

      doXRayTypeDefs(mod, modQual);
      
      doAtomSites(mod, modQual);
      doCell(mod, modQual);
      doDiffrn(mod, modQual);
      doExptl(mod, modQual);
      doPhasing(mod, modQual);
      doRefine(mod, modQual);
      doRefln(mod, modQual);
      doSymmetry(mod, modQual);
    }

  public void doNmrModDefs(ModuleTrans mod)
    {
      //___________________________________________________________
      // Nuclear Magnetic Resonance Module
      //
      // Begin NMR module
      ModuleTrans[] modQual = {mod};

      doNmrTypeDefs(mod, modQual);
    }

  public void doAtomSite(ModuleTrans cmod)
    {
      do_ATOM_SITE(cmod);
      do_ATOM_SITE_ANISOTROP(cmod);
    }

  public void doAtomSites(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      do_ATOM_SITES(cmod, modQual);
      do_ATOM_SITES_ALT(cmod, modQual);
      do_ATOM_SITES_ALT_ENS(cmod, modQual);
      do_ATOM_SITES_ALT_GEN(cmod, modQual);
      do_ATOM_SITES_FOOTNOTE(cmod, modQual);
    }

  public void doAtomType(ModuleTrans cmod)
    {
      do_ATOM_TYPE(cmod);
    }

  public void doAudit(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      do_AUDIT(cmod, modQual);
      do_AUDIT_AUTHOR(cmod, modQual);
      do_AUDIT_CONFORM(cmod, modQual);
      do_AUDIT_CONTACT_AUTHOR(cmod, modQual);
    }

  public void doCell(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      do_CELL(cmod, modQual);
      do_CELL_MEASUREMENT(cmod, modQual);
      do_CELL_MEASUREMENT_REFLN(cmod, modQual);
    }

  public void doChemComp(ModuleTrans cmod)
    {
      do_CHEM_COMP(cmod);
      do_CHEM_COMP_ANGLE(cmod);
      do_CHEM_COMP_ATOM(cmod);
      do_CHEM_COMP_BOND(cmod);
      do_CHEM_COMP_CHIR(cmod);
      do_CHEM_COMP_CHIR_ATOM(cmod);
      do_CHEM_COMP_LINK(cmod);
      do_CHEM_COMP_PLANE(cmod);
      do_CHEM_COMP_PLANE_ATOM(cmod);
      do_CHEM_COMP_TOR(cmod);
      do_CHEM_COMP_TOR_VALUE(cmod);
    }

  public void doChemLink(ModuleTrans cmod)
    {
      do_CHEM_LINK(cmod);
      do_CHEM_LINK_ANGLE(cmod);
      do_CHEM_LINK_BOND(cmod);
      do_CHEM_LINK_CHIR(cmod);
      do_CHEM_LINK_CHIR_ATOM(cmod);
      do_CHEM_LINK_PLANE(cmod);
      do_CHEM_LINK_PLANE_ATOM(cmod);
      do_CHEM_LINK_TOR(cmod);
      do_CHEM_LINK_TOR_VALUE(cmod);
    }

  public void doCitation(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      do_CITATION(cmod, modQual);
      do_CITATION_AUTHOR(cmod, modQual);
      do_CITATION_EDITOR(cmod, modQual);
    }

  public void doComputing(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      do_COMPUTING(cmod, modQual);
    }

  public void doDatabase(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      // CIF DATABASE Category superceded by DATABASE_2
      // do_DATABASE(cmod, modQual);
      do_DATABASE_2(cmod, modQual);
      do_DATABASE_PDB_CAVEAT(cmod, modQual);
      do_DATABASE_PDB_MATRIX(cmod, modQual);
      do_DATABASE_PDB_REMARK(cmod, modQual);
      do_DATABASE_PDB_REV(cmod, modQual);
      do_DATABASE_PDB_REV_RECORD(cmod, modQual);
      do_DATABASE_PDB_TVECT(cmod, modQual);
    }

  public void doDiffrn(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      do_DIFFRN(cmod, modQual);
      do_DIFFRN_ATTENUATOR(cmod, modQual);
      do_DIFFRN_DETECTOR(cmod, modQual);
      do_DIFFRN_MEASUREMENT(cmod, modQual);
      do_DIFFRN_ORIENT_MATRIX(cmod, modQual);
      do_DIFFRN_ORIENT_REFLN(cmod, modQual);
      do_DIFFRN_RADIATION(cmod, modQual);
      do_DIFFRN_RADIATION_WAVELENGTH(cmod, modQual);
      do_DIFFRN_REFLN(cmod, modQual);
      do_DIFFRN_REFLNS(cmod, modQual);
      do_DIFFRN_SCALE_GROUP(cmod, modQual);
      do_DIFFRN_SOURCE(cmod, modQual);
      do_DIFFRN_STANDARD_REFLN(cmod, modQual);
      do_DIFFRN_STANDARDS(cmod, modQual);
    }

  public void doEntity(ModuleTrans cmod)
    {
      do_ENTITY(cmod);
      do_ENTITY_KEYWORDS(cmod);
      do_ENTITY_LINK(cmod);
      do_ENTITY_NAME_COM(cmod);
      do_ENTITY_NAME_SYS(cmod);
      do_ENTITY_POLY(cmod);
      do_ENTITY_POLY_SEQ(cmod);
      do_ENTITY_SRC_GEN(cmod);
      do_ENTITY_SRC_NAT(cmod);
    }

  public void doEntryLink(ModuleTrans cmod)
    {
      do_ENTRY_LINK(cmod);
    }

  public void doExptl(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      do_EXPTL(cmod, modQual);
      do_EXPTL_CRYSTAL(cmod, modQual);
      do_EXPTL_CRYSTAL_FACE(cmod, modQual);
      do_EXPTL_CRYSTAL_GROW(cmod, modQual);
      do_EXPTL_CRYSTAL_GROW_COMP(cmod, modQual);
    }

  public void doGeom(ModuleTrans cmod)
    {
      do_GEOM(cmod);
      do_GEOM_ANGLE(cmod);
      do_GEOM_BOND(cmod);
      do_GEOM_CONTACT(cmod);
      do_GEOM_HBOND(cmod);
      do_GEOM_TORSION(cmod);
    }

  public void doJournal(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      do_JOURNAL(cmod, modQual);
      do_JOURNAL_INDEX(cmod, modQual);
    }

  public void doPhasing(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      do_PHASING(cmod, modQual);
      do_PHASING_AVERAGING(cmod, modQual);
      do_PHASING_ISOMORPHOUS(cmod, modQual);
      do_PHASING_MAD(cmod, modQual);
      do_PHASING_MAD_CLUST(cmod, modQual);
      do_PHASING_MAD_EXPT(cmod, modQual);
      do_PHASING_MAD_RATIO(cmod, modQual);
      do_PHASING_MAD_SET(cmod, modQual);
      do_PHASING_MIR(cmod, modQual);
      do_PHASING_MIR_DER(cmod, modQual);
      do_PHASING_MIR_DER_REFLN(cmod, modQual);
      do_PHASING_MIR_DER_SHELL(cmod, modQual);
      do_PHASING_MIR_DER_SITE(cmod, modQual);
      do_PHASING_MIR_SHELL(cmod, modQual);
      do_PHASING_SET(cmod, modQual);
      do_PHASING_SET_REFLN(cmod, modQual);
    }

  public void doPubl(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      do_PUBL(cmod, modQual);
      do_PUBL_AUTHOR(cmod, modQual);
      do_PUBL_BODY(cmod, modQual);
      do_PUBL_MANUSCRIPT_INCL(cmod, modQual);
    }

  public void doRefine(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      do_REFINE(cmod, modQual);
      do_REFINE_ANALYZE(cmod, modQual);
      do_REFINE_B_ISO(cmod, modQual);
      do_REFINE_HIST(cmod, modQual);
      do_REFINE_LS_RESTR(cmod, modQual);
      do_REFINE_LS_RESTR_NCS(cmod, modQual);
      do_REFINE_LS_SHELL(cmod, modQual);
      do_REFINE_OCCUPANCY(cmod, modQual);
    }

  public void doRefln(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      do_REFLN(cmod, modQual);
      do_REFLNS(cmod, modQual);
      do_REFLNS_SCALE(cmod, modQual);
      do_REFLNS_SHELL(cmod, modQual);
    }

  public void doSoftware(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      do_SOFTWARE(cmod, modQual);
    }

  public void doStruct(ModuleTrans cmod)
    {
      do_STRUCT(cmod);
      do_STRUCT_ASYM(cmod);
      do_STRUCT_BIOL(cmod);
      do_STRUCT_BIOL_GEN(cmod);
      do_STRUCT_BIOL_KEYWORDS(cmod);
      do_STRUCT_BIOL_VIEW(cmod);
      do_STRUCT_CONF(cmod);
      do_STRUCT_CONF_TYPE(cmod);
      do_STRUCT_CONN(cmod);
      do_STRUCT_CONN_TYPE(cmod);
      do_STRUCT_KEYWORDS(cmod);
      do_STRUCT_MON_DETAILS(cmod);
      do_STRUCT_MON_NUCL(cmod);
      do_STRUCT_MON_PROT(cmod);
      do_STRUCT_MON_PROT_CIS(cmod);
      do_STRUCT_NCS_DOM(cmod);
      do_STRUCT_NCS_DOM_LIM(cmod);
      do_STRUCT_NCS_ENS(cmod);
      do_STRUCT_NCS_ENS_GEN(cmod);
      do_STRUCT_NCS_OPER(cmod);
      do_STRUCT_REF(cmod);
      do_STRUCT_REF_SEQ(cmod);
      do_STRUCT_REF_SEQ_DIF(cmod);
      do_STRUCT_SHEET(cmod);
      do_STRUCT_SHEET_HBOND(cmod);
      do_STRUCT_SHEET_ORDER(cmod);
      do_STRUCT_SHEET_RANGE(cmod);
      do_STRUCT_SHEET_TOPOLOGY(cmod);
      do_STRUCT_SITE(cmod);
      do_STRUCT_SITE_GEN(cmod);
      do_STRUCT_SITE_KEYWORDS(cmod);
      do_STRUCT_SITE_VIEW(cmod);
    }

  public void doSymmetry(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      do_SYMMETRY(cmod, modQual);
      do_SYMMETRY_EQUIV(cmod, modQual);
    }

  public void do_ATOM_SITE(ModuleTrans cmod)
    {
      //___________________________________________________________
      // ATOM_SITE (PDB)
      FieldTrans ft;
      MatrixTrans mt;
      CategoryTrans cat = new CategoryTrans("atom_site", "AtomSite");
      cmod.add(cat);
      // StructureTrans strk = defaultContainer("AtomSite", cat);
      StructureTrans strk
	= new StructureTrans("AtomSite", cat, null, MAX_PARAGRAPHS);
      strk.setUseBlockMethod(true);
      cat.add(strk);
      {
	ft = new FieldTrans("id", "id", 1);
	strk.add(ft);
 	ft = new FieldTrans("type_symbol");
 	strk.add(ft);

	ft = new FieldTrans(atomIndex, "label");
	strk.add(ft);
	ft.add(new SubfieldTrans("atom", "label_atom_id"));
	ft.add(new SubfieldTrans("seq", "label_seq_id"));
	ft.add(new SubfieldTrans("comp", "label_comp_id"));
	ft.add(new SubfieldTrans("asym", "label_asym_id"));
	ft.add(new SubfieldTrans("alt", "label_alt_id"));

	ft = new FieldTrans("label_entity_id");
	strk.add(ft);

	ft = new FieldTrans(stVectorXYZ, "cartn");
	strk.add(ft);
	ft.add(new SubfieldTrans("x", "cartn_x"));
	ft.add(new SubfieldTrans("y", "cartn_y"));
	ft.add(new SubfieldTrans("z", "cartn_z"));

	ft = new FieldTrans("occupancy");
	strk.add(ft);
 	ft = new FieldTrans("b_iso_or_equiv", "B_iso_or_equiv");
 	strk.add(ft);
 	ft = new FieldTrans("model_num", "pdbx_PDB_model_num");
 	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);

      //___________________________________________________________
      // ATOM_SITE
      // strk = defaultContainer("AtomSiteExt", cat);
      strk = new StructureTrans("AtomSiteExt", cat, null, MAX_PARAGRAPHS);
      strk.setUseBlockMethod(true);
      cat.add(strk);
      {
//  	mt = new MatrixTrans("aniso_b", "aniso_B", "", true);
//  	strk.add(mt);
//  	mt = new MatrixTrans("aniso_b", "aniso_B", "_esd", true);
//  	strk.add(mt);
//  	ft = new FieldTrans("aniso_ratio");
//  	strk.add(ft);
//  	mt = new MatrixTrans("aniso_u", "aniso_U", "", true);
//  	strk.add(mt);
//  	mt = new MatrixTrans("aniso_u", "aniso_U", "_esd", true);
//  	strk.add(mt);
 	ft = new FieldTrans("attached_hydrogens");
 	strk.add(ft);
 	ft = new FieldTrans("auth_asym_id");
 	strk.add(ft);
 	ft = new FieldTrans("auth_atom_id");
 	strk.add(ft);
 	ft = new FieldTrans("auth_comp_id");
 	strk.add(ft);
 	ft = new FieldTrans("auth_seq_id");
 	strk.add(ft);
//  	ft = new FieldTrans("b_equiv_geom_mean", "B_equiv_geom_mean");
//  	strk.add(ft);
//  	ft = new FieldTrans("b_equiv_geom_mean_esd",
// 			    "B_equiv_geom_mean_esd");
//  	strk.add(ft);
//   	ft = new FieldTrans("b_iso_or_equiv_esd", "B_iso_or_equiv_esd");
//   	strk.add(ft);
 	ft = new FieldTrans("calc_attached_atom");
 	strk.add(ft);
// 	ft = new FieldTrans("calc_flag");
// 	strk.add(ft);

//  	ft = new FieldTrans(stVectorXYZ, "cartn_esd");
//  	strk.add(ft);
//  	ft.add(new SubfieldTrans("x", "cartn_x_esd"));
//  	ft.add(new SubfieldTrans("y", "cartn_y_esd"));
//  	ft.add(new SubfieldTrans("z", "cartn_z_esd"));

	// depricated field
// 	ft = new FieldTrans("chemical_conn_number");
// 	strk.add(ft);
//  	ft = new FieldTrans("constraints");
//  	strk.add(ft);
//  	ft = new FieldTrans("details");
//  	strk.add(ft);
// 	ft = new FieldTrans("disorder_assembly");
// 	strk.add(ft);
//  	ft = new FieldTrans("disorder_group");
//  	strk.add(ft);
//  	ft = new FieldTrans("footnote_id");
//  	strk.add(ft);

// 	ft = new FieldTrans(stVectorXYZ, "fract");
// 	strk.add(ft);
// 	ft.add(new SubfieldTrans("x", "fract_x"));
// 	ft.add(new SubfieldTrans("y", "fract_y"));
// 	ft.add(new SubfieldTrans("z", "fract_z"));
// 	ft = new FieldTrans(stVectorXYZ, "fract_esd");
// 	strk.add(ft);
// 	ft.add(new SubfieldTrans("x", "fract_x_esd"));
// 	ft.add(new SubfieldTrans("y", "fract_y_esd"));
//	ft.add(new SubfieldTrans("z", "fract_z_esd"));

// 	ft = new FieldTrans("group_pdb", "group_PDB");
// 	strk.add(ft);
 	ft = new FieldTrans("occupancy_esd");
 	strk.add(ft);
//  	ft = new FieldTrans("refinement_flags");
//  	strk.add(ft);
//  	ft = new FieldTrans("restraints");
//  	strk.add(ft);
//  	ft = new FieldTrans("symmetry_multiplicity");
//  	strk.add(ft);
//  	ft = new FieldTrans("thermal_displace_type");
//  	strk.add(ft);
//  	ft = new FieldTrans("u_equiv_geom_mean", "U_equiv_geom_mean");
//  	strk.add(ft);
//  	ft = new FieldTrans("u_equiv_geom_mean_esd", 
// 			    "U_equiv_geom_mean_esd");
//  	strk.add(ft);
//  	ft = new FieldTrans("u_iso_or_equiv", "U_iso_or_equiv");
//  	strk.add(ft);
//  	ft = new FieldTrans("u_iso_or_equiv_esd", "U_iso_or_equiv_esd");
//  	strk.add(ft);
//  	ft = new FieldTrans("wyckoff_symbol", "Wyckoff_symbol");
// 	strk.add(ft);
      }
      list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_ATOM_SITE_ANISOTROP(ModuleTrans cmod)
    {
      //___________________________________________________________
      // ATOM_SITE_ANISOTROP
      FieldTrans ft;
      MatrixTrans mt;
      CategoryTrans cat = new CategoryTrans("atom_site_anisotrop",
					    "AtomSiteAnisotrop");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("AtomSiteAnisotrop", cat);
      cat.add(strk);
      {
	mt = new MatrixTrans("b", "B", "", true);
	strk.add(mt);
	mt = new MatrixTrans("b", "B", "_esd", true);
	strk.add(mt);
	ft = new FieldTrans("ratio");
	strk.add(ft);
	ft = new FieldTrans("id");
	strk.add(ft);
	ft = new FieldTrans("type_symbol");
	strk.add(ft);
	mt = new MatrixTrans("u", "U", "", true);
	strk.add(mt);
	mt = new MatrixTrans("u", "U", "_esd", true);
	strk.add(mt);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_ATOM_SITES(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // ATOM_SITES
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("atom_sites",
					    "AtomSites");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("AtomSites", cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("entry_id");
	strk.add(ft);
	ft = new MatrixTrans("cartn_transf_matrix",
			     "Cartn_transf_matrix", "", false);
	strk.add(ft);
	ft = new VectorTrans("cartn_transf_vector",
			     "Cartn_transf_vector");
	strk.add(ft);
	ft = new FieldTrans("cartn_transform_axes",
			    "Cartn_transform_axes");
	strk.add(ft);
	ft = new MatrixTrans("fract_transf_matrix");
	strk.add(ft);
	ft = new VectorTrans("fract_transf_vector");
	strk.add(ft);
	ft = new FieldTrans("solution_primary");
	strk.add(ft);
	ft = new FieldTrans("solution_secondary");
	strk.add(ft);
	ft = new FieldTrans("solution_hydrogens");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_ATOM_SITES_ALT(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // ATOM_SITES_ALT
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("atom_sites_alt",
					    "AtomSitesAlt");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("AtomSitesAlt", cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("details");
	strk.add(ft);
	ft = new FieldTrans("id");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_ATOM_SITES_ALT_ENS(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // ATOM_SITES_ALT_ENS
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("atom_sites_alt_ens",
					    "AtomSitesAltEns");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("AtomSitesAltEns", cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("details");
	strk.add(ft);
	ft = new FieldTrans("id");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_ATOM_SITES_ALT_GEN(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // ATOM_SITES_ALT_GEN
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("atom_sites_alt_gen",
					    "AtomSitesAltGen");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("AtomSitesAltGen", cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("alt_id");
	strk.add(ft);
	ft = new FieldTrans("ens_id");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_ATOM_SITES_FOOTNOTE(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // ATOM_SITES_FOOTNOTE
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("atom_sites_footnote",
					    "AtomSitesFootnote");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("AtomSitesFootnote",
					       cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("id");
	strk.add(ft);
	ft = new FieldTrans("text");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_ATOM_TYPE(ModuleTrans cmod)
    {
      //___________________________________________________________
      // ATOM_TYPE
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("atom_type",
					    "AtomType");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("AtomType", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("analytical_mass_percent");
	strk.add(ft);
	ft = new FieldTrans("description");
	strk.add(ft);
	ft = new FieldTrans("number_in_cell");
	strk.add(ft);
	ft = new FieldTrans("oxidation_number");
	strk.add(ft);
	ft = new FieldTrans("radius_bond");
	strk.add(ft);
	ft = new FieldTrans("radius_contact");
	strk.add(ft);
	ft = new FieldTrans("scat_cromer_mann_a1",
			    "scat_Cromer_Mann_a1");
	strk.add(ft);
	ft = new FieldTrans("scat_cromer_mann_a2",
			    "scat_Cromer_Mann_a2");
	strk.add(ft);
	ft = new FieldTrans("scat_cromer_mann_a3",
			    "scat_Cromer_Mann_a3");
	strk.add(ft);
	ft = new FieldTrans("scat_cromer_mann_a4",
			    "scat_Cromer_Mann_a4");
	strk.add(ft);
	ft = new FieldTrans("scat_cromer_mann_b1",
			    "scat_Cromer_Mann_b1");
	strk.add(ft);
	ft = new FieldTrans("scat_cromer_mann_b2",
			    "scat_Cromer_Mann_b2");
	strk.add(ft);
	ft = new FieldTrans("scat_cromer_mann_b3",
			    "scat_Cromer_Mann_b3");
	strk.add(ft);
	ft = new FieldTrans("scat_cromer_mann_b4",
			    "scat_Cromer_Mann_b4");
	strk.add(ft);
	ft = new FieldTrans("scat_cromer_mann_c",
			    "scat_Cromer_Mann_c");
	strk.add(ft);
	ft = new FieldTrans("scat_dispersion_imag");
	strk.add(ft);
	ft = new FieldTrans("scat_dispersion_real");
	strk.add(ft);
	ft = new FieldTrans("scat_length_neutron");
	strk.add(ft);
	ft = new FieldTrans("scat_source");
	strk.add(ft);
	ft = new FieldTrans("scat_versus_stol_list");
	strk.add(ft);
	ft = new FieldTrans("symbol");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_AUDIT(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // AUDIT
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("audit",
					    "Audit");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("Audit", cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("creation_date");
	strk.add(ft);
	ft = new FieldTrans("creation_method");
	strk.add(ft);
	ft = new FieldTrans("revision_id");
	strk.add(ft);
	ft = new FieldTrans("update_record");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_AUDIT_AUTHOR(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // AUDIT_AUTHOR
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("audit_author",
					    "AuditAuthor");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("AuditAuthor", cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("address");
	strk.add(ft);
	ft = new FieldTrans("name");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_AUDIT_CONFORM(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // AUDIT_CONFORM
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("audit_conform",
					    "AuditConform");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("AuditConform", cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("dict_location");
	strk.add(ft);
	ft = new FieldTrans("dict_name");
	strk.add(ft);
	ft = new FieldTrans("dict_version");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_AUDIT_CONTACT_AUTHOR(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // AUDIT_CONTACT_AUTHOR
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("audit_contact_author",
					    "AuditContactAuthor");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("AuditContactAuthor",
					       cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("address");
	strk.add(ft);
	ft = new FieldTrans("email");
	strk.add(ft);
	ft = new FieldTrans("fax");
	strk.add(ft);
	ft = new FieldTrans("name");
	strk.add(ft);
	ft = new FieldTrans("phone");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_CELL(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // CELL
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("cell",
					    "Cell");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("Cell", cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans(unitCell, "cell");
	strk.add(ft);
	ft.add(new SubfieldTrans("length_a", "length_a"));
	ft.add(new SubfieldTrans("length_b", "length_b"));
	ft.add(new SubfieldTrans("length_c", "length_c"));
	ft.add(new SubfieldTrans("angle_alpha", "angle_alpha"));
	ft.add(new SubfieldTrans("angle_beta", "angle_beta"));
	ft.add(new SubfieldTrans("angle_gamma", "angle_gamma"));

	ft = new FieldTrans(unitCell, "cell_esd");
	strk.add(ft);
	ft.add(new SubfieldTrans("length_a", "length_a_esd"));
	ft.add(new SubfieldTrans("length_b", "length_b_esd"));
	ft.add(new SubfieldTrans("length_c", "length_c_esd"));
	ft.add(new SubfieldTrans("angle_alpha", "angle_alpha_esd"));
	ft.add(new SubfieldTrans("angle_beta", "angle_beta_esd"));
	ft.add(new SubfieldTrans("angle_gamma", "angle_gamma_esd"));

	ft = new FieldTrans("entry_id");
	strk.add(ft);
	ft = new FieldTrans("details");
	strk.add(ft);

	// formulat_units used only by CHEMICAL_* categories
	// strk.add(ft);
	// ft = new FieldTrans("formula_units_Z");
	// strk.add(ft);

	ft = new FieldTrans("volume");
	strk.add(ft);
	ft = new FieldTrans("volume_esd");
	strk.add(ft);
	ft = new FieldTrans("z_pdb", "Z_PDB");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_CELL_MEASUREMENT(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // CELL_MEASUREMENT
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("cell_measurement",
					    "CellMeasurement");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("CellMeasurement", cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("entry_id");
	strk.add(ft);
	ft = new FieldTrans("pressure");
	strk.add(ft);
	ft = new FieldTrans("pressure_esd");
	strk.add(ft);
	ft = new FieldTrans("radiation");
	strk.add(ft);
	ft = new FieldTrans("reflns_used");
	strk.add(ft);
	ft = new FieldTrans("temp");
	strk.add(ft);
	ft = new FieldTrans("temp_esd");
	strk.add(ft);
	ft = new FieldTrans("theta_max");
	strk.add(ft);
	ft = new FieldTrans("theta_min");
	strk.add(ft);
	ft = new FieldTrans("wavelength");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_CELL_MEASUREMENT_REFLN(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // CELL_MEASUREMENT_REFLN
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("cell_measurement_refln",
					    "CellMeasurementRefln");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("CellMeasurementRefln",
					       cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans(millerIndices, "index");
	strk.add(ft);
	ft.add(new SubfieldTrans("h", "index_h"));
	ft.add(new SubfieldTrans("k", "index_k"));
	ft.add(new SubfieldTrans("l", "index_l"));

	ft = new FieldTrans("theta");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_CHEM_COMP(ModuleTrans cmod)
    {
      //___________________________________________________________
      // CHEM_COMP
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("chem_comp",
					    "ChemComp");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("ChemComp", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("formula");
	strk.add(ft);
	ft = new FieldTrans("formula_weight");
	strk.add(ft);
	ft = new FieldTrans("id");
	strk.add(ft);
	ft = new FieldTrans("model_details");
	strk.add(ft);
	ft = new FieldTrans("model_ext_reference_file", "model_erf");
	strk.add(ft);
	ft = new FieldTrans("model_source");
	strk.add(ft);
	ft = new FieldTrans("mon_nstd_class");
	strk.add(ft);
	ft = new FieldTrans("mon_nstd_details");
	strk.add(ft);
	ft = new FieldTrans("mon_nstd_flag");
	strk.add(ft);
	ft = new FieldTrans("mon_nstd_parent");
	strk.add(ft);
	ft = new FieldTrans("mon_nstd_parent_comp_id");
	strk.add(ft);
	ft = new FieldTrans("name");
	strk.add(ft);
	ft = new FieldTrans("number_atoms_all");
	strk.add(ft);
	ft = new FieldTrans("number_atoms_nh");
	strk.add(ft);
	ft = new FieldTrans("one_letter_code");
	strk.add(ft);
	ft = new FieldTrans("three_letter_code");
	strk.add(ft);
	ft = new FieldTrans("type");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_CHEM_COMP_ANGLE(ModuleTrans cmod)
    {
      //___________________________________________________________
      // CHEM_COMP_ANGLE
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("chem_comp_angle",
					    "ChemCompAngle");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("ChemCompAngle", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("atom_id_1");
	strk.add(ft);
	ft = new FieldTrans("atom_id_2");
	strk.add(ft);
	ft = new FieldTrans("atom_id_3");
	strk.add(ft);
	ft = new FieldTrans("comp_id");
	strk.add(ft);
	ft = new FieldTrans("value_angle");
	strk.add(ft);
	ft = new FieldTrans("value_angle_esd");
	strk.add(ft);
	ft = new FieldTrans("value_dist");
	strk.add(ft);
	ft = new FieldTrans("value_dist_esd");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_CHEM_COMP_ATOM(ModuleTrans cmod)
    {
      //___________________________________________________________
      // CHEM_COMP_ATOM
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("chem_comp_atom",
					    "ChemCompAtom");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("ChemCompAtom", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("alt_atom_id");
	strk.add(ft);
	ft = new FieldTrans("atom_id");
	strk.add(ft);
	ft = new FieldTrans("charge");
	strk.add(ft);

	ft = new FieldTrans(stVectorXYZ, "model_cartn");
	strk.add(ft);
	ft.add(new SubfieldTrans("x", "model_Cartn_x"));
	ft.add(new SubfieldTrans("y", "model_Cartn_y"));
	ft.add(new SubfieldTrans("z", "model_Cartn_z"));
	ft = new FieldTrans(stVectorXYZ, "model_cartn_esd");
	strk.add(ft);
	ft.add(new SubfieldTrans("x", "model_Cartn_x_esd"));
	ft.add(new SubfieldTrans("y", "model_Cartn_y_esd"));
	ft.add(new SubfieldTrans("z", "model_Cartn_z_esd"));

	ft = new FieldTrans("comp_id");
	strk.add(ft);
	ft = new FieldTrans("partial_charge");
	strk.add(ft);
	ft = new FieldTrans("substruct_code");
	strk.add(ft);
	ft = new FieldTrans("type_symbol");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_CHEM_COMP_BOND(ModuleTrans cmod)
    {
      //___________________________________________________________
      // CHEM_COMP_BOND
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("chem_comp_bond",
					    "ChemCompBond");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("ChemCompBond", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("atom_id_1");
	strk.add(ft);
	ft = new FieldTrans("atom_id_2");
	strk.add(ft);
	ft = new FieldTrans("comp_id");
	strk.add(ft);
	ft = new FieldTrans("value_order");
	strk.add(ft);
	ft = new FieldTrans("value_dist");
	strk.add(ft);
	ft = new FieldTrans("value_dist_esd");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_CHEM_COMP_CHIR(ModuleTrans cmod)
    {
      //___________________________________________________________
      // CHEM_COMP_CHIR
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("chem_comp_chir",
					    "ChemCompChir");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("ChemCompChir", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("atom_id");
	strk.add(ft);
	ft = new FieldTrans("atom_config");
	strk.add(ft);
	ft = new FieldTrans("id");
	strk.add(ft);
	ft = new FieldTrans("comp_id");
	strk.add(ft);
	ft = new FieldTrans("number_atoms_all");
	strk.add(ft);
	ft = new FieldTrans("number_atoms_nh");
	strk.add(ft);
	ft = new FieldTrans("volume_flag");
	strk.add(ft);
	ft = new FieldTrans("volume_three");
	strk.add(ft);
	ft = new FieldTrans("volume_three_esd");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_CHEM_COMP_CHIR_ATOM(ModuleTrans cmod)
    {
      //___________________________________________________________
      // CHEM_COMP_CHIR_ATOM
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("chem_comp_chir_atom",
					    "ChemCompChirAtom");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("ChemCompChirAtom", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("atom_id");
	strk.add(ft);
	ft = new FieldTrans("chir_id");
	strk.add(ft);
	ft = new FieldTrans("comp_id");
	strk.add(ft);
	ft = new FieldTrans("dev");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_CHEM_COMP_LINK(ModuleTrans cmod)
    {
      //___________________________________________________________
      // CHEM_COMP_LINK
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("chem_comp_link",
					    "ChemCompLink");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("ChemCompLink", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("link_id");
	strk.add(ft);
	ft = new FieldTrans("details");
	strk.add(ft);
	ft = new FieldTrans("type_comp_1");
	strk.add(ft);
	ft = new FieldTrans("type_comp_2");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_CHEM_COMP_PLANE(ModuleTrans cmod)
    {
      //___________________________________________________________
      // CHEM_COMP_PLANE
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("chem_comp_plane",
					    "ChemCompPlane");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("ChemCompPlane", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("id");
	strk.add(ft);
	ft = new FieldTrans("comp_id");
	strk.add(ft);
	ft = new FieldTrans("number_atoms_all");
	strk.add(ft);
	ft = new FieldTrans("number_atoms_nh");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_CHEM_COMP_PLANE_ATOM(ModuleTrans cmod)
    {
      //___________________________________________________________
      // CHEM_COMP_PLANE_ATOM
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("chem_comp_plane_atom",
					    "ChemCompPlaneAtom");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("ChemCompPlaneAtom", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("atom_id");
	strk.add(ft);
	ft = new FieldTrans("comp_id");
	strk.add(ft);
	ft = new FieldTrans("plane_id");
	strk.add(ft);
	ft = new FieldTrans("dist_esd");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_CHEM_COMP_TOR(ModuleTrans cmod)
    {
      //___________________________________________________________
      // CHEM_COMP_TOR
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("chem_comp_tor",
					    "ChemCompTor");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("ChemCompTor", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("atom_id_1");
	strk.add(ft);
	ft = new FieldTrans("atom_id_2");
	strk.add(ft);
	ft = new FieldTrans("atom_id_3");
	strk.add(ft);
	ft = new FieldTrans("atom_id_4");
	strk.add(ft);
	ft = new FieldTrans("id");
	strk.add(ft);
	ft = new FieldTrans("comp_id");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_CHEM_COMP_TOR_VALUE(ModuleTrans cmod)
    {
      //___________________________________________________________
      // CHEM_COMP_TOR_VALUE
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("chem_comp_tor_value",
					    "ChemCompTorValue");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("ChemCompTorValue", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("comp_id");
	strk.add(ft);
	ft = new FieldTrans("tor_id");
	strk.add(ft);
	ft = new FieldTrans("angle");
	strk.add(ft);
	ft = new FieldTrans("angle_esd");
	strk.add(ft);
	ft = new FieldTrans("dist");
	strk.add(ft);
	ft = new FieldTrans("dist_esd");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_CHEM_LINK(ModuleTrans cmod)
    {
      //___________________________________________________________
      // CHEM_LINK
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("chem_link",
					    "ChemLink");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("ChemLink", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("id");
	strk.add(ft);
	ft = new FieldTrans("details");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_CHEM_LINK_ANGLE(ModuleTrans cmod)
    {
      //___________________________________________________________
      // CHEM_LINK_ANGLE
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("chem_link_angle",
					    "ChemLinkAngle");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("ChemLinkAngle", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("atom_1_comp_id");
	strk.add(ft);
	ft = new FieldTrans("atom_2_comp_id");
	strk.add(ft);
	ft = new FieldTrans("atom_3_comp_id");
	strk.add(ft);
	ft = new FieldTrans("atom_id_1");
	strk.add(ft);
	ft = new FieldTrans("atom_id_2");
	strk.add(ft);
	ft = new FieldTrans("atom_id_3");
	strk.add(ft);
	ft = new FieldTrans("link_id");
	strk.add(ft);
	ft = new FieldTrans("value_angle");
	strk.add(ft);
	ft = new FieldTrans("value_angle_esd");
	strk.add(ft);
	ft = new FieldTrans("value_dist");
	strk.add(ft);
	ft = new FieldTrans("value_dist_esd");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_CHEM_LINK_BOND(ModuleTrans cmod)
    {
      //___________________________________________________________
      // CHEM_LINK_BOND
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("chem_link_bond",
					    "ChemLinkBond");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("ChemLinkBond", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("atom_1_comp_id");
	strk.add(ft);
	ft = new FieldTrans("atom_2_comp_id");
	strk.add(ft);
	ft = new FieldTrans("atom_id_1");
	strk.add(ft);
	ft = new FieldTrans("atom_id_2");
	strk.add(ft);
	ft = new FieldTrans("link_id");
	strk.add(ft);
	ft = new FieldTrans("value_dist");
	strk.add(ft);
	ft = new FieldTrans("value_dist_esd");
	strk.add(ft);
	ft = new FieldTrans("value_order");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_CHEM_LINK_CHIR(ModuleTrans cmod)
    {
      //___________________________________________________________
      // CHEM_LINK_CHIR
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("chem_link_chir",
					    "ChemLinkChir");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("ChemLinkChir", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("atom_comp_id");
	strk.add(ft);
	ft = new FieldTrans("atom_id");
	strk.add(ft);
	ft = new FieldTrans("atom_config");
	strk.add(ft);
	ft = new FieldTrans("id");
	strk.add(ft);
	ft = new FieldTrans("link_id");
	strk.add(ft);
	ft = new FieldTrans("number_atoms_all");
	strk.add(ft);
	ft = new FieldTrans("number_atoms_nh");
	strk.add(ft);
	ft = new FieldTrans("volume_flag");
	strk.add(ft);
	ft = new FieldTrans("volume_three");
	strk.add(ft);
	ft = new FieldTrans("volume_three_esd");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_CHEM_LINK_CHIR_ATOM(ModuleTrans cmod)
    {
      //___________________________________________________________
      // CHEM_LINK_CHIR_ATOM
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("chem_link_chir_atom",
					    "ChemLinkChirAtom");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("ChemLinkChirAtom", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("atom_comp_id");
	strk.add(ft);
	ft = new FieldTrans("atom_id");
	strk.add(ft);
	ft = new FieldTrans("chir_id");
	strk.add(ft);
	ft = new FieldTrans("dev");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_CHEM_LINK_PLANE(ModuleTrans cmod)
    {
      //___________________________________________________________
      // CHEM_LINK_PLANE
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("chem_link_plane",
					    "ChemLinkPlane");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("ChemLinkPlane", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("id");
	strk.add(ft);
	ft = new FieldTrans("link_id");
	strk.add(ft);
	ft = new FieldTrans("number_atoms_all");
	strk.add(ft);
	ft = new FieldTrans("number_atoms_nh");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_CHEM_LINK_PLANE_ATOM(ModuleTrans cmod)
    {
      //___________________________________________________________
      // CHEM_LINK_PLANE_ATOM
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("chem_link_plane_atom",
					    "ChemLinkPlaneAtom");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("ChemLinkPlaneAtom", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("atom_comp_id");
	strk.add(ft);
	ft = new FieldTrans("atom_id");
	strk.add(ft);
	ft = new FieldTrans("plane_id");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_CHEM_LINK_TOR(ModuleTrans cmod)
    {
      //___________________________________________________________
      // CHEM_LINK_TOR
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("chem_link_tor",
					    "ChemLinkTor");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("ChemLinkTor", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("atom_1_comp_id");
	strk.add(ft);
	ft = new FieldTrans("atom_2_comp_id");
	strk.add(ft);
	ft = new FieldTrans("atom_3_comp_id");
	strk.add(ft);
	ft = new FieldTrans("atom_4_comp_id");
	strk.add(ft);
	ft = new FieldTrans("atom_id_1");
	strk.add(ft);
	ft = new FieldTrans("atom_id_2");
	strk.add(ft);
	ft = new FieldTrans("atom_id_3");
	strk.add(ft);
	ft = new FieldTrans("atom_id_4");
	strk.add(ft);
	ft = new FieldTrans("id");
	strk.add(ft);
	ft = new FieldTrans("link_id");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_CHEM_LINK_TOR_VALUE(ModuleTrans cmod)
    {
      //___________________________________________________________
      // CHEM_LINK_TOR_VALUE
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("chem_link_tor_value",
					    "ChemLinkTorValue");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("ChemLinkTorValue", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("tor_id");
	strk.add(ft);
	ft = new FieldTrans("angle");
	strk.add(ft);
	ft = new FieldTrans("angle_esd");
	strk.add(ft);
	ft = new FieldTrans("dist");
	strk.add(ft);
	ft = new FieldTrans("dist_esd");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_CITATION(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // CITATION
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("citation",
					    "Citation");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("Citation", cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("abstract_text",
			    "abstract");
	strk.add(ft);
	ft = new FieldTrans("abstract_id_CAS");
	strk.add(ft);
	ft = new FieldTrans("book_id_isbn",
			    "book_id_ISBN");
	strk.add(ft);
	ft = new FieldTrans("book_publisher");
	strk.add(ft);
	ft = new FieldTrans("book_publisher_city");
	strk.add(ft);
	ft = new FieldTrans("book_title");
	strk.add(ft);
	ft = new FieldTrans("coordinate_linkage");
	strk.add(ft);
	ft = new FieldTrans("country");
	strk.add(ft);
	ft = new FieldTrans("database_id_medline",
			    "database_id_Medline");
	strk.add(ft);
	ft = new FieldTrans("details");
	strk.add(ft);
	ft = new FieldTrans("id");
	strk.add(ft);
	ft = new FieldTrans("journal_abbrev");
	strk.add(ft);
	ft = new FieldTrans("journal_id_astm",
			    "journal_id_ASTM");
	strk.add(ft);
	ft = new FieldTrans("journal_id_csd",
			    "journal_id_CSD");
	strk.add(ft);
	ft = new FieldTrans("journal_id_issn",
			    "journal_id_ISSN");
	strk.add(ft);
	ft = new FieldTrans("journal_full");
	strk.add(ft);
	ft = new FieldTrans("journal_issue");
	strk.add(ft);
	ft = new FieldTrans("journal_volume");
	strk.add(ft);
	ft = new FieldTrans("language");
	strk.add(ft);
	ft = new FieldTrans("page_first");
	strk.add(ft);
	ft = new FieldTrans("page_last");
	strk.add(ft);
	ft = new FieldTrans("title");
	strk.add(ft);
	ft = new FieldTrans("year");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_CITATION_AUTHOR(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // CITATION_AUTHOR
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("citation_author",
					    "CitationAuthor");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("CitationAuthor", cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("citation_id");
	strk.add(ft);
	ft = new FieldTrans("name");
	strk.add(ft);
	ft = new FieldTrans("ordinal");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_CITATION_EDITOR(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // CITATION_EDITOR
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("citation_editor",
					    "CitationEditor");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("CitationEditor", cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("citation_id");
	strk.add(ft);
	ft = new FieldTrans("name");
	strk.add(ft);
	ft = new FieldTrans("ordinal");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_COMPUTING(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // COMPUTING
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("computing",
					    "Computing");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("Computing", cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("entry_id");
	strk.add(ft);
	ft = new FieldTrans("cell_refinement");
	strk.add(ft);
	ft = new FieldTrans("data_collection");
	strk.add(ft);
	ft = new FieldTrans("data_reduction");
	strk.add(ft);
	ft = new FieldTrans("molecular_graphics");
	strk.add(ft);
	ft = new FieldTrans("publication_material");
	strk.add(ft);
	ft = new FieldTrans("structure_refinement");
	strk.add(ft);
	ft = new FieldTrans("structure_solution");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_DATABASE(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // DATABASE
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("database",
					    "Database");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("Database", cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("entry_id");
	strk.add(ft);
	ft = new FieldTrans("code_cas",
			    "code_CAS");
	strk.add(ft);
	ft = new FieldTrans("code_csd",
			    "code_CSD");
	strk.add(ft);
	ft = new FieldTrans("code_icsd",
			    "code_ICSD");
	strk.add(ft);
	ft = new FieldTrans("code_mdf",
			    "code_MDF");
	strk.add(ft);
	ft = new FieldTrans("code_nbs",
			    "code_NBS");
	strk.add(ft);
	ft = new FieldTrans("code_pdf",
			    "code_PDF");
	strk.add(ft);
	ft = new FieldTrans("journal_astm",
			    "journal_ASTM");
	strk.add(ft);
	ft = new FieldTrans("journal_csd",
			    "journal_CSD");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_DATABASE_2(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // DATABASE_2
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("database_2",
					    "Database");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("Database", cat, modQual, 2);
      cat.add(strk);
      {
	ft = new FieldTrans("database_id");
	strk.add(ft);
	ft = new FieldTrans("database_code");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_DATABASE_PDB_CAVEAT(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // DATABASE_PDB_CAVEAT
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("database_PDB_caveat",
					    "DatabasePdbCaveat");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("DatabasePdbCaveat",
					       cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("id");
	strk.add(ft);
	ft = new FieldTrans("text");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_DATABASE_PDB_MATRIX(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // DATABASE_PDB_MATRIX
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("database_PDB_matrix",
					    "DatabasePdbMatrix");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("DatabasePdbMatrix",
					       cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("entry_id");
	strk.add(ft);
	ft = new MatrixTrans("origx");
	strk.add(ft);
	ft = new VectorTrans("origx_vector");
	strk.add(ft);
	ft = new MatrixTrans("scale");
	strk.add(ft);
	ft = new VectorTrans("scale_vector");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_DATABASE_PDB_REMARK(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // DATABASE_PDB_REMARK
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("database_PDB_remark",
					    "DatabasePdbRemark");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("DatabasePdbRemark",
					       cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("id");
	strk.add(ft);
	ft = new FieldTrans("text");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_DATABASE_PDB_REV(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // DATABASE_PDB_REV
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("database_PDB_rev",
					    "DatabasePdbRev");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("DatabasePdbRev",
					       cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("author_name");
	strk.add(ft);
	ft = new FieldTrans("date");
	strk.add(ft);
	ft = new FieldTrans("date_original");
	strk.add(ft);
	ft = new FieldTrans("mod_type");
	strk.add(ft);
	ft = new FieldTrans("num");
	strk.add(ft);
	ft = new FieldTrans("replaced_by");
	strk.add(ft);
	ft = new FieldTrans("replaces");
	strk.add(ft);
	ft = new FieldTrans("status");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_DATABASE_PDB_REV_RECORD(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // DATABASE_PDB_REV_RECORD
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("database_PDB_rev_record",
					    "DatabasePdbRevRecord");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("DatabasePdbRevRecord", 
					       cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("details");
	strk.add(ft);
	ft = new FieldTrans("rev_num");
	strk.add(ft);
	ft = new FieldTrans("type");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_DATABASE_PDB_TVECT(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // DATABASE_PDB_TVECT
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("database_PDB_tvect",
					    "DatabasePdbTvect");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("DatabasePdbTvect",
					       cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("details");
	strk.add(ft);
	ft = new FieldTrans("id");
	strk.add(ft);
	ft = new VectorTrans("vector");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_DIFFRN(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // DIFFRN
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("diffrn",
					    "Diffrn");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("Diffrn", cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("ambient_environment");
	strk.add(ft);
	ft = new FieldTrans("ambient_pressure");
	strk.add(ft);
	ft = new FieldTrans("ambient_pressure_esd");
	strk.add(ft);
	ft = new FieldTrans("ambient_temp");
	strk.add(ft);
	ft = new FieldTrans("ambient_temp_details");
	strk.add(ft);
	ft = new FieldTrans("ambient_temp_esd");
	strk.add(ft);
	ft = new FieldTrans("crystal_id");
	strk.add(ft);
	ft = new FieldTrans("crystal_support");
	strk.add(ft);
	ft = new FieldTrans("crystal_treatment");
	strk.add(ft);
	ft = new FieldTrans("details");
	strk.add(ft);
	ft = new FieldTrans("id");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_DIFFRN_ATTENUATOR(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // DIFFRN_ATTENUATOR
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("diffrn_attenuator",
					    "DiffrnAttenuator");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("DiffrnAttenuator", 
					       cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("code");
	strk.add(ft);
	ft = new FieldTrans("scale");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_DIFFRN_DETECTOR(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // DIFFRN_DETECTOR
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("diffrn_detector",
					    "DiffrnDetector");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("DiffrnDetector",
					       cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("details");
	strk.add(ft);
	ft = new FieldTrans("detector");
	strk.add(ft);
	ft = new FieldTrans("diffrn_id");
	strk.add(ft);
	ft = new FieldTrans("dtime");
	strk.add(ft);
	ft = new FieldTrans("type");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_DIFFRN_MEASUREMENT(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // DIFFRN_MEASUREMENT
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("diffrn_measurement",
					    "DiffrnMeasurement");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("DiffrnMeasurement", 
					       cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("diffrn_id");
	strk.add(ft);
	ft = new FieldTrans("details");
	strk.add(ft);
	ft = new FieldTrans("device");
	strk.add(ft);
	ft = new FieldTrans("device_details");
	strk.add(ft);
	ft = new FieldTrans("device_type");
	strk.add(ft);
	ft = new FieldTrans("method");
	strk.add(ft);
	ft = new FieldTrans("specimen_support");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_DIFFRN_ORIENT_MATRIX(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // DIFFRN_ORIENT_MATRIX
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("diffrn_orient_matrix",
					    "DiffrnOrientMatrix");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("DiffrnOrientMatrix",
					       cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("diffrn_id");
	strk.add(ft);
	ft = new FieldTrans("type");
	strk.add(ft);
	ft = new MatrixTrans("ub",
			     "UB", "", false);
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_DIFFRN_ORIENT_REFLN(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // DIFFRN_ORIENT_REFLN
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("diffrn_orient_refln",
					    "DiffrnOrientRefln");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("DiffrnOrientRefln", 
					       cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("angle_chi");
	strk.add(ft);
	ft = new FieldTrans("angle_kappa");
	strk.add(ft);
	ft = new FieldTrans("angle_omega");
	strk.add(ft);
	ft = new FieldTrans("angle_phi");
	strk.add(ft);
	ft = new FieldTrans("angle_psi");
	strk.add(ft);
	ft = new FieldTrans("angle_theta");
	strk.add(ft);
	ft = new FieldTrans("diffrn_id");
	strk.add(ft);

	ft = new FieldTrans(millerIndices, "index");
	strk.add(ft);
	ft.add(new SubfieldTrans("h", "index_h"));
	ft.add(new SubfieldTrans("k", "index_k"));
	ft.add(new SubfieldTrans("l", "index_l"));
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_DIFFRN_RADIATION(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // DIFFRN_RADIATION
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("diffrn_radiation",
					    "DiffrnRadiation");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("DiffrnRadiation", 
					       cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("collimation");
	strk.add(ft);
	ft = new FieldTrans("diffrn_id");
	strk.add(ft);
	ft = new FieldTrans("filter_edge");
	strk.add(ft);
	ft = new FieldTrans("inhomogeneity");
	strk.add(ft);
	ft = new FieldTrans("monochromator");
	strk.add(ft);
	ft = new FieldTrans("polarisn_norm");
	strk.add(ft);
	ft = new FieldTrans("polarisn_ratio");
	strk.add(ft);
	ft = new FieldTrans("probe");
	strk.add(ft);
	ft = new FieldTrans("type");
	strk.add(ft);
	ft = new FieldTrans("xray_symbol");
	strk.add(ft);
	ft = new FieldTrans("wavelength_code", "wavelength_id");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_DIFFRN_RADIATION_WAVELENGTH(ModuleTrans cmod,
					     ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // DIFFRN_RADIATION_WAVELENGTH
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("diffrn_radiation_wavelength",
					    "DiffrnRadiationWavelength");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("DiffrnRadiationWavelength",
					       cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("id");
	strk.add(ft);
	ft = new FieldTrans("wavelength");
	strk.add(ft);
	ft = new FieldTrans("wt");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_DIFFRN_REFLN(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // DIFFRN_REFLN
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("diffrn_refln",
					    "DiffrnRefln");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("DiffrnRefln", cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("angle_chi");
	strk.add(ft);
	ft = new FieldTrans("angle_kappa");
	strk.add(ft);
	ft = new FieldTrans("angle_omega");
	strk.add(ft);
	ft = new FieldTrans("angle_phi");
	strk.add(ft);
	ft = new FieldTrans("angle_psi");
	strk.add(ft);
	ft = new FieldTrans("angle_theta");
	strk.add(ft);
	ft = new FieldTrans("attenuator_code");
	strk.add(ft);
	ft = new FieldTrans("counts_bg_1");
	strk.add(ft);
	ft = new FieldTrans("counts_bg_2");
	strk.add(ft);
	ft = new FieldTrans("counts_net");
	strk.add(ft);
	ft = new FieldTrans("counts_peak");
	strk.add(ft);
	ft = new FieldTrans("counts_total");
	strk.add(ft);
	ft = new FieldTrans("detect_slit_horiz");
	strk.add(ft);
	ft = new FieldTrans("detect_slit_vert");
	strk.add(ft);
	ft = new FieldTrans("diffrn_id");
	strk.add(ft);
	ft = new FieldTrans("elapsed_time");
	strk.add(ft);
	ft = new FieldTrans("id");
	strk.add(ft);

	ft = new FieldTrans(millerIndices, "index");
	strk.add(ft);
	ft.add(new SubfieldTrans("h", "index_h"));
	ft.add(new SubfieldTrans("k", "index_k"));
	ft.add(new SubfieldTrans("l", "index_l"));

	ft = new FieldTrans("intensity_net");
	strk.add(ft);
	ft = new FieldTrans("intensity_sigma");
	strk.add(ft);
	ft = new FieldTrans("scale_group_code");
	strk.add(ft);
	ft = new FieldTrans("scan_mode");
	strk.add(ft);
	ft = new FieldTrans("scan_mode_backgd");
	strk.add(ft);
	ft = new FieldTrans("scan_rate");
	strk.add(ft);
	ft = new FieldTrans("scan_time_backgd");
	strk.add(ft);
	ft = new FieldTrans("scan_width");
	strk.add(ft);
	ft = new FieldTrans("sint_over_lambda");
	strk.add(ft);
	ft = new FieldTrans("standard_code");
	strk.add(ft);
	ft = new FieldTrans("wavelength");
	strk.add(ft);
	ft = new FieldTrans("wavelength_code", "wavelength_id");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_DIFFRN_REFLNS(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // DIFFRN_REFLNS
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("diffrn_reflns",
					    "DiffrnReflns");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("DiffrnReflns", cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("av_r_equivalents", "av_R_equivalents");
	strk.add(ft);
	ft = new FieldTrans("av_sigmaI_over_netI");
	strk.add(ft);
	ft = new FieldTrans("diffrn_id");
	strk.add(ft);

	ft = new FieldTrans(millerIndices, "limit_min");
	strk.add(ft);
	ft.add(new SubfieldTrans("h", "limit_h_min"));
	ft.add(new SubfieldTrans("k", "limit_k_min"));
	ft.add(new SubfieldTrans("l", "limit_l_min"));

	ft = new FieldTrans(millerIndices, "limit_max");
	strk.add(ft);
	ft.add(new SubfieldTrans("h", "limit_h_max"));
	ft.add(new SubfieldTrans("k", "limit_k_max"));
	ft.add(new SubfieldTrans("l", "limit_l_max"));

	ft = new FieldTrans("number");
	strk.add(ft);
	ft = new FieldTrans("reduction_process");
	strk.add(ft);
	ft = new FieldTrans("theta_max");
	strk.add(ft);
	ft = new FieldTrans("theta_min");
	strk.add(ft);
	ft = new MatrixTrans("transf_matrix");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_DIFFRN_SCALE_GROUP(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // DIFFRN_SCALE_GROUP
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("diffrn_scale_group",
					    "DiffrnScaleGroup");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("DiffrnScaleGroup", cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("code");
	strk.add(ft);
	ft = new FieldTrans("i_net", "I_net");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_DIFFRN_SOURCE(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // DIFFRN_SOURCE
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("diffrn_source",
					    "DiffrnSource");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("DiffrnSource", cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("current");
	strk.add(ft);
	ft = new FieldTrans("details");
	strk.add(ft);
	ft = new FieldTrans("diffrn_id");
	strk.add(ft);
	ft = new FieldTrans("power");
	strk.add(ft);
	ft = new FieldTrans("size");
	strk.add(ft);
	ft = new FieldTrans("source");
	strk.add(ft);
	ft = new FieldTrans("target");
	strk.add(ft);
	ft = new FieldTrans("type");
	strk.add(ft);
	ft = new FieldTrans("voltage");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_DIFFRN_STANDARD_REFLN(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // DIFFRN_STANDARD_REFLN
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("diffrn_standard_refln",
					    "DiffrnStandardRefln");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("DiffrnStandardRefln",
					       cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("code");
	strk.add(ft);
	ft = new FieldTrans("diffrn_id");
	strk.add(ft);

	ft = new FieldTrans(millerIndices, "index");
	strk.add(ft);
	ft.add(new SubfieldTrans("h", "index_h"));
	ft.add(new SubfieldTrans("k", "index_k"));
	ft.add(new SubfieldTrans("l", "index_l"));
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_DIFFRN_STANDARDS(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // DIFFRN_STANDARDS
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("diffrn_standards",
					    "DiffrnStandards");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("DiffrnStandards",
					       cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("diffrn_id");
	strk.add(ft);
	ft = new FieldTrans("decay_percent",
			    "decay_%");
	strk.add(ft);
	ft = new FieldTrans("interval_count");
	strk.add(ft);
	ft = new FieldTrans("interval_time");
	strk.add(ft);
	ft = new FieldTrans("number");
	strk.add(ft);
	ft = new FieldTrans("scale_sigma");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_ENTITY(ModuleTrans cmod)
    {
      //___________________________________________________________
      // ENTITY
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("entity",
					    "Entity");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("Entity", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("details");
	strk.add(ft);
	ft = new FieldTrans("formula_weight");
	strk.add(ft);
	ft = new FieldTrans("id");
	strk.add(ft);
	ft = new FieldTrans("src_method");
	strk.add(ft);
	ft = new FieldTrans("type");
	strk.add(ft);
 	ft = new FieldTrans("description", "pdbx_description");
 	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_ENTITY_KEYWORDS(ModuleTrans cmod)
    {
      //___________________________________________________________
      // ENTITY_KEYWORDS
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("entity_keywords",
					    "EntityKeywords");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("EntityKeywords", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("entity_id");
	strk.add(ft);
	ft = new FieldTrans("text");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_ENTITY_LINK(ModuleTrans cmod)
    {
      //___________________________________________________________
      // ENTITY_LINK
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("entity_link",
					    "EntityLink");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("EntityLink", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("link_id");
	strk.add(ft);
	ft = new FieldTrans("details");
	strk.add(ft);
	ft = new FieldTrans("entity_id_1");
	strk.add(ft);
	ft = new FieldTrans("entity_id_2");
	strk.add(ft);
	ft = new FieldTrans("entity_seq_num_1");
	strk.add(ft);
	ft = new FieldTrans("entity_seq_num_2");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_ENTITY_NAME_COM(ModuleTrans cmod)
    {
      //___________________________________________________________
      // ENTITY_NAME_COM
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("entity_name_com",
					    "EntityNameCom");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("EntityNameCom", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("entity_id");
	strk.add(ft);
	ft = new FieldTrans("name");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_ENTITY_NAME_SYS(ModuleTrans cmod)
    {
      //___________________________________________________________
      // ENTITY_NAME_SYS
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("entity_name_sys",
					    "EntityNameSys");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("EntityNameSys", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("entity_id");
	strk.add(ft);
	ft = new FieldTrans("name");
	strk.add(ft);
	ft = new FieldTrans("system");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_ENTITY_POLY(ModuleTrans cmod)
    {
      //___________________________________________________________
      // ENTITY_POLY
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("entity_poly",
					    "EntityPoly");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("EntityPoly", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("entity_id");
	strk.add(ft);
	ft = new FieldTrans("nstd_chirality");
	strk.add(ft);
	ft = new FieldTrans("nstd_linkage");
	strk.add(ft);
	ft = new FieldTrans("nstd_monomer");
	strk.add(ft);
	ft = new FieldTrans("number_of_monomers");
	strk.add(ft);
	ft = new FieldTrans("type");
	strk.add(ft);
	ft = new FieldTrans("type_details");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_ENTITY_POLY_SEQ(ModuleTrans cmod)
    {
      //___________________________________________________________
      // ENTITY_POLY_SEQ
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("entity_poly_seq",
					    "EntityPolySeq");
      cmod.add(cat);
      // StructureTrans strk = defaultContainer("EntityPolySeq", cat);
      StructureTrans strk
	= new StructureTrans("EntityPolySeq", cat, null, MAX_PARAGRAPHS);
      strk.setUseBlockMethod(true);
      cat.add(strk);
      {
	ft = new FieldTrans("entity_id");
	strk.add(ft);
	ft = new FieldTrans("hetero");
	strk.add(ft);
	ft = new FieldTrans("mon_id");
	strk.add(ft);
	ft = new FieldTrans("num");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_ENTITY_SRC_GEN(ModuleTrans cmod)
    {
      //___________________________________________________________
      // ENTITY_SRC_GEN
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("entity_src_gen",
					    "EntitySrcGen");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("EntitySrcGen", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("entity_id");
	strk.add(ft);
	ft = new FieldTrans("gene_src_common_name");
	strk.add(ft);
	ft = new FieldTrans("gene_src_details");
	strk.add(ft);
	ft = new FieldTrans("gene_src_genus");
	strk.add(ft);
	ft = new FieldTrans("gene_src_species");
	strk.add(ft);
	ft = new FieldTrans("gene_src_strain");
	strk.add(ft);
	ft = new FieldTrans("gene_src_tissue");
	strk.add(ft);
	ft = new FieldTrans("gene_src_tissue_fraction");
	strk.add(ft);
	ft = new FieldTrans("host_org_common_name");
	strk.add(ft);
	ft = new FieldTrans("host_org_details");
	strk.add(ft);
	ft = new FieldTrans("host_org_genus");
	strk.add(ft);
	ft = new FieldTrans("host_org_species");
	strk.add(ft);
	ft = new FieldTrans("host_org_strain");
	strk.add(ft);
	ft = new FieldTrans("plasmid_details");
	strk.add(ft);
	ft = new FieldTrans("plasmid_name");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_ENTITY_SRC_NAT(ModuleTrans cmod)
    {
      //___________________________________________________________
      // ENTITY_SRC_NAT
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("entity_src_nat",
					    "EntitySrcNat");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("EntitySrcNat", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("common_name");
	strk.add(ft);
	ft = new FieldTrans("details");
	strk.add(ft);
	ft = new FieldTrans("entity_id");
	strk.add(ft);
	ft = new FieldTrans("genus");
	strk.add(ft);
	ft = new FieldTrans("species");
	strk.add(ft);
	ft = new FieldTrans("strain");
	strk.add(ft);
	ft = new FieldTrans("tissue");
	strk.add(ft);
	ft = new FieldTrans("tissue_fraction");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_ENTRY_LINK(ModuleTrans cmod)
    {
      //___________________________________________________________
      // ENTRY_LINK
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("entry_link",
					    "EntryLink");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("EntryLink", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("entry_id");
	strk.add(ft);
	ft = new FieldTrans("id");
	strk.add(ft);
	ft = new FieldTrans("details");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_EXPTL(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // EXPTL
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("exptl",
					    "Exptl");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("Exptl", cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("absorpt_coefficient_mu");
	strk.add(ft);
	ft = new FieldTrans("absorpt_correction_t_max",
			    "absorpt_correction_T_max");
	strk.add(ft);
	ft = new FieldTrans("absorpt_correction_t_min",
			    "absorpt_correction_T_min");
	strk.add(ft);
	ft = new FieldTrans("absorpt_correction_type");
	strk.add(ft);
	ft = new FieldTrans("absorpt_process_details");
	strk.add(ft);
	ft = new FieldTrans("entry_id");
	strk.add(ft);
	ft = new FieldTrans("crystals_number");
	strk.add(ft);
	ft = new FieldTrans("details");
	strk.add(ft);
	ft = new FieldTrans("method");
	strk.add(ft);
	ft = new FieldTrans("method_details");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_EXPTL_CRYSTAL(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // EXPTL_CRYSTAL
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("exptl_crystal",
					    "ExptlCrystal");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("ExptlCrystal", cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("colour");
	strk.add(ft);
	ft = new FieldTrans("density_diffrn");
	strk.add(ft);
	ft = new FieldTrans("density_matthews",
			    "density_Matthews");
	strk.add(ft);
	ft = new FieldTrans("density_meas");
	strk.add(ft);
	ft = new FieldTrans("density_meas_temp");
	strk.add(ft);
	ft = new FieldTrans("density_method");
	strk.add(ft);
	ft = new FieldTrans("density_percent_sol");
	strk.add(ft);
	ft = new FieldTrans("description");
	strk.add(ft);
	ft = new FieldTrans("f_000",
			    "F_000");
	strk.add(ft);
	ft = new FieldTrans("id");
	strk.add(ft);
	ft = new FieldTrans("preparation");
	strk.add(ft);
	ft = new FieldTrans("size_max");
	strk.add(ft);
	ft = new FieldTrans("size_mid");
	strk.add(ft);
	ft = new FieldTrans("size_min");
	strk.add(ft);
	ft = new FieldTrans("size_rad");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_EXPTL_CRYSTAL_FACE(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // EXPTL_CRYSTAL_FACE
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("exptl_crystal_face",
					    "ExptlCrystalFace");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("ExptlCrystalFace",
					       cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("crystal_id");
	strk.add(ft);
	ft = new FieldTrans("diffr_chi");
	strk.add(ft);
	ft = new FieldTrans("diffr_kappa");
	strk.add(ft);
	ft = new FieldTrans("diffr_phi");
	strk.add(ft);
	ft = new FieldTrans("diffr_psi");
	strk.add(ft);

	ft = new FieldTrans(millerIndices, "index");
	strk.add(ft);
	ft.add(new SubfieldTrans("h", "index_h"));
	ft.add(new SubfieldTrans("k", "index_k"));
	ft.add(new SubfieldTrans("l", "index_l"));

	ft = new FieldTrans("perp_dist");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_EXPTL_CRYSTAL_GROW(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // EXPTL_CRYSTAL_GROW
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("exptl_crystal_grow",
					    "ExptlCrystalGrow");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("ExptlCrystalGrow", 
					       cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("apparatus");
	strk.add(ft);
	ft = new FieldTrans("atmosphere");
	strk.add(ft);
	ft = new FieldTrans("crystal_id");
	strk.add(ft);
	ft = new FieldTrans("details");
	strk.add(ft);
	ft = new FieldTrans("method");
	strk.add(ft);
	ft = new FieldTrans("method_ref");
	strk.add(ft);
	ft = new FieldTrans("ph",
			    "pH");
	strk.add(ft);
	ft = new FieldTrans("pressure");
	strk.add(ft);
	ft = new FieldTrans("pressure_esd");
	strk.add(ft);
	ft = new FieldTrans("seeding");
	strk.add(ft);
	ft = new FieldTrans("seeding_ref");
	strk.add(ft);
	ft = new FieldTrans("temp");
	strk.add(ft);
	ft = new FieldTrans("temp_details");
	strk.add(ft);
	ft = new FieldTrans("temp_esd");
	strk.add(ft);
	ft = new FieldTrans("time");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_EXPTL_CRYSTAL_GROW_COMP(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // EXPTL_CRYSTAL_GROW_COMP
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("exptl_crystal_grow_comp",
					    "ExptlCrystalGrowComp");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("ExptlCrystalGrowComp",
					       cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("conc");
	strk.add(ft);
	ft = new FieldTrans("details");
	strk.add(ft);
	ft = new FieldTrans("crystal_id");
	strk.add(ft);
	ft = new FieldTrans("id");
	strk.add(ft);
	ft = new FieldTrans("name");
	strk.add(ft);
	ft = new FieldTrans("sol_id");
	strk.add(ft);
	ft = new FieldTrans("volume");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_GEOM(ModuleTrans cmod)
    {
      //___________________________________________________________
      // GEOM
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("geom",
					    "Geom");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("Geom", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("entry_id");
	strk.add(ft);
	ft = new FieldTrans("details");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_GEOM_ANGLE(ModuleTrans cmod)
    {
      //___________________________________________________________
      // GEOM_ANGLE
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("geom_angle",
					    "GeomAngle");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("GeomAngle", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("atom_site_id_1");
	strk.add(ft);
	ft = new FieldTrans(atomIndex, "atom_site_label_1");
	strk.add(ft);
	ft.add(new SubfieldTrans("atom", "atom_site_label_atom_id_1"));
	ft.add(new SubfieldTrans("seq", "atom_site_label_seq_id_1"));
	ft.add(new SubfieldTrans("comp", "atom_site_label_comp_id_1"));
	ft.add(new SubfieldTrans("asym", "atom_site_label_asym_id_1"));
	ft.add(new SubfieldTrans("alt", "atom_site_label_alt_id_1"));

	ft = new FieldTrans("atom_site_id_2");
	strk.add(ft);
	ft = new FieldTrans(atomIndex, "atom_site_label_2");
	strk.add(ft);
	ft.add(new SubfieldTrans("atom", "atom_site_label_atom_id_2"));
	ft.add(new SubfieldTrans("seq", "atom_site_label_seq_id_2"));
	ft.add(new SubfieldTrans("comp", "atom_site_label_comp_id_2"));
	ft.add(new SubfieldTrans("asym", "atom_site_label_asym_id_2"));
	ft.add(new SubfieldTrans("alt", "atom_site_label_alt_id_2"));

	ft = new FieldTrans("atom_site_id_3");
	strk.add(ft);
	ft = new FieldTrans(atomIndex, "atom_site_label_3");
	strk.add(ft);
	ft.add(new SubfieldTrans("atom", "atom_site_label_atom_id_3"));
	ft.add(new SubfieldTrans("seq", "atom_site_label_seq_id_3"));
	ft.add(new SubfieldTrans("comp", "atom_site_label_comp_id_3"));
	ft.add(new SubfieldTrans("asym", "atom_site_label_asym_id_3"));
	ft.add(new SubfieldTrans("alt", "atom_site_label_alt_id_3"));

	ft = new FieldTrans(atomIndex, "atom_site_auth_1");
	strk.add(ft);
	ft.add(new SubfieldTrans("atom", "atom_site_auth_atom_id_1"));
	ft.add(new SubfieldTrans("seq", "atom_site_auth_seq_id_1"));
	ft.add(new SubfieldTrans("comp", "atom_site_auth_comp_id_1"));
	ft.add(new SubfieldTrans("asym", "atom_site_auth_asym_id_1"));

	ft = new FieldTrans(atomIndex, "atom_site_auth_2");
	strk.add(ft);
	ft.add(new SubfieldTrans("atom", "atom_site_auth_atom_id_2"));
	ft.add(new SubfieldTrans("seq", "atom_site_auth_seq_id_2"));
	ft.add(new SubfieldTrans("comp", "atom_site_auth_comp_id_2"));
	ft.add(new SubfieldTrans("asym", "atom_site_auth_asym_id_2"));

	ft = new FieldTrans(atomIndex, "atom_site_auth_3");
	strk.add(ft);
	ft.add(new SubfieldTrans("atom", "atom_site_auth_atom_id_3"));
	ft.add(new SubfieldTrans("seq", "atom_site_auth_seq_id_3"));
	ft.add(new SubfieldTrans("comp", "atom_site_auth_comp_id_3"));
	ft.add(new SubfieldTrans("asym", "atom_site_auth_asym_id_3"));

	ft = new FieldTrans("publ_flag");
	strk.add(ft);
	ft = new FieldTrans("site_symmetry_1");
	strk.add(ft);
	ft = new FieldTrans("site_symmetry_2");
	strk.add(ft);
	ft = new FieldTrans("site_symmetry_3");
	strk.add(ft);
	ft = new FieldTrans("value");
	strk.add(ft);
	ft = new FieldTrans("value_esd");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_GEOM_BOND(ModuleTrans cmod)
    {
      //___________________________________________________________
      // GEOM_BOND
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("geom_bond",
					    "GeomBond");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("GeomBond", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("atom_site_id_1");
	strk.add(ft);
	ft = new FieldTrans(atomIndex, "atom_site_label_1");
	strk.add(ft);
	ft.add(new SubfieldTrans("atom", "atom_site_label_atom_id_1"));
	ft.add(new SubfieldTrans("seq", "atom_site_label_seq_id_1"));
	ft.add(new SubfieldTrans("comp", "atom_site_label_comp_id_1"));
	ft.add(new SubfieldTrans("asym", "atom_site_label_asym_id_1"));
	ft.add(new SubfieldTrans("alt", "atom_site_label_alt_id_1"));

	ft = new FieldTrans("atom_site_id_2");
	strk.add(ft);
	ft = new FieldTrans(atomIndex, "atom_site_label_2");
	strk.add(ft);
	ft.add(new SubfieldTrans("atom", "atom_site_label_atom_id_2"));
	ft.add(new SubfieldTrans("seq", "atom_site_label_seq_id_2"));
	ft.add(new SubfieldTrans("comp", "atom_site_label_comp_id_2"));
	ft.add(new SubfieldTrans("asym", "atom_site_label_asym_id_2"));
	ft.add(new SubfieldTrans("alt", "atom_site_label_alt_id_2"));

	ft = new FieldTrans(atomIndex, "atom_site_auth_1");
	strk.add(ft);
	ft.add(new SubfieldTrans("atom", "atom_site_auth_atom_id_1"));
	ft.add(new SubfieldTrans("seq", "atom_site_auth_seq_id_1"));
	ft.add(new SubfieldTrans("comp", "atom_site_auth_comp_id_1"));
	ft.add(new SubfieldTrans("asym", "atom_site_auth_asym_id_1"));

	ft = new FieldTrans(atomIndex, "atom_site_auth_2");
	strk.add(ft);
	ft.add(new SubfieldTrans("atom", "atom_site_auth_atom_id_2"));
	ft.add(new SubfieldTrans("seq", "atom_site_auth_seq_id_2"));
	ft.add(new SubfieldTrans("comp", "atom_site_auth_comp_id_2"));
	ft.add(new SubfieldTrans("asym", "atom_site_auth_asym_id_2"));

	ft = new FieldTrans("dist");
	strk.add(ft);
	ft = new FieldTrans("dist_esd");
	strk.add(ft);
	ft = new FieldTrans("publ_flag");
	strk.add(ft);
	ft = new FieldTrans("site_symmetry_1");
	strk.add(ft);
	ft = new FieldTrans("site_symmetry_2");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_GEOM_CONTACT(ModuleTrans cmod)
    {
      //___________________________________________________________
      // GEOM_CONTACT
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("geom_contact",
					    "GeomContact");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("GeomContact", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("atom_site_id_1");
	strk.add(ft);
	ft = new FieldTrans(atomIndex, "atom_site_label_1");
	strk.add(ft);
	ft.add(new SubfieldTrans("atom", "atom_site_label_atom_id_1"));
	ft.add(new SubfieldTrans("seq", "atom_site_label_seq_id_1"));
	ft.add(new SubfieldTrans("comp", "atom_site_label_comp_id_1"));
	ft.add(new SubfieldTrans("asym", "atom_site_label_asym_id_1"));
	ft.add(new SubfieldTrans("alt", "atom_site_label_alt_id_1"));

	ft = new FieldTrans("atom_site_id_2");
	strk.add(ft);
	ft = new FieldTrans(atomIndex, "atom_site_label_2");
	strk.add(ft);
	ft.add(new SubfieldTrans("atom", "atom_site_label_atom_id_2"));
	ft.add(new SubfieldTrans("seq", "atom_site_label_seq_id_2"));
	ft.add(new SubfieldTrans("comp", "atom_site_label_comp_id_2"));
	ft.add(new SubfieldTrans("asym", "atom_site_label_asym_id_2"));
	ft.add(new SubfieldTrans("alt", "atom_site_label_alt_id_2"));

	ft = new FieldTrans(atomIndex, "atom_site_auth_1");
	strk.add(ft);
	ft.add(new SubfieldTrans("atom", "atom_site_auth_atom_id_1"));
	ft.add(new SubfieldTrans("seq", "atom_site_auth_seq_id_1"));
	ft.add(new SubfieldTrans("comp", "atom_site_auth_comp_id_1"));
	ft.add(new SubfieldTrans("asym", "atom_site_auth_asym_id_1"));

	ft = new FieldTrans(atomIndex, "atom_site_auth_2");
	strk.add(ft);
	ft.add(new SubfieldTrans("atom", "atom_site_auth_atom_id_2"));
	ft.add(new SubfieldTrans("seq", "atom_site_auth_seq_id_2"));
	ft.add(new SubfieldTrans("comp", "atom_site_auth_comp_id_2"));
	ft.add(new SubfieldTrans("asym", "atom_site_auth_asym_id_2"));

	ft = new FieldTrans("dist");
	strk.add(ft);
	ft = new FieldTrans("dist_esd");
	strk.add(ft);
	ft = new FieldTrans("publ_flag");
	strk.add(ft);
	ft = new FieldTrans("site_symmetry_1");
	strk.add(ft);
	ft = new FieldTrans("site_symmetry_2");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_GEOM_HBOND(ModuleTrans cmod)
    {
      //___________________________________________________________
      // GEOM_HBOND
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("geom_hbond",
					    "GeomHbond");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("GeomHbond", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("angle_dha",
			    "angle_DHA");
	strk.add(ft);
	ft = new FieldTrans("angle_dha_esd",
			    "angle_DHA_esd");
	strk.add(ft);

	ft = new FieldTrans("atom_site_id_a");
	strk.add(ft);
	ft = new FieldTrans(atomIndex, "atom_site_label_a");
	strk.add(ft);
	ft.add(new SubfieldTrans("atom", "atom_site_label_atom_id_A"));
	ft.add(new SubfieldTrans("seq", "atom_site_label_seq_id_A"));
	ft.add(new SubfieldTrans("comp", "atom_site_label_comp_id_A"));
	ft.add(new SubfieldTrans("asym", "atom_site_label_asym_id_A"));
	ft.add(new SubfieldTrans("alt", "atom_site_label_alt_id_A"));

	ft = new FieldTrans("atom_site_id_d");
	strk.add(ft);
	ft = new FieldTrans(atomIndex, "atom_site_label_d");
	strk.add(ft);
	ft.add(new SubfieldTrans("atom", "atom_site_label_atom_id_D"));
	ft.add(new SubfieldTrans("seq", "atom_site_label_seq_id_D"));
	ft.add(new SubfieldTrans("comp", "atom_site_label_comp_id_D"));
	ft.add(new SubfieldTrans("asym", "atom_site_label_asym_id_D"));
	ft.add(new SubfieldTrans("alt", "atom_site_label_alt_id_D"));

	ft = new FieldTrans("atom_site_id_h");
	strk.add(ft);
	ft = new FieldTrans(atomIndex, "atom_site_label_h");
	strk.add(ft);
	ft.add(new SubfieldTrans("atom", "atom_site_label_atom_id_H"));
	ft.add(new SubfieldTrans("seq", "atom_site_label_seq_id_H"));
	ft.add(new SubfieldTrans("comp", "atom_site_label_comp_id_H"));
	ft.add(new SubfieldTrans("asym", "atom_site_label_asym_id_H"));
	ft.add(new SubfieldTrans("alt", "atom_site_label_alt_id_H"));

	ft = new FieldTrans(atomIndex, "atom_site_auth_a");
	strk.add(ft);
	ft.add(new SubfieldTrans("atom", "atom_site_auth_atom_id_A"));
	ft.add(new SubfieldTrans("seq", "atom_site_auth_seq_id_A"));
	ft.add(new SubfieldTrans("comp", "atom_site_auth_comp_id_A"));
	ft.add(new SubfieldTrans("asym", "atom_site_auth_asym_id_A"));

	ft = new FieldTrans(atomIndex, "atom_site_auth_d");
	strk.add(ft);
 	ft.add(new SubfieldTrans("atom", "atom_site_auth_atom_id_D"));
 	ft.add(new SubfieldTrans("seq", "atom_site_auth_seq_id_D"));
 	ft.add(new SubfieldTrans("comp", "atom_site_auth_comp_id_D"));
 	ft.add(new SubfieldTrans("asym", "atom_site_auth_asym_id_D"));

	ft = new FieldTrans(atomIndex, "atom_site_auth_h");
	strk.add(ft);
 	ft.add(new SubfieldTrans("atom", "atom_site_auth_atom_id_H"));
 	ft.add(new SubfieldTrans("seq", "atom_site_auth_seq_id_H"));
 	ft.add(new SubfieldTrans("comp", "atom_site_auth_comp_id_H"));
 	ft.add(new SubfieldTrans("asym", "atom_site_auth_asym_id_H"));

	ft = new FieldTrans("dist_da",
			    "dist_DA");
	strk.add(ft);
	ft = new FieldTrans("dist_da_esd",
			    "dist_DA_esd");
	strk.add(ft);
	ft = new FieldTrans("dist_dh",
			    "dist_DH");
	strk.add(ft);
	ft = new FieldTrans("dist_dh_esd",
			    "dist_DH_esd");
	strk.add(ft);
	ft = new FieldTrans("dist_ha",
			    "dist_HA");
	strk.add(ft);
	ft = new FieldTrans("dist_ha_esd",
			    "dist_HA_esd");
	strk.add(ft);
	ft = new FieldTrans("publ_flag");
	strk.add(ft);
	ft = new FieldTrans("site_symmetry_a",
			    "site_symmetry_A");
	strk.add(ft);
	ft = new FieldTrans("site_symmetry_d",
			    "site_symmetry_D");
	strk.add(ft);
	ft = new FieldTrans("site_symmetry_h",
			    "site_symmetry_H");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_GEOM_TORSION(ModuleTrans cmod)
    {
      //___________________________________________________________
      // GEOM_TORSION
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("geom_torsion",
					    "GeomTorsion");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("GeomTorsion", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("atom_site_id_1");
	strk.add(ft);
	ft = new FieldTrans(atomIndex, "atom_site_label_1");
	strk.add(ft);
	ft.add(new SubfieldTrans("atom", "atom_site_label_atom_id_1"));
	ft.add(new SubfieldTrans("seq", "atom_site_label_seq_id_1"));
	ft.add(new SubfieldTrans("comp", "atom_site_label_comp_id_1"));
	ft.add(new SubfieldTrans("asym", "atom_site_label_asym_id_1"));
	ft.add(new SubfieldTrans("alt", "atom_site_label_alt_id_1"));

	ft = new FieldTrans("atom_site_id_2");
	strk.add(ft);
	ft = new FieldTrans(atomIndex, "atom_site_label_2");
	strk.add(ft);
	ft.add(new SubfieldTrans("atom", "atom_site_label_atom_id_2"));
	ft.add(new SubfieldTrans("seq", "atom_site_label_seq_id_2"));
	ft.add(new SubfieldTrans("comp", "atom_site_label_comp_id_2"));
	ft.add(new SubfieldTrans("asym", "atom_site_label_asym_id_2"));
	ft.add(new SubfieldTrans("alt", "atom_site_label_alt_id_2"));

	ft = new FieldTrans("atom_site_id_3");
	strk.add(ft);
	ft = new FieldTrans(atomIndex, "atom_site_label_3");
	strk.add(ft);
	ft.add(new SubfieldTrans("atom", "atom_site_label_atom_id_3"));
	ft.add(new SubfieldTrans("seq", "atom_site_label_seq_id_3"));
	ft.add(new SubfieldTrans("comp", "atom_site_label_comp_id_3"));
	ft.add(new SubfieldTrans("asym", "atom_site_label_asym_id_3"));
	ft.add(new SubfieldTrans("alt", "atom_site_label_alt_id_3"));

	ft = new FieldTrans("atom_site_id_4");
	strk.add(ft);
	ft = new FieldTrans(atomIndex, "atom_site_label_4");
	strk.add(ft);
	ft.add(new SubfieldTrans("atom", "atom_site_label_atom_id_4"));
	ft.add(new SubfieldTrans("seq", "atom_site_label_seq_id_4"));
	ft.add(new SubfieldTrans("comp", "atom_site_label_comp_id_4"));
	ft.add(new SubfieldTrans("asym", "atom_site_label_asym_id_4"));
	ft.add(new SubfieldTrans("alt", "atom_site_label_alt_id_4"));

	ft = new FieldTrans(atomIndex, "atom_site_auth_1");
	strk.add(ft);
	ft.add(new SubfieldTrans("atom", "atom_site_auth_atom_id_1"));
	ft.add(new SubfieldTrans("seq", "atom_site_auth_seq_id_1"));
	ft.add(new SubfieldTrans("comp", "atom_site_auth_comp_id_1"));
	ft.add(new SubfieldTrans("asym", "atom_site_auth_asym_id_1"));

	ft = new FieldTrans(atomIndex, "atom_site_auth_2");
	strk.add(ft);
	ft.add(new SubfieldTrans("atom", "atom_site_auth_atom_id_2"));
	ft.add(new SubfieldTrans("seq", "atom_site_auth_seq_id_2"));
	ft.add(new SubfieldTrans("comp", "atom_site_auth_comp_id_2"));
	ft.add(new SubfieldTrans("asym", "atom_site_auth_asym_id_2"));

	ft = new FieldTrans(atomIndex, "atom_site_auth_3");
	strk.add(ft);
	ft.add(new SubfieldTrans("atom", "atom_site_auth_atom_id_3"));
	ft.add(new SubfieldTrans("seq", "atom_site_auth_seq_id_3"));
	ft.add(new SubfieldTrans("comp", "atom_site_auth_comp_id_3"));
	ft.add(new SubfieldTrans("asym", "atom_site_auth_asym_id_3"));

	ft = new FieldTrans(atomIndex, "atom_site_auth_4");
	strk.add(ft);
	ft.add(new SubfieldTrans("atom", "atom_site_auth_atom_id_4"));
	ft.add(new SubfieldTrans("seq", "atom_site_auth_seq_id_4"));
	ft.add(new SubfieldTrans("comp", "atom_site_auth_comp_id_4"));
	ft.add(new SubfieldTrans("asym", "atom_site_auth_asym_id_4"));

	ft = new FieldTrans("publ_flag");
	strk.add(ft);
	ft = new FieldTrans("site_symmetry_1");
	strk.add(ft);
	ft = new FieldTrans("site_symmetry_2");
	strk.add(ft);
	ft = new FieldTrans("site_symmetry_3");
	strk.add(ft);
	ft = new FieldTrans("site_symmetry_4");
	strk.add(ft);
	ft = new FieldTrans("value");
	strk.add(ft);
	ft = new FieldTrans("value_esd");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_JOURNAL(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // JOURNAL
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("journal",
					    "Journal");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("Journal", cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("entry_id");
	strk.add(ft);
	ft = new FieldTrans("coden_astm",
			    "coden_ASTM");
	strk.add(ft);
	ft = new FieldTrans("coden_cambridge",
			    "coden_Cambridge");
	strk.add(ft);
	ft = new FieldTrans("coeditor_address");
	strk.add(ft);
	ft = new FieldTrans("coeditor_code");
	strk.add(ft);
	ft = new FieldTrans("coeditor_email");
	strk.add(ft);
	ft = new FieldTrans("coeditor_fax");
	strk.add(ft);
	ft = new FieldTrans("coeditor_name");
	strk.add(ft);
	ft = new FieldTrans("coeditor_notes");
	strk.add(ft);
	ft = new FieldTrans("coeditor_phone");
	strk.add(ft);
	ft = new FieldTrans("data_validation_number");
	strk.add(ft);
	ft = new FieldTrans("date_accepted");
	strk.add(ft);
	ft = new FieldTrans("date_from_coeditor");
	strk.add(ft);
	ft = new FieldTrans("date_to_coeditor");
	strk.add(ft);
	ft = new FieldTrans("date_printers_final");
	strk.add(ft);
	ft = new FieldTrans("date_printers_first");
	strk.add(ft);
	ft = new FieldTrans("date_proofs_in");
	strk.add(ft);
	ft = new FieldTrans("date_proofs_out");
	strk.add(ft);
	ft = new FieldTrans("date_recd_copyright");
	strk.add(ft);
	ft = new FieldTrans("date_recd_electronic");
	strk.add(ft);
	ft = new FieldTrans("date_recd_hard_copy");
	strk.add(ft);
	ft = new FieldTrans("issue");
	strk.add(ft);
	ft = new FieldTrans("language");
	strk.add(ft);
	ft = new FieldTrans("name_full");
	strk.add(ft);
	ft = new FieldTrans("page_first");
	strk.add(ft);
	ft = new FieldTrans("page_last");
	strk.add(ft);
	ft = new FieldTrans("paper_category");
	strk.add(ft);
	ft = new FieldTrans("suppl_publ_number");
	strk.add(ft);
	ft = new FieldTrans("suppl_publ_pages");
	strk.add(ft);
	ft = new FieldTrans("techeditor_address");
	strk.add(ft);
	ft = new FieldTrans("techeditor_code");
	strk.add(ft);
	ft = new FieldTrans("techeditor_email");
	strk.add(ft);
	ft = new FieldTrans("techeditor_fax");
	strk.add(ft);
	ft = new FieldTrans("techeditor_name");
	strk.add(ft);
	ft = new FieldTrans("techeditor_notes");
	strk.add(ft);
	ft = new FieldTrans("techeditor_phone");
	strk.add(ft);
	ft = new FieldTrans("volume");
	strk.add(ft);
	ft = new FieldTrans("year");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_JOURNAL_INDEX(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // JOURNAL_INDEX
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("journal_index",
					    "JournalIndex");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("JournalIndex", cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("subterm");
	strk.add(ft);
	ft = new FieldTrans("term");
	strk.add(ft);
	ft = new FieldTrans("type");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_PHASING(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // PHASING
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("phasing",
					    "Phasing");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("Phasing", cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("method");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_PHASING_AVERAGING(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // PHASING_AVERAGING
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("phasing_averaging",
					    "PhasingAveraging");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("PhasingAveraging",
					       cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("details");
	strk.add(ft);
	ft = new FieldTrans("entry_id");
	strk.add(ft);
	ft = new FieldTrans("method");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_PHASING_ISOMORPHOUS(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // PHASING_ISOMORPHOUS
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("phasing_isomorphous",
					    "PhasingIsomorphous");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("PhasingIsomorphous",
					       cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("details");
	strk.add(ft);
	ft = new FieldTrans("entry_id");
	strk.add(ft);
	ft = new FieldTrans("method");
	strk.add(ft);
	ft = new FieldTrans("parent");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_PHASING_MAD(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // PHASING_MAD
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("phasing_MAD",
					    "PhasingMad");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("PhasingMad",
					       cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("details");
	strk.add(ft);
	ft = new FieldTrans("entry_id");
	strk.add(ft);
	ft = new FieldTrans("method");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_PHASING_MAD_CLUST(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // PHASING_MAD_CLUST
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("phasing_MAD_clust",
					    "PhasingMadClust");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("PhasingMadClust",
					       cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("expt_id");
	strk.add(ft);
	ft = new FieldTrans("id");
	strk.add(ft);
	ft = new FieldTrans("number_set");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_PHASING_MAD_EXPT(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // PHASING_MAD_EXPT
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("phasing_MAD_expt",
					    "PhasingMadExpt");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("PhasingMadExpt",
					       cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("delta_delta_phi");
	strk.add(ft);
	ft = new FieldTrans("delta_phi");
	strk.add(ft);
	ft = new FieldTrans("delta_phi_sigma");
	strk.add(ft);
	ft = new FieldTrans("id");
	strk.add(ft);
	ft = new FieldTrans("mean_fom");
	strk.add(ft);
	ft = new FieldTrans("number_clust");
	strk.add(ft);
	ft = new FieldTrans("r_normal_all",
			    "R_normal_all");
	strk.add(ft);
	ft = new FieldTrans("r_normal_anom_scat",
			    "R_normal_anom_scat");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_PHASING_MAD_RATIO(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // PHASING_MAD_RATIO
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("phasing_MAD_ratio",
					    "PhasingMadRatio");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("PhasingMadRatio",
					       cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("d_res_high");
	strk.add(ft);
	ft = new FieldTrans("d_res_low");
	strk.add(ft);
	ft = new FieldTrans("expt_id");
	strk.add(ft);
	ft = new FieldTrans("clust_id");
	strk.add(ft);
	ft = new FieldTrans("ratio_one_wl");
	strk.add(ft);
	ft = new FieldTrans("ratio_one_wl_centric");
	strk.add(ft);
	ft = new FieldTrans("ratio_two_wl");
	strk.add(ft);
	ft = new FieldTrans("wavelength_1");
	strk.add(ft);
	ft = new FieldTrans("wavelength_2");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_PHASING_MAD_SET(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // PHASING_MAD_SET
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("phasing_MAD_set",
					    "PhasingMadSet");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("PhasingMadSet",
					       cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("clust_id");
	strk.add(ft);
	ft = new FieldTrans("d_res_high");
	strk.add(ft);
	ft = new FieldTrans("d_res_low");
	strk.add(ft);
	ft = new FieldTrans("expt_id");
	strk.add(ft);
	ft = new FieldTrans("f_double_prime");
	strk.add(ft);
	ft = new FieldTrans("f_prime");
	strk.add(ft);
	ft = new FieldTrans("set_id");
	strk.add(ft);
	ft = new FieldTrans("wavelength");
	strk.add(ft);
	ft = new FieldTrans("wavelength_details");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_PHASING_MIR(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // PHASING_MIR
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("phasing_mir",
					    "PhasingMir");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("PhasingMir",
					       cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("details");
	strk.add(ft);
	ft = new FieldTrans("entry_id");
	strk.add(ft);
	ft = new FieldTrans("method");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_PHASING_MIR_DER(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // PHASING_MIR_DER
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("phasing_MIR_der",
					    "PhasingMirDer");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("PhasingMirDer",
					       cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("d_res_high");
	strk.add(ft);
	ft = new FieldTrans("d_res_low");
	strk.add(ft);
	ft = new FieldTrans("der_set_id");
	strk.add(ft);
	ft = new FieldTrans("details");
	strk.add(ft);
	ft = new FieldTrans("id");
	strk.add(ft);
	ft = new FieldTrans("native_set_id");
	strk.add(ft);
	ft = new FieldTrans("number_of_sites");
	strk.add(ft);
	ft = new FieldTrans("reflns_criteria");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_PHASING_MIR_DER_REFLN(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // PHASING_MIR_DER_REFLN
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("phasing_MIR_der_refln",
					    "PhasingMirDerRefln");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("PhasingMirDerRefln",
					       cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("der_id");
	strk.add(ft);
	ft = new FieldTrans("f_calc",
			    "F_calc");
	strk.add(ft);
	ft = new FieldTrans("f_calc_au",
			    "F_calc_au");
	strk.add(ft);
	ft = new FieldTrans("f_meas",
			    "F_meas");
	strk.add(ft);
	ft = new FieldTrans("f_meas_au",
			    "F_meas_au");
	strk.add(ft);
	ft = new FieldTrans("f_meas_sigma",
			    "F_meas_sigma");
	strk.add(ft);
	ft = new FieldTrans("f_meas_sigma_au",
			    "F_meas_sigma_au");
	strk.add(ft);
	ft = new FieldTrans("hl_a_iso",
			    "HL_A_iso");
	strk.add(ft);
	ft = new FieldTrans("hl_b_iso",
			    "HL_B_iso");
	strk.add(ft);
	ft = new FieldTrans("hl_c_iso",
			    "HL_C_iso");
	strk.add(ft);
	ft = new FieldTrans("hl_d_iso",
			    "HL_D_iso");
	strk.add(ft);

	ft = new FieldTrans(millerIndices, "index");
	strk.add(ft);
	ft.add(new SubfieldTrans("h", "index_h"));
	ft.add(new SubfieldTrans("k", "index_k"));
	ft.add(new SubfieldTrans("l", "index_l"));

	ft = new FieldTrans("phase_calc");
	strk.add(ft);
	ft = new FieldTrans("set_id");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_PHASING_MIR_DER_SHELL(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // PHASING_MIR_DER_SHELL
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("phasing_MIR_der_shell",
					    "PhasingMirDerShell");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("PhasingMirDerShell",
					       cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("d_res_high");
	strk.add(ft);
	ft = new FieldTrans("d_res_low");
	strk.add(ft);
	ft = new FieldTrans("der_id");
	strk.add(ft);
	ft = new FieldTrans("fom");
	strk.add(ft);
	ft = new FieldTrans("ha_ampl");
	strk.add(ft);
	ft = new FieldTrans("loc");
	strk.add(ft);
	ft = new FieldTrans("phase");
	strk.add(ft);
	ft = new FieldTrans("power");
	strk.add(ft);
	ft = new FieldTrans("r_cullis",
			    "R_cullis");
	strk.add(ft);
	ft = new FieldTrans("r_kraut",
			    "R_kraut");
	strk.add(ft);
	ft = new FieldTrans("reflns");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_PHASING_MIR_DER_SITE(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // PHASING_MIR_DER_SITE
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("phasing_MIR_der_site",
					    "PhasingMirDerSite");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("PhasingMirDerSite",
					       cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("atom_type_symbol");
	strk.add(ft);
	ft = new FieldTrans("b_iso",
			    "B_iso");
	strk.add(ft);
	ft = new FieldTrans("b_iso_esd",
			    "B_iso_esd");
	strk.add(ft);

	ft = new FieldTrans(stVectorXYZ, "cartn");
	strk.add(ft);
	ft.add(new SubfieldTrans("x", "Cartn_x"));
	ft.add(new SubfieldTrans("y", "Cartn_y"));
	ft.add(new SubfieldTrans("z", "Cartn_z"));

	ft = new FieldTrans(stVectorXYZ, "cartn_esd");
	strk.add(ft);
	ft.add(new SubfieldTrans("x", "Cartn_x_esd"));
	ft.add(new SubfieldTrans("y", "Cartn_y_esd"));
	ft.add(new SubfieldTrans("z", "Cartn_z_esd"));

	ft = new FieldTrans("der_id");
	strk.add(ft);
	ft = new FieldTrans("details");
	strk.add(ft);

	ft = new FieldTrans(stVectorXYZ, "fract");
	strk.add(ft);
	ft.add(new SubfieldTrans("x", "fract_x"));
	ft.add(new SubfieldTrans("y", "fract_y"));
	ft.add(new SubfieldTrans("z", "fract_z"));
	ft = new FieldTrans(stVectorXYZ, "fract_esd");
	strk.add(ft);
	ft.add(new SubfieldTrans("x", "fract_x_esd"));
	ft.add(new SubfieldTrans("y", "fract_y_esd"));
	ft.add(new SubfieldTrans("z", "fract_z_esd"));

	ft = new FieldTrans("id");
	strk.add(ft);
	ft = new FieldTrans("occupancy");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_PHASING_MIR_SHELL(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // PHASING_MIR_SHELL
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("phasing_MIR_shell",
					    "PhasingMirShell");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("PhasingMirShell",
					       cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("d_res_high");
	strk.add(ft);
	ft = new FieldTrans("d_res_low");
	strk.add(ft);
	ft = new FieldTrans("fom");
	strk.add(ft);
	ft = new FieldTrans("loc");
	strk.add(ft);
	ft = new FieldTrans("mean_phase");
	strk.add(ft);
	ft = new FieldTrans("power");
	strk.add(ft);
	ft = new FieldTrans("r_cullis", "R_cullis");
	strk.add(ft);
	ft = new FieldTrans("r_kraut", "R_kraut");
	strk.add(ft);
	ft = new FieldTrans("reflns");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_PHASING_SET(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // PHASING_SET
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("phasing_set",
					    "PhasingSet");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("PhasingSet",
					       cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans(unitCell, "cell");
	strk.add(ft);
	ft.add(new SubfieldTrans("length_a", "cell_length_a"));
	ft.add(new SubfieldTrans("length_b", "cell_length_b"));
	ft.add(new SubfieldTrans("length_c", "cell_length_c"));
	ft.add(new SubfieldTrans("angle_alpha", "cell_angle_alpha"));
	ft.add(new SubfieldTrans("angle_beta", "cell_angle_beta"));
	ft.add(new SubfieldTrans("angle_gamma", "cell_angle_gamma"));

	ft = new FieldTrans("detector_specific");
	strk.add(ft);
	ft = new FieldTrans("detector_type");
	strk.add(ft);
	ft = new FieldTrans("id");
	strk.add(ft);
	ft = new FieldTrans("radiation_source_specific");
	strk.add(ft);
	ft = new FieldTrans("radiation_wavelength");
	strk.add(ft);
	ft = new FieldTrans("temp");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_PHASING_SET_REFLN(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // PHASING_SET_REFLN
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("phasing_set_refln",
					    "PhasingSetRefln");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("PhasingSetRefln",
					       cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("set_id");
	strk.add(ft);
	ft = new FieldTrans("f_meas",
			    "F_meas");
	strk.add(ft);
	ft = new FieldTrans("f_meas_au",
			    "F_meas_au");
	strk.add(ft);
	ft = new FieldTrans("f_meas_sigma",
			    "F_meas_sigma");
	strk.add(ft);
	ft = new FieldTrans("f_meas_sigma_au",
			    "F_meas_sigma_au");
	strk.add(ft);

	ft = new FieldTrans(millerIndices, "index");
	strk.add(ft);
	ft.add(new SubfieldTrans("h", "index_h"));
	ft.add(new SubfieldTrans("k", "index_k"));
	ft.add(new SubfieldTrans("l", "index_l"));
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_PUBL(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // PUBL
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("publ",
					    "Publ");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("Publ",
					       cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("entry_id");
	strk.add(ft);
	ft = new FieldTrans("contact_author");
	strk.add(ft);
	ft = new FieldTrans("contact_author_address");
	strk.add(ft);
	ft = new FieldTrans("contact_author_email");
	strk.add(ft);
	ft = new FieldTrans("contact_author_fax");
	strk.add(ft);
	ft = new FieldTrans("contact_author_name");
	strk.add(ft);
	ft = new FieldTrans("contact_author_phone");
	strk.add(ft);
	ft = new FieldTrans("contact_letter");
	strk.add(ft);
	ft = new FieldTrans("manuscript_creation");
	strk.add(ft);
	ft = new FieldTrans("manuscript_processed");
	strk.add(ft);
	ft = new FieldTrans("manuscript_text");
	strk.add(ft);
	ft = new FieldTrans("requested_category");
	strk.add(ft);
	ft = new FieldTrans("requested_coeditor_name");
	strk.add(ft);
	ft = new FieldTrans("requested_journal");
	strk.add(ft);
	ft = new FieldTrans("section_abstract");
	strk.add(ft);
	ft = new FieldTrans("section_acknowledgements");
	strk.add(ft);
	ft = new FieldTrans("section_comment");
	strk.add(ft);
	ft = new FieldTrans("section_discussion");
	strk.add(ft);
	ft = new FieldTrans("section_experimental");
	strk.add(ft);
	ft = new FieldTrans("section_exptl_prep");
	strk.add(ft);
	ft = new FieldTrans("section_exptl_refinement");
	strk.add(ft);
	ft = new FieldTrans("section_exptl_solution");
	strk.add(ft);
	ft = new FieldTrans("section_figure_captions");
	strk.add(ft);
	ft = new FieldTrans("section_introduction");
	strk.add(ft);
	ft = new FieldTrans("section_references");
	strk.add(ft);
	ft = new FieldTrans("section_synopsis");
	strk.add(ft);
	ft = new FieldTrans("section_table_legends");
	strk.add(ft);
	ft = new FieldTrans("section_title");
	strk.add(ft);
	ft = new FieldTrans("section_title_footnote");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_PUBL_AUTHOR(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // PUBL_AUTHOR
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("publ_author",
					    "PublAuthor");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("PublAuthor", cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("address");
	strk.add(ft);
	ft = new FieldTrans("footnote");
	strk.add(ft);
	ft = new FieldTrans("name");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_PUBL_BODY(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // PUBL_BODY
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("publ_body",
					    "PublBody");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("PublBody", cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("contents");
	strk.add(ft);
	ft = new FieldTrans("element");
	strk.add(ft);
	ft = new FieldTrans("format");
	strk.add(ft);
	ft = new FieldTrans("label");
	strk.add(ft);
	ft = new FieldTrans("title");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_PUBL_MANUSCRIPT_INCL(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // PUBL_MANUSCRIPT_INCL
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("publ_manuscript_incl",
					    "PublManuscriptIncl");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("PublManuscriptIncl",
					       cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("entry_id");
	strk.add(ft);
	ft = new FieldTrans("extra_defn");
	strk.add(ft);
	ft = new FieldTrans("extra_info");
	strk.add(ft);
	ft = new FieldTrans("extra_item");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_REFINE(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // REFINE
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("refine",
					    "Refine");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("Refine",
					       cat, modQual);
      cat.add(strk);
      {
	ft = new MatrixTrans("aniso_b",
			     "aniso_B", "", true);
	strk.add(ft);
	ft = new FieldTrans("b_iso_max",
			    "B_iso_max");
	strk.add(ft);
	ft = new FieldTrans("b_iso_mean",
			    "B_iso_mean");
	strk.add(ft);
	ft = new FieldTrans("b_iso_min",
			    "B_iso_min");
	strk.add(ft);
	ft = new FieldTrans("entry_id");
	strk.add(ft);
	ft = new FieldTrans("details");
	strk.add(ft);
	ft = new FieldTrans("diff_density_max");
	strk.add(ft);
	ft = new FieldTrans("diff_density_max_esd");
	strk.add(ft);
	ft = new FieldTrans("diff_density_min");
	strk.add(ft);
	ft = new FieldTrans("diff_density_min_esd");
	strk.add(ft);
	ft = new FieldTrans("diff_density_rms");
	strk.add(ft);
	ft = new FieldTrans("diff_density_rms_esd");
	strk.add(ft);
	ft = new FieldTrans("ls_abs_structure_details");
	strk.add(ft);
	ft = new FieldTrans("ls_abs_structure_flack",
			    "ls_abs_structure_Flack");
	strk.add(ft);
	ft = new FieldTrans("ls_abs_structure_flack_esd",
			    "ls_abs_structure_Flack_esd");
	strk.add(ft);
	ft = new FieldTrans("ls_abs_structure_rogers",
			    "ls_abs_structure_Rogers");
	strk.add(ft);
	ft = new FieldTrans("ls_abs_structure_rogers_esd",
			    "ls_abs_structure_Rogers_esd");
	strk.add(ft);
	ft = new FieldTrans("ls_d_res_high");
	strk.add(ft);
	ft = new FieldTrans("ls_d_res_low");
	strk.add(ft);
	ft = new FieldTrans("ls_extinction_coef");
	strk.add(ft);
	ft = new FieldTrans("ls_extinction_coef_esd");
	strk.add(ft);
	ft = new FieldTrans("ls_extinction_expression");
	strk.add(ft);
	ft = new FieldTrans("ls_extinction_method");
	strk.add(ft);
	ft = new FieldTrans("ls_goodness_of_fit_all");
	strk.add(ft);
	ft = new FieldTrans("ls_goodness_of_fit_all_esd");
	strk.add(ft);
	ft = new FieldTrans("ls_goodness_of_fit_obs");
	strk.add(ft);
	ft = new FieldTrans("ls_goodness_of_fit_obs_esd");
	strk.add(ft);
	ft = new FieldTrans("ls_hydrogen_treatment");
	strk.add(ft);
	ft = new FieldTrans("ls_matrix_type");
	strk.add(ft);
	ft = new FieldTrans("ls_number_constraints");
	strk.add(ft);
	ft = new FieldTrans("ls_number_parameters");
	strk.add(ft);
	ft = new FieldTrans("ls_number_reflns_all");
	strk.add(ft);
	ft = new FieldTrans("ls_number_reflns_obs");
	strk.add(ft);
	ft = new FieldTrans("ls_number_reflns_r_free",
			    "ls_number_reflns_R_free");
	strk.add(ft);
	ft = new FieldTrans("ls_number_reflns_r_work",
			    "ls_number_reflns_R_work");
	strk.add(ft);
	ft = new FieldTrans("ls_number_restraints");
	strk.add(ft);
	ft = new FieldTrans("ls_percent_reflns_obs");
	strk.add(ft);
	ft = new FieldTrans("ls_percent_reflns_r_free",
			    "ls_percent_reflns_R_free");
	strk.add(ft);
	ft = new FieldTrans("ls_r_factor_all",
			    "ls_R_factor_all");
	strk.add(ft);
	ft = new FieldTrans("ls_r_factor_obs",
			    "ls_R_factor_obs");
	strk.add(ft);
	ft = new FieldTrans("ls_r_factor_r_free",
			    "ls_R_factor_R_free");
	strk.add(ft);
	ft = new FieldTrans("ls_r_factor_r_free_error",
			    "ls_R_factor_R_free_error");
	strk.add(ft);
	ft = new FieldTrans("ls_r_factor_r_free_error_details",
			    "ls_R_factor_R_free_error_details");
	strk.add(ft);
	ft = new FieldTrans("ls_r_factor_r_work",
			    "ls_R_factor_R_work");
	strk.add(ft);
	ft = new FieldTrans("ls_r_fsqd_factor_obs",
			    "ls_R_Fsqd_factor_obs");
	strk.add(ft);
	ft = new FieldTrans("ls_r_i_factor_obs",
			    "ls_R_I_factor_obs");
	strk.add(ft);
	ft = new FieldTrans("ls_redundancy_reflns_all");
	strk.add(ft);
	ft = new FieldTrans("ls_redundancy_reflns_obs");
	strk.add(ft);
	ft = new FieldTrans("ls_restrained_s_all",
			    "ls_restrained_S_all");
	strk.add(ft);
	ft = new FieldTrans("ls_restrained_s_obs",
			    "ls_restrained_S_obs");
	strk.add(ft);
	ft = new FieldTrans("ls_shift_over_esd_max");
	strk.add(ft);
	ft = new FieldTrans("ls_shift_over_esd_mean");
	strk.add(ft);
	ft = new FieldTrans("ls_structure_factor_coef");
	strk.add(ft);
	ft = new FieldTrans("ls_weighting_details");
	strk.add(ft);
	ft = new FieldTrans("ls_weighting_scheme");
	strk.add(ft);
	ft = new FieldTrans("ls_wr_factor_all",
			    "ls_wR_factor_all");
	strk.add(ft);
	ft = new FieldTrans("ls_wr_factor_obs",
			    "ls_wR_factor_obs");
	strk.add(ft);
	ft = new FieldTrans("ls_wr_factor_r_free",
			    "ls_wR_factor_R_free");
	strk.add(ft);
	ft = new FieldTrans("ls_wr_factor_r_work",
			    "ls_wR_factor_R_work");
	strk.add(ft);
	ft = new FieldTrans("occupancy_max");
	strk.add(ft);
	ft = new FieldTrans("occupancy_min");
	strk.add(ft);
	ft = new FieldTrans("solvent_model_details");
	strk.add(ft);
	ft = new FieldTrans("solvent_model_param_bsol");
	strk.add(ft);
	ft = new FieldTrans("solvent_model_param_ksol");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_REFINE_ANALYZE(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // REFINE_ANALYZE
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("refine_analyze",
					    "RefineAnalyze");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("RefineAnalyze",
					       cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("entry_id");
	strk.add(ft);
	ft = new FieldTrans("luzzati_coordinate_error_obs",
			    "Luzzati_coordinate_error_obs");
	strk.add(ft);
	ft = new FieldTrans("luzzati_d_res_low_obs",
			    "Luzzati_d_res_low_obs");
	strk.add(ft);
	ft = new FieldTrans("luzzati_sigma_a_obs",
			    "Luzzati_sigma_a_obs");
	strk.add(ft);
	ft = new FieldTrans("luzzati_sigma_a_obs_details",
			    "Luzzati_sigma_a_obs_details");
	strk.add(ft);
	ft = new FieldTrans("luzzati_coordinate_error_free",
			    "Luzzati_coordinate_error_free");
	strk.add(ft);
	ft = new FieldTrans("luzzati_d_res_low_free",
			    "Luzzati_d_res_low_free");
	strk.add(ft);
	ft = new FieldTrans("luzzati_sigma_a_free",
			    "Luzzati_sigma_a_free");
	strk.add(ft);
	ft = new FieldTrans("luzzati_sigma_a_free_details",
			    "Luzzati_sigma_a_free_details");
	strk.add(ft);
	ft = new FieldTrans("number_disordered_residues");
	strk.add(ft);
	ft = new FieldTrans("occupancy_sum_hydrogen");
	strk.add(ft);
	ft = new FieldTrans("occupancy_sum_non_hydrogen");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_REFINE_B_ISO(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // REFINE_B_ISO
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("refine_b_iso",
					    "RefineBIso");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("RefineBIso",
					       cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("class_atoms", "class");
	strk.add(ft);
	ft = new FieldTrans("details");
	strk.add(ft);
	ft = new FieldTrans("treatment");
	strk.add(ft);
	ft = new FieldTrans("value");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_REFINE_HIST(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // REFINE_HIST
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("refine_hist",
					    "RefineHist");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("RefineHist",
					       cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("cycle_id");
	strk.add(ft);
	ft = new FieldTrans("details");
	strk.add(ft);
	ft = new FieldTrans("d_res_high");
	strk.add(ft);
	ft = new FieldTrans("d_res_low");
	strk.add(ft);
	ft = new FieldTrans("number_atoms_solvent");
	strk.add(ft);
	ft = new FieldTrans("number_atoms_total");
	strk.add(ft);
	ft = new FieldTrans("number_reflns_all");
	strk.add(ft);
	ft = new FieldTrans("number_reflns_obs");
	strk.add(ft);
	ft = new FieldTrans("number_reflns_R_free");
	strk.add(ft);
	ft = new FieldTrans("number_reflns_R_work");
	strk.add(ft);
	ft = new FieldTrans("r_factor_all",
			    "R_factor_all");
	strk.add(ft);
	ft = new FieldTrans("r_factor_obs",
			    "R_factor_obs");
	strk.add(ft);
	ft = new FieldTrans("r_factor_r_free",
			    "R_factor_R_free");
	strk.add(ft);
	ft = new FieldTrans("r_factor_r_work",
			    "R_factor_R_work");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_REFINE_LS_RESTR(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // REFINE_LS_RESTR
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("refine_ls_restr",
					    "RefineLsRestr");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("RefineLsRestr",
					       cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("criterion");
	strk.add(ft);
	ft = new FieldTrans("dev_ideal");
	strk.add(ft);
	ft = new FieldTrans("number");
	strk.add(ft);
	ft = new FieldTrans("rejects");
	strk.add(ft);
	ft = new FieldTrans("dev_ideal_target");
	strk.add(ft);
	ft = new FieldTrans("type");
	strk.add(ft);
	ft = new FieldTrans("weight");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_REFINE_LS_RESTR_NCS(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // REFINE_LS_RESTR_NCS
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("refine_ls_restr_ncs",
					    "RefineLsRestrNcs");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("RefineLsRestrNcs",
					       cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("dom_id");
	strk.add(ft);
	ft = new FieldTrans("ncs_model_details");
	strk.add(ft);
	ft = new FieldTrans("weight_position");
	strk.add(ft);
	ft = new FieldTrans("weight_b_iso",
			    "weight_B_iso");
	strk.add(ft);
	ft = new FieldTrans("rms_dev_position");
	strk.add(ft);
	ft = new FieldTrans("rms_dev_b_iso",
			    "rms_dev_B_iso");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_REFINE_LS_SHELL(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // REFINE_LS_SHELL
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("refine_ls_shell",
					    "RefineLsShell");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("RefineLsShell",
					       cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("d_res_high");
	strk.add(ft);
	ft = new FieldTrans("d_res_low");
	strk.add(ft);
	ft = new FieldTrans("number_reflns_all");
	strk.add(ft);
	ft = new FieldTrans("number_reflns_obs");
	strk.add(ft);
	ft = new FieldTrans("number_reflns_r_free",
			    "number_reflns_R_free");
	strk.add(ft);
	ft = new FieldTrans("number_reflns_r_work",
			    "number_reflns_R_work");
	strk.add(ft);
	ft = new FieldTrans("percent_reflns_obs");
	strk.add(ft);
	ft = new FieldTrans("percent_reflns_r_free",
			    "percent_reflns_R_free");
	strk.add(ft);
	ft = new FieldTrans("r_factor_all",
			    "R_factor_all");
	strk.add(ft);
	ft = new FieldTrans("r_factor_obs",
			    "R_factor_obs");
	strk.add(ft);
	ft = new FieldTrans("r_factor_r_free",
			    "R_factor_R_free");
	strk.add(ft);
	ft = new FieldTrans("r_factor_r_free_error",
			    "R_factor_R_free_error");
	strk.add(ft);
	ft = new FieldTrans("r_factor_r_work",
			    "R_factor_R_work");
	strk.add(ft);
	ft = new FieldTrans("redundancy_reflns_all");
	strk.add(ft);
	ft = new FieldTrans("redundancy_reflns_obs");
	strk.add(ft);
	ft = new FieldTrans("wr_factor_all",
			    "wR_factor_all");
	strk.add(ft);
	ft = new FieldTrans("wr_factor_obs",
			    "wR_factor_obs");
	strk.add(ft);
	ft = new FieldTrans("wr_factor_r_free",
			    "wR_factor_R_free");
	strk.add(ft);
	ft = new FieldTrans("wr_factor_r_work",
			    "wR_factor_R_work");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_REFINE_OCCUPANCY(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // REFINE_OCCUPANCY
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("refine_occupancy",
					    "RefineOccupancy");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("RefineOccupancy",
					       cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("class_atoms", "class");
	strk.add(ft);
	ft = new FieldTrans("details");
	strk.add(ft);
	ft = new FieldTrans("treatment");
	strk.add(ft);
	ft = new FieldTrans("value");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_REFLN(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // REFLN
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("refln",
					    "Refln");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("Refln",
					       cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("a_calc",
			    "A_calc");
	strk.add(ft);
	ft = new FieldTrans("a_calc_au",
			    "A_calc_au");
	strk.add(ft);
	ft = new FieldTrans("a_meas",
			    "A_meas");
	strk.add(ft);
	ft = new FieldTrans("a_meas_au",
			    "A_meas_au");
	strk.add(ft);
	ft = new FieldTrans("b_calc",
			    "B_calc");
	strk.add(ft);
	ft = new FieldTrans("b_calc_au",
			    "B_calc_au");
	strk.add(ft);
	ft = new FieldTrans("b_meas",
			    "B_meas");
	strk.add(ft);
	ft = new FieldTrans("b_meas_au",
			    "B_meas_au");
	strk.add(ft);
	ft = new FieldTrans("crystal_id");
	strk.add(ft);
	ft = new FieldTrans("f_calc",
			    "F_calc");
	strk.add(ft);
	ft = new FieldTrans("f_calc_au",
			    "F_calc_au");
	strk.add(ft);
	ft = new FieldTrans("f_meas",
			    "F_meas");
	strk.add(ft);
	ft = new FieldTrans("f_meas_au",
			    "F_meas_au");
	strk.add(ft);
	ft = new FieldTrans("f_meas_sigma",
			    "F_meas_sigma");
	strk.add(ft);
	ft = new FieldTrans("f_meas_sigma_au",
			    "F_meas_sigma_au");
	strk.add(ft);
	ft = new FieldTrans("f_squared_calc",
			    "F_squared_calc");
	strk.add(ft);
	ft = new FieldTrans("f_squared_meas",
			    "F_squared_meas");
	strk.add(ft);
	ft = new FieldTrans("f_squared_sigma",
			    "F_squared_sigma");
	strk.add(ft);
	ft = new FieldTrans("fom");
	strk.add(ft);

	ft = new FieldTrans(millerIndices, "index");
	strk.add(ft);
	ft.add(new SubfieldTrans("h", "index_h"));
	ft.add(new SubfieldTrans("k", "index_k"));
	ft.add(new SubfieldTrans("l", "index_l"));

	ft = new FieldTrans("intensity_calc");
	strk.add(ft);
	ft = new FieldTrans("intensity_meas");
	strk.add(ft);
	ft = new FieldTrans("intensity_sigma");
	strk.add(ft);
	ft = new FieldTrans("mean_path_length_tbar");
	strk.add(ft);
	ft = new FieldTrans("status");
	strk.add(ft);
	ft = new FieldTrans("phase_calc");
	strk.add(ft);
	ft = new FieldTrans("phase_meas");
	strk.add(ft);
	ft = new FieldTrans("refinement_status");
	strk.add(ft);
	ft = new FieldTrans("scale_group_code");
	strk.add(ft);
	ft = new FieldTrans("sint_over_lambda");
	strk.add(ft);
	ft = new FieldTrans("symmetry_epsilon");
	strk.add(ft);
	ft = new FieldTrans("symmetry_multiplicity");
	strk.add(ft);
	ft = new FieldTrans("wavelength");
	strk.add(ft);
	ft = new FieldTrans("wavelength_code", "wavelength_id");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_REFLNS(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // REFLNS
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("reflns",
					    "Reflns");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("Reflns",
					       cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("b_iso_wilson_estimate",
			    "B_iso_Wilson_estimate");
	strk.add(ft);
	ft = new FieldTrans("entry_id");
	strk.add(ft);
	ft = new FieldTrans("data_reduction_details");
	strk.add(ft);
	ft = new FieldTrans("data_reduction_method");
	strk.add(ft);
	ft = new FieldTrans("d_resolution_high");
	strk.add(ft);
	ft = new FieldTrans("d_resolution_low");
	strk.add(ft);
	ft = new FieldTrans("details");
	strk.add(ft);

	ft = new FieldTrans(millerIndices, "limit_min");
	strk.add(ft);
	ft.add(new SubfieldTrans("h", "limit_h_min"));
	ft.add(new SubfieldTrans("k", "limit_k_min"));
	ft.add(new SubfieldTrans("l", "limit_l_min"));

	ft = new FieldTrans(millerIndices, "limit_max");
	strk.add(ft);
	ft.add(new SubfieldTrans("h", "limit_h_max"));
	ft.add(new SubfieldTrans("k", "limit_k_max"));
	ft.add(new SubfieldTrans("l", "limit_l_max"));

	ft = new FieldTrans("number_all");
	strk.add(ft);
	ft = new FieldTrans("number_obs");
	strk.add(ft);
	ft = new FieldTrans("observed_criterion");
	strk.add(ft);
	ft = new FieldTrans("observed_criterion_F_max");
	strk.add(ft);
	ft = new FieldTrans("observed_criterion_F_min");
	strk.add(ft);
	ft = new FieldTrans("observed_criterion_I_max");
	strk.add(ft);
	ft = new FieldTrans("observed_criterion_I_min");
	strk.add(ft);
	ft = new FieldTrans("observed_criterion_sigma_F");
	strk.add(ft);
	ft = new FieldTrans("observed_criterion_sigma_I");
	strk.add(ft);
	ft = new FieldTrans("percent_possible_obs");
	strk.add(ft);
	ft = new FieldTrans("r_free_details",
			    "R_free_details");
	strk.add(ft);
	ft = new FieldTrans("rmerge_f_all",
			    "Rmerge_F_all");
	strk.add(ft);
	ft = new FieldTrans("rmerge_f_obs",
			    "Rmerge_F_obs");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_REFLNS_SCALE(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // REFLNS_SCALE
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("reflns_scale",
					    "ReflnsScale");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("ReflnsScale",
					       cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("group_code");
	strk.add(ft);
	ft = new FieldTrans("meas_f",
			    "meas_F");
	strk.add(ft);
	ft = new FieldTrans("meas_f_squared",
			    "meas_F_squared");
	strk.add(ft);
	ft = new FieldTrans("meas_intensity");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_REFLNS_SHELL(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // REFLNS_SHELL
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("reflns_shell",
					    "ReflnsShell");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("ReflnsShell",
					       cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("d_res_high");
	strk.add(ft);
	ft = new FieldTrans("d_res_low");
	strk.add(ft);
	ft = new FieldTrans("mean_i_over_sig_i_all",
			    "meanI_over_sigI_all");
	strk.add(ft);
	ft = new FieldTrans("mean_i_over_sig_i_obs",
			    "meanI_over_sigI_obs");
	strk.add(ft);
	ft = new FieldTrans("number_measured_all");
	strk.add(ft);
	ft = new FieldTrans("number_measured_obs");
	strk.add(ft);
	ft = new FieldTrans("number_possible");
	strk.add(ft);
	ft = new FieldTrans("number_unique_all");
	strk.add(ft);
	ft = new FieldTrans("number_unique_obs");
	strk.add(ft);
	ft = new FieldTrans("percent_possible_all");
	strk.add(ft);
	ft = new FieldTrans("percent_possible_obs");
	strk.add(ft);
	ft = new FieldTrans("rmerge_f_all",
			    "Rmerge_F_all");
	strk.add(ft);
	ft = new FieldTrans("rmerge_f_obs",
			    "Rmerge_F_obs");
	strk.add(ft);
	ft = new FieldTrans("rmerge_i_all",
			    "Rmerge_I_all");
	strk.add(ft);
	ft = new FieldTrans("rmerge_i_obs",
			    "Rmerge_I_obs");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_SOFTWARE(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // SOFTWARE
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("software",
					    "Software");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("Software",
					       cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("citation_id");
	strk.add(ft);
	ft = new FieldTrans("classification");
	strk.add(ft);
	ft = new FieldTrans("compiler_name");
	strk.add(ft);
	ft = new FieldTrans("compiler_version");
	strk.add(ft);
	ft = new FieldTrans("contact_author");
	strk.add(ft);
	ft = new FieldTrans("contact_author_email");
	strk.add(ft);
	ft = new FieldTrans("date");
	strk.add(ft);
	ft = new FieldTrans("description");
	strk.add(ft);
	ft = new FieldTrans("dependencies");
	strk.add(ft);
	ft = new FieldTrans("hardware");
	strk.add(ft);
	ft = new FieldTrans("language");
	strk.add(ft);
	ft = new FieldTrans("location");
	strk.add(ft);
	ft = new FieldTrans("mods");
	strk.add(ft);
	ft = new FieldTrans("name");
	strk.add(ft);
	ft = new FieldTrans("os");
	strk.add(ft);
	ft = new FieldTrans("os_version");
	strk.add(ft);
	ft = new FieldTrans("type");
	strk.add(ft);
	ft = new FieldTrans("version");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_STRUCT(ModuleTrans cmod)
    {
      //___________________________________________________________
      // STRUCT
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("struct",
					    "Struct");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("Structure", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("entry_id");
	strk.add(ft);
	ft = new FieldTrans("title");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_STRUCT_ASYM(ModuleTrans cmod)
    {
      //___________________________________________________________
      // STRUCT_ASYM
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("struct_asym",
					    "StructAsym");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("StructAsym", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("details");
	strk.add(ft);
	ft = new FieldTrans("entity_id");
	strk.add(ft);
	ft = new FieldTrans("id");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_STRUCT_BIOL(ModuleTrans cmod)
    {
      //___________________________________________________________
      // STRUCT_BIOL
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("struct_biol",
					    "StructBiol");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("StructBiol", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("details");
	strk.add(ft);
	ft = new FieldTrans("id");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_STRUCT_BIOL_GEN(ModuleTrans cmod)
    {
      //___________________________________________________________
      // STRUCT_BIOL_GEN
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("struct_biol_gen",
					    "StructBiolGen");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("StructBiolGen", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("asym_id");
	strk.add(ft);
	ft = new FieldTrans("biol_id");
	strk.add(ft);
	ft = new FieldTrans("details");
	strk.add(ft);
	ft = new FieldTrans("symmetry");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_STRUCT_BIOL_KEYWORDS(ModuleTrans cmod)
    {
      //___________________________________________________________
      // STRUCT_BIOL_KEYWORDS
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("struct_biol_keywords",
					    "StructBiolKeywords");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("StructBiolKeywords", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("biol_id");
	strk.add(ft);
	ft = new FieldTrans("text");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_STRUCT_BIOL_VIEW(ModuleTrans cmod)
    {
      //___________________________________________________________
      // STRUCT_BIOL_VIEW
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("struct_biol_view",
					    "StructBiolView");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("StructBiolView", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("biol_id");
	strk.add(ft);
	ft = new FieldTrans("details");
	strk.add(ft);
	ft = new FieldTrans("id");
	strk.add(ft);
	ft = new MatrixTrans("rot_matrix");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_STRUCT_CONF(ModuleTrans cmod)
    {
      //___________________________________________________________
      // STRUCT_CONF
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("struct_conf",
					    "StructConf");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("StructConf", cat);
      cat.add(strk);
      {
	ft = new FieldTrans(seqIndex, "beg_label");
	strk.add(ft);
	ft.add(new SubfieldTrans("seq", "beg_label_seq_id"));
	ft.add(new SubfieldTrans("comp", "beg_label_comp_id"));
	ft.add(new SubfieldTrans("asym", "beg_label_asym_id"));

	ft = new FieldTrans(seqIndex, "beg_auth");
	strk.add(ft);
	ft.add(new SubfieldTrans("seq", "beg_auth_seq_id"));
	ft.add(new SubfieldTrans("comp", "beg_auth_comp_id"));
	ft.add(new SubfieldTrans("asym", "beg_auth_asym_id"));

	ft = new FieldTrans("conf_type_id");
	strk.add(ft);
	ft = new FieldTrans("details");
	strk.add(ft);

	ft = new FieldTrans(seqIndex, "end_label");
	strk.add(ft);
	ft.add(new SubfieldTrans("seq", "end_label_seq_id"));
	ft.add(new SubfieldTrans("comp", "end_label_comp_id"));
	ft.add(new SubfieldTrans("asym", "end_label_asym_id"));

	ft = new FieldTrans(seqIndex, "end_auth");
	strk.add(ft);
	ft.add(new SubfieldTrans("seq", "end_auth_seq_id"));
	ft.add(new SubfieldTrans("comp", "end_auth_comp_id"));
	ft.add(new SubfieldTrans("asym", "end_auth_asym_id"));

	ft = new FieldTrans("id");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_STRUCT_CONF_TYPE(ModuleTrans cmod)
    {
      //___________________________________________________________
      // STRUCT_CONF_TYPE
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("struct_conf_type",
					    "StructConfType");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("StructConfType", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("criteria");
	strk.add(ft);
	ft = new FieldTrans("id");
	strk.add(ft);
	ft = new FieldTrans("reference");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_STRUCT_CONN(ModuleTrans cmod)
    {
      //___________________________________________________________
      // STRUCT_CONN
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("struct_conn",
					    "StructConn");
      cmod.add(cat);
      // StructureTrans strk = defaultContainer("StructConn", cat);
      StructureTrans strk 
	= new StructureTrans("StructConn", cat, null, MAX_PARAGRAPHS);
      cat.add(strk);
      {
	ft = new FieldTrans("conn_type_id");
	strk.add(ft);
	ft = new FieldTrans("details");
	strk.add(ft);
	ft = new FieldTrans("id");
	strk.add(ft);

	ft = new FieldTrans(atomIndex, "ptnr1_label");
	strk.add(ft);
	ft.add(new SubfieldTrans("atom", "ptnr1_label_atom_id"));
	ft.add(new SubfieldTrans("seq", "ptnr1_label_seq_id"));
	ft.add(new SubfieldTrans("comp", "ptnr1_label_comp_id"));
	ft.add(new SubfieldTrans("asym", "ptnr1_label_asym_id"));
	ft.add(new SubfieldTrans("alt", "ptnr1_label_alt_id"));

	ft = new FieldTrans(atomIndex, "ptnr1_auth");
	strk.add(ft);
	ft.add(new SubfieldTrans("atom", "ptnr1_auth_atom_id"));
	ft.add(new SubfieldTrans("seq", "ptnr1_auth_seq_id"));
	ft.add(new SubfieldTrans("comp", "ptnr1_auth_comp_id"));
	ft.add(new SubfieldTrans("asym", "ptnr1_auth_asym_id"));

	ft = new FieldTrans("ptnr1_role");
	strk.add(ft);
	ft = new FieldTrans("ptnr1_symmetry");
	strk.add(ft);

	ft = new FieldTrans(atomIndex, "ptnr2_label");
	strk.add(ft);
	ft.add(new SubfieldTrans("atom", "ptnr2_label_atom_id"));
	ft.add(new SubfieldTrans("seq", "ptnr2_label_seq_id"));
	ft.add(new SubfieldTrans("comp", "ptnr2_label_comp_id"));
	ft.add(new SubfieldTrans("asym", "ptnr2_label_asym_id"));
	ft.add(new SubfieldTrans("alt", "ptnr2_label_alt_id"));

	ft = new FieldTrans(atomIndex, "ptnr2_auth");
	strk.add(ft);
	ft.add(new SubfieldTrans("atom", "ptnr2_auth_atom_id"));
	ft.add(new SubfieldTrans("seq", "ptnr2_auth_seq_id"));
	ft.add(new SubfieldTrans("comp", "ptnr2_auth_comp_id"));
	ft.add(new SubfieldTrans("asym", "ptnr2_auth_asym_id"));

	ft = new FieldTrans("ptnr2_role");
	strk.add(ft);
	ft = new FieldTrans("ptnr2_symmetry");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_STRUCT_CONN_TYPE(ModuleTrans cmod)
    {
      //___________________________________________________________
      // STRUCT_CONN_TYPE
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("struct_conn_type",
					    "StructConnType");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("StructConnType", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("criteria");
	strk.add(ft);
	ft = new FieldTrans("id");
	strk.add(ft);
	ft = new FieldTrans("reference");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_STRUCT_KEYWORDS(ModuleTrans cmod)
    {
      //___________________________________________________________
      // STRUCT_KEYWORDS
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("struct_keywords",
					    "StructKeywords");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("StructKeywords", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("entry_id");
	strk.add(ft);
	ft = new FieldTrans("text");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_STRUCT_MON_DETAILS(ModuleTrans cmod)
    {
      //___________________________________________________________
      // STRUCT_MON_DETAILS
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("struct_mon_details",
					    "StructMonDetails");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("StructMonDetails", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("entry_id");
	strk.add(ft);
	ft = new FieldTrans("prot_cis");
	strk.add(ft);
	ft = new FieldTrans("rscc",
			    "RSCC");
	strk.add(ft);
	ft = new FieldTrans("rsr",
			    "RSR");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_STRUCT_MON_NUCL(ModuleTrans cmod)
    {
      //___________________________________________________________
      // STRUCT_MON_NUCL
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("struct_mon_nucl",
					    "StructMonNucl");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("StructMonNucl", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("alpha");
	strk.add(ft);
	ft = new FieldTrans("beta");
	strk.add(ft);
	ft = new FieldTrans("chi1");
	strk.add(ft);
	ft = new FieldTrans("chi2");
	strk.add(ft);
	ft = new FieldTrans("delta");
	strk.add(ft);
	ft = new FieldTrans("details");
	strk.add(ft);
	ft = new FieldTrans("epsilon");
	strk.add(ft);
	ft = new FieldTrans("gamma");
	strk.add(ft);

	ft = new FieldTrans(seqIndex, "label");
	strk.add(ft);
	ft.add(new SubfieldTrans("seq", "label_seq_id"));
	ft.add(new SubfieldTrans("comp", "label_comp_id"));
	ft.add(new SubfieldTrans("asym", "label_asym_id"));
	ft.add(new SubfieldTrans("alt", "label_alt_id"));

	ft = new FieldTrans(seqIndex, "auth");
	strk.add(ft);
	ft.add(new SubfieldTrans("seq", "auth_seq_id"));
	ft.add(new SubfieldTrans("comp", "auth_comp_id"));
	ft.add(new SubfieldTrans("asym", "auth_asym_id"));

	ft = new FieldTrans("mean_b_all",
			    "mean_B_all");
	strk.add(ft);
	ft = new FieldTrans("mean_b_base",
			    "mean_B_base");
	strk.add(ft);
	ft = new FieldTrans("mean_b_phos",
			    "mean_B_phos");
	strk.add(ft);
	ft = new FieldTrans("mean_b_sugar",
			    "mean_B_sugar");
	strk.add(ft);
	ft = new FieldTrans("nu0");
	strk.add(ft);
	ft = new FieldTrans("nu1");
	strk.add(ft);
	ft = new FieldTrans("nu2");
	strk.add(ft);
	ft = new FieldTrans("nu3");
	strk.add(ft);
	ft = new FieldTrans("nu4");
	strk.add(ft);
	ft = new FieldTrans("p",
			    "P");
	strk.add(ft);
	ft = new FieldTrans("rscc_all",
			    "RSCC_all");
	strk.add(ft);
	ft = new FieldTrans("rscc_base",
			    "RSCC_base");
	strk.add(ft);
	ft = new FieldTrans("rscc_phos",
			    "RSCC_phos");
	strk.add(ft);
	ft = new FieldTrans("rscc_sugar",
			    "RSCC_sugar");
	strk.add(ft);
	ft = new FieldTrans("rsr_all",
			    "RSR_all");
	strk.add(ft);
	ft = new FieldTrans("rsr_base",
			    "RSR_base");
	strk.add(ft);
	ft = new FieldTrans("rsr_phos",
			    "RSR_phos");
	strk.add(ft);
	ft = new FieldTrans("rsr_sugar",
			    "RSR_sugar");
	strk.add(ft);
	ft = new FieldTrans("tau0");
	strk.add(ft);
	ft = new FieldTrans("tau1");
	strk.add(ft);
	ft = new FieldTrans("tau2");
	strk.add(ft);
	ft = new FieldTrans("tau3");
	strk.add(ft);
	ft = new FieldTrans("tau4");
	strk.add(ft);
	ft = new FieldTrans("taum");
	strk.add(ft);
	ft = new FieldTrans("zeta");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_STRUCT_MON_PROT(ModuleTrans cmod)
    {
      //___________________________________________________________
      // STRUCT_MON_PROT
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("struct_mon_prot",
					    "StructMonProt");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("StructMonProt", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("chi1");
	strk.add(ft);
	ft = new FieldTrans("chi2");
	strk.add(ft);
	ft = new FieldTrans("chi3");
	strk.add(ft);
	ft = new FieldTrans("chi4");
	strk.add(ft);
	ft = new FieldTrans("chi5");
	strk.add(ft);
	ft = new FieldTrans("details");
	strk.add(ft);

	ft = new FieldTrans(seqIndex, "label");
	strk.add(ft);
	ft.add(new SubfieldTrans("seq", "label_seq_id"));
	ft.add(new SubfieldTrans("comp", "label_comp_id"));
	ft.add(new SubfieldTrans("asym", "label_asym_id"));
	ft.add(new SubfieldTrans("alt", "label_alt_id"));

	ft = new FieldTrans(seqIndex, "auth");
	strk.add(ft);
	ft.add(new SubfieldTrans("seq", "auth_seq_id"));
	ft.add(new SubfieldTrans("comp", "auth_comp_id"));
	ft.add(new SubfieldTrans("asym", "auth_asym_id"));

	ft = new FieldTrans("rscc_all",
			    "RSCC_all");
	strk.add(ft);
	ft = new FieldTrans("rscc_main",
			    "RSCC_main");
	strk.add(ft);
	ft = new FieldTrans("rscc_side",
			    "RSCC_side");
	strk.add(ft);
	ft = new FieldTrans("rsr_all",
			    "RSR_all");
	strk.add(ft);
	ft = new FieldTrans("rsr_main",
			    "RSR_main");
	strk.add(ft);
	ft = new FieldTrans("rsr_side",
			    "RSR_side");
	strk.add(ft);
	ft = new FieldTrans("mean_b_all",
			    "mean_B_all");
	strk.add(ft);
	ft = new FieldTrans("mean_b_main",
			    "mean_B_main");
	strk.add(ft);
	ft = new FieldTrans("mean_b_side",
			    "mean_B_side");
	strk.add(ft);
	ft = new FieldTrans("omega");
	strk.add(ft);
	ft = new FieldTrans("phi");
	strk.add(ft);
	ft = new FieldTrans("psi");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_STRUCT_MON_PROT_CIS(ModuleTrans cmod)
    {
      //___________________________________________________________
      // STRUCT_MON_PROT_CIS
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("struct_mon_prot_cis",
					    "StructMonProtCis");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("StructMonProtCis", cat);
      cat.add(strk);
      {
	ft = new FieldTrans(seqIndex, "label");
	strk.add(ft);
	ft.add(new SubfieldTrans("seq", "label_seq_id"));
	ft.add(new SubfieldTrans("comp", "label_comp_id"));
	ft.add(new SubfieldTrans("asym", "label_asym_id"));
	ft.add(new SubfieldTrans("alt", "label_alt_id"));

	ft = new FieldTrans(seqIndex, "auth");
	strk.add(ft);
	ft.add(new SubfieldTrans("seq", "auth_seq_id"));
	ft.add(new SubfieldTrans("comp", "auth_comp_id"));
	ft.add(new SubfieldTrans("asym", "auth_asym_id"));
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_STRUCT_NCS_DOM(ModuleTrans cmod)
    {
      //___________________________________________________________
      // STRUCT_NCS_DOM
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("struct_ncs_dom",
					    "StructNcsDom");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("StructNcsDom", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("details");
	strk.add(ft);
	ft = new FieldTrans("id");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_STRUCT_NCS_DOM_LIM(ModuleTrans cmod)
    {
      //___________________________________________________________
      // STRUCT_NCS_DOM_LIM
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("struct_ncs_dom_lim",
					    "StructNcsDomLim");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("StructNcsDomLim", cat);
      cat.add(strk);
      {
	ft = new FieldTrans(seqIndex, "beg_label");
	strk.add(ft);
	ft.add(new SubfieldTrans("seq", "beg_label_seq_id"));
	ft.add(new SubfieldTrans("comp", "beg_label_comp_id"));
	ft.add(new SubfieldTrans("asym", "beg_label_asym_id"));
	ft.add(new SubfieldTrans("alt", "beg_label_alt_id"));

	ft = new FieldTrans(seqIndex, "beg_auth");
	strk.add(ft);
	ft.add(new SubfieldTrans("seq", "beg_auth_seq_id"));
	ft.add(new SubfieldTrans("comp", "beg_auth_comp_id"));
	ft.add(new SubfieldTrans("asym", "beg_auth_asym_id"));

	ft = new FieldTrans("dom_id");
	strk.add(ft);

	ft = new FieldTrans(seqIndex, "end_label");
	strk.add(ft);
	ft.add(new SubfieldTrans("seq", "end_label_seq_id"));
	ft.add(new SubfieldTrans("comp", "end_label_comp_id"));
	ft.add(new SubfieldTrans("asym", "end_label_asym_id"));
	ft.add(new SubfieldTrans("alt", "end_label_alt_id"));

	ft = new FieldTrans(seqIndex, "end_auth");
	strk.add(ft);
	ft.add(new SubfieldTrans("seq", "end_auth_seq_id"));
	ft.add(new SubfieldTrans("comp", "end_auth_comp_id"));
	ft.add(new SubfieldTrans("asym", "end_auth_asym_id"));
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_STRUCT_NCS_ENS(ModuleTrans cmod)
    {
      //___________________________________________________________
      // STRUCT_NCS_ENS
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("struct_ncs_ens",
					    "StructNcsEns");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("StructNcsEns", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("details");
	strk.add(ft);
	ft = new FieldTrans("id");
	strk.add(ft);
	ft = new FieldTrans("point_group");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_STRUCT_NCS_ENS_GEN(ModuleTrans cmod)
    {
      //___________________________________________________________
      // STRUCT_NCS_ENS_GEN
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("struct_ncs_ens_gen",
					    "StructNcsEnsGen");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("StructNcsEnsGen", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("dom_id_1");
	strk.add(ft);
	ft = new FieldTrans("dom_id_2");
	strk.add(ft);
	ft = new FieldTrans("ens_id");
	strk.add(ft);
	ft = new FieldTrans("oper_id");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_STRUCT_NCS_OPER(ModuleTrans cmod)
    {
      //___________________________________________________________
      // STRUCT_NCS_OPER
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("struct_ncs_oper",
					    "StructNcsOper");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("StructNcsOper", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("code");
	strk.add(ft);
	ft = new FieldTrans("details");
	strk.add(ft);
	ft = new FieldTrans("id");
	strk.add(ft);
	ft = new MatrixTrans("matrix");
	strk.add(ft);
	ft = new VectorTrans("vector");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_STRUCT_REF(ModuleTrans cmod)
    {
      //___________________________________________________________
      // STRUCT_REF
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("struct_ref",
					    "StructRef");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("StructRef", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("biol_id");
	strk.add(ft);
	ft = new FieldTrans("db_code");
	strk.add(ft);
	ft = new FieldTrans("db_name");
	strk.add(ft);
	ft = new FieldTrans("details");
	strk.add(ft);
	ft = new FieldTrans("entity_id");
	strk.add(ft);
	ft = new FieldTrans("id");
	strk.add(ft);
	ft = new FieldTrans("seq_align");
	strk.add(ft);
	ft = new FieldTrans("seq_dif");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_STRUCT_REF_SEQ(ModuleTrans cmod)
    {
      //___________________________________________________________
      // STRUCT_REF_SEQ
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("struct_ref_seq",
					    "StructRefSeq");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("StructRefSeq", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("align_id");
	strk.add(ft);
	ft = new FieldTrans("db_align_beg");
	strk.add(ft);
	ft = new FieldTrans("db_align_end");
	strk.add(ft);
	ft = new FieldTrans("details");
	strk.add(ft);
	ft = new FieldTrans("ref_id");
	strk.add(ft);
	ft = new FieldTrans("seq_align_beg");
	strk.add(ft);
	ft = new FieldTrans("seq_align_end");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_STRUCT_REF_SEQ_DIF(ModuleTrans cmod)
    {
      //___________________________________________________________
      // STRUCT_REF_SEQ_DIF
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("struct_ref_seq_dif",
					    "StructRefSeqDif");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("StructRefSeqDif", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("align_id");
	strk.add(ft);
	ft = new FieldTrans("db_mon_id");
	strk.add(ft);
	ft = new FieldTrans("details");
	strk.add(ft);
	ft = new FieldTrans("mon_id");
	strk.add(ft);
	ft = new FieldTrans("seq_num");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_STRUCT_SHEET(ModuleTrans cmod)
    {
      //___________________________________________________________
      // STRUCT_SHEET
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("struct_sheet",
					    "StructSheet");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("StructSheet", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("details");
	strk.add(ft);
	ft = new FieldTrans("id");
	strk.add(ft);
	ft = new FieldTrans("number_strands");
	strk.add(ft);
	ft = new FieldTrans("type");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_STRUCT_SHEET_HBOND(ModuleTrans cmod)
    {
      //___________________________________________________________
      // STRUCT_SHEET_HBOND
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("struct_sheet_hbond",
					    "StructSheetHbond");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("StructSheetHbond", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("range_1_beg_label_atom_id");
	strk.add(ft);
	ft = new FieldTrans("range_1_beg_label_seq_id");
	strk.add(ft);
	ft = new FieldTrans("range_1_end_label_atom_id");
	strk.add(ft);
	ft = new FieldTrans("range_1_end_label_seq_id");
	strk.add(ft);
	ft = new FieldTrans("range_2_beg_label_atom_id");
	strk.add(ft);
	ft = new FieldTrans("range_2_beg_label_seq_id");
	strk.add(ft);
	ft = new FieldTrans("range_2_end_label_atom_id");
	strk.add(ft);
	ft = new FieldTrans("range_2_end_label_seq_id");
	strk.add(ft);
	ft = new FieldTrans("range_1_beg_auth_atom_id");
	strk.add(ft);
	ft = new FieldTrans("range_1_beg_auth_seq_id");
	strk.add(ft);
	ft = new FieldTrans("range_1_end_auth_atom_id");
	strk.add(ft);
	ft = new FieldTrans("range_1_end_auth_seq_id");
	strk.add(ft);
	ft = new FieldTrans("range_2_beg_auth_atom_id");
	strk.add(ft);
	ft = new FieldTrans("range_2_beg_auth_seq_id");
	strk.add(ft);
	ft = new FieldTrans("range_2_end_auth_atom_id");
	strk.add(ft);
	ft = new FieldTrans("range_2_end_auth_seq_id");
	strk.add(ft);
	ft = new FieldTrans("range_id_1");
	strk.add(ft);
	ft = new FieldTrans("range_id_2");
	strk.add(ft);
	ft = new FieldTrans("sheet_id");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_STRUCT_SHEET_ORDER(ModuleTrans cmod)
    {
      //___________________________________________________________
      // STRUCT_SHEET_ORDER
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("struct_sheet_order",
					    "StructSheetOrder");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("StructSheetOrder", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("offset");
	strk.add(ft);
	ft = new FieldTrans("range_id_1");
	strk.add(ft);
	ft = new FieldTrans("range_id_2");
	strk.add(ft);
	ft = new FieldTrans("sense");
	strk.add(ft);
	ft = new FieldTrans("sheet_id");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_STRUCT_SHEET_RANGE(ModuleTrans cmod)
    {
      //___________________________________________________________
      // STRUCT_SHEET_RANGE
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("struct_sheet_range",
					    "StructSheetRange");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("StructSheetRange", cat);
      cat.add(strk);
      {
	ft = new FieldTrans(seqIndex, "beg_label");
	strk.add(ft);
	ft.add(new SubfieldTrans("seq", "beg_label_seq_id"));
	ft.add(new SubfieldTrans("comp", "beg_label_comp_id"));
	ft.add(new SubfieldTrans("asym", "beg_label_asym_id"));

	ft = new FieldTrans(seqIndex, "beg_auth");
	strk.add(ft);
	ft.add(new SubfieldTrans("seq", "beg_auth_seq_id"));
	ft.add(new SubfieldTrans("comp", "beg_auth_comp_id"));
	ft.add(new SubfieldTrans("asym", "beg_auth_asym_id"));

	ft = new FieldTrans(seqIndex, "end_label");
	strk.add(ft);
	ft.add(new SubfieldTrans("seq", "end_label_seq_id"));
	ft.add(new SubfieldTrans("comp", "end_label_comp_id"));
	ft.add(new SubfieldTrans("asym", "end_label_asym_id"));

	ft = new FieldTrans(seqIndex, "end_auth");
	strk.add(ft);
	ft.add(new SubfieldTrans("seq", "end_auth_seq_id"));
	ft.add(new SubfieldTrans("comp", "end_auth_comp_id"));
	ft.add(new SubfieldTrans("asym", "end_auth_asym_id"));

	ft = new FieldTrans("id");
	strk.add(ft);
	ft = new FieldTrans("sheet_id");
	strk.add(ft);
	ft = new FieldTrans("symmetry");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_STRUCT_SHEET_TOPOLOGY(ModuleTrans cmod)
    {
      //___________________________________________________________
      // STRUCT_SHEET_TOPOLOGY
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("struct_sheet_topology",
					    "StructSheetTopology");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("StructSheetTopology", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("offset");
	strk.add(ft);
	ft = new FieldTrans("range_id_1");
	strk.add(ft);
	ft = new FieldTrans("range_id_2");
	strk.add(ft);
	ft = new FieldTrans("sense");
	strk.add(ft);
	ft = new FieldTrans("sheet_id");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_STRUCT_SITE(ModuleTrans cmod)
    {
      //___________________________________________________________
      // STRUCT_SITE
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("struct_site",
					    "StructSite");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("StructSite", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("details");
	strk.add(ft);
	ft = new FieldTrans("id");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_STRUCT_SITE_GEN(ModuleTrans cmod)
    {
      //___________________________________________________________
      // STRUCT_SITE_GEN
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("struct_site_gen",
					    "StructSiteGen");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("StructSiteGen", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("details");
	strk.add(ft);
	ft = new FieldTrans("id");
	strk.add(ft);

	ft = new FieldTrans(atomIndex, "label");
	strk.add(ft);
	ft.add(new SubfieldTrans("atom", "label_atom_id"));
	ft.add(new SubfieldTrans("seq", "label_seq_id"));
	ft.add(new SubfieldTrans("comp", "label_comp_id"));
	ft.add(new SubfieldTrans("asym", "label_asym_id"));
	ft.add(new SubfieldTrans("alt", "label_alt_id"));

	ft = new FieldTrans(atomIndex, "auth");
	strk.add(ft);
	ft.add(new SubfieldTrans("atom", "auth_atom_id"));
	ft.add(new SubfieldTrans("seq", "auth_seq_id"));
	ft.add(new SubfieldTrans("comp", "auth_comp_id"));
	ft.add(new SubfieldTrans("asym", "auth_asym_id"));

	ft = new FieldTrans("site_id");
	strk.add(ft);
	ft = new FieldTrans("symmetry");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_STRUCT_SITE_KEYWORDS(ModuleTrans cmod)
    {
      //___________________________________________________________
      // STRUCT_SITE_KEYWORDS
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("struct_site_keywords",
					    "StructSiteKeywords");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("StructSiteKeywords", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("site_id");
	strk.add(ft);
	ft = new FieldTrans("text");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_STRUCT_SITE_VIEW(ModuleTrans cmod)
    {
      //___________________________________________________________
      // STRUCT_SITE_VIEW
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("struct_site_view",
					    "StructSiteView");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("StructSiteView", cat);
      cat.add(strk);
      {
	ft = new FieldTrans("details");
	strk.add(ft);
	ft = new FieldTrans("id");
	strk.add(ft);
	ft = new MatrixTrans("rot_matrix");
	strk.add(ft);
	ft = new FieldTrans("site_id");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_SYMMETRY(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // SYMMETRY
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("symmetry",
					    "Symmetry");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("Symmetry",
					       cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("entry_id");
	strk.add(ft);
	ft = new FieldTrans("cell_setting");
	strk.add(ft);
	ft = new FieldTrans("int_tables_number",
			    "Int_Tables_number");
	strk.add(ft);
 	ft = new FieldTrans("space_group_name_hall",
			    "space_group_name_Hall");
	strk.add(ft);
	ft = new FieldTrans( "space_group_name_h_m",
			     "space_group_name_H-M");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }

  public void do_SYMMETRY_EQUIV(ModuleTrans cmod, ModuleTrans[] modQual)
    {
      //___________________________________________________________
      // SYMMETRY_EQUIV
      FieldTrans ft;
      CategoryTrans cat = new CategoryTrans("symmetry_equiv",
					    "SymmetryEquiv");
      cmod.add(cat);
      StructureTrans strk = defaultContainer("SymmetryEquiv",
					       cat, modQual);
      cat.add(strk);
      {
	ft = new FieldTrans("id");
	strk.add(ft);
	ft = new FieldTrans("pos_as_xyz");
	strk.add(ft);
      }
      ListTrans list = new ListTrans(strk);
      cmod.add(list);
    }
}
